OC.L10N.register(
    "files",
    {
    "Added to favorites" : "Lemmikutesse lisatud",
    "Removed from favorites" : "Lemmikutest eemaldatud",
    "You added {file} to your favorites" : "Märkisid „{file}“ faili lemmikuks",
    "You removed {file} from your favorites" : "Eemaldasid „{file}“ faili lemmikutest",
    "Favorites" : "Lemmikud",
    "File changes" : "Failimuudatused",
    "Created by {user}" : "Loodud kasutaja {user} poolt",
    "Changed by {user}" : "Muudetud kasutaja {user} poolt",
    "Deleted by {user}" : "Kustutatud kasutaja {user} poolt",
    "Restored by {user}" : "Taastatud kasutaja {user} poolt",
    "Renamed by {user}" : "Kasutaja {user} muutis nime",
    "Moved by {user}" : "Teisaldatud „{user}“ kasutaja poolt",
    "\"remote account\"" : "„kaugkonto“",
    "You created {file}" : "Sa lõid faili: {file}",
    "You created an encrypted file in {file}" : "Sa lõid krüptitud faili: {file}",
    "{user} created {file}" : "Kasutaja {user} lõi faili {file}",
    "{user} created an encrypted file in {file}" : "Kasutaja {user} lõi krüpteeritud faili {file}",
    "{file} was created in a public folder" : "{file} loodi avalikus kaustas",
    "You changed {file}" : "Sa muutsid „{file}“ faili",
    "You changed an encrypted file in {file}" : "Sa muutsid krüptitud faili „{file}“",
    "{user} changed {file}" : "Kasutaja {user} muutis „{file}“ faili",
    "{user} changed an encrypted file in {file}" : "Kasutaja {user} muutis krüptitud faili „{file}“",
    "You deleted {file}" : "Sa kustutasid „{file}“ faili",
    "You deleted an encrypted file in {file}" : "Sa kustutasid krüptitud faili „{file}“",
    "{user} deleted {file}" : "Kasutaja {user} kustutas „{file}“ faili",
    "{user} deleted an encrypted file in {file}" : "Kasutaja {user} kustutas krüpteeritud faili {file}",
    "You restored {file}" : "Sa taastasid faili {file}",
    "{user} restored {file}" : "Kasutaja {user} taastas faili {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Sa muutsid „{oldfile}“ (peidetud) faili nime, uus nimi on „{newfile}“ (peidetud)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Sa muutsid „{oldfile}“ (peidetud) faili nime, uus nimi on „{newfile}“",
    "You renamed {oldfile} to {newfile} (hidden)" : "Sa muutsid „{oldfile}“ faili nime, uus nimi on „{newfile}“ (peidetud)",
    "You renamed {oldfile} to {newfile}" : "Sa muutsid „{oldfile}“ faili nime, uus nimi on „{newfile}“",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "Kasutaja {user} muutis „{oldfile}“ (peidetud) faili nime, uus nimi on „{newfile}“ (peidetud)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "Kasutaja {user} muutis (peidetud) „{oldfile}“ faili nime, uus nimi on „{newfile}“",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "Kasutaja {user} muutis „{oldfile}“ faili nime, uus nimi on „{newfile}“ (peidetud)",
    "{user} renamed {oldfile} to {newfile}" : "Kasutaja {user} muutis „{oldfile}“ faili nime, uus nimi on „{newfile}“",
    "You moved {oldfile} to {newfile}" : "Sa liigutasid faili: {oldfile} nüüd {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} liigutas faili: {oldfile} nüüd {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Fail lisati su <strong>lemmikutesse</strong> või eemaldati sealt",
    "Files" : "Failid",
    "A file or folder has been <strong>changed</strong>" : "Fail või kaust on <strong>muudetud</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "Lemmikuks märgitud faili või kausta on <strong>muudetud</strong>",
    "Failed to authorize" : "Autoriseerimine ei õnnestunud",
    "Invalid folder path" : "Kausta vigane asukoht",
    "Folder not found" : "Kausta ei leidu",
    "The file cannot be found" : "Faili ei õnnestu leida",
    "The destination path does not exist: %1$s" : "Sihtasukohta pole olemas: %1$s",
    "You do not have permission to create a file at the specified location" : "Sul puudvad õigused faili loomiseks antud asukohas",
    "The file could not be converted." : "Seda faili ei õnnestunud teisendada.",
    "Could not get relative path to converted file" : "Teisendatud faili suhtelist asukohta ei õnnestunud tuvastada",
    "Limit must be a positive integer." : "Piirang peab olema positiivne täisarv",
    "The replacement character may only be a single character." : "Asendatav tähemärk saab olla vaid üks tähemärk.",
    "Filename sanitization already started." : "Failinime normaliseerimine on juba alanud.",
    "No filename sanitization in progress." : "Failinimede normaliseerimine on hetkel töös.",
    "Favorite files" : "Lemmikfailid",
    "No favorites" : "Lemmikuid pole",
    "More favorites" : "Veel lemmikuid",
    "No read permission on file." : "Puuduvad faili lugemisõigused",
    "Accept" : "Nõustu",
    "Reject" : "Keeldu",
    "Incoming ownership transfer from {user}" : "Saaduv omandi üleandmine kasutajalt {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Kas sa soovid „{path}“ omandi üle võtta?\n\nMärkus: palun arvesta, et selleks võib kuluda kuni 1 tund.",
    "Ownership transfer denied" : "Keeldumine omandi üleandmisest",
    "Your ownership transfer of {path} was denied by {user}." : "Kasutaja {user} keeldus sinu soovist „{path}“ omand üle anda.",
    "Ownership transfer failed" : "Omandi üleandmine ei õnnestunud",
    "Your ownership transfer of {path} to {user} failed." : "Sinu poolt algatatud „{path}“ omandi üleandmine kasutajale {user} ei õnnestunud.",
    "The ownership transfer of {path} from {user} failed." : "„{path}“ omandi üleandmine kasutajale {user} ei õnnestunud.",
    "Ownership transfer done" : "Omandi üleandmine on lõppenud",
    "Your ownership transfer of {path} to {user} has completed." : "Sinu poolt algatatud „{path}“ omandi üleandmine kasutajale {user} on lõppenud.",
    "The ownership transfer of {path} from {user} has completed." : "„{path}“ omandi üleandmine kasutajale {user} on tehtud.",
    "in %s" : "kaustas %s",
    "Transferred from %1$s on %2$s" : "%2$s üleantud kasutajalt %1$s",
    "Create files" : "Loo faile",
    "Delete files" : "Kustuta failid",
    "Download files" : "Laadi failid alla",
    "When disabled, the option to download will be hidden" : "Kui see valik pole kasutusel, siis allalaadimise võimalus pole näha",
    "View files" : "Vaata faile",
    "Edit files" : "Muuda faile",
    "Show files in grid view" : "Näita faile ruudustikuvaates",
    "File" : "Fail",
    "File Management" : "Failihaldus",
    "Home" : "Avaleht",
    "Target folder does not exist any more" : "Sihtkausta pole enam olemas",
    "Reload current directory" : "Laadi see kaust uuesti",
    "Go to the \"{dir}\" directory" : "Mine kausta „{dir}“",
    "Current directory path" : "Praeguse kausta asukoht",
    "Share" : "Jaga",
    "Reload content" : "Laadi sisu uuesti",
    "Your have used your space quota and cannot upload files anymore" : "Sa oled kasutanud ära kogu oma andmeruumi kvoodi ega saa rohkem faile üles laadida.",
    "You do not have permission to upload or create files here." : "Sul puuduvad õigused siia failide üleslaadimiseks või loomiseks.",
    "Drag and drop files here to upload" : "Üleslaadimiseks lohista failid siia",
    "Favorite" : "Lemmik",
    "Back" : "Tagasi",
    "Toggle selection for file \"{displayName}\"" : "Lülita „{displayName}“ faili valimine sisse/välja",
    "Toggle selection for folder \"{displayName}\"" : "Lülita „{displayName}“ kausta valimine sisse/välja",
    "File is loading" : "Fail on laadimisel",
    "Folder is loading" : "Kaust on laadimisel",
    "Filename" : "Failinimi",
    "Folder name" : "Kausta nimi",
    "{displayName} (unavailable)" : "{displayName} (pole saadaval)",
    "Another entry with the same name already exists." : "Selle nimega kirje on juba olemas.",
    "Invalid filename." : "Vigane failinimi.",
    "Rename file" : "Muuda failinime",
    "Recently created" : "Loodud hiljuti",
    "Folder" : "Kaust",
    "Unknown file type" : "Tundmatu failitüüp",
    "{ext} image" : "{ext} pilt",
    "{ext} video" : "{ext} video",
    "{ext} audio" : "{ext} helifail",
    "{ext} text" : "{ext} tekst",
    "Pending" : "Ootel",
    "Unknown date" : "Tundmatu kuupäev",
    "Active filters" : "Aktiivsed filtrid",
    "Remove filter" : "Eemalda filter",
    "Today" : "Täna",
    "Last 7 days" : "Viimase 7 päeva jooksul",
    "Last 30 days" : "Viimase 30 päeva jooksul",
    "This year ({year})" : "Sel aastal ({year})",
    "Last year ({year})" : "Eelmisel aastal ({year})",
    "Custom range" : "Valitud vahemik",
    "Custom date range" : "Sinu valitud kuupäevavahemik",
    "Search everywhere" : "Otsi kõikjalt",
    "Documents" : "Dokumendid",
    "Spreadsheets" : "Arvutustabelid",
    "Presentations" : "Esitlused",
    "PDFs" : "PDF-failid",
    "Folders" : "Kaustad",
    "Audio" : "Helifailid",
    "Images" : "Pildid",
    "Videos" : "Videod",
    "Filters" : "Filtrid",
    "Back to filters" : "Tagasi filtrite juurde",
    "Appearance" : "Välimus",
    "Show hidden files" : "Näita peidetud faile",
    "Show file type column" : "Näita failitüübi veergu",
    "Show file extensions" : "Näita faililaiendeid",
    "Crop image previews" : "Kadreeri piltide eelvaated",
    "General" : "Üldine",
    "Sort favorites first" : "Järjesta lemmikud esimesena",
    "Sort folders before files" : "Järjesta kaustad enne faile",
    "Enable folder tree view" : "Võta kasutusele kaustapuu vaade",
    "Default view" : "Vaikimisi vaade",
    "All files" : "Kõik failid",
    "Personal files" : "Isiklikud failid",
    "Additional settings" : "Lisaseadistused",
    "Actions" : "Tegevused",
    "File actions" : "Tegevused failidega",
    "Selection" : "Valik",
    "Select all files" : "Vali kõik failid",
    "Deselect all" : "Eemalda kogu valik",
    "Select or deselect" : "Vali või eemalda valik",
    "Select a range" : "Vali vahemik",
    "Navigation" : "Liikumine",
    "Go to parent folder" : "Mine ülakausta",
    "Go to file above" : "Mine ülal oleva faili juurde",
    "Go to file below" : "Mine allpool oleva faili juurde",
    "Go left in grid" : "Mine ruudustikus vasakule",
    "Go right in grid" : "Mine ruudustikus paremale",
    "View" : "Vaata",
    "Toggle grid view" : "Lülita ruudustikuvaade sisse/välja",
    "Show those shortcuts" : "Näita neid otseteid",
    "Warnings" : "Hoiatused",
    "Warn before changing a file extension" : "Hoiata enne faililaiendi muutmist",
    "Warn before deleting a file" : "Hoiata enne faili kustutamist",
    "WebDAV URL" : "WebDAV-i võrguaadress",
    "Create an app password" : "Loo rakenduse salasõna",
    "Required for WebDAV authentication because Two-Factor Authentication is enabled for this account." : "Kuna see konto kasutab kahefaktorilist autentimist, siis on see nõutav WebDAV-i autentimise jaoks.",
    "How to access files using WebDAV" : "Ligipääs failidele WebDAV-i vahendusel",
    "Total rows summary" : "Ridade koondkokkuvõte",
    "Toggle selection for all files and folders" : "Lülita kõikide failide ja kaustade valik sisse/välja",
    "Name" : "Nimi",
    "File type" : "Failitüüp",
    "Size" : "Suurus",
    "Modified" : "Muudetud",
    "{displayName}: failed on some elements" : "{displayName}: ei toiminud mõne objekti puhul",
    "{displayName}: done" : "{displayName}: valmis",
    "{displayName}: failed" : "{displayName}: ei õnnestunud",
    "(selected)" : "(valitud)",
    "List of files and folders." : "Failide ja kaustade loend",
    "You have used your space quota and cannot upload files anymore." : "Sa oled kasutanud ära kogu oma andmeruumi kvoodi ega saa rohkem faile üles laadida.",
    "Column headers with buttons are sortable." : "Võid kasutada nuppudega veerupäised järjestamiseks.",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Jõudluse mõttes ei ole kogu loend esimesel hetkel tervikuna nähtav. Uued failid lisanduvad sedamööda, kuidas sa loendis edasi liigud.",
    "File not found" : "Faili ei leitud",
    "_{count} selected_::_{count} selected_" : ["{count} valitud","{count} valitud"],
    "Views" : "Vaated",
    "Search everywhere …" : "Otsi kõikjalt…",
    "Search here …" : "Otsi siin…",
    "Search scope options" : "Otsinguulatuse valikud",
    "Search here" : "Otsi siin",
    "Owner" : "Omanik",
    "{usedQuotaByte} used" : "{usedQuotaByte} kasutusel",
    "{used} of {quota} used" : "{used} / {quota} kasutusel",
    "{relative}% used" : "{relative}% kasutusel",
    "Could not refresh storage stats" : "Andmeruumi statistika värskendamine ei õnnestunud",
    "Your storage is full, files can not be updated or synced anymore!" : "Sinu andmeruum on täis - faile ei saa enam uuendada ega sünkroniseerida!",
    "Storage information" : "Andmeruumi teave",
    "Storage quota" : "Andmeruumi kvoot",
    "New folder" : "Uus kaust",
    "Create new folder" : "Loo uus kaust",
    "This name is already in use." : "See nimi on juba kasutusel.",
    "Create" : "Loo",
    "Files starting with a dot are hidden by default" : "Punktiga algavad failinimed vaikimisi muudavad faili peidetuks",
    "Failed to start filename sanitization." : "Failinime normaliseerimise alustamine ei õnnestunud.",
    "Failed to refresh filename sanitization status." : "Failinime normaliseerimise oleku uuendamine ei õnnestunud.",
    "Filename sanitization in progress." : "Failinime normaliseerimise on töös.",
    "Currently {processedUsers} of {totalUsers} accounts are already processed." : "Hetkel töödeldud kasutajakontosid: {processedUsers}/{totalUsers}.",
    "Preparing …" : "Ettevalmistamisel…",
    "Refresh" : "Värskenda",
    "All files have been santized for Windows filename support." : "Kõik failid on normaliseeritud vastavalt Windowsi failinimede toele.",
    "Some files could not be sanitized, please check your logs." : "Mõnede failide normaliseerimine ei õnnestunud, palun vaata lisateavet logidest.",
    "Sanitization errors" : "Normaliseerimise vead",
    "Not sanitized filenames" : "Normaliseerimata failinimed",
    "Windows filename support has been enabled." : "Windowsi failinimede tugi on kasutusel.",
    "While this blocks users from creating new files with unsupported filenames, existing files are not yet renamed and thus still may break sync on Windows." : "See valik takistab kasutajatel uute mittetoetatud failinimede loomist. Olemasolevad failid pole ümber nimetatud ja see võib Windowsis tekitada veaolukordi.",
    "You can trigger a rename of files with invalid filenames, this will be done in the background and may take some time." : "Sa võid käivitada mittesobivate failinimede korrastamise. Seda tehakse taustateenuse poolt ning lõpetamiseks võib kuluda märgatavalt aega.",
    "Please note that this may cause high workload on the sync clients." : "Palun arvesta, et see võib sünkroonimisklientides tekitada märgatava koormuse.",
    "Limit" : "Piirang",
    "This allows to configure how many users should be processed in one background job run." : "See võimaldab seadistada kasutajate arvu, kelle andmed ühe taustateenuse käivituskorraga töödeldakse.",
    "Sanitize filenames" : "Normaliseeri failinimed",
    "(starting)" : "(alustamisel)",
    "Fill template fields" : "Täida malli väljad",
    "Submitting fields …" : "Saadan välju…",
    "Submit" : "Saada",
    "Choose a file or folder to transfer" : "Vali üleantav fail või kaust",
    "Transfer \"{path}\"" : "Anna „{path}“ üle",
    "Select file or folder" : "Vali fail või kaust",
    "Transfer" : "Anna üle teisele kasutajale",
    "Transfer {path} to {userid}" : "Anna „{path}“ üle kasutajale {userid}",
    "Error while opening file picker for transfer ownership" : "Viga failivalija avamisel omandi üleandmiseks",
    "Error while searching for users" : "Viga kasutajate otsimisel",
    "Ownership transfer request sent" : "Üleandmispäring on saadetud",
    "Cannot transfer ownership of a file or folder you do not own" : "Sa ei saa teisele kasutaja anda üle kausta või faili, mis pole sinu oma",
    "Error while sending ownership transfer request" : "Viga omandi üleandmispäringu saatmisel",
    "Transfer ownership of a file or folder" : "Kaustade või failide omandi üleandmine teisele kasutajale",
    "File or folder to transfer" : "Üleantav fail või kaust",
    "No file or folder selected" : "Ühtegi faili ega kausta pole valitud",
    "New owner" : "Uus omanik",
    "You need to select a file or folder to transfer ownership." : "Omandi üleandmiseks pead valima faili või kausta.",
    "You need to select a new owner for the file or folder." : "Sa pead failile või kaustale valima uue omaniku.",
    "Keep {old}" : "Säilita „{old}“",
    "Keep without extension" : "Säilita ilma faililaiendita",
    "Use {new}" : "Kasuta „{new}“",
    "Remove extension" : "Eemalda faililaiend",
    "Change file extension" : "Muuda faililaiendit",
    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "Muutes senist faililaiendit „{old}“ uueks laiendiks „{new}“ võib fail muutuda loetamatuks.",
    "Removing the file extension \"{old}\" may render the file unreadable." : "„{old}“ faililaiendi eemaldamine võib muuta faili loetamatuks.",
    "Adding the file extension \"{new}\" may render the file unreadable." : "„{new}“ faililaiendi lisamine võib muuta faili loetamatuks.",
    "Do not show this dialog again." : "Ära näita seda vaadet enam uuesti.",
    "Rename file to hidden" : "Oled muutmas faili peidetuks",
    "Prefixing a filename with a dot may render the file hidden." : "Kui lisad faili algusesse punkti, siis ta võib muutuda peidetuks.",
    "Are you sure you want to rename the file to \"{filename}\"?" : "Kas sa tahad uueks faillinimeks muuta „{filename}“?",
    "Cancel" : "Loobu",
    "Rename" : "Muuda nime",
    "Select file or folder to link to" : "Vali lingitav fail või kaust",
    "Choose {file}" : "Vali „{file}“",
    "Files settings" : "Failide seadistused",
    "Switch to list view" : "Kasuta loendivaadet",
    "Switch to grid view" : "Kasuta ruudustikuvaadet",
    "The file could not be found" : "Seda faili ei õnnestu leida",
    "Upload was cancelled by user" : "Kasutaja katkestas üleslaadimise",
    "Not enough free space" : "Pole piisavalt vaba ruumi",
    "Operation is blocked by access control" : "Tegevus on blokeeritud ligipääsupiirangute poolt",
    "Error during upload: {message}" : "Viga üleslaadimisel: {message}",
    "Error during upload, status code {status}" : "Viga üleslaadimisel, olekukood {status} ",
    "Unknown error during upload" : "Tundmatu viga üleslaadimisel",
    "File list is reloading" : "Faililoend on laadimisel",
    "Loading current folder" : "Laadin käesolevat kausta",
    "Retry" : "Proovi uuesti",
    "No files in here" : "Siin ei ole faile",
    "Upload some content or sync with your devices!" : "Laadi sisu üles või sünkrooni oma seadmetega!",
    "Go back" : "Mine tagasi",
    "Loading …" : "Andmed on laadimisel…",
    "Your files" : "Sinu failid",
    "Open in files" : "Ava failirakenduses",
    "File cannot be accessed" : "Puudub ligipääs failile",
    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Faili kas ei leidu või sul puudub õigus selle vaatamiseks. Palu saatjat, et ta jagaks antud faili sulle.",
    "No search results for “{query}”" : "„{query}“ otsingul pole tulemusi",
    "Search for files" : "Otsi faile",
    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Luba failinimede piiramine tagamaks, et sünkroonimine toimib kõikide platvormide klientide vahel. Vaikimisi on lubatud kõik POSIX-i standardile vastavad failinimed (seda järgivad Linux ja macOS).",
    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Kui võtad kasutusele Windowsiga ühilduvad failinimed, siis olemasolevaid mitteühilduvaid faile ei saa enam muuta, aga faili omanik saab failinime muuta ühilduvaks.",
    "Failed to toggle Windows filename support" : "Windowsi failinimede toe sisse/välja lülitamine ei õnnestunud",
    "Files compatibility" : "Failide ühilduvus",
    "Enforce Windows compatibility" : "Kasuta ühilduvust Windowsiga",
    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Sellega blokeerid niisuguste failinimede kasutamise, mis Windowsis ei toimiks. See tähendab mõnede nimede ja tähemärkide keelamist. Aga see seadistus ei jõusta suur- ja väiketähtede kasutust.",
    "Blank" : "Tühi",
    "Unable to create new file from template" : "Faili loomine mallist ei õnnestunud",
    "Pick a template for {name}" : "Vali mall „{name}“ faili jaoks",
    "Create a new file with the selected template" : "Loo valitud malli alusel uus fail",
    "Creating file" : "Fail on loomisel",
    "Save as {displayName}" : "Salvesta kui „{displayName}“",
    "Save as …" : "Salvesta kui…",
    "Converting files …" : "Teisendan faile…",
    "Failed to convert files: {message}" : "Failide teisendamine ei õnnestunud: {message}",
    "All files failed to be converted" : "Kõiki faile ei õnnestunud teisendada",
    "One file could not be converted: {message}" : "Ühe faili teisendamine ei õnnestunud: {message}",
    "_%n file could not be converted_::_%n files could not be converted_" : ["%n faili teisendamine ei õnnestunud","%n faili teisendamine ei õnnestunud"],
    "_%n file converted_::_%n files converted_" : ["%n fail on teisendatud","%n faili on teisendatud"],
    "Files converted" : "Failid on teisendatud",
    "Failed to convert files" : "Failide teisendamine ei õnnestunud",
    "Converting file …" : "Teisendan faili…",
    "File successfully converted" : "Faili teisendamine õnnestus",
    "Failed to convert file: {message}" : "Faili teisendamine ei õnnestunud: {message}",
    "Failed to convert file" : "Faili teisendamine ei õnnestunud",
    "Delete" : "Kustuta",
    "Leave this share" : "Lahku jaoskaustast",
    "Leave these shares" : "Lahku neist jaoskaustadest",
    "Disconnect storage" : "Ühenda andmeruum lahti",
    "Disconnect storages" : "Ühenda andmeruumid lahti",
    "Delete permanently" : "Kustuta jäädavalt",
    "Delete and unshare" : "Kustuta ja lõpeta jagamine",
    "Delete file" : "Kustuta fail",
    "Delete folder" : "Kustuta kaust",
    "Delete folders" : "Kustuta kaustad",
    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Sa oled jäädavalt kustutamas {count} objekti","Sa oled jäädavalt kustutamas {count} objekti"],
    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Sa oled kustutamas {count} objekti","Sa oled kustutamas {count} objekti"],
    "Confirm deletion" : "Kinnita kustutamine",
    "Download" : "Laadi alla",
    "The requested file is not available." : "Soovitud fail pole saadaval.",
    "The requested files are not available." : "Soovitud failid pole saadaval.",
    "Add to favorites" : "Lisa lemmikuks",
    "Remove from favorites" : "Eemalda lemmikutest",
    "Add or remove favorite" : "Lisa või eemalda lemmik",
    "Move" : "Teisalda",
    "Copy" : "Kopeeri",
    "Move or copy" : "Liiguta või kopeeri",
    "Destination is not a folder" : "Sihtasukoht pole kaust",
    "This file/folder is already in that directory" : "See fail või kaust juba asub selles kaustas",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "Sa ei saa faili või kausta iseendaks teisaldada ega teisaldada kausta iseenda alamkausta",
    "A file or folder with that name already exists in this folder" : "Selles kaustas juba on olemas sama nimega fail või kaust",
    "The files are locked" : "Need failid on lukustatud",
    "The file does not exist anymore" : "Neid faile pole enam olemas",
    "Moving \"{source}\" to \"{destination}\" …" : "Teisaldan „{source}“ → „{destination}“…",
    "_Moving %n file to \"{destination}\" …_::_Moving %n files to \"{destination}\" …_" : ["Tõstan %n faili asukohta „{destination}“…","Tõstan %n faili asukohta „{destination}“…"],
    "Copying \"{source}\" to \"{destination}\" …" : "Kopeerin „{source}“ → „{destination}“…",
    "_Copying %n file to \"{destination}\" …_::_Copying %n files to \"{destination}\" …_" : ["Kopeerin %n faili asukohta „{destination}“…","Kopeerin %n faili asukohta „{destination}“…"],
    "Choose destination" : "Vali sihtkaust",
    "Copy to {target}" : "Kopeeri kausta {target}",
    "Move to {target}" : "Teisalda kausta {target}",
    "Move or copy operation failed" : "Teisaldamine või kopeerimine ei õnnestunud",
    "Open folder" : "Ava kaust",
    "Open folder {displayName}" : "Ava kaust {displayName}",
    "Open in Files" : "Ava failirakenduses",
    "Open locally" : "Ava kohalikust andmeruumist",
    "Failed to redirect to client" : "Kliendi ümbersuunamine ei õnnestunud",
    "Open file locally" : "Ava fail kohalikus seadmes",
    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Fail peaks nüüd sinu seadmes või arvutis olema avatud. Kui see nii pole, siis palun kontrolli, et töölauarakendus on paigaldatud.",
    "Retry and close" : "Proovi uuesti ja sulge",
    "Open online" : "Ava võrgust",
    "Details" : "Üksikasjad",
    "Open the details sidebar" : "Ava üksikasjade külgpaan",
    "Unfavorite" : "Eemalda lemmikute seast",
    "View in folder" : "Vaata kaustas",
    "Type" : "Tüüp",
    "Created new folder \"{name}\"" : "Uus „{name}“ kaust on loodud",
    "Unable to initialize the templates directory" : "Mallide kausta loomine ebaõnnestus",
    "Create templates folder" : "Loo mallide kaust",
    "Templates" : "Mallid",
    "New template folder" : "Uus kaustamall",
    "In folder" : "Kaustas",
    "Pick folder to search in" : "Vali kaust, kus soovid otsida",
    "Search in all files" : "Otsi kõikide failide seast",
    "Search in folder: {folder}" : "Otsi kaustast: {folder}",
    "One of the dropped files could not be processed" : "Ühte siia lisatud failidest ei õnnestunud töödelda",
    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Sinu veebibrauser ei toeta „Filesystem API“ liidestust. Kaustad jäävad üleslaadimata",
    "No files to upload" : "Üleslaaditavaid faile pole",
    "Unable to create the directory {directory}" : "„{directory}“ kausta loomine ei õnnestu",
    "Some files could not be uploaded" : "Mõnda faili ei saanud üles laadida",
    "Files uploaded successfully" : "Failide üleslaadimine õnnestus",
    "No files to process" : "Töödeldavaid faile pole",
    "Files copied successfully" : "Failide kopeerimine õnnestus",
    "Files moved successfully" : "Failide teisaldamine õnnestus",
    "Some files could not be copied" : "Mõnda faili ei saanud kopeerida",
    "Some files could not be moved" : "Mõnda faili ei saanud teisaldada",
    "Conflicts resolution skipped" : "Andmekonfilkti lahendamine jäi vahele",
    "Upload cancelled" : "Üleslaadimine on katkestatud",
    "Could not rename \"{oldName}\", it does not exist any more" : "„{oldName}“ faili nime muutmine ei õnnestunud, seda pole enam olemas",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "„{newName}“ nimi on juba „{dir}“ kaustas kasutusel. Palun vali teine nimi.",
    "Could not rename \"{oldName}\"" : "„{oldName}“ faili nime muutmine ei õnnestunud",
    "This operation is forbidden" : "See toiming on keelatud",
    "This folder is unavailable, please try again later or contact the administration" : "See kaust pole saadaval, palun proovi hiljem uuesti või võta ühendust haldajaga",
    "Storage is temporarily not available" : "Salvestusruum pole ajutiselt kättesaadav",
    "Unexpected error: {error}" : "Tundmatu viga: {error}",
    "Unknown error" : "Tundmatu viga",
    "_%n file_::_%n files_" : ["%n fail","%n faili"],
    "_%n folder_::_%n folders_" : ["%n kaust","%n kausta"],
    "_%n hidden_::_%n hidden_" : ["%n peidetud","%n peidetud"],
    "Folder name must not be empty." : "Kaustanimi ei saa olla tühi.",
    "Filename must not be empty." : "Failinimi ei saa olla tühi.",
    "\"{char}\" is not allowed inside a folder name." : "„{char}“ pole kaustanimedes lubatud.",
    "\"{char}\" is not allowed inside a filename." : "„{char}“ pole failinimedes lubatud.",
    "\"{segment}\" is a reserved name and not allowed for folder names." : "„{segment}“ on reserveeritud nimi ja seda kaustanimedes ei saa kasutada.",
    "\"{segment}\" is a reserved name and not allowed for filenames." : "„{segment}“ on reserveeritud nimi ja seda failinimedes ei saa kasutada.",
    "\"{extension}\" is not an allowed filetype." : "„{extension}“ pole lubatud failitüüp.",
    "Folder names must not end with \"{extension}\"." : "Kaustanimede lõpus ei tohi olla „{extension}“.",
    "Filenames must not end with \"{extension}\"." : "Failinimede lõpus ei tohi olla „{extension}“.",
    "Invalid folder name." : "Vigane või vale kaustanimi.",
    "List of favorite files and folders." : "Sinu lemmikfailide ja -kaustade loend.",
    "No favorites yet" : "Lemmikuid veel pole",
    "Files and folders you mark as favorite will show up here" : "Siin kuvatakse faile ja kaustasid, mille oled märkinud lemmikuteks",
    "List of your files and folders." : "Sinu failide ja kaustade loend.",
    "Folder tree" : "Kaustapuu",
    "List of your files and folders that are not shared." : "Sinu mittejagatud failide ja kaustade loend",
    "No personal files found" : "Isiklikke faile ei leidu",
    "Files that are not shared will show up here." : "Siin kuvatakse faile ja kaustu, mida sa pole teistega jaganud.",
    "Recent" : "Hiljutised",
    "List of recently modified files and folders." : "Hiljuti muudetud failide ja kaustade loend.",
    "No recently modified files" : "Hiljuti muudetud faile pole.",
    "Files and folders you recently modified will show up here." : "Failid ja kaustad, mida oled hiljuti muutnud, ilmuvad siia.",
    "Search" : "Otsi",
    "Search results within your files." : "Otsingutulemused sinu failide seast.",
    "This node is unavailable" : "See sõlm pole saadaval",
    "Renamed \"{oldName}\" to \"{newName}\"" : "Failinimi on muutunud „{oldName}“ ⇨ „{newName}“",
    "Clear filter" : "Tühjenda filter",
    "Open file sidebar" : "Ava failide külgriba",
    "Search everywhere …" : "Otsi kõikjalt…",
    "Search here …" : "Otsi siin…",
    "Preparing …" : "Ettevalmistamisel…",
    "Submitting fields …" : "Saadan välju…",
    "Invalid path selected" : "Vigane asukoht on valitud",
    "Choose file or folder to transfer" : "Vali üleantav fail või kaust",
    "Change" : "Muuda",
    "Shared by link" : "Jagatud lingiga",
    "Shared" : "Jagatud",
    "You" : "Sina",
    "Shared multiple times with different people" : "Jagatud mitu korda eri kasutajate poolt",
    "Unable to change the favorite state of the file" : "Faili olekut lemmikuna ei õnnestu muuta",
    "Error while loading the file data" : "Viga faili andmete laadimisel",
    "Tags" : "Sildid",
    "Save as …" : "Salvesta kui…",
    "Converting files …" : "Teisendan faile…",
    "Converting file …" : "Teisendan faili…",
    "No entries found in this folder" : "Selles kaustast ei leidunud kirjeid",
    "Select all" : "Vali kõik",
    "Upload too large" : "Üleslaaditu on liiga suur",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Failid, mida sa proovid üles laadida, ületavad serveri poolt üleslaaditavatele failidele määratud maksimaalse suuruse."
},
"nplurals=2; plural=(n != 1);");
