OC.L10N.register(
    "files_sharing",
    {
    "File shares" : "Κοινή χρήση αρχείων",
    "Downloaded via public link" : "Μεταφορτώθηκε μέσω δημόσιου συνδέσμου",
    "Downloaded by {email}" : "Μεταφορτώθηκε από {email}",
    "{file} downloaded via public link" : "{file} μεταφορτώθηκε από δημόσιο σύνδεσμο",
    "{email} downloaded {file}" : "{email} μεταφορτώθηκε {file}",
    "Shared with group {group}" : "Διαμοιρασμένα με την ομάδα {group}",
    "Removed share for group {group}" : "Αφαιρέθηκε ο διαμοιρασμός για την ομάδα {group}",
    "{actor} shared with group {group}" : "Ο/Η {actor} διαμοιράστηκε με την ομάδα {group}",
    "{actor} removed share for group {group}" : "Ο/Η {actor} αφαίρεσε τον διαμοιρασμό για την ομάδα {group}",
    "Share for group {group} expired" : "Η κοινή χρήση για την ομάδα {group} έληξε",
    "You shared {file} with group {group}" : "Διαμοιραστήκατε το {file} με την ομάδα {group}",
    "You removed group {group} from {file}" : "Αφαιρέσατε την ομάδα {group} από {file}",
    "{actor} shared {file} with group {group}" : "Ο/Η {actor} διαμοιράστηκε το {file} με την ομάδα {group}",
    "{actor} removed group {group} from {file}" : "Ο/Η {actor} αφαίρεσε την ομάδα {group} από {file}",
    "Share for file {file} with group {group} expired" : "Η κοινή χρήση του {file} με την ομάδα {group} έληξε",
    "Shared as public link" : "Διαμοιρασμός με δημόσιο σύνδεσμο",
    "Removed public link" : "Αφαίρεση δημόσιου συνδέσμου",
    "Public link expired" : "Ο δημόσιος σύνδεσμος έληξε",
    "{actor} shared as public link" : "Ο/Η {actor} διαμοιράστηκε με δημόσιο σύνδεσμο",
    "{actor} removed public link" : "Ο/Η {actor} αφαίρεσε δημόσιο σύνδεσμο",
    "Public link of {actor} expired" : "Ο δημόσιος σύνδεσμος από {actor} έληξε",
    "You shared {file} as public link" : "Διαμοιραστήκατε το {file} με δημόσιο σύνδεσμο",
    "You removed public link for {file}" : "Αφαιρέσατε δημόσιο σύνδεσμο για {file}",
    "Public link expired for {file}" : "Δημόσιος σύνδεσμος έληξε για {file}",
    "{actor} shared {file} as public link" : "{actor} διαμοίρασε {file} με δημόσιο σύνδεσμο",
    "{actor} removed public link for {file}" : "{actor} αφαιρέθηκε δημόσιος σύνδεσμος από {file}",
    "Public link of {actor} for {file} expired" : "Δημόσιος σύνδεσμος από {actor} για {file} έλληξε",
    "{user} accepted the remote share" : "Ο/Η {user} αποδέχτηκε τον απομακρυσμένο διαμοιρασμό",
    "{user} declined the remote share" : "Ο/Η {user} αποδέχτηκε τον δημόσιο διαμοιρασμό",
    "You received a new remote share {file} from {user}" : "Λάβατε ένα νέο απομακρυσμένο διαμοιρασμό {file} από {user}",
    "{user} accepted the remote share of {file}" : "Ο/Η {user} αποδέχτηκε τον απομακρυσμένο διαμοιρασμό από {file}",
    "{user} declined the remote share of {file}" : "Ο/Η {user} απέρριψε τον απομακρυσμένο διαμοιρασμό από {file}",
    "{user} unshared {file} from you" : "Ο/Η {user} απέσυρε τον διαμοιρασμό {file} από εσάς",
    "Shared with {user}" : "Διαμοιραζόμενο με {user}",
    "Removed share for {user}" : "Αφαιρέθηκε διαμοιρασμός για {user}",
    "You removed yourself" : "Αφαιρέσατε τον εαυτό σας",
    "{actor} removed themselves" : "Ο {actor} αφαίρεσε τον εαυτό του",
    "{actor} shared with {user}" : "Ο/Η {actor} διαμοιράστηκε με τον/την {user}",
    "{actor} removed share for {user}" : "Ο/Η {actor} αφαίρεσε διαμοιρασμό για {user}",
    "Shared by {actor}" : "Διαμοιράστηκε από τον/την {actor}",
    "{actor} removed share" : "Ο/Η {actor} αφαίρεσε διαμοιρασμό",
    "Share for {user} expired" : "Η κοινή χρήση για τον {user} έληξε",
    "Share expired" : "Η κοινή χρήση έληξε",
    "You shared {file} with {user}" : "Διαμοιραστήκατε {file} με {user}",
    "You removed {user} from {file}" : "Αφαιρέσατε {user} από {file}",
    "You removed yourself from {file}" : "Αφαιρέσατε τον εαυτό σας από {file}",
    "{actor} removed themselves from {file}" : "Οι {actor} αφαίρεσαν τον εαυτό τους από το {file}",
    "{actor} shared {file} with {user}" : "Ο/Η {actor} διαμοιράστηκε το {file} με τον/την {user}",
    "{actor} removed {user} from {file}" : "Ο/Η {actor} αφαίρεσε τον/την {user} από το {file}",
    "{actor} shared {file} with you" : "Ο/Η {actor} διαμοιράστηκε το {file} με εσάς",
    "{actor} removed you from the share named {file}" : "Ο/Η  {actor} σας αφαίρεσε από το κοινόχρηστο με όνομα {file}",
    "Share for file {file} with {user} expired" : "Η κοινή χρήση του αρχείου {file} με τον {user} έληξε",
    "Share for file {file} expired" : "Η κοινή χρήση του αρχείου {file} έληξε",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Ένα αρχείο ή φάκελος διαμοιρασμένο με mail ή με δημόσιο σύνδεσμο <strong>κατέβηκε</strong>",
    "Files have been <strong>uploaded</strong> to a folder shared by mail or by public link" : "Έχουν <strong>μεταφορτωθεί</strong> αρχεία σε έναν φάκελο που διαμοιράζεται μέσω email ή δημόσιου συνδέσμου",
    "A file or folder was shared from <strong>another server</strong>" : "Ένα αρχείο ή φάκελος διαμοιράστηκε από <strong>έναν άλλο διακομιστή</strong>",
    "Sharing" : "Διαμοιρασμός",
    "A file or folder has been <strong>shared</strong>" : "Ένα αρχείο ή φάκελος <strong>διαμοιράστηκε</strong>",
    "Shared link" : "Διαμοιρασμένος σύνδεσμος",
    "Wrong share ID, share does not exist" : "Λάθος ID κοινής χρήσης, η κοινή χρήση δεν υπάρχει",
    "Could not delete share" : "Αδυναμία διαγραφής κοινόχρηστου φακέλου",
    "Please specify a file or folder path" : "Παρακαλούμε καθορίστε την διαδρομή για το αρχείο ή τον φάκελο",
    "Wrong path, file/folder does not exist" : "Λάθος διαδρομή, το αρχείο/φάκελος δεν υπάρχει",
    "Could not create share" : "Αδυναμία δημιουργίας κοινόχρηστου",
    "Please specify a valid account to share with" : "Παρακαλούμε καθορίστε έναν έγκυρο λογαριασμό για κοινή χρήση",
    "Please specify a valid group" : "Παρακαλούμε καθορίστε μια έγκυρη ομάδα",
    "Please specify a valid email address" : "Παρακαλώ καθορίστε μια έγκυρη διεύθυνση email",
    "Sharing %s sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "Η κοινή χρήση %s της αποστολής του κωδικού πρόσβασης από το Nextcloud Talk απέτυχε επειδή δεν είναι ενεργοποιημένο το Nextcloud Talk",
    "Please specify a valid federated account ID" : "Παρακαλώ καθορίστε ένα έγκυρο ID ομοσπονδιακού λογαριασμού",
    "Please specify a valid federated group ID" : "Παρακαλώ καθορίστε ένα έγκυρο ID ομοσπονδιακής ομάδας",
    "You cannot share to a Team if the app is not enabled" : "Δεν μπορείτε να διαμοιραστείτε σε Ομάδα εάν η εφαρμογή δεν είναι ενεργοποιημένη",
    "Please specify a valid team" : "Παρακαλώ καθορίστε μια έγκυρη ομάδα",
    "Sharing %s failed because the back end does not support room shares" : "Διαμοιρασμός %s απέτυχε επειδή ο εξυπηρετητής δεν επιτρέπει διαμοιρασμούς δωματίων",
    "Unknown share type" : "Άγνωστος τύπος διαμοιρασμού",
    "Not a directory" : "Δεν είναι κατάλογος",
    "Could not lock node" : "Δεν ήταν δυνατό να κλειδώσει ο κόμβος",
    "Public upload is only possible for publicly shared folders" : "Δημόσιο ανέβασμα είναι δυνατό μόνο για δημόσια διαμοιρασμένους φακέλους",
    "Share must at least have READ or CREATE permissions" : "Το κοινόχρηστο πρέπει να έχει τουλάχιστον άδεια για ΑΝΑΓΝΩΣΗ ή ΔΗΜΙΟΥΡΓΙΑ",
    "Share must have READ permission if UPDATE or DELETE permission is set" : "Το κοινόχρηστο πρέπει να έχει άδεια ΑΝΑΓΝΩΣΗ αν οριστεί άδεια ΕΝΗΜΕΡΩΣΗ ή ΔΙΑΓΡΑΦΗ",
    "Could not lock path" : "Αδυναμία κλειδώματος διαδρομής",
    "no sharing rights on this item" : "καθόλου δικαιώματα διαμοιρασμού σε αυτό το αντικείμενο",
    "You are not allowed to edit incoming shares" : "Δεν επιτρέπεται να επεξεργαστείτε εισερχόμενους διαμοιρασμούς",
    "Wrong or no update parameter given" : "Λάθος ή καμία παράμετρος αναβάθμισης δεν δόθηκε",
    "\"Sending the password by Nextcloud Talk\" for sharing a file or folder failed because Nextcloud Talk is not enabled." : "Η \"Αποστολή του κωδικού πρόσβασης μέσω Nextcloud Talk\" για διαμοιρασμό ενός αρχείου ή φακέλου απέτυχε επειδή το Nextcloud Talk δεν είναι ενεργοποιημένο.",
    "Custom share link tokens have been disabled by the administrator" : "Τα προσαρμοσμένα tokens συνδέσμων διαμοιρασμού έχουν απενεργοποιηθεί από τον διαχειριστή",
    "Invalid date. Format must be YYYY-MM-DD" : "Μη έγκυρη ημερομηνία. Η μορφή πρέπει να είναι ΕΕΕΕ-ΜΜ-ΗΗ",
    "No sharing rights on this item" : "Καθόλου δικαιώματα διαμοιρασμού σε αυτό το αντικείμενο",
    "Invalid share attributes provided: \"%s\"" : "Παρέχονται μη έγκυρα χαρακτηριστικά διαμοιρασμού: \"%s\"",
    "You are not allowed to send mail notifications" : "Δεν επιτρέπεται να στέλνετε ειδοποιήσεις email",
    "No mail notification configured for this share type" : "Δεν έχει ρυθμιστεί ειδοποίηση email για αυτόν τον τύπο διαμοιρασμού",
    "Wrong password" : "Λάθος κωδικός πρόσβασης",
    "Error while sending mail notification" : "Σφάλμα κατά την αποστολή ειδοποίησης email",
    "Failed to generate a unique token" : "Αποτυχία δημιουργίας μοναδικού token",
    "This share does not exist or is no longer available" : "Αυτός ο διαμοιρασμός δεν υπάρχει ή δεν είναι πλέον διαθέσιμος",
    "shared by %s" : "Διαμοιράστηκε από 1 %s",
    "Download" : "Λήψη",
    "Add to your %s" : "Προσθήκη στο %s σας",
    "Direct link" : "Άμεσος σύνδεσμος",
    "You are not allowed to share \"%s\"." : "Δεν επιτρέπεται να διαμοιραστείτε το \"%s\".",
    "You cannot share your home folder." : "Δεν μπορείτε να κάνετε κοινή χρήση του αρχικού σας φακέλου.",
    "File cannot be shared with delete permission." : "Δεν είναι δυνατή η κοινή χρήση του αρχείου με άδεια διαγραφής.",
    "File cannot be shared with create permission." : "Δεν είναι δυνατή η κοινή χρήση του αρχείου με άδεια δημιουργίας.",
    "File share needs at least read permission." : "Το κοινόχρηστο αρχείο χρειάζεται τουλάχιστον άδεια ανάγνωσης.",
    "Public upload is not allowed." : "Δεν επιτρέπεται η δημόσια μεταφόρτωση.",
    "You cannot share \"%s\" with more permission than you have yourself." : "Δεν μπορείτε να διαμοιραστείτε το \"%s\" με μεγαλύτερη άδεια από αυτή που έχετε εσείς.",
    "Share API is disabled" : "API διαμοιρασμού είναι απενεργοποιημένο",
    "File sharing" : "Διαμοιρασμός αρχείων",
    "Share will expire tomorrow" : "Η κοινή χρήση θα λήξει αύριο",
    "Your share of {node} will expire tomorrow" : "Η κοινή χρήση του {node} θα λήξει αύριο",
    "You received {share} as a share by {user}" : "Λάβατε το {share} ως κοινή χρήση από τον {user}",
    "You received {share} to group {group} as a share by {user}" : "Λάβατε το {share} ομάδας {group} ως κοινή χρήση από τον {user}",
    "Accept" : "Αποδοχή",
    "Decline" : "Απόρριψη",
    "Remember to upload the files to %s" : "Θυμηθείτε να ανεβάσετε τα αρχεία στο %s",
    "We would like to kindly remind you that you have not yet uploaded any files to the shared folder." : "Θα θέλαμε να σας υπενθυμίσουμε ότι δεν έχετε ανεβάσει ακόμα αρχεία στον κοινόχρηστο φάκελο.",
    "Open \"%s\"" : "Άνοιγμα \"%s\"",
    "This application enables people to share files within Nextcloud. If enabled, the admin can choose which groups can share files. The applicable people can then share files and folders with other accounts and groups within Nextcloud. In addition, if the admin enables the share link feature, an external link can be used to share files with other people outside of Nextcloud. Admins can also enforce passwords, expirations dates, and enable server to server sharing via share links, as well as sharing from mobile devices.\nTurning the feature off removes shared files and folders on the server for all share recipients, and also on the sync clients and mobile apps. More information is available in the Nextcloud Documentation." : "Αυτή η εφαρμογή επιτρέπει στους χρήστες να διαμοιράζονται αρχεία εντός του Nextcloud. Εάν ενεργοποιηθεί, ο διαχειριστής μπορεί να επιλέξει ποιες ομάδες μπορούν να διαμοιράζονται αρχεία. Οι σχετικοί χρήστες μπορούν στη συνέχεια να διαμοιράζονται αρχεία και φακέλους με άλλους λογαριασμούς και ομάδες εντός του Nextcloud. Επιπλέον, εάν ο διαχειριστής ενεργοποιήσει τη λειτουργία συνδέσμων διαμοιρασμού, ένας εξωτερικός σύνδεσμος μπορεί να χρησιμοποιηθεί για διαμοιρασμό αρχείων με άλλα άτομα εκτός του Nextcloud. Οι διαχειριστές μπορούν επίσης να επιβάλουν κωδικούς πρόσβασης, ημερομηνίες λήξης και να ενεργοποιήσουν διαμοιρασμό από διακομιστή σε διακομιστή μέσω συνδέσμων διαμοιρασμού, καθώς και διαμοιρασμό από κινητές συσκευές.\nΗ απενεργοποίηση της λειτουργίας αφαιρεί τα διαμοιρασμένα αρχεία και φακέλους στον διακομιστή για όλους τους παραλήπτες διαμοιρασμού, καθώς και στους συγχρονισμένους πελάτες και τις εφαρμογές για κινητές συσκευές. Περισσότερες πληροφορίες είναι διαθέσιμες στην Τεκμηρίωση του Nextcloud.",
    "Filter accounts" : "Φιλτράρισμα λογαριασμών",
    "you" : "εσείς",
    "The request will expire on {date} at midnight and will be password protected." : "Το αίτημα θα λήξει στις {date} τα μεσάνυχτα και θα προστατεύεται με κωδικό πρόσβασης.",
    "The request will expire on {date} at midnight." : "Το αίτημα θα λήξει στις {date} τα μεσάνυχτα.",
    "The request will be password protected." : "Το αίτημα θα προστατεύεται με κωδικό πρόσβασης.",
    "When should the request expire?" : "Πότε θα πρέπει να λήξει το αίτημα;",
    "Set a submission expiration date" : "Ορίστε μια ημερομηνία λήξης υποβολής",
    "Expiration date" : "Ημερομηνία λήξης",
    "Select a date" : "Επιλέξτε μια ημερομηνία",
    "Your administrator has enforced a {count} days expiration policy." : "Ο διαχειριστής σας έχει επιβάλει πολιτική λήξης {count} ημερών.",
    "What password should be used for the request?" : "Ποιο συνθηματικό θα πρέπει να χρησιμοποιηθεί για το αίτημα;",
    "Set a password" : "Ορισμός συνθηματικού",
    "Password" : "Συνθηματικό",
    "Enter a valid password" : "Εισάγετε ένα έγκυρο συνθηματικό",
    "Generate a new password" : "Δημιουργία νέου συνθηματικού",
    "Your administrator has enforced a password protection." : "Ο διαχειριστής σας έχει επιβάλει προστασία με κωδικό πρόσβασης.",
    "Automatically copying failed, please copy the share link manually" : "Η αυτόματη αντιγραφή απέτυχε, παρακαλώ αντιγράψτε τον σύνδεσμο διαμοιρασμού χειροκίνητα",
    "Link copied" : "Ο σύνδεσμος αντιγράφηκε",
    "Email already added" : "Το email έχει ήδη προστεθεί",
    "Invalid email address" : "Μη έγκυρη διεύθυνση email",
    "_The following email address is not valid: {emails}_::_The following email addresses are not valid: {emails}_" : ["Η ακόλουθη διεύθυνση email δεν είναι έγκυρη: {emails}","Οι ακόλουθες διευθύνσεις email δεν είναι έγκυρες: {emails}"],
    "_{count} email address already added_::_{count} email addresses already added_" : ["{count} διεύθυνση email έχει ήδη προστεθεί","{count} διευθύνσεις email έχουν ήδη προστεθεί"],
    "_{count} email address added_::_{count} email addresses added_" : ["{count} διεύθυνση email προστέθηκε","{count} διευθύνσεις email προστέθηκαν"],
    "You can now share the link below to allow people to upload files to your directory." : "Μπορείτε τώρα να διαμοιραστείτε τον παρακάτω σύνδεσμο για να επιτρέψετε σε άτομα να ανεβάσουν αρχεία στον κατάλογό σας.",
    "Share link" : "Διαμοιρασμός συνδέσμου",
    "Copy" : "Αντιγραφή",
    "Send link via email" : "Αποστολή συνδέσμου μέσω email",
    "Enter an email address or paste a list" : "Εισάγετε μια διεύθυνση email ή επικολλήστε μια λίστα",
    "Remove email" : "Αφαίρεση email",
    "Select a destination" : "Επιλογή προορισμού",
    "Select" : "Επιλογή",
    "What are you requesting?" : "Τι ζητάτε;",
    "Request subject" : "Θέμα αιτήματος",
    "Birthday party photos, History assignment…" : "Φωτογραφίες πάρτι γενεθλίων, Εργασία ιστορίας…",
    "Where should these files go?" : "Πού θα πρέπει να πάνε αυτά τα αρχεία;",
    "Upload destination" : "Προορισμός μεταφόρτωσης",
    "Revert to default" : "Επιστροφή στην προεπιλογή",
    "The uploaded files are visible only to you unless you choose to share them." : "Τα ανεβασμένα αρχεία είναι ορατά μόνο σε εσάς, εκτός αν επιλέξετε να τα διαμοιραστείτε.",
    "Add a note" : "Προσθήκη σημείωσης",
    "Note for recipient" : "Σημείωση για τον παραλήπτη",
    "Add a note to help people understand what you are requesting." : "Προσθέστε μια σημείωση για να βοηθήσετε τα άτομα να καταλάβουν τι ζητάτε.",
    "You can add links, date or any other information that will help the recipient understand what you are requesting." : "Μπορείτε να προσθέσετε συνδέσμους, ημερομηνία ή οποιαδήποτε άλλη πληροφορία που θα βοηθήσει τον παραλήπτη να καταλάβει τι ζητάτε.",
    "Close" : "Κλείσιμο",
    "_Send email and close_::_Send {count} emails and close_" : ["Αποστολή email και κλείσιμο","Αποστολή {count} email και κλείσιμο"],
    "Please select a folder, you cannot share the root directory." : "Παρακαλώ επιλέξτε ένα φάκελο, δεν μπορείτε να διαμοιραστείτε τον ριζικό κατάλογο.",
    "File request created" : "Το αίτημα αρχείου δημιουργήθηκε",
    "_File request created and email sent_::_File request created and {count} emails sent_" : ["Το αίτημα αρχείου δημιουργήθηκε και το email απεστάλη","Το αίτημα αρχείου δημιουργήθηκε και {count} email απεστάλησαν"],
    "Error creating the share: {errorMessage}" : "Σφάλμα κατά τη δημιουργία της κοινής χρήσης: {errorMessage}",
    "Error creating the share" : "Σφάλμα κατά την δημιουργία κοινόχρηστου",
    "Error sending emails: {errorMessage}" : "Σφάλμα κατά την αποστολή email: {errorMessage}",
    "Error sending emails" : "Σφάλμα κατά την αποστολή email",
    "Create a file request" : "Δημιουργία αιτήματος αρχείου",
    "Collect files from others even if they do not have an account." : "Συλλογή αρχείων από άλλους ακόμα και αν δεν έχουν λογαριασμό.",
    "To ensure you can receive files, verify you have enough storage available." : "Για να διασφαλίσετε ότι μπορείτε να λάβετε αρχεία, επαληθεύστε ότι έχετε αρκετό διαθέσιμο χώρο αποθήκευσης.",
    "File request" : "Αίτημα αρχείου",
    "Previous step" : "Προηγούμενο βήμα",
    "Cancel" : "Ακύρωση",
    "Cancel the file request creation" : "Ακύρωση δημιουργίας αιτήματος αρχείου",
    "Close without sending emails" : "Κλείσιμο χωρίς αποστολή email",
    "Continue" : "Συνέχεια",
    "Error while toggling options" : "Σφάλμα κατά την εναλλαγή επιλογών",
    "Accept shares from other accounts and groups by default" : "Αποδοχή κοινόχρηστων από άλλους λογαριασμούς και ομάδες από προεπιλογή",
    "Choose a default folder for accepted shares" : "Επιλέξτε έναν προεπιλεγμένο φάκελο για τα κοινόχρηστα στοιχεία που γίνονται αποδεκτά ",
    "Invalid path selected" : "Επιλέχθηκε μη έγκυρη διαδρομή",
    "Unknown error" : "Άγνωστο σφάλμα",
    "Set default folder for accepted shares" : "Ορισμός προεπιλεγμένου φακέλου για αποδεκτά κοινόχρηστα στοιχεία",
    "Reset" : "Επαναφορά",
    "Reset folder to system default" : "Επαναφορά του φακέλου στις προεπιλογές συστήματος",
    "Share expiration: {date}" : "Λήξη διαμοιρασμού: {date}",
    "Share Expiration" : "Λήξη Διαμοιρασμού",
    "group" : "ομάδα",
    "conversation" : "συνομιλία",
    "remote" : "απομακρυσμένα",
    "remote group" : "απομακρυσμένη ομάδα",
    "guest" : "Επισκέπτης",
    "by {initiator}" : "από {initiator}",
    "Shared with the group {user} by {owner}" : "Διαμοιράστηκε με την ομάδα {user} από τον {owner}",
    "Shared with the conversation {user} by {owner}" : "Διαμοιράστηκε με τη συζήτηση {user} από τον {owner}",
    "Shared with {user} by {owner}" : "Διαμοιράστηκε με τον {user} από τον {owner}",
    "Open Sharing Details" : "Άνοιγμα Λεπτομερειών Διαμοιρασμού",
    "Added by {initiator}" : "Προστέθηκε από {initiator}",
    "Via “{folder}”" : "Μέσω “{folder}”",
    "Unshare" : "Αναίρεση διαμοιρασμού",
    "Cannot copy, please copy the link manually" : "Δεν μπορεί να αντιγραφεί, παρακαλώ αντιγράψτε χειροκίνητα",
    "Copy internal link" : "Αντιγραφή εσωτερικού συνδέσμου",
    "For people who already have access" : "Για άτομα που έχουν ήδη πρόσβαση",
    "Internal link" : "Εσωτερικός σύνδεσμος",
    "{shareWith} by {initiator}" : "{shareWith} από {initiator}",
    "Shared via link by {initiator}" : "Διαμοιράστηκε μέσω συνδέσμου από {initiator}",
    "File request ({label})" : "Αίτημα αρχείου ({label})",
    "Mail share ({label})" : "Διαμοιρασμός μέσω email ({label})",
    "Share link ({label})" : "Σύνδεσμος κοινής χρήσης ({label})",
    "Mail share" : "Διαμοιρασμός μέσω email",
    "Share link ({index})" : "Διαμοιρασμός συνδέσμου ({index})",
    "Create public link" : "Δημιουργία δημόσιου συνδέσμου",
    "Actions for \"{title}\"" : "Ενέργειες για \"{title}\"",
    "Copy public link of \"{title}\"" : "Αντιγραφή δημόσιου συνδέσμου του \"{title}\"",
    "Error, please enter proper password and/or expiration date" : "Σφάλμα, παρακαλώ εισάγετε τον σωστό κωδικό πρόσβασης και/ή ημερομηνία λήξης",
    "Link share created" : "Δημιουργήθηκε ο σύνδεσμος κοινής χρήσης",
    "Error while creating the share" : "Σφάλμα κατά τη δημιουργία κοινόχρηστου",
    "Your browser does not support copying, please copy the link manually:" : "Το πρόγραμμα περιήγησής σας δεν υποστηρίζει αντιγραφή, παρακαλώ αντιγράψτε τον σύνδεσμο χειροκίνητα:",
    "Successfully copied public link" : "Ο δημόσιος σύνδεσμος αντιγράφηκε με επιτυχία",
    "Please enter the following required information before creating the share" : "Καταχωρίστε τις ακόλουθες απαιτούμενες πληροφορίες πριν δημιουργήσετε το κοινόχρηστο στοιχείο",
    "Password protection (enforced)" : "Προστασία με κωδικό (υποχρεωτικό)",
    "Password protection" : "Προστασία συνθηματικού",
    "Enter a password" : "Εισάγετε ένα συνθηματικό",
    "Enable link expiration (enforced)" : "Ενεργοποίηση λήξης συνδέσμου (υποχρεωτικό)",
    "Enable link expiration" : "Ενεργοποίηση λήξης συνδέσμου",
    "Enter expiration date (enforced)" : "Εισαγωγή ημερομηνίας λήξης (υποχρεωτικό)",
    "Enter expiration date" : "Εισαγωγή ημερομηνίας λήξης",
    "Create share" : "Δημιουργήστε κοινή χρήση",
    "Customize link" : "Προσαρμογή συνδέσμου",
    "Generate QR code" : "Δημιουργία QR code",
    "Add another link" : "Προσθήκη άλλου συνδέσμου",
    "Create a new share link" : "Δημιουργία νέου κοινόχρηστου συνδέσμου",
    "Quick share options, the current selected is \"{selectedOption}\"" : "Επιλογές γρήγορου διαμοιρασμού, η τρέχουσα επιλογή είναι \"{selectedOption}\"",
    "View only" : "Μόνο για προβολή",
    "Can edit" : "Δυνατότητα επεξεργασίας",
    "Custom permissions" : "Προσαρμοσμένα δικαιώματα",
    "Resharing is not allowed" : "Δεν επιτρέπεται ο επαναμοιρασμός",
    "Name or email …" : "Όνομα ή διεύθυνση ηλεκτρονικού ταχυδρομείου …",
    "Name, email, or Federated Cloud ID …" : "Όνομα, διεύθυνση ηλεκτρονικού ταχυδρομείου ή Ομοσπονδιακό αναγνωριστικό Cloud …",
    "Searching …" : "Γίνεται αναζήτηση ...",
    "No elements found." : "Δεν βρέθηκαν στοιχεία.",
    "Search everywhere" : "Αναζητήστε παντού",
    "Guest" : "Επισκέπτης",
    "Group" : "Ομάδα",
    "Email" : "Email",
    "Team" : "Ομάδα",
    "Talk conversation" : "Συνομιλία στο Talk",
    "Deck board" : "Πίνακας του Deck",
    "ScienceMesh" : "ScienceMesh",
    "on {server}" : "στον {server}",
    "Enter external recipients" : "Εισαγωγή εξωτερικών παραληπτών",
    "Search for internal recipients" : "Αναζήτηση εσωτερικών παραληπτών",
    "Note from" : "Σημείωση από",
    "Note:" : "Σημείωση:",
    "File drop" : "Απόθεση αρχείου",
    "Upload files to {foldername}." : "Ανεβάστε αρχεία στο {foldername}.",
    "By uploading files, you agree to the terms of service." : "Με την μεταφόρτωση αρχείων, συμφωνείτε με τους όρους χρήσης.",
    "Successfully uploaded files" : "Επιτυχής μεταφόρτωση αρχείων",
    "View terms of service" : "Προβολή όρων χρήσης",
    "Terms of service" : "Όροι χρήσης",
    "Share with {user}" : "Διαμοιρασμός με {user}",
    "Share with email {email}" : "Διαμοιρασμός με email {email}",
    "Share with group" : "Κοινή χρήση με ομάδα",
    "Share in conversation" : "Κοινή χρήση σε συζήτηση",
    "Share with {user} on remote server {server}" : "Διαμοιρασμός με {user} στον απομακρυσμένο διακομιστή {server}",
    "Share with remote group" : "Διαμοιρασμός με απομακρυσμένη ομάδα",
    "Share with guest" : "Κοινή χρήση με επισκέπτη",
    "Update share" : "Ενημέρωση κοινόχρηστου",
    "Save share" : "Αποθήκευση κοινόχρηστου",
    "Read" : "Ανάγνωση",
    "Create" : "Δημιουργία",
    "Edit" : "Επεξεργασία",
    "Share" : "Διαμοιρασμός",
    "Delete" : "Διαγραφή",
    "Password field cannot be empty" : "Το πεδίο κωδικού πρόσβασης δεν μπορεί να είναι κενό",
    "Replace current password" : "Αντικατάσταση τρέχοντος κωδικού πρόσβασης",
    "Failed to generate a new token" : "Αποτυχία δημιουργίας νέου token",
    "Allow upload and editing" : "Επέτρεψε την μεταφόρτωση και επεξεργασία",
    "Allow editing" : "Επιτρέπεται η επεξεργασία",
    "Upload only" : "Μόνο μεταφόρτωση",
    "Advanced settings" : "Ρυθμίσεις για προχωρημένους",
    "Share label" : "Ετικέτα διαμοιρασμού",
    "Share link token" : "Διακριτικό συνδέσμου διαμοιρασμού",
    "Set the public share link token to something easy to remember or generate a new token. It is not recommended to use a guessable token for shares which contain sensitive information." : "Ορίστε το token του δημόσιου συνδέσμου διαμοιρασμού σε κάτι εύκολο να θυμηθείτε ή δημιουργήστε ένα νέο διακριτικό. Δεν συνιστάται η χρήση ευανάγνωστου token για διαμοιρασμούς που περιέχουν ευαίσθητες πληροφορίες.",
    "Generating…" : "Δημιουργείται…",
    "Generate new token" : "Δημιουργία νέου διακριτικού",
    "Set password" : "Ορισμός συνθηματικού",
    "Password expires {passwordExpirationTime}" : "Το συνθματικό λήγει {passwordExpirationTime}",
    "Password expired" : "Το συνθηματικό έληξε",
    "Video verification" : "Επαλήθευση βίντεο",
    "Expiration date (enforced)" : "Ημερομηνία λήξης (υποχρεωτικά)",
    "Set expiration date" : "Ορισμός ημερομηνίας λήξης",
    "Hide download" : "Απόκρυψη λήψης",
    "Allow download and sync" : "Να επιτρέπεται η λήψη και ο συγχρονισμός",
    "Note to recipient" : "Σημείωση προς τον παραλήπτη",
    "Enter a note for the share recipient" : "Προσθέτε σημείωση για τους παραλήπτες του κοινόχρηστου",
    "Show files in grid view" : "Εμφάνιση αρχείων σε προβολή πλέγματος",
    "Delete share" : "Διαγραφή κοινόχρηστου",
    "Others with access" : "Άλλοι με πρόσβαση",
    "No other accounts with access found" : "Δεν βρέθηκαν άλλοι λογαριασμοί με πρόσβαση",
    "Toggle list of others with access to this directory" : "Εναλλαγή λίστας άλλων με πρόσβαση σε αυτόν τον κατάλογο",
    "Toggle list of others with access to this file" : "Εναλλαγή λίστας άλλων με πρόσβαση σε αυτόν το αρχείο",
    "Unable to fetch inherited shares" : "Δεν είναι δυνατή η λήψη άλλων διαμοιρασμών",
    "Link shares" : "Διαμοιρασμοί συνδέσμων",
    "Shares" : "Κοινόχρηστα",
    "Share files within your organization. Recipients who can already view the file can also use this link for easy access." : "Διαμοιρασμός αρχείων εντός του οργανισμού σας. Οι παραλήπτες που μπορούν ήδη να δουν το αρχείο μπορούν επίσης να χρησιμοποιήσουν αυτόν τον σύνδεσμο για εύκολη πρόσβαση.",
    "Share files with others outside your organization via public links and email addresses. You can also share to {productName} accounts on other instances using their federated cloud ID." : "Διαμοιρασμός αρχείων με άλλους εκτός του οργανισμού σας μέσω δημόσιων συνδέσμων και διευθύνσεων email. Μπορείτε επίσης να διαμοιραστείτε σε λογαριασμούς {productName} σε άλλα στιγμιότυπα χρησιμοποιώντας το ομοσπονδιακό cloud ID τους.",
    "Shares from apps or other sources which are not included in internal or external shares." : "Διαμοιρασμοί από εφαρμογές ή άλλες πηγές που δεν περιλαμβάνονται σε εσωτερικούς ή εξωτερικούς διαμοιρασμούς.",
    "Type names, teams, federated cloud IDs" : "Πληκτρολογήστε ονόματα, ομάδες, ομοσπονδιακά cloud IDs",
    "Type names or teams" : "Πληκτρολογήστε ονόματα ή ομάδες",
    "Type a federated cloud ID" : "Πληκτρολογήστε ένα ομοσπονδιακό αναγνωριστικόο νέφους",
    "Type an email" : "Πληκτρολογήστε ένα email",
    "Type an email or federated cloud ID" : "Πληκτρολογήστε ένα email ή ομοσπονδιακό cloud ID",
    "Unable to load the shares list" : "Δεν είναι δυνατή η φόρτωση λίστας διαμοιρασμών",
    "Expires {relativetime}" : "Λήγει {relativetime}",
    "this share just expired." : "το κοινόχρηστο μόλις έληξε.",
    "Shared with you by {owner}" : "Διαμοιράστηκε με σας από τον {owner}",
    "Internal shares" : "Εσωτερικοί διαμοιρασμοί",
    "Internal shares explanation" : "Εξήγηση εσωτερικών διαμοιρασμών",
    "External shares" : "Εξωτερικοί διαμοιρασμοί",
    "External shares explanation" : "Εξήγηση εξωτερικών διαμοιρασμών",
    "Additional shares" : "Πρόσθετοι διαμοιρασμοί",
    "Additional shares explanation" : "Εξήγηση πρόσθετων διαμοιρασμών",
    "Link to a file" : "Σύνδεσμος σε αρχείο",
    "_Accept share_::_Accept shares_" : ["Αποδοχή κοινόχρηστου","Αποδοχή κοινόχρηστων"],
    "Open in Files" : "Άνοιγμα στα Αρχεία",
    "_Reject share_::_Reject shares_" : ["Απόρριψη κοινόχρηστου","Απόρριψη κοινόχρηστων"],
    "_Restore share_::_Restore shares_" : ["Επαναφορά κοινόχρηστου","Επαναφορά κοινόχρηστων"],
    "Shared" : "Κοινόχρηστα",
    "Shared by {ownerDisplayName}" : "Διαμοιράστηκε από {ownerDisplayName}",
    "Shared multiple times with different people" : "Κοινοποιήθηκε πολλές φορές με διαφορετικά άτομα",
    "Sharing options" : "Επιλογές διαμοιρασμού",
    "Shared with others" : "Διαμοιρασμένα με άλλους",
    "You do not have enough permissions to share this file." : "Δεν έχετε αρκετά δικαιώματα για να διαμοιράσετε αυτό το αρχείο.",
    "People" : "Άτομα",
    "Create file request" : "Δημιουργία αιτήματος αρχείου",
    "Upload files to {foldername}" : "Ανεβάστε αρχεία στο {foldername}",
    "Public file share" : "Δημόσιος διαμοιρασμός αρχείου",
    "Publicly shared file." : "Δημόσια διαμοιρασμένο αρχείο.",
    "No file" : "Κανένα αρχείο",
    "The file shared with you will show up here" : "Το αρχείο που διαμοιράστηκε μαζί σας θα εμφανιστεί εδώ",
    "Public share" : "Δημόσια κοινόχρηστο",
    "Publicly shared files." : "Δημόσια διαμοιρασμένα αρχεία.",
    "No files" : "Κανένα αρχείο",
    "Files and folders shared with you will show up here" : "Τα αρχεία και οι φάκελοι που διαμοιράστηκαν μαζί σας θα εμφανιστούν εδώ",
    "Overview of shared files." : "Επισκόπηση κοινόχρηστων αρχείων.",
    "No shares" : "Κανένα κοινόχρηστο",
    "Files and folders you shared or have been shared with you will show up here" : "Αρχεία και φάκελοι που μοιραστήκατε ή έχουν μοιραστεί με εσάς θα εμφανιστούν εδώ",
    "Shared with you" : "Διαμοιρασμένα με εσάς",
    "List of files that are shared with you." : "Λίστα αρχείων σε κοινή χρήση με εσάς.",
    "Nothing shared with you yet" : "Κανένα αρχείο δεν έχει διαμοιραστεί ακόμα με εσάς.",
    "Files and folders others shared with you will show up here" : "Αρχεία και φάκελοι που άλλοι έχουν μοιραστεί μαζί σας θα εμφανιστούν εδώ",
    "List of files that you shared with others." : "Λίστα των αρχείων που μοιραστήκατε με άλλους.",
    "Nothing shared yet" : "Δεν έχει διαμοιραστεί τίποτα μέχρι στιγμής",
    "Files and folders you shared will show up here" : "Αρχεία και φάκελοι που μοιραστήκατε θα εμφανιστούν εδώ",
    "Shared by link" : "Διαμοιρασμένα μέσω συνδέσμου",
    "List of files that are shared by link." : "Λίστα αρχείων που έχουν μοιραστεί με σύνδεσμο.",
    "No shared links" : "Κανένας διαμοιρασμένος σύνδεσμος",
    "Files and folders you shared by link will show up here" : "Αρχεία και φάκελοι που μοιραστήκατε με σύνδεσμο θα εμφανιστούν εδώ",
    "File requests" : "Αιτήματα αρχείων",
    "List of file requests." : "Λίστα αιτημάτων αρχείων.",
    "No file requests" : "Κανένα αίτημα αρχείου",
    "File requests you have created will show up here" : "Τα αιτήματα αρχείων που έχετε δημιουργήσει θα εμφανιστούν εδώ",
    "Deleted shares" : "Διαγραμμένα κοινόχρηστα",
    "List of shares you left." : "Λίστα κοινόχρηστων από τα οποία αποχωρήσατε",
    "No deleted shares" : "Δεν υπάρχουν διαγραμμένα κοινόχρηστα",
    "Shares you have left will show up here" : "Κοινόχρηστα από τα οποία έχετε αποχωρήσει θα εμφανιστούν εδώ",
    "Pending shares" : "Κοινή χρήση σε εκκρεμότητα",
    "List of unapproved shares." : "Λίστα μη αποδεκτών κοινόχρηστων.",
    "No pending shares" : "Δεν εκκρεμούν κοινόχρηστα",
    "Shares you have received but not approved will show up here" : "Κοινόχρηστα που έχετε λάβει αλλά δεν έχετε εγκρίνει θα εμφανιστούν εδώ",
    "Error deleting the share" : "Σφάλμα διαγραφής του κοινόχρηστου",
    "Error updating the share" : "Σφάλμα κατά την ενημέρωση του κοινόχρηστου",
    "File \"{path}\" has been unshared" : "Το αρχείο \"{path}\" έχει σταματήσει να διαμοιράζεται",
    "Folder \"{path}\" has been unshared" : "Ο φάκελος \"{path}\" έχει σταματήσει να διαμοιράζεται",
    "Could not update share" : "Δεν ήταν δυνατή η ενημέρωση του διαμοιρασμού",
    "Share saved" : "Αποθηκεύτηκε το κοινόχρηστο",
    "Share expiry date saved" : "Αποθηκεύτηκε η ημερομηνία λήξης του κοινόχρηστου",
    "Share hide-download state saved" : "Η κατάσταση απόκρυψης λήψης του κοινόχρηστου αποθηκεύτηκε",
    "Share label saved" : "Η ετικέτα του κοινόχρηστου αποθηκεύτηκε",
    "Share note for recipient saved" : "Η σημείωση κοινόχρηστου για τον παραλήπτη αποθηκεύτηκε",
    "Share password saved" : "Το συνθηματικό του κοινόχρηστου αποθηκεύτηκε",
    "Share permissions saved" : "Τα δικαιώματα κοινόχρηστου αποθηκεύτηκαν",
    "To upload files to {folder}, you need to provide your name first." : "Για να ανεβάσετε αρχεία στο {folder}, πρέπει πρώτα να δώσετε το όνομά σας.",
    "Upload files to {folder}" : "Ανεβάστε αρχεία στο {folder}",
    "Please confirm your name to upload files to {folder}" : "Παρακαλώ επιβεβαιώστε το όνομά σας για να ανεβάσετε αρχεία στο {folder}",
    "{ownerDisplayName} shared a folder with you." : "Ο {ownerDisplayName} διαμοιράστηκε έναν φάκελο μαζί σας.",
    "Names must not be empty." : "Τα ονόματα δεν πρέπει να είναι κενά.",
    "Names must not start with a dot." : "Τα ονόματα δεν πρέπει να ξεκινούν με τελεία.",
    "\"{char}\" is not allowed inside a name." : "Το \"{char}\" δεν επιτρέπεται μέσα σε ένα όνομα.",
    "\"{segment}\" is a reserved name and not allowed." : "Το \"{segment}\" είναι ένα δεσμευμένο όνομα και δεν επιτρέπεται.",
    "\"{extension}\" is not an allowed name." : "Το \"{extension}\" δεν είναι επιτρεπτό όνομα.",
    "Names must not end with \"{extension}\"." : "Τα ονόματα δεν πρέπει να τελειώνουν με \"{extension}\".",
    "Invalid name." : "Μη έγκυρο όνομα.",
    "Password created successfully" : "Συνθηματικό δημιουργήθηκε με επιτυχία",
    "Error generating password from password policy" : "Σφάλμα δημιουργίας συνθηματικού από την πολιτική συνθηματικών",
    "Shared with you and the group {group} by {owner}" : "Διαμοιράστηκε με σας και με την ομάδα {group} του {owner}",
    "Shared with you and {circle} by {owner}" : "Διαμοιράστηκε με σας και τον {circle} από τον {owner}",
    "Shared with you and the conversation {conversation} by {owner}" : "Διαμοιράστηκε με σας και με τη συζήτηση {conversation} από {owner}",
    "Shared with you in a conversation by {owner}" : "Διαμοιράστηκε με σας από τον {owner}",
    "Share not found" : "Δεν βρέθηκε το κονόχρηστο",
    "Back to %s" : "Πίσω στο %s",
    "Add to your Nextcloud" : "Προσθήκη στο Nextcloud σου",
    "Group sharing is disabled by the administrator" : "Διαμοιρασμός σε ομάδες είναι απενεργοποιημένος από τον διαχειρηστή",
    "Public link sharing is disabled by the administrator" : "Διαμοιρασμός δημόσιου συνδέσμου είναι απενεργοποιημένος από τον διαχειριστή",
    "Sharing %1$s failed because the back end does not allow shares from type %2$s" : "Διαμοιρασμός %1$s απέτυχε επειδή ο εξυπηρετητής δεν επιτρέπει διαμοιρασμούς από τύπο %2$s",
    "Sharing %s failed because the back end does not support ScienceMesh shares" : "Ο διαμοιρασμός %s απέτυχε επειδή το σύστημα υποστήριξης δεν υποστηρίζει μετοχές ScienceMesh",
    "Public upload disabled by the administrator" : "Δημόσιο ανέβασμα είναι απενεργοποιημένο από τον διαχειριστή",
    "Tokens must contain at least 1 character and may only contain letters, numbers, or a hyphen" : "Τα tokens πρέπει να περιέχουν τουλάχιστον 1 χαρακτήρα και μπορούν να περιέχουν μόνο γράμματα, αριθμούς ή παύλα",
    "Name or email …" : "Όνομα ή διεύθυνση ηλεκτρονικού ταχυδρομείου",
    "Name, email, or Federated Cloud ID …" : "Όνομα, διεύθυνση ηλεκτρονικού ταχυδρομείου ή Ομοσπονδιακό αναγνωριστικό Cloud…",
    "Searching …" : "Αναζήτηση ..."
},
"nplurals=2; plural=(n != 1);");
