OC.L10N.register(
    "files_trashbin",
    {
    "restored" : "obnovené",
    "Deleted files" : "Zmazané súbory",
    "Deleted files and folders in the trash bin (may expire during export if you are low on storage space)" : "Odstránené súbory a priečinky v koši (môže vypršať platnosť počas exportu, ak máte málo miesta v úložisku)",
    "This application enables people to restore files that were deleted from the system." : "Táto aplikácia povoluje ľuďom obnoviť súbory, ktoré boli zo systému vymazané.",
    "This application enables people to restore files that were deleted from the system. It displays a list of deleted files in the web interface, and has options to restore those deleted files back to the people file directories or remove them permanently from the system. Restoring a file also restores related file versions, if the versions application is enabled. When a file is deleted from a share, it can be restored in the same manner, though it is no longer shared. By default, these files remain in the trash bin for 30 days.\nTo prevent an account from running out of disk space, the Deleted files app will not utilize more than 50% of the currently available free quota for deleted files. If the deleted files exceed this limit, the app deletes the oldest files until it gets below this limit. More information is available in the Deleted Files documentation." : "Táto aplikácia umožňuje ľuďom obnoviť súbory, ktoré boli zo systému vymazané. Zobrazuje zoznam vymazaných súborov vo webovom rozhraní a poskytuje možnosti obnovenia týchto vymazaných súborov späť do adresárov ľudí alebo ich permanentného odstránenia zo systému. Obnovenie súboru tiež obnovuje predchádzajúce verzie súborov, ak je povolená aplikácia pre verzie. Keď je súbor vymazaný zo zdieľaného miesta, môže byť obnovený rovnakým spôsobom, aj keď už nie je zdieľaný. Tieto súbory zostávajú v koši 30 dní.\nAby sa účet nedostal do stavu nedostatku miesta na disku, aplikácia na správu zmazaných súborov nevyužije viac ako 50 % momentálne dostupnej voľnej kvóty pre zmazané súbory. Ak prekročia tento limit, aplikácia odstráni najstaršie súbory, kým sa nedostane pod tento limit. Viac informácií nájdete v dokumentácii aplikácie na správu zmazaných súborov.",
    "Restore" : "Obnoviť",
    "Not enough free space to restore the file/folder" : "Nedostatok voľného miesta na obnovenie súboru/zložky",
    "Empty deleted files" : "Vyprázdniť odstránené súbory",
    "Confirm permanent deletion" : "Potvrdiť premanentné zmazanie",
    "Are you sure you want to permanently delete all files and folders in the trash? This cannot be undone." : "Naozaj chcete natrvalo odstrániť všetky súbory a priečinky v koši? Toto sa nedá vrátiť späť.",
    "Cancel" : "Zrušiť",
    "Original location" : "Pôvodné umiestnenie",
    "Deleted by" : "Odstránil",
    "Deleted" : "Zmazané",
    "few seconds ago" : "pred niekoľkými sekundami",
    "A long time ago" : "Pred dlhším časom",
    "Unknown" : "Neznámy",
    "All files" : "Všetky súbory",
    "You" : "Vy",
    "List of files that have been deleted." : "Zoznam súborov, ktoré boli vymazané.",
    "No deleted files" : "Žiadne zmazané súbory",
    "Files and folders you have deleted will show up here" : "Súbory a adresáre, ktoré ste vymazali, sa zobrazia tu",
    "All files have been permanently deleted" : "Všetky súbory boli trvalo vymazané",
    "Failed to empty deleted files" : "Nepodarilo sa vyprázdniť zmazané súbory"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
