OC.L10N.register(
    "files_versions",
    {
    "Block file versioning" : "Blokeeri failiversioonide loomine",
    "Automatic tag based blocking of file version creation." : "Automaatne silt, mis põhineb failiversioonide loomise blokeerimisel.",
    "No rule given" : "Reeglit pole määratud",
    "A new version is created" : "Uus versioon on loodud",
    "Versions" : "Versioonid",
    "This application automatically maintains older versions of files that are changed." : "See rakendus haldab automaatselt muudetud failide vanemaid versioone.",
    "This application automatically maintains older versions of files that are changed. When enabled, a hidden versions folder is provisioned in every user's directory and is used to store old file versions. A user can revert to an older version through the web interface at any time, with the replaced file becoming a version. The app automatically manages the versions folder to ensure the account does not run out of Quota because of versions.\n\t\tIn addition to the expiry of versions, the versions app makes certain never to use more than 50% of the account's currently available free space. If stored versions exceed this limit, the app will delete the oldest versions first until it meets this limit. More information is available in the Versions documentation." : "See rakendus säilitab automaatselt muudetud failide vanemaid versioonid. Kui see on lubatud, luuakse iga kasutaja kaustas peidetud versioonide alamkaust ja seda kasutatakse vanade failiversioonide salvestamiseks. Kasutaja saab veebiliidese kaudu igal ajal naasta vanema versiooni juurde, kusjuures asendatud failist saab versioon. Rakendus haldab automaatselt versioonide kausta, et kasutajakonto mahukvoot versioonide tõttu otsa ei saaks.\nLisaks versioonide aegumisele tagab versioonirakendus, et ei kasutataks kunagi rohkem kui 50% konto hetkel saadaolevast vabast ruumist. Kui salvestatud versioonid ületavad selle piirangu, kustutab rakendus kõigepealt vanimad versioonid, kuni on jälle piisavalt vaba ruumi. Lisateavet leiad versioonide dokumentatsioonist.",
    "Current version" : "Hetkeversioon",
    "Initial version" : "Algversioon",
    "You" : "Sina",
    "Actions for version from {versionHumanExplicitDate}" : "Tegevused versiooniga alates kuupäevast: {versionHumanExplicitDate}",
    "Name this version" : "Lisa sellele versioonile nimi",
    "Edit version name" : "Muuda versiooni nime",
    "Compare to current version" : "Võrdle hetkeversiooniga",
    "Restore version" : "Taasta versioon",
    "Download version" : "Laadi versioon alla",
    "Delete version" : "Kustuta versioon",
    "Cancel" : "Tühista",
    "Remove version name" : "Eemalda versiooni nimi",
    "Save version name" : "Salvesta versiooni nimi",
    "Version name" : "Versiooni nimi",
    "Named versions are persisted, and excluded from automatic cleanups when your storage quota is full." : "Nimelised versioonid hoitakse alles ja ei kustutata automaatselt, kui salvestusruum on täis.",
    "Initial version restored" : "Algne versioon on taastatud",
    "Version restored" : "Versioon on taastatud",
    "Could not restore version" : "Versiooni taastamine ei õnnestunud",
    "Could not set version label" : "Ei saanud määrata versiooni märget",
    "Could not delete version" : "Versiooni kustutamine ei õnnestunud",
    "File versions" : "Faili versioonid"
},
"nplurals=2; plural=(n != 1);");
