OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "Wizard de arranque inicial",
    "Add your profile information! For example your email is needed to receive notifications." : "Adicione a sua informação de perfil! Por exemplo, o seu email é necessário para receber notificações.",
    "Add your profile information! For example your email is needed to receive notifications and reset your password." : "Adicione a sua informação de perfil! Por exemplo, o seu email é necessário para receber notificações e efetuar a reposição da sua palavra-passe.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Adicione informação ao seu perfil! Definir uma image de perfil e um nome completo para facilitar o reconhecimento em todas as funcionalidades.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Adicione informação ao seu perfil! Defina um nome completo para facilitar o reconhecimento em todas as funcionalidades.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Adicione informação ao seu perfil! Defina uma imagem de perfil para facilitar o reconhecimento em todas as funcionalidades.",
    "App recommendation: Calendar" : "Recomendação de aplicativo: Calendário",
    "Schedule work & meetings, synced with all your devices." : "Agende trabalho e reuniões, sincronizando com todos os seus dispositivos.",
    "App recommendation: Contacts" : "Recomendação de aplicativo: Contatos",
    "Keep your colleagues and friends in one place without leaking their private info." : "Mantenha os seus colegas e amigos no mesmo lugar sem divulgar as suas informações privadas.",
    "App recommendation: Mail" : "Recomendação de aplicativo: E-Mail",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Aplicação de email simples integrada com Ficheiros, Contactos e Calendário.",
    "App recommendation: Tasks" : "Recomendação de aplicação: Tarefas Nextcloud",
    "App recommendation: Deck" : "Recomendação de aplicação: Deck",
    "Kanban style organization for personal planning and team projects." : "Organização no estilo Kanban para planejamento pessoal e projetos de equipe.",
    "App recommendation: Forms" : "Recomendação de aplicativo: Formulários",
    "Simple surveys and questionnaires, self-hosted" : "Enquetes e questionários simples, auto-hospedados",
    "Smart media tagging for Nextcloud" : "Etiquetamento inteligente de mídia para o Nextcloud",
    "App recommendation: Group folders" : "Recomendação de aplicação: Pastas de grupo",
    "Admin-configured folders shared by everyone in a group." : "Pastas configuradas pelo administrador compartilhadas por todos em um grupo.",
    "Create and share whiteboards with others and collaborate in real-time." : "Crie e compartilhe quadros brancos com outras pessoas e colabore em tempo real.",
    "Connect your calendar" : "Ligar o seu calendário",
    "Connect your contacts" : "Ligar os seus contactos",
    "Access files via WebDAV" : "Aceder aos ficheiros via WebDAV",
    "Download macOS/iOS configuration profile" : "Transferir perfil de configuração de macOS/iOS",
    "Desktop client" : "Cliente de PC",
    "Android app on Google Play Store" : "Aplicativo Android na Google Play Store",
    "Android app on F-Droid" : "Aplicativo Android no F-Droid",
    "iOS app" : "Aplicação iOS",
    "About & What's new" : "Sobre & Novidades",
    "A welcome and introduction wizard for Nextcloud" : "Um assistente de boas-vindas e introdução ao Nextcloud",
    "This application enables a pop-up window when a user first logs into Nextcloud. This window welcomes new users to Nextcloud, and contains links to the standard desktop client, Android app, and the iOS app. The window also shows a link for accessing Nextcloud via WebDAV. At any time, the first run wizard can be opened again via link \"About\" on settings menu.\nThe First run wizard can be customized to meet specific design goals, or to change links and messages. Create an appropriate theme following the Theming documentation, and changes to the look and feel of this Wizard are simple. More information is available in the first run wizard documentation, as well as the theming documentation." : "Este aplicativo ativa uma janela pop-up quando um usuário faz login pela primeira vez no Nextcloud. Essa janela dá boas-vindas aos novos usuários e contém links para os clientes padrões para desktop Android e iOS. A janela também mostra um link para acessar o Nextcloud via WebDAV. A qualquer momento, este assistente pode ser aberto novamente pelo link \"Sobre\" no menu de configurações.\nO assistente de primeira execução pode ser personalizado para atender a metas de design específicas ou para alterar links e mensagens. Crie um tema apropriado seguindo a documentação de Theming. Mais informações estão disponíveis na documentação deste assistente, bem como na documentação sobre temas.",
    "Download on Apple app store" : "Transferir na loja App Store",
    "Download on Google play store" : "Transferir na loja Google Play",
    "Go to previous page" : "Ir para a página anterior",
    "Close" : "Fechar",
    "Get involved! ↗" : "Envolva-se! ↗",
    "Find out more about your Nextcloud setup with the admin, user or developer documentation." : "Descubra mais sobre seu Nextcloud com as documentações para administradores, usuários ou desenvolvedores.",
    "For large organisations ↗" : "Para grandes organizações ↗",
    "Seamless integration with your devices." : "Integração perfeita com seus dispositivos.",
    "Sync your files across your devices with the desktop and mobile apps, and connect your calendar and contacts." : "Sincronize seus arquivos em todos os seus dispositivos com os aplicativos de desktop e aplicativos móveis, e conecte seu calendário e contatos.",
    "Desktop app ↗" : "Aplicativo Desktop ↗",
    "Download For Windows, Mac OS and Linux." : "Transferir para Windows, Mac OS e Linux.",
    "Connect your calendar and contacts with your devices." : "Conecte seu calendário e contatos com seus dispositivos.",
    "Welcome to {cloudName}!" : "Bem-vindo a {cloudName}!",
    "Skip" : "Ignorar",
    "This Nextcloud is on version {version}" : "Este Nextcloud está na versão {version}",
    "Privacy" : "Privacidade",
    "Productivity" : "Produtividade",
    "Collaborate and communicate across any platform." : "Colabore e comunique através de qualquer plataforma.",
    "Import and export anything you want with open standards." : "Importe e exporte tudo que quiser com protocolos abertos",
    "Community" : "Comunidade",
    "Nextcloud Hub {version} release" : "Lançamento do Nextcloud Hub {version}",
    "Read more about it on the Nextcloud Hub {version} blog" : "Leia mais sobre isso no blog Nextcloud Hub {version}",
    "Find out more on the blog" : "Saiba mais no blog",
    "Share your opinion about Nextcloud Hub {version}" : "Compartilhe sua opinião sobre Nextcloud Hub {version}",
    "Share via email" : "Partilhar via correio eletrónico",
    "New in Nextcloud Hub {version}" : "Novidades no Nextcloud Hub {version}",
    "Connect other apps to {productName}" : "Conecte outros aplicativos a {productName}",
    "Besides the mobile apps and desktop client you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to {productName}." : "Além dos aplicativos móveis e do cliente de desktop, você pode conectar qualquer outro software que suporte os protocolos WebDAV/CalDAV/CardDAV ao {productName}.",
    "Set up sync clients using an {linkStart}app password{linkEnd}. That way you can make sure you are able to revoke access in case you lose that device." : "Configure clientes de sincronização usando uma {linkStart}senha de aplicativo{linkEnd}. Dessa forma, você pode ter certeza de que poderá revogar o acesso caso perca o dispositivo.",
    "Get the apps to sync your files" : "Obtenha as aplicações para sincronizar os seus ficheiros",
    "{productName} gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "{productName} lhe dá acesso aos seus arquivos onde quer que você esteja. Nossos clientes móveis e de desktop fáceis de usar estão disponíveis para todas as principais plataformas a custo zero.",
    "URL copied" : "URL copiado",
    "Could not copy the URL, please copy manually" : "Não foi possível copiar o URL, copie manualmente",
    "Server address" : "Endereço do servidor",
    "Use this link to connect your apps and desktop client to this server:" : "Use este link para conectar seus aplicativos e clientes de desktop a este servidor:",
    "Empowering developers with an open platform" : "Capacitando desenvolvedores com uma plataforma aberta",
    "Your choice: Nextcloud Office powered by Collabora or Euro-Office" : "Sua escolha: Nextcloud Office com tecnologia Collabora ou Euro-Office",
    "Delegate calendars, meetings and mail boxes for better collaboration" : "Delegue calendários, reuniões e caixas de correio para melhorar a colaboração",
    "Gantt charts, dependencies & more in Nextcloud Deck" : "Gráficos de Gantt, dependências e muito mais no Nextcloud Deck",
    "Pexip, Matrix, and more updates in integrations" : "Pexip, Matrix e outras atualizações nas integrações",
    "Experience the brand new Nextcloud Hub!" : "Experimente o novo Nextcloud Hub!",
    "Get to know the new features of Hub {version}" : "Saiba mais sobre os novos recursos do Hub {version}",
    "Time to own your collaboration: Meet Nextcloud Hub 26 Spring! 🚀" : "É hora de assumir o controle da sua colaboração: conheça o Nextcloud Hub 26 Primavera! 🚀",
    "What's new?" : "O que há de novo?",
    "Nextcloud on all your devices" : "Nextcloud em todos os seus dispositivos",
    "Nextcloud Hub {version}" : "Nextcloud Hub {version}",
    "Global redesign and usability lift" : "Redesenho global e melhoria da usabilidade",
    "New Office UI: colors, tabs, bars" : "Nova interface do usuário do Office: cores, abas, barras",
    "Performance and stability boost" : "Melhoria de desempenho e estabilidade",
    "New AI Agency tools unlocked" : "Novas ferramentas da Agência de IA destrancadas",
    "Calendar: date poll for participants" : "Calendário: enquete sobre datas para os participantes",
    "Intuitive file search" : "Pesquisa intuitiva de arquivos",
    "Quick presets & many other admin updates" : "Predefinições rápidas e muitas outras atualizações administrativas",
    "… and much more!" : "… e muito mais!",
    "Nextcloud Hub 25 Autumn – Your digital workspace, ready in no time ⚡" : "Nextcloud Hub 25 Autumn – Seu espaço de trabalho digital, pronto em instantes ⚡",
    "Nextcloud Talk: live translations, pinned messages, scheduling" : "Nextcloud Talk: traduções em tempo real, mensagens fixadas, agendamento",
    "Office document comparison" : "Comparação de documentos do Office",
    "Whiteboard: comments, reactions, timers" : "Quadro branco: comentários, reações, temporizadores",
    "Powerful E2EE in the web interface" : "Criptografia de ponta-a-ponta poderosa na interface web",
    "Speed-up with ADA engine" : "Aceleração com o ADA engine"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
