OC.L10N.register(
    "suspicious_login",
    {
    "New login location detected" : "检测到新的登录地点",
    "More info about the suspicious IP address available on %s" : "关于更多可疑IP地址的详细资料，请见%s",
    "Open %s ↗" : "打开%s ↗",
    "Suspicious Login" : "可疑登录行为",
    "New login detected" : "检测到新的登录行为",
    "Detect and warn about suspicious IPs logging into Nextcloud\n\t" : "检测并警告登录到 Nextcloud 的可疑 IP 地址\n\t",
    "A new login into your account was detected. The IP address %s was classified as suspicious. If this was you, you can ignore this message. Otherwise you should change your password." : "检测到您账号的一个新的登录行为。IP地址 %s 被归类为可疑。如果这是您自己，您可忽略此消息。否则您应该修改您的密码。"
},
"nplurals=1; plural=0;");
