OC.L10N.register(
    "appstore",
    {
    "Apps" : "ئەپلەر",
    "App name" : "ئەپ ئىسمى",
    "Version" : "نەشرى",
    "Groups" : "گۇرۇپپىلار",
    "Actions" : "ھەرىكەتلەر",
    "Show details" : "تەپسىلاتلارنى كۆرسەت",
    "Grid view" : "كاتەكچە كۆرۈنۈش",
    "Cancel" : "ۋاز كەچ",
    "Learn more" : "تېخىمۇ كۆپ بىلىڭ",
    "Daemon" : "Daemon",
    "Deploy Daemon" : "Daemon نى ئورۇنلاشتۇرۇڭ",
    "Type" : "تىپ",
    "Name" : "ئاتى",
    "Display Name" : "كۆرسىتىش ئىسمى",
    "GPUs support" : "GPUs نى قوللايدۇ",
    "Compute device" : "ھېسابلاش ئۈسكۈنىسى",
    "Advanced deploy options" : "ئىلغار ئورۇنلاشتۇرۇش تاللانمىلىرى",
    "Edit ExApp deploy options before installation" : "قاچىلاشتىن بۇرۇن ExApp ئورۇنلاشتۇرۇش تاللانمىلىرىنى تەھرىرلەڭ",
    "Configured ExApp deploy options. Can be set only during installation" : "ExApp ئورۇنلاشتۇرۇش تاللانمىلىرى سەپلەندى. پەقەت ئورنىتىش جەريانىدا تەڭشىگىلى بولىدۇ.",
    "Environment variables" : "مۇھىت مىقدارلىرى",
    "ExApp container environment variables" : "ExApp كونتېينېر مۇھىت ئۆزگەرگۈچىلىرى",
    "No environment variables defined" : "ھېچقانداق مۇھىت مىقدارلىرى بەلگىلەنمىدى",
    "Mounts" : "ئورناتمىلار",
    "Define host folder mounts to bind to the ExApp container" : "ExApp قاچىسىغا باغلىنىدىغان host قىسقۇچ ئۇلىنىشلىرىنى بەلگىلەڭ",
    "Must exist on the Deploy daemon host prior to installing the ExApp" : "ExApp نى قاچىلاشتىن بۇرۇن Deploy daemon كومپيۇتېرىدا مەۋجۇت بولۇشى كېرەك",
    "Host path" : "سېستىما يولى",
    "Container path" : "قاچىلىغۇچ يولى",
    "Read-only" : "ئوقۇشقىلا-بولىدىغان",
    "Remove mount" : "ئورناتمىنى چىقىرىۋەت",
    "New mount" : "يېڭى ئورناتما",
    "Enter path to host folder" : "سېستىما قىسقۇچىنىڭ يولىنى كىرگۈز",
    "Enter path to container folder" : "قاچىلىغۇچ قىسقۇچىنىڭ يولىنى كىرگۈز",
    "Toggle read-only mode" : "ئوقۇشقىلا-بولىدىغان ھالىتىنى ئۆزگەرت",
    "Confirm adding new mount" : "يېڭى ئورناتما قېتىشنى جەزىملەشتۈر",
    "Confirm" : "جەزملەشتۈرۈڭ",
    "Cancel adding mount" : "ئورناتما قېتىشنى ئەمەلدىن قالدۇر",
    "Add mount" : "ئورناتما قوش",
    "ExApp container mounts" : "ExApp قاچىلىغۇچ ئورناتمىلىرى",
    "No mounts defined" : "ھېچقانداق ئورناتما تېپىلمىدى",
    "Description" : "چۈشەندۈرۈش",
    "View in store" : "دۇكاندا كۆرۈش",
    "Visit website" : "توربېكەتنى زىيارەت قىلىڭ",
    "Usage documentation" : "ئىشلىتىش ھۆججىتى",
    "Admin documentation" : "باشقۇرغۇچى ھۆججەتلىرى",
    "Developer documentation" : "ئاچقۇچىلار ھۆججىتى",
    "Details" : "تەپسىلاتى",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "تۆۋەندىكى باغلىنىشلار ئەمەلگە ئاشمىغاچقا ، بۇ دېتالنى قاچىلىغىلى بولمايدۇ:",
    "Latest updated" : "ئەڭ يېڭى يېڭىلاندى",
    "Author" : "ئاپتور",
    "Categories" : "سەھىپىلەر",
    "Resources" : "بايلىق",
    "Changelog" : "ئۆزگىرىش خاتىرسى",
    "Supported" : "قوللايدۇ",
    "Featured" : "ئالاھىدە ئەپلەر",
    "This app is supported via your current Nextcloud subscription." : "بۇ ئەپ نۆۋەتتىكى Nextcloud مۇشتەرىلىكىڭىز ئارقىلىق قوللىنىدۇ.",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "ئالاھىدە ئەپلەر جەمئىيەت تەرىپىدىن ۋە تەرەققىي قىلدۇرۇلغان. ئۇلار مەركىزى ئىقتىدار بىلەن تەمىنلەيدۇ ھەمدە ئىشلەپچىقىرىشقا تەييار.",
    "Community rating: {score}/5" : "مەھەللە دەرىجىسى: {score} / 5",
    "Choose Deploy Daemon for {appName}" : "{appName} نىڭ ئورۇنلاشتۇرۇش قوزغاتقۇچىسىنى تاللاڭ",
    "No Deploy daemons configured" : "ھېچقانداق ئورۇنلاشتۇرۇش لايىھىسى سەپلەنمىگەن",
    "Register a custom one or setup from available templates" : "ئىختىيارى قېلىپ ياكى تىزىملىتىڭ",
    "Manage Deploy daemons" : "ئورۇنلاشتۇرۇش قوزغاتقۇچىسىنى باشقۇرۇش",
    "Registered Deploy daemons list" : "تىزىملاتقان دامونلار تىزىملىكى",
    "Default" : "كۆڭۈلدىكى",
    "Carousel" : "كورسۇل",
    "Previous slide" : "ئالدىنقى تام تەسۋىر",
    "Next slide" : "كېيىنكى تام تەسۋىر",
    "Choose slide to display" : "كۆرسىتىش ئۈچۈن تام تەسۋىرنى تاللاڭ",
    "{index} of {total}" : "{index} of {total}",
    "Limit to groups" : "گۇرۇپپىلارغا چەك قويۇڭ",
    "Save" : "ساقلا",
    "Update all" : "ھەممىنى يېڭىلا",
    "Loading app list" : "ئەپ تىزىملىكى",
    "Search everywhere" : "ھەممە يەردىن ئىزدەڭ",
    "Download and enable all" : "ھەممىنى چۈشۈرۈپ قوزغىتىڭ",
    "Could not load app discover section" : "ئەپ بايقاش بۆلىكىنى يۈكلىيەلمىدى",
    "Could not render element" : "ئېلېمېنتنى بېرەلمىدى",
    "Nothing to show" : "كۆرسىتىدىغان ھېچنېمە يوق",
    "Could not load section content from app store." : "ئەپ دۇكىنىدىن بۆلەك مەزمۇنىنى يۈكلىيەلمىدى.",
    "Loading" : "يۈكلەۋاتىدۇ",
    "Fetching the latest news…" : "ئەڭ يېڭى خەۋەرلەرگە ئېرىشىش…",
    "Loading categories" : "تۈرلەرنى يۈكلەۋاتىدۇ",
    "Version {version}, {license}-licensed" : "نەشرى {version} ، {license} ئىجازەتنامىسى",
    "Version {version}" : "نەشرى {version}",
    "Disable" : "چەكلە",
    "Enable" : "قوزغىتىش",
    "Download and enable" : "چۈشۈرۈش ۋە قوزغىتىش",
    "Rate the app" : "ئەپكە باھا بېرىڭ",
    "Report a bug" : "خاتالىق مەلۇم قىلىڭ",
    "Remove" : "ئۆچۈرۈڭ",
    "Update to {version}" : "{version} يېڭىلاش",
    "Discover" : "بايقاش",
    "Your apps" : "ئەپلىرىڭىز",
    "Active apps" : "ئاكتىپ ئەپلەر",
    "Disabled apps" : "چەكلەنگەن ئەپلەر",
    "Updates" : "يېڭىلانمىلار",
    "App bundles" : "ئەپ بوغچىسى",
    "Featured apps" : "ئالاھىدە ئەپلەر",
    "Supported apps" : "قوللايدىغان ئەپلەر",
    "An error occurred during the request. Unable to proceed." : "تەلەپ جەريانىدا خاتالىق كۆرۈلدى. داۋاملاشتۇرالمىدى."
},
"nplurals=2; plural=(n != 1);");
