OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "Procedura guidata di primo avvio",
    "Add your profile information! For example your email is needed to receive notifications." : "Aggiungi le tue informazioni di profilo! Ad esempio, il tuo indirizzo di posta è necessario per ricevere le notifiche.",
    "Add your profile information! For example your email is needed to receive notifications and reset your password." : "Aggiungi le tue informazioni di profilo! Ad esempio, il tuo indirizzo di posta è necessario per ricevere le notifiche e per ripristinare la password.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Aggiungi le informazioni del tuo profilo! Imposta un'immagine del profilo per una analisi veloce di tutte le funzionalità.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Aggiungi le informazioni del profilo! Imposta un nome completo per una analisi veloce delle funzionalità.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Aggiungi le informazioni del profilo! Imposta un'immagine del profilo per una analisi delle funzionalità.",
    "App recommendation: Calendar" : "App consigliata: Calendario",
    "Schedule work & meetings, synced with all your devices." : "Pianificare lavoro e riunioni, sincronizzati con tutti i tuoi dispositivi.",
    "App recommendation: Contacts" : "App consigliata: Contatti",
    "Keep your colleagues and friends in one place without leaking their private info." : "Tieni i tuoi colleghi e i tuoi amici in un posto proteggendo le loro Informazioni personali.",
    "App recommendation: Mail" : "App consigliata: Mail",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Applicazione di posta elettronica semplice e ben integrata con File, Contatti e Calendario.",
    "App recommendation: Tasks" : "Applicazione consigliata: Attività",
    "Sync tasks from various devices with your Nextcloud and edit them online." : "Sincronizza le attività tra diversi dispositivi con il tuo Nextcloud e modificale in linea.",
    "App recommendation: Deck" : "Applicazione consigliata: Deck",
    "Kanban style organization for personal planning and team projects." : "Organizzazione in stile Kanban per la pianificazione personale e per i progetti di squadra.",
    "App recommendation: Forms" : "Applicazione consigliata: Forms",
    "Simple surveys and questionnaires, self-hosted" : "Sondaggi e questionari semplici, autonomi",
    "App recommendation: Recognize" : "Applicazione consigliata: Recognize",
    "Smart media tagging for Nextcloud" : "Etichettatura intelligente dei media per Nextcloud",
    "App recommendation: Group folders" : "Applicazione consigliata: Cartelle di gruppo",
    "Admin-configured folders shared by everyone in a group." : "Cartelle configurate dall'amministratore condivise da chiunque in un gruppo.",
    "App recommendation: Whiteboard" : "Applicazione consigliata: Lavagna",
    "Create and share whiteboards with others and collaborate in real-time." : "Crea e condividi lavagne con altri e collabora in tempo reale.",
    "Connect your calendar" : "Connetti il tuo calendario",
    "Connect your contacts" : "Connetti i tuoi contatti",
    "Access files via WebDAV" : "Accedi ai file tramite WebDAV",
    "Download macOS/iOS configuration profile" : "Scarica il profilo di configurazione per macOS/iOS",
    "Desktop client" : "Client desktop",
    "Android app on Google Play Store" : "Applicazione Android su Google Play Store",
    "Android app on F-Droid" : "Applicazione Android su F-Droid",
    "iOS app" : "Applicazione iOS",
    "About & What's new" : "Informazioni e novità",
    "A welcome and introduction wizard for Nextcloud" : "Una procedura guidata di benvenuto e introduzione a Nextcloud",
    "This application enables a pop-up window when a user first logs into Nextcloud. This window welcomes new users to Nextcloud, and contains links to the standard desktop client, Android app, and the iOS app. The window also shows a link for accessing Nextcloud via WebDAV. At any time, the first run wizard can be opened again via link \"About\" on settings menu.\nThe First run wizard can be customized to meet specific design goals, or to change links and messages. Create an appropriate theme following the Theming documentation, and changes to the look and feel of this Wizard are simple. More information is available in the first run wizard documentation, as well as the theming documentation." : "Questa applicazione abilita una finestra a comparsa quando un utente accede per la prima volta Nextcloud. Questa finestra dà il benvenuto ai nuovi utenti di Nextcloud e contiene collegamenti al client desktop standard, all'applicazione Android e all'applicazione iOS. La finestra mostra anche un collegamento per accedere a Nextcloud tramite WebDAV. In qualsiasi momento, la procedura guidata di primo avvio può essere aperta tramite il collegamento \"Informazioni\" nel menu delle impostazioni.\nLa procedura guidata di primo avvio può essere personalizzata per rispondere a obiettivi specifici di design, o modificare collegamenti e messaggi. Creare un tema appropriato seguendo la documentazione di Temi, e cambiare l'aspetto della procedura guidata è semplice. Altre informazioni sono disponibili nella documentazione relativa alla procedura guidata di primo avvio così come nella documentazione relativa ai temi.",
    "Download on Apple app store" : "Scarica dall'app store di Apple",
    "Download on Google play store" : "Scarica dal Play store di Google",
    "Go to previous page" : "Vai alla pagina precedente",
    "Close" : "Chiudi",
    "More about Nextcloud" : "Informazioni su Nextcloud",
    "Explore more apps ↗" : "Esplora altre applicazioni ↗",
    "Extend the functionality of Nextcloud with hundreds of community-developed apps." : "Estendi le funzionalità di Nextcloud con centinaia di app sviluppate dalla comunità.",
    "Get involved! ↗" : "Partecipa! ↗",
    "Be a part of the community that helps build, design, translate and promote Nextcloud!" : "Fai parte della comunità che aiuta a costruire, progettare, tradurre e promuovere Nextcloud!",
    "Need help? ↗" : "Serve aiuto? ↗",
    "Find out more about your Nextcloud setup with the admin, user or developer documentation." : "Scopri di più sulla tua configurazione di Nextcloud con la documentazione per amministratori, utenti o sviluppatori.",
    "For large organisations ↗" : "Per grandi organizzazioni ↗",
    "Get Nextcloud Enterprise for mission critical environments where advanced security and compliance are important." : "Ottieni Nextcloud Enterprise per ambienti critici in cui la sicurezza avanzata e la conformità sono importanti.",
    "Seamless integration with your devices." : "Integrazione senza soluzione di continuità con i tuoi dispositivi.",
    "Sync your files across your devices with the desktop and mobile apps, and connect your calendar and contacts." : "Sincronizza i tuoi file su tutti i dispositivi con le app per desktop e mobile, e collega il tuo calendario e contatti.",
    "Desktop app ↗" : "Applicazione desktop ↗",
    "Download For Windows, Mac OS and Linux." : "Scarica per Windows, Mac OS e Linux.",
    "Calendar and contacts ↗" : "Calendario e contatti ↗",
    "Connect your calendar and contacts with your devices." : "Collega il tuo calendario e contatti ai tuoi dispositivi.",
    "Welcome to {cloudName}!" : "Benvenuto su {cloudName}!",
    "Skip" : "Salta",
    "This Nextcloud is on version {version}" : "Questo Nextcloud è alla versione {version}",
    "A collaboration platform that puts you in control" : "Una piattaforma di collaborazione che ti mette al controllo",
    "Privacy" : "Riservatezza",
    "Host your data and files where you decide." : "Ospita i tuoi dati e file dove decidi tu.",
    "Productivity" : "Produttività",
    "Collaborate and communicate across any platform." : "Collabora e comunica attraverso qualsiasi piattaforma.",
    "Interoperability" : "Interoperabilità",
    "Import and export anything you want with open standards." : "Importa ed esporta qualsiasi cosa desideri con standard aperti.",
    "Community" : "Comunità",
    "Enjoy constant improvements from a thriving open-source community." : "Goditi continui miglioramenti da una fiorente comunità open-source.",
    "Nextcloud Hub {version} release" : "Nextcloud Hub versione {version}",
    "Read more about it on the Nextcloud Hub {version} blog" : "Leggi di più sul blog di Nextcloud Hub {version}",
    "Find out more on the blog" : "Scopri di più sul blog",
    "Read the Nextcloud Hub {version} blog" : "Leggi il blog di Nextcloud Hub {version}",
    "Share your opinion about Nextcloud Hub {version}" : "Condividi la tua opinione su Nextcloud Hub {version}",
    "Share via email" : "Condividi tramite email",
    "Share on {socialMedia}" : "Condividi su {socialMedia}",
    "New in Nextcloud Hub {version}" : "Novità in Nextcloud Hub {version}",
    "Connect other apps to {productName}" : "Connetti altre applicazioni a {productName}",
    "Besides the mobile apps and desktop client you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to {productName}." : "Oltre alle applicazioni mobili e al client desktop, puoi connettere qualsiasi altro software che supporti i protocolli WebDAV/CalDAV/CardDAV a {productName}.",
    "Apps to connect to {productName}" : "Applicazioni da connettere a {productName}",
    "Set up sync clients using an {linkStart}app password{linkEnd}. That way you can make sure you are able to revoke access in case you lose that device." : "Imposta i client di sincronizzazione utilizzando una {linkStart}password di applicazione{linkEnd}. In tal modo, puoi assicurarti di essere in grado di revocare l'accesso nel caso in cui tu perda il dispositivo.",
    "Get the apps to sync your files" : "Scarica le applicazioni per sincronizzare i tuoi file",
    "{productName} gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "{productName} ti fornisce l'accesso ai tuoi file ovunque tu sia. I nostri client per desktop e mobile sono facili da utilizzare e sono disponibili gratuitamente per tutte le principali piattaforme.",
    "App for syncing" : "Applicazione per sincronizzazione",
    "URL copied" : "URL copiato",
    "Could not copy the URL, please copy manually" : "Impossibile copiare l'URL, copialo manualmente:",
    "Server address" : "Indirizzo del server",
    "Use this link to connect your apps and desktop client to this server:" : "Usa questo collegamento per connettere le tue applicazioni e il client desktop a questo server:",
    "Get to know the new features of Hub {version}" : "Scopri le nuove funzionalità di Hub {version}",
    "What's new?" : "Cosa c'è di nuovo?",
    "Nextcloud on all your devices" : "Nextcloud in tutti i tuoi dispositivi",
    "Nextcloud Hub {version}" : "Nextcloud Hub {version}",
    "Share on social media" : "Condividi nei social",
    "Get started!" : "Cominciamo!",
    "Global redesign and usability lift" : "Riprogettazione globale e miglioramento dell'usabilità",
    "New Office UI: colors, tabs, bars" : "Nuova UI dell'ufficio: colori, schede, barre",
    "Performance and stability boost" : "Miglioramento delle prestazioni e della stabilità",
    "New AI Agency tools unlocked" : "Nuovi strumenti Agenti AI sbloccati",
    "Talk threads & live transcription" : "Argomenti e trascrizione in tempo reale su Talk",
    "Calendar: date poll for participants" : "Calendario: sondaggio sulla data per i partecipanti",
    "Intuitive file search" : "Ricerca intuitiva dei file",
    "Teams 2.0 & quick Guest accounts" : "Teams 2.0 e account Ospite rapidi",
    "Quick presets & many other admin updates" : "Preimpostazioni rapide e molti altri aggiornamenti per gli amministratori",
    "Vue3, WebSockets and more OpenAPI for devs" : "Vue3, WebSocket e altre OpenAPI per sviluppatori",
    "… and much more!" : "… e molto altro ancora!",
    "Nextcloud Hub 25 Autumn – Your digital workspace, ready in no time ⚡" : "Nextcloud Hub 25 Autunno – Il tuo spazio di lavoro digitale, pronto in un attimo ⚡"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
