.tiled-row[data-v-c003b6e3]{display:flex}.tiled-container[data-v-f2880905]{height:100%}.tiled-container .tiled-row[data-v-f2880905]{display:flex}.vs-container[data-v-cb2732da]{overflow-y:scroll;height:100%}.vs-rows-container[data-v-cb2732da]{box-sizing:border-box;will-change:scroll-position,padding;contain:layout paint style}.files-list-viewer[data-v-2ca16ec8]{height:100%;position:relative}.files-list-viewer__placeholder[data-v-2ca16ec8]{background:var(--color-primary-element-light);width:100%;height:100%;border:2px solid var(--color-main-background)}.files-list-viewer .tiled-container[data-v-2ca16ec8]{flex-basis:0}.files-list-viewer ul[data-v-2ca16ec8]{display:flex;flex-wrap:wrap}.files-list-viewer ul li[data-v-2ca16ec8]:not(.last-tiled-rows){flex-grow:1}.files-list-viewer__section-header[data-v-2ca16ec8]{position:sticky;top:0;z-index:3;background:var(--color-main-background)}.files-list-viewer__loader[data-v-2ca16ec8]{margin:50px 0}
