OC.L10N.register(
    "provisioning_api",
    {
    "Logged in account must be an administrator or have authorization to edit this setting." : "A conta logada deve ser um administrador ou ter autorização para editar esta configuração.",
    "Could not create non-existing user ID" : "Não foi possível criar um ID de usuário inexistente",
    "User already exists" : "Usuário já existe",
    "Group %1$s does not exist" : "Grupo %1$s não existe",
    "Insufficient privileges for group %1$s" : "Privilégios insuficientes para o grupo %1$s",
    "Sub-admin group does not exist" : "O grupo de subadministradores não existe",
    "Cannot create sub-admins for admin group" : "Não é possível criar subadministradores para o grupo de administradores",
    "No permissions to promote sub-admins" : "Sem permissões para promover subadministradores",
    "Invalid password value" : "Valor de senha inválido",
    "An email address is required, to send a password link to the user." : "É necessário um endereço de e-mail, para enviar um link de senha para o usuário.",
    "Required email address was not provided" : "O endereço de e-mail obrigatório não foi fornecido",
    "User creation failed" : "Falha na criação do usuário",
    "Cannot change display name for this user" : "Não é possível alterar o nome de exibição deste usuário",
    "Invalid email address" : "Endereço de e-mail inválido",
    "Invalid language" : "Idioma inválido",
    "Insufficient permissions to change quota" : "Permissões insuficientes para alterar a cota",
    "Insufficient permissions to change groups" : "Permissões insuficientes para alterar grupos",
    "Group %s does not exist" : "Grupo %s não existe",
    "Insufficient permissions to change sub-admin groups" : "Permissões insuficientes para alterar grupos de subadministradores",
    "Insufficient permissions to change manager" : "Permissões insuficientes para alterar o gerente",
    "Invalid quota value: %1$s" : "Valor de cota inválido: %1$s",
    "Invalid quota value. %1$s is exceeding the maximum quota" : "Valor de cota inválido. %1$s está excedendo a cota máxima",
    "Unlimited quota is forbidden on this instance" : "Cota ilimitada é proibida nesta instância",
    "Setting the password is not supported by the users backend" : "A configuração da senha não é suportada pelo back-end dos usuários",
    "Invalid locale" : "Configuração regional inválida",
    "Invalid timezone" : "Fuso horário inválido",
    "Invalid first day of week" : "Primeiro dia da semana inválido",
    "Cannot remove yourself from the admin group" : "Não é possível remover a si mesmo do grupo de administradores",
    "Cannot remove yourself from this group as you are a sub-admin" : "Não é possível remover a si mesmo desse grupo, pois você é um subadministrador",
    "Not viable to remove user from the last group you are sub-admin of" : "Não é viável remover o usuário do último grupo do qual você é subadministrador",
    "User does not exist" : "Usuário não existe",
    "User is not a sub-admin of this group" : "O usuário não é um subadministrador deste grupo",
    "Email address not available" : "Endereço de e-mail não disponível",
    "Sending email failed" : "Falha ao enviar e-mail",
    "Logged in account is not mail address owner" : "Conta logada não é o proprietário do endereço de e-mail",
    "Email confirmation" : "Verificação de correio eletrónico.",
    "To enable the email address %s please click the button below." : "Para ativar o endereço de correio eletrónico %s, clique no botão abaixo.",
    "Confirm" : "Confirmar",
    "Email was already removed from account and cannot be confirmed anymore." : "O endereço já foi removido da conta e não pode mais ser confirmado.",
    "Could not verify mail because the token is expired." : "Não foi possível verificar o correio porque o token expirou.",
    "Could not verify mail because the token is invalid." : "Não foi possível verificar o endereço porque o token é inválido.",
    "An unexpected error occurred. Please contact your admin." : "Ocorreu um erro inesperado. Contacte o seu administrador de sistemas.",
    "Email confirmation successful" : "Endereço confirmado com sucesso",
    "Provisioning API" : "API de aprovisionamento",
    "This application enables a set of APIs that external systems can use to manage accounts, groups and apps." : "Este aplicativo habilita um conjunto de APIs que sistemas externos podem usar para gerenciar contas, grupos e aplicativos.",
    "This application enables a set of APIs that external systems can use to create, edit, delete and query account\n\t\tattributes, query, set and remove groups, set quota and query total storage used in Nextcloud. Group admin accounts\n\t\tcan also query Nextcloud and perform the same functions as an admin for groups they manage. The API also enables\n\t\tan admin to query for active Nextcloud applications, application info, and to enable or disable an app remotely.\n\t\tOnce the app is enabled, HTTP requests can be used via a Basic Auth header to perform any of the functions\n\t\tlisted above. More information is available in the Provisioning API documentation, including example calls\n\t\tand server responses." : "Este aplicativo habilita um conjunto de APIs que sistemas externos podem usar para criar, editar, excluir e consultar atributos\n\t\tde conta, consultar, definir e remover grupos, definir cotas e consultar o armazenamento total usado no Nextcloud. As contas de administrador de grupo\n\t\ttambém podem consultar o Nextcloud e executar as mesmas funções de um administrador para os grupos que gerenciam. A API também permite\n\t\tque um administrador consulte os aplicativos ativos do Nextcloud, as informações do aplicativo e ative ou desative um aplicativo remotamente.\n\t\tDepois que o aplicativo é ativado, as solicitações HTTP podem ser usadas por meio de um cabeçalho Basic Auth para executar qualquer uma das funções\n\t\tlistadas acima. Mais informações estão disponíveis na documentação da API de Provisionamento, incluindo exemplos de solicitações\n\t\te respostas do servidor."
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
