OC.L10N.register(
    "contactsinteraction",
    {
    "Recently contacted" : "Äskettäin yhteydessä",
    "Contacts Interaction" : "Yhteystietojen vuorovaikutteisuus"
},
"nplurals=2; plural=(n != 1);");
