OC.L10N.register(
    "dav",
    {
    "Calendar" : "Kalender",
    "Tasks" : "Tugas",
    "Personal" : "Pribadi",
    "{actor} created calendar {calendar}" : "{actor} membuat kalender {calendar}",
    "You created calendar {calendar}" : "Anda membuat kalender {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} menghapus kalender {calendar}",
    "You deleted calendar {calendar}" : "Anda menghapus kalender {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} memperbarui kalender {calendar}",
    "You updated calendar {calendar}" : "Anda memperbarui kalender {calendar}",
    "{actor} restored calendar {calendar}" : "{actor} memulihkan kalender {calendar}",
    "You restored calendar {calendar}" : "Anda memulihkan kalender {calendar}",
    "You shared calendar {calendar} as public link" : "Anda membagikan kalender {calendar} sebagai tautan publik",
    "You removed public link for calendar {calendar}" : "Anda menghapus tautan publik untuk kalender {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} membagikan kalender {calendar} kepada Anda",
    "You shared calendar {calendar} with {user}" : "Anda membagikan kalender {calendar} dengan {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} membagikan kalender {calendar} dengan {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} membatalkan berbagi kalender {calendar} dari Anda",
    "You unshared calendar {calendar} from {user}" : "Anda membatalkan berbagi kalender {calendar} dari {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} membatalkan berbagi kalender {calendar} dari {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} membatalkan berbagi kalender {calendar} dari diri mereka sendiri",
    "You shared calendar {calendar} with group {group}" : "Anda membagikan kalender {calendar} dengan grup {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} membagikan kalender {calendar} dengan grup {group}",
    "You unshared calendar {calendar} from group {group}" : "Anda membatalkan berbagi kalender {calendar} dari grup {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} membatalkan berbagi kalender {calendar} dari grup {group}",
    "Untitled event" : "Acara tanpa judul",
    "{actor} created event {event} in calendar {calendar}" : "{actor} membuat acara {event} di kalender {calendar}",
    "You created event {event} in calendar {calendar}" : "Anda membuat acara {event} di kalender {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} menghapus acara {event} dari kalender {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Anda menghapus acara {event} dari kalender {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} memperbarui acara {event} di kalender {calendar}",
    "You updated event {event} in calendar {calendar}" : "Anda memperbarui acara {event} di kalender {calendar}",
    "{actor} moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "{actor} memindahkan acara {event} dari kalender {sourceCalendar} ke kalender {targetCalendar}",
    "You moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "Anda memindahkan acara {event} dari kalender {sourceCalendar} ke kalender {targetCalendar}",
    "{actor} restored event {event} of calendar {calendar}" : "{actor} memulihkan acara {event} dari kalender {calendar}",
    "You restored event {event} of calendar {calendar}" : "Anda memulihkan acara {event} dari kalender {calendar}",
    "Busy" : "Sibuk",
    "{actor} created to-do {todo} in list {calendar}" : "{actor} membuat tugas {todo} di daftar {calendar}",
    "You created to-do {todo} in list {calendar}" : "Anda membuat tugas {todo} di daftar {calendar}",
    "{actor} deleted to-do {todo} from list {calendar}" : "{actor} menghapus tugas {todo} dari daftar {calendar}",
    "You deleted to-do {todo} from list {calendar}" : "Anda menghapus tugas {todo} dari daftar {calendar}",
    "{actor} updated to-do {todo} in list {calendar}" : "{actor} memperbarui tugas {todo} di daftar {calendar}",
    "You updated to-do {todo} in list {calendar}" : "Anda memperbarui tugas {todo} di daftar {calendar}",
    "{actor} solved to-do {todo} in list {calendar}" : "{actor} menyelesaikan tugas {todo} di daftar {calendar}",
    "You solved to-do {todo} in list {calendar}" : "Anda menyelesaikan tugas {todo} di daftar {calendar}",
    "{actor} reopened to-do {todo} in list {calendar}" : "{actor} membuka kembali tugas {todo} di daftar {calendar}",
    "You reopened to-do {todo} in list {calendar}" : "Anda membuka kembali tugas {todo} di daftar {calendar}",
    "{actor} moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "{actor} memindahkan tugas {todo} dari daftar {sourceCalendar} ke daftar {targetCalendar}",
    "You moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "Anda memindahkan tugas {todo} dari daftar {sourceCalendar} ke daftar {targetCalendar}",
    "Calendar, contacts and tasks" : "Kalender, kontak, dan tugas",
    "A <strong>calendar</strong> was modified" : "<strong>Kalender</strong> telah diubah",
    "A calendar <strong>event</strong> was modified" : "Sebuah <strong>acara</strong> kalender telah diubah",
    "A calendar <strong>to-do</strong> was modified" : "Sebuah <strong>tugas</strong> kalender telah diubah",
    "Contact birthdays" : "Ulang tahun kontak",
    "Death of %s" : "Wafatnya %s",
    "Accept" : "Terima",
    "Decline" : "Tolak",
    "Untitled calendar" : "Kalender tanpa judul",
    "Calendar:" : "Kalender:",
    "Date:" : "Tanggal:",
    "Where:" : "Tempat:",
    "Description:" : "Deskripsi:",
    "_%n year_::_%n years_" : ["%n tahun"],
    "_%n month_::_%n months_" : ["%n bulan"],
    "_%n day_::_%n days_" : ["%n hari"],
    "_%n hour_::_%n hours_" : ["%n jam"],
    "_%n minute_::_%n minutes_" : ["%n menit"],
    "%s (in %s)" : "%s (dalam %s)",
    "%s (%s ago)" : "%s (%s yang lalu)",
    "Calendar: %s" : "Kalender: %s",
    "Date: %s" : "Tanggal: %s",
    "Description: %s" : "Deskripsi: %s",
    "Where: %s" : "Di mana: %s",
    "%1$s via %2$s" : "%1$s melalui %2$s",
    "In the past on %1$s for the entire day" : "Di masa lalu pada %1$s sepanjang hari",
    "_In %n minute on %1$s for the entire day_::_In %n minutes on %1$s for the entire day_" : ["Dalam %n menit pada %1$s untuk sepanjang hari"],
    "_In %n hour on %1$s for the entire day_::_In %n hours on %1$s for the entire day_" : ["Dalam %n jam pada %1$s untuk sepanjang hari"],
    "_In %n day on %1$s for the entire day_::_In %n days on %1$s for the entire day_" : ["Dalam %n hari pada %1$s untuk sepanjang hari"],
    "_In %n week on %1$s for the entire day_::_In %n weeks on %1$s for the entire day_" : ["Dalam %n minggu pada %1$s untuk sepanjang hari"],
    "_In %n month on %1$s for the entire day_::_In %n months on %1$s for the entire day_" : ["Dalam %n bulan pada %1$s untuk sepanjang hari"],
    "_In %n year on %1$s for the entire day_::_In %n years on %1$s for the entire day_" : ["Dalam %n tahun pada %1$s untuk sepanjang hari"],
    "In the past on %1$s between %2$s - %3$s" : "Di masa lalu pada %1$s antara %2$s - %3$s",
    "_In %n minute on %1$s between %2$s - %3$s_::_In %n minutes on %1$s between %2$s - %3$s_" : ["Dalam %n menit pada %1$s antara %2$s - %3$s"],
    "_In %n hour on %1$s between %2$s - %3$s_::_In %n hours on %1$s between %2$s - %3$s_" : ["Dalam %n jam pada %1$s antara %2$s - %3$s"],
    "_In %n day on %1$s between %2$s - %3$s_::_In %n days on %1$s between %2$s - %3$s_" : ["Dalam %n hari pada %1$s antara %2$s - %3$s"],
    "_In %n week on %1$s between %2$s - %3$s_::_In %n weeks on %1$s between %2$s - %3$s_" : ["Dalam %n minggu pada %1$s antara %2$s - %3$s"],
    "_In %n month on %1$s between %2$s - %3$s_::_In %n months on %1$s between %2$s - %3$s_" : ["Dalam %n bulan pada %1$s antara %2$s - %3$s"],
    "_In %n year on %1$s between %2$s - %3$s_::_In %n years on %1$s between %2$s - %3$s_" : ["Dalam %n tahun pada %1$s antara %2$s - %3$s"],
    "Could not generate when statement" : "Tidak dapat membuat pernyataan waktu",
    "Every Day for the entire day" : "Setiap hari sepanjang hari",
    "Every Day for the entire day until %1$s" : "Setiap hari sepanjang hari hingga %1$s",
    "Every Day between %1$s - %2$s" : "Setiap hari antara %1$s - %2$s",
    "Every Day between %1$s - %2$s until %3$s" : "Setiap hari antara %1$s - %2$s hingga %3$s",
    "Every %1$d Days for the entire day" : "Setiap %1$d hari sepanjang hari",
    "Every %1$d Days for the entire day until %2$s" : "Setiap %1$d hari sepanjang hari hingga %2$s",
    "Every %1$d Days between %2$s - %3$s" : "Setiap %1$d hari antara %2$s - %3$s",
    "Every %1$d Days between %2$s - %3$s until %4$s" : "Setiap %1$d hari antara %2$s - %3$s hingga %4$s",
    "Could not generate event recurrence statement" : "Tidak dapat membuat pernyataan pengulangan acara",
    "Every Week on %1$s for the entire day" : "Setiap minggu pada %1$s sepanjang hari",
    "Every Week on %1$s for the entire day until %2$s" : "Setiap minggu pada %1$s sepanjang hari hingga %2$s",
    "Every Week on %1$s between %2$s - %3$s" : "Setiap minggu pada %1$s antara %2$s - %3$s",
    "Every Week on %1$s between %2$s - %3$s until %4$s" : "Setiap minggu pada %1$s antara %2$s - %3$s hingga %4$s",
    "Every %1$d Weeks on %2$s for the entire day" : "Setiap %1$d minggu pada %2$s sepanjang hari",
    "Every %1$d Weeks on %2$s for the entire day until %3$s" : "Setiap %1$d minggu pada %2$s sepanjang hari hingga %3$s",
    "Every %1$d Weeks on %2$s between %3$s - %4$s" : "Setiap %1$d minggu pada %2$s antara %3$s - %4$s",
    "Every %1$d Weeks on %2$s between %3$s - %4$s until %5$s" : "Setiap %1$d minggu pada %2$s antara %3$s - %4$s hingga %5$s",
    "Every Month on the %1$s for the entire day" : "Setiap bulan pada tanggal %1$s sepanjang hari",
    "Every Month on the %1$s for the entire day until %2$s" : "Setiap bulan pada tanggal %1$s sepanjang hari hingga %2$s",
    "Every Month on the %1$s between %2$s - %3$s" : "Setiap bulan pada tanggal %1$s antara %2$s - %3$s",
    "Every Month on the %1$s between %2$s - %3$s until %4$s" : "Setiap bulan pada tanggal %1$s antara %2$s - %3$s hingga %4$s",
    "Every %1$d Months on the %2$s for the entire day" : "Setiap %1$d bulan pada tanggal %2$s sepanjang hari",
    "Every %1$d Months on the %2$s for the entire day until %3$s" : "Setiap %1$d bulan pada tanggal %2$s sepanjang hari hingga %3$s",
    "Every %1$d Months on the %2$s between %3$s - %4$s" : "Setiap %1$d bulan pada tanggal %2$s antara %3$s - %4$s",
    "Every %1$d Months on the %2$s between %3$s - %4$s until %5$s" : "Setiap %1$d bulan pada tanggal %2$s antara %3$s - %4$s hingga %5$s",
    "Every Year in %1$s on the %2$s for the entire day" : "Setiap tahun pada bulan %1$s tanggal %2$s sepanjang hari",
    "Every Year in %1$s on the %2$s for the entire day until %3$s" : "Setiap tahun pada bulan %1$s tanggal %2$s sepanjang hari hingga %3$s",
    "Every Year in %1$s on the %2$s between %3$s - %4$s" : "Setiap tahun pada bulan %1$s tanggal %2$s antara %3$s - %4$s",
    "Every Year in %1$s on the %2$s between %3$s - %4$s until %5$s" : "Setiap tahun pada bulan %1$s tanggal %2$s antara %3$s - %4$s hingga %5$s",
    "Every %1$d Years in %2$s on the %3$s for the entire day" : "Setiap %1$d tahun pada bulan %2$s tanggal %3$s sepanjang hari",
    "Every %1$d Years in %2$s on the %3$s for the entire day until %4$s" : "Setiap %1$d tahun pada bulan %2$s tanggal %3$s sepanjang hari hingga %4$s",
    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s" : "Setiap %1$d tahun pada bulan %2$s tanggal %3$s antara %4$s - %5$s",
    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s until %6$s" : "Setiap %1$d tahun pada bulan %2$s tanggal %3$s antara %4$s - %5$s hingga %6$s",
    "On specific dates for the entire day until %1$s" : "Pada tanggal tertentu sepanjang hari hingga %1$s",
    "On specific dates between %1$s - %2$s until %3$s" : "Pada tanggal tertentu antara %1$s - %2$s hingga %3$s",
    "In the past on %1$s" : "Di masa lalu pada %1$s",
    "_In %n minute on %1$s_::_In %n minutes on %1$s_" : ["Dalam %n menit pada %1$s"],
    "_In %n hour on %1$s_::_In %n hours on %1$s_" : ["Dalam %n jam pada %1$s"],
    "_In %n day on %1$s_::_In %n days on %1$s_" : ["Dalam %n hari pada %1$s"],
    "_In %n week on %1$s_::_In %n weeks on %1$s_" : ["Dalam %n minggu pada %1$s"],
    "_In %n month on %1$s_::_In %n months on %1$s_" : ["Dalam %n bulan pada %1$s"],
    "_In %n year on %1$s_::_In %n years on %1$s_" : ["Dalam %n tahun pada %1$s"],
    "In the past on %1$s then on %2$s" : "Di masa lalu pada %1$s lalu pada %2$s",
    "_In %n minute on %1$s then on %2$s_::_In %n minutes on %1$s then on %2$s_" : ["Dalam %n menit pada %1$s kemudian pada %2$s"],
    "_In %n hour on %1$s then on %2$s_::_In %n hours on %1$s then on %2$s_" : ["Dalam %n jam pada %1$s kemudian pada %2$s"],
    "_In %n day on %1$s then on %2$s_::_In %n days on %1$s then on %2$s_" : ["Dalam %n hari pada %1$s kemudian pada %2$s"],
    "_In %n week on %1$s then on %2$s_::_In %n weeks on %1$s then on %2$s_" : ["Dalam %n minggu pada %1$s kemudian pada %2$s"],
    "_In %n month on %1$s then on %2$s_::_In %n months on %1$s then on %2$s_" : ["Dalam %n bulan pada %1$s kemudian pada %2$s"],
    "_In %n year on %1$s then on %2$s_::_In %n years on %1$s then on %2$s_" : ["Dalam %n tahun pada %1$s kemudian pada %2$s"],
    "In the past on %1$s then on %2$s and %3$s" : "Di masa lalu pada %1$s lalu pada %2$s dan %3$s",
    "_In %n minute on %1$s then on %2$s and %3$s_::_In %n minutes on %1$s then on %2$s and %3$s_" : ["Dalam %n menit pada %1$s kemudian pada %2$s dan %3$s"],
    "_In %n hour on %1$s then on %2$s and %3$s_::_In %n hours on %1$s then on %2$s and %3$s_" : ["Dalam %n jam pada %1$s kemudian pada %2$s dan %3$s"],
    "_In %n day on %1$s then on %2$s and %3$s_::_In %n days on %1$s then on %2$s and %3$s_" : ["Dalam %n hari pada %1$s kemudian pada %2$s dan %3$s"],
    "_In %n week on %1$s then on %2$s and %3$s_::_In %n weeks on %1$s then on %2$s and %3$s_" : ["Dalam %n minggu pada %1$s kemudian pada %2$s dan %3$s"],
    "_In %n month on %1$s then on %2$s and %3$s_::_In %n months on %1$s then on %2$s and %3$s_" : ["Dalam %n bulan pada %1$s kemudian pada %2$s dan %3$s"],
    "_In %n year on %1$s then on %2$s and %3$s_::_In %n years on %1$s then on %2$s and %3$s_" : ["Dalam %n tahun pada %1$s kemudian pada %2$s dan %3$s"],
    "Could not generate next recurrence statement" : "Tidak dapat membuat pernyataan pengulangan berikutnya",
    "Cancelled: %1$s" : "Dibatalkan: %1$s",
    "\"%1$s\" has been canceled" : "\"%1$s\" telah dibatalkan",
    "Re: %1$s" : "Re: %1$s",
    "%1$s has accepted your invitation" : "%1$s telah menerima undangan Anda",
    "%1$s has tentatively accepted your invitation" : "%1$s telah menerima undangan Anda secara sementara",
    "%1$s has declined your invitation" : "%1$s telah menolak undangan Anda",
    "%1$s has responded to your invitation" : "%1$s telah merespons undangan Anda",
    "Invitation updated: %1$s" : "Undangan diperbarui: %1$s",
    "%1$s updated the event \"%2$s\"" : "%1$s memperbarui acara \"%2$s\"",
    "Invitation: %1$s" : "Undangan: %1$s",
    "%1$s would like to invite you to \"%2$s\"" : "%1$s ingin mengundang Anda ke \"%2$s\"",
    "Organizer:" : "Penyelenggara:",
    "Attendees:" : "Peserta:",
    "Title:" : "Judul:",
    "When:" : "Kapan:",
    "Location:" : "Lokasi:",
    "Link:" : "Tautan:",
    "Occurring:" : "Berlangsung:",
    "More options …" : "Opsi lainnya …",
    "More options at %s" : "Opsi lainnya di %s",
    "Monday" : "Senin",
    "Tuesday" : "Selasa",
    "Wednesday" : "Rabu",
    "Thursday" : "Kamis",
    "Friday" : "Jumat",
    "Saturday" : "Sabtu",
    "Sunday" : "Minggu",
    "January" : "Januari",
    "February" : "Februari",
    "March" : "Maret",
    "April" : "April",
    "May" : "Mei",
    "June" : "Juni",
    "July" : "Juli",
    "August" : "Agustus",
    "September" : "September",
    "October" : "Oktober",
    "November" : "November",
    "December" : "Desember",
    "First" : "Pertama",
    "Second" : "Kedua",
    "Third" : "Ketiga",
    "Fourth" : "Keempat",
    "Fifth" : "Kelima",
    "Last" : "Terakhir",
    "Second Last" : "Kedua terakhir",
    "Third Last" : "Ketiga terakhir",
    "Fourth Last" : "Keempat terakhir",
    "Fifth Last" : "Kelima terakhir",
    "Contacts" : "Kontak",
    "{actor} created address book {addressbook}" : "{actor} membuat buku alamat {addressbook}",
    "You created address book {addressbook}" : "Anda membuat buku alamat {addressbook}",
    "{actor} deleted address book {addressbook}" : "{actor} menghapus buku alamat {addressbook}",
    "You deleted address book {addressbook}" : "Anda menghapus buku alamat {addressbook}",
    "{actor} updated address book {addressbook}" : "{actor} memperbarui buku alamat {addressbook}",
    "You updated address book {addressbook}" : "Anda memperbarui buku alamat {addressbook}",
    "{actor} shared address book {addressbook} with you" : "{actor} membagikan buku alamat {addressbook} kepada Anda",
    "You shared address book {addressbook} with {user}" : "Anda membagikan buku alamat {addressbook} dengan {user}",
    "{actor} shared address book {addressbook} with {user}" : "{actor} membagikan buku alamat {addressbook} dengan {user}",
    "{actor} unshared address book {addressbook} from you" : "{actor} membatalkan berbagi buku alamat {addressbook} dari Anda",
    "You unshared address book {addressbook} from {user}" : "Anda membatalkan berbagi buku alamat {addressbook} dari {user}",
    "{actor} unshared address book {addressbook} from {user}" : "{actor} membatalkan berbagi buku alamat {addressbook} dari {user}",
    "{actor} unshared address book {addressbook} from themselves" : "{actor} membatalkan berbagi buku alamat {addressbook} dari diri mereka sendiri",
    "You shared address book {addressbook} with group {group}" : "Anda membagikan buku alamat {addressbook} dengan grup {group}",
    "{actor} shared address book {addressbook} with group {group}" : "{actor} membagikan buku alamat {addressbook} dengan grup {group}",
    "You unshared address book {addressbook} from group {group}" : "Anda membatalkan berbagi buku alamat {addressbook} dari grup {group}",
    "{actor} unshared address book {addressbook} from group {group}" : "{actor} membatalkan berbagi buku alamat {addressbook} dari grup {group}",
    "{actor} created contact {card} in address book {addressbook}" : "{actor} membuat kontak {card} di buku alamat {addressbook}",
    "You created contact {card} in address book {addressbook}" : "Anda membuat kontak {card} di buku alamat {addressbook}",
    "{actor} deleted contact {card} from address book {addressbook}" : "{actor} menghapus kontak {card} dari buku alamat {addressbook}",
    "You deleted contact {card} from address book {addressbook}" : "Anda menghapus kontak {card} dari buku alamat {addressbook}",
    "{actor} updated contact {card} in address book {addressbook}" : "{actor} memperbarui kontak {card} di buku alamat {addressbook}",
    "You updated contact {card} in address book {addressbook}" : "Anda memperbarui kontak {card} di buku alamat {addressbook}",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "Sebuah <strong>kontak</strong> atau <strong>buku alamat</strong> telah diubah",
    "System address book disabled" : "Buku alamat sistem dinonaktifkan",
    "The system contacts address book has been automatically disabled during upgrade. This means that the address book will no longer be available to users in the contacts app or other clients. The system contacts address book was disabled because the amount of contacts in the address book exceeded the maximum recommended number of contacts. This limit is set to prevent performance issues. You can re-enable the system address book with the following command {command}" : "Buku alamat kontak sistem telah dinonaktifkan secara otomatis selama peningkatan. Ini berarti buku alamat tersebut tidak akan lagi tersedia bagi pengguna di aplikasi kontak atau klien lain. Buku alamat kontak sistem dinonaktifkan karena jumlah kontak dalam buku alamat melebihi jumlah maksimum kontak yang direkomendasikan. Batas ini ditetapkan untuk mencegah masalah performa. Anda dapat mengaktifkan kembali buku alamat sistem dengan perintah berikut {command}",
    "Accounts" : "Accounts",
    "System address book which holds all accounts" : "Buku alamat sistem yang menyimpan semua akun",
    "File is not updatable: %1$s" : "File tidak dapat diperbarui: %1$s",
    "Failed to get storage for file" : "Gagal mendapatkan penyimpanan untuk file",
    "Could not write to final file, canceled by hook" : "Tidak dapat menulis ke file akhir, dibatalkan oleh hook",
    "Could not write file contents" : "Tidak dapat menulis konten file",
    "_%n byte_::_%n bytes_" : ["%n byte"],
    "Error while copying file to target location (copied: %1$s, expected filesize: %2$s)" : "Kesalahan saat menyalin file ke lokasi tujuan (disalin: %1$s, ukuran file yang diharapkan: %2$s)",
    "Expected filesize of %1$s but read (from Nextcloud client) and wrote (to Nextcloud storage) %2$s. Could either be a network problem on the sending side or a problem writing to the storage on the server side." : "Ukuran file %1$s yang diharapkan adalah %1$s tetapi membaca (dari klien Nextcloud) dan menulis (ke penyimpanan Nextcloud) %2$s. Ini bisa jadi masalah jaringan di sisi pengirim atau masalah saat menulis ke penyimpanan di sisi server.",
    "Could not rename part file to final file, canceled by hook" : "Tidak dapat mengganti nama file bagian menjadi file akhir, dibatalkan oleh hook",
    "Could not rename part file to final file" : "Tidak dapat mengganti nama file bagian menjadi file akhir",
    "Failed to check file size: %1$s" : "Gagal memeriksa ukuran file: %1$s",
    "Could not open file: %1$s (%2$d), file does seem to exist" : "Tidak dapat membuka file: %1$s (%2$d), file tampaknya ada",
    "Could not open file: %1$s (%2$d), file doesn't seem to exist" : "Tidak dapat membuka file: %1$s (%2$d), file tampaknya tidak ada",
    "Encryption not ready: %1$s" : "Enkripsi belum siap: %1$s",
    "Failed to open file: %1$s" : "Gagal membuka file: %1$s",
    "Failed to unlink: %1$s" : "Gagal melepas tautan: %1$s",
    "Failed to write file contents: %1$s" : "Gagal menulis konten file: %1$s",
    "File not found: %1$s" : "File tidak ditemukan: %1$s",
    "Invalid target path" : "Jalur tujuan tidak valid",
    "System is in maintenance mode." : "Sistem sedang dalam mode pemeliharaan.",
    "Upgrade needed" : "Perlu peningkatan",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "%s Anda perlu dikonfigurasi untuk menggunakan HTTPS agar dapat menggunakan CalDAV dan CardDAV dengan iOS/macOS.",
    "Configures a CalDAV account" : "Mengonfigurasi akun CalDAV",
    "Configures a CardDAV account" : "Mengonfigurasi akun CardDAV",
    "Events" : "Acara",
    "Untitled task" : "Tugas tanpa judul",
    "Completed on %s" : "Selesai pada %s",
    "Due on %s by %s" : "Jatuh tempo pada %s oleh %s",
    "Due on %s" : "Jatuh tempo pada %s",
    "Welcome to Nextcloud Calendar!\n\nThis is a sample event - explore the flexibility of planning with Nextcloud Calendar by making any edits you want!\n\nWith Nextcloud Calendar, you can:\n- Create, edit, and manage events effortlessly.\n- Create multiple calendars and share them with teammates, friends, or family.\n- Check availability and display your busy times to others.\n- Seamlessly integrate with apps and devices via CalDAV.\n- Customize your experience: schedule recurring events, adjust notifications and other settings." : "Selamat datang di Kalender Nextcloud!\n\nIni adalah acara contoh - jelajahi fleksibilitas perencanaan dengan Kalender Nextcloud dengan melakukan perubahan apa pun yang Anda inginkan!\n\nDengan Kalender Nextcloud, Anda dapat:\n- Membuat, mengedit, dan mengelola acara dengan mudah.\n- Membuat beberapa kalender dan membagikannya dengan rekan tim, teman, atau keluarga.\n- Memeriksa ketersediaan dan menampilkan waktu sibuk Anda kepada orang lain.\n- Terintegrasi dengan lancar dengan aplikasi dan perangkat melalui CalDAV.\n- Menyesuaikan pengalaman Anda: jadwalkan acara berulang, sesuaikan notifikasi, dan pengaturan lainnya.",
    "Example event - open me!" : "Acara contoh - buka saya!",
    "System Address Book" : "Buku Alamat Sistem",
    "The system address book contains contact information for all users in your instance." : "Buku alamat sistem berisi informasi kontak untuk semua pengguna di instance Anda.",
    "Enable System Address Book" : "Aktifkan Buku Alamat Sistem",
    "DAV system address book" : "Buku alamat sistem DAV",
    "No outstanding DAV system address book sync." : "Tidak ada sinkronisasi buku alamat sistem DAV yang tertunda.",
    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "Sinkronisasi buku alamat sistem DAV belum berjalan karena instance Anda memiliki lebih dari 1000 pengguna atau karena terjadi kesalahan. Silakan jalankan secara manual dengan memanggil \"occ dav:sync-system-addressbook\".",
    "DAV system address book size" : "Ukuran buku alamat sistem DAV",
    "The system address book is disabled" : "Buku alamat sistem dinonaktifkan",
    "The system address book is enabled, but contains more than the configured limit of %d contacts" : "Buku alamat sistem diaktifkan, tetapi berisi lebih dari batas yang dikonfigurasi yaitu %d kontak",
    "The system address book is enabled and contains less than the configured limit of %d contacts" : "Buku alamat sistem diaktifkan dan berisi kurang dari batas yang dikonfigurasi yaitu %d kontak",
    "WebDAV endpoint" : "Endpoint WebDAV",
    "Could not check that your web server is properly set up to allow file synchronization over WebDAV. Please check manually." : "Tidak dapat memeriksa apakah web server Anda telah disiapkan dengan benar untuk mengizinkan sinkronisasi file melalui WebDAV. Silakan periksa secara manual.",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Peladen web Anda belum diatur sesuai untuk sinkronisasi berkas, karena antarmuka WebDAV tidak berfungsi.",
    "Your web server is properly set up to allow file synchronization over WebDAV." : "Web server Anda telah disiapkan dengan benar untuk mengizinkan sinkronisasi file melalui WebDAV.",
    "Calendars including events, details and attendees" : "Kalender termasuk acara, detail, dan peserta",
    "Migrated calendar (%1$s)" : "Kalender termigrasi (%1$s)",
    "Contacts and groups" : "Kontak dan grup",
    "WebDAV" : "WebDAV",
    "Absence saved" : "Ketidakhadiran disimpan",
    "Failed to save your absence settings" : "Gagal menyimpan pengaturan ketidakhadiran Anda",
    "Absence cleared" : "Ketidakhadiran dihapus",
    "Failed to clear your absence settings" : "Gagal menghapus pengaturan ketidakhadiran Anda",
    "First day" : "Hari pertama",
    "Last day (inclusive)" : "Hari terakhir (termasuk)",
    "Out of office replacement (optional)" : "Pengganti di luar kantor (opsional)",
    "Name of the replacement" : "Nama pengganti",
    "Short absence status" : "Status ketidakhadiran singkat",
    "Long absence Message" : "Pesan ketidakhadiran panjang",
    "Save" : "Simpan",
    "Disable absence" : "Nonaktifkan ketidakhadiran",
    "Failed to load availability" : "Gagal memuat ketersediaan",
    "Saved availability" : "Ketersediaan disimpan",
    "Failed to save availability" : "Gagal menyimpan ketersediaan",
    "to" : "untuk",
    "Delete slot" : "Hapus slot",
    "No working hours set" : "Tidak ada jam kerja yang ditetapkan",
    "Add slot" : "Tambahkan slot",
    "Weekdays" : "Hari kerja",
    "Pick a start time for {dayName}" : "Pilih waktu mulai untuk {dayName}",
    "Pick a end time for {dayName}" : "Pilih waktu selesai untuk {dayName}",
    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Secara otomatis tetapkan status pengguna menjadi \"Jangan ganggu\" di luar ketersediaan untuk membisukan semua notifikasi.",
    "Cancel" : "Batal",
    "Import" : "Impor",
    "Error while saving settings" : "Kesalahan saat menyimpan pengaturan",
    "Contact reset successfully" : "Kontak berhasil direset",
    "Error while resetting contact" : "Kesalahan saat mereset kontak",
    "Contact imported successfully" : "Kontak berhasil diimpor",
    "Error while importing contact" : "Kesalahan saat mengimpor kontak",
    "Import contact" : "Impor kontak",
    "Reset to default" : "Reset ke default",
    "Import contacts" : "Impor kontak",
    "Importing a new .vcf file will delete the existing default contact and replace it with the new one. Do you want to continue?" : "Mengunggah file .vcf baru akan menghapus kontak default yang ada dan menggantinya dengan yang baru. Apakah Anda ingin melanjutkan?",
    "Failed to save example event creation setting" : "Gagal menyimpan pengaturan pembuatan acara contoh",
    "Failed to upload the example event" : "Gagal mengunggah acara contoh",
    "Custom example event was saved successfully" : "Acara contoh kustom berhasil disimpan",
    "Failed to delete the custom example event" : "Gagal menghapus acara contoh kustom",
    "Custom example event was deleted successfully" : "Acara contoh kustom berhasil dihapus",
    "Import calendar event" : "Impor acara kalender",
    "Uploading a new event will overwrite the existing one." : "Mengunggah acara baru akan menimpa acara yang sudah ada.",
    "Upload event" : "Unggah acara",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Instal juga {calendarappstoreopen}aplikasi Kalender{linkclose}, atau {calendardocopen}hubungkan desktop & seluler Anda untuk sinkronisasi ↗{linkclose}.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Pastikan Anda menyiapkan {emailopen}server email{linkclose} dengan benar.",
    "Calendar server" : "Server kalender",
    "Send invitations to attendees" : "Kirim undangan kepada peserta",
    "Automatically generate a birthday calendar" : "Buat kalender ulang tahun secara otomatis",
    "Birthday calendars will be generated by a background job." : "Kalender ulang tahun akan dibuat oleh tugas latar belakang.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Karena itu kalender tersebut tidak akan tersedia segera setelah diaktifkan, tetapi akan muncul setelah beberapa waktu.",
    "Send notifications for events" : "Kirim notifikasi untuk acara",
    "Notifications are sent via background jobs, so these must occur often enough." : "Notifikasi dikirim melalui tugas latar belakang, jadi tugas tersebut harus dijalankan cukup sering.",
    "Send reminder notifications to calendar sharees as well" : "Kirim juga notifikasi pengingat kepada pengguna yang dibagikan kalendernya",
    "Reminders are always sent to organizers and attendees." : "Pengingat selalu dikirim kepada penyelenggara dan peserta.",
    "Enable notifications for events via push" : "Aktifkan notifikasi untuk acara melalui push",
    "Example content" : "Konten contoh",
    "Example content serves to showcase the features of Nextcloud. Default content is shipped with Nextcloud, and can be replaced by custom content." : "Konten contoh berfungsi untuk menampilkan fitur Nextcloud. Konten default disertakan dengan Nextcloud, dan dapat diganti dengan konten kustom.",
    "Availability" : "Ketersediaan",
    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Jika Anda mengonfigurasi jam kerja, orang lain akan melihat kapan Anda di luar kantor saat mereka memesan rapat.",
    "Absence" : "Ketidakhadiran",
    "Configure your next absence period." : "Konfigurasikan periode ketidakhadiran Anda berikutnya.",
    "There was an error updating your attendance status." : "Terjadi kesalahan saat memperbarui status kehadiran Anda.",
    "Please contact the organizer directly." : "Silakan hubungi penyelenggara secara langsung.",
    "Are you accepting the invitation?" : "Apakah Anda menerima undangan ini?",
    "Tentative" : "Tentatif",
    "Your attendance was updated successfully." : "Kehadiran Anda berhasil diperbarui.",
    "No results." : "Tidak ada hasil.",
    "Start typing." : "Mulai mengetik."
},
"nplurals=1; plural=0;");
