<?php

declare (strict_types=1);
namespace OCA\Notifications\Vendor\SpomkyLabs\Pki\ASN1\Type\Primitive;

use OCA\Notifications\Vendor\SpomkyLabs\Pki\ASN1\Type\PrimitiveString;
use OCA\Notifications\Vendor\SpomkyLabs\Pki\ASN1\Type\UniversalClass;
/**
 * Implements *VideotexString* type.
 */
final class VideotexString extends PrimitiveString
{
    use UniversalClass;
    private function __construct(string $string)
    {
        parent::__construct(self::TYPE_VIDEOTEX_STRING, $string);
    }
    public static function create(string $string): self
    {
        return new self($string);
    }
    protected function validateString(string $string): bool
    {
        // allow everything
        return true;
    }
}