OC.L10N.register(
    "app_api",
    {
    "Cancel" : "Cancel",
    "Delete" : "Borrar",
    "Edit" : "Editar",
    "Unlimited" : "Ilimitado",
    "Name" : "Nombre",
    "Host" : "Servidor",
    "Enabled" : "Habilitado",
    "Add" : "Guardar",
    "Confirm" : "Confirmar",
    "Save" : "Guardar",
    "Register" : "Registrar",
    "Update to {version}" : "Actualizar a {version}",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación no cuenta con una versión mínima de Nextcloud asignada. Esto será un error en el futuro.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación no cuenta con una versión máxima de Nextcloud asignada. Esto será un error en el futuro.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Esta aplicación no puede ser instalada porque las siguientes dependencias no están satisfechas:",
    "View in store" : "Ver en la tienda",
    "Visit website" : "Visita el sitio web",
    "Report a bug" : "Reporta un detalle",
    "User documentation" : "Documentación del usuario",
    "Admin documentation" : "Documentación del administrador",
    "Developer documentation" : "Documentación del desarrollador",
    "Featured" : "Destacado",
    "Icon" : "Ícono",
    "Version" : "Versión",
    "Daemon" : "Demonio",
    "Level" : "Nivel",
    "Actions" : "Acciones",
    "Display Name" : "Nombre a desplegar",
    "Your apps" : "Tus aplicaciones",
    "Documentation" : "Documentación",
    "Details" : "Detalles",
    "Changelog" : "Bitácora de cambios",
    "Disabled apps" : "Aplicaciones deshabilitadas",
    "Updates" : "Actualizaciones",
    "Enable" : "Habilitar",
    "Disable" : "Deshabilitar"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
