OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "Ógilt skýjasambandsauðkenni (Federated Cloud ID)",
    "Server to server sharing is not enabled on this server" : "Deiling frá þjóni til þjóns er ekki virk á þessum þjóni",
    "Couldn't establish a federated share." : "Gat ekki bætt við skýjasambandssameign.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Gat ekki bætt við skýjasambandssameign, hugsanlega var lykilorðið ekki rétt.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Sendi beiðni um skýjasambandssameign, þú munt fá boðskort. Athugaðu skilaboð til þín.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Gat ekki bætt við skýjasambandssameign, það lítur út fyrir að þjónninn sem á að koma sambandi við sé of gamall (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "Ekki er heimilt að senda skýjasambandssameign fyrir hópa af þessum þjóni.",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "Deiling %1$s mistókst, því þessu atriði er þegar deilt með aðgangnum %2$s",
    "Not allowed to create a federated share to the same account" : "Ekki er heimilt að búa til skýjasambandssameign með sama aðgangi",
    "Federated shares require read permissions" : "Sameignir í skýjasambandi krefjast lesheimilda",
    "File is already shared with %s" : "Skránni er þegar deilt með %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Deiling %1$s mistókst, gat ekki fundið %2$s, hugsanlega er þjónninn ekki tiltækur í augnablikinu eða að hann notar sjálfundirritað skilríki.",
    "Could not find share" : "Gat ekki fundið sameign",
    "Federated sharing" : "Deiling milli þjóna (skýjasambandssameign)",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Þú tókst við {share} sem fjartengdri sameign frá {user} (fyrir hönd {behalf})",
    "You received {share} as a remote share from {user}" : "Þú tókst við {share} sem fjartengdri sameign frá {user}",
    "Accept" : "Samþykkja",
    "Decline" : "Hafna",
    "Federated Cloud Sharing" : "Deiling með skýjasambandi",
    "Sharing" : "Deiling",
    "Federated file sharing" : "Deiling skráa milli þjóna (skýjasambandssameign)",
    "Provide federated file sharing across servers" : "Sér um deilingu skráa milli skýjaþjóna (skýjasambandssameign)",
    "Disable upload" : "Gera innsendingar óvirkar",
    "Unable to update federated files sharing config" : "Get ekki uppfært stillingar á deilingu með skýjasambandi",
    "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "Stilltu hvernig fólk getur deilt á milli þjóna. Það þýðir sameignir á milli fólks á þessum þjóni, en einnig ef stuðst er við deilingu skýjasambandssameigna.",
    "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Leyfa fólki á þessum þjóni að senda sameignir til hópa á öðrum þjónum (þessi kostur leyfir einnig WebDAV-aðgang að opinberum sameignum)",
    "Allow people on this server to receive shares from other servers" : "Leyfa fólki á þessum þjóni að taka á móti sameignum frá öðrum þjónum",
    "Allow people on this server to send shares to groups on other servers" : "Leyfa fólki á þessum þjóni að senda sameignir til hópa á öðrum þjónum",
    "Allow people on this server to receive group shares from other servers" : "Leyfa fólki á þessum þjóni að taka á móti hópsameignum frá öðrum þjónum",
    "Search global and public address book for people" : "Leita að fólki í víðværri og opinberri vistfangaskrá",
    "Allow people to publish their data to a global and public address book" : "Leifa fólki að birta gögnin sín í víðværri og opinberri vistfangaskrá",
    "Trusted federation" : "Treyst skýjasamband",
    "Automatically accept shares from trusted federated accounts and groups by default" : "Sjálfgefið samþykkja sjálfkrafa sameignir frá treystum skýjasambandsaðgöngum og hópum",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Deila með mér í gegnum víðværa skýjasambandsauðkennið mitt #Nextcloud Federated Cloud ID, sjá {url}",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Deila með mér í gegnum víðværa skýjasambandsauðkennið mitt #Nextcloud Federated Cloud ID",
    "Share with me via Nextcloud" : "Deila með mér í gegnum Nextcloud",
    "Copy" : "Afrita",
    "Clipboard not available. Please copy the cloud ID manually." : "Klippispjald er ekki tiltækt. Afritaðu skýjasambandsauðkennið handvirkt.",
    "Copied!" : "Afritað!",
    "Federated Cloud" : "Skýjasamband (federated)",
    "Your Federated Cloud ID" : "Skýjasambandsauðkennið þitt (Federated Cloud ID)",
    "Share it so your friends can share files with you:" : "Deildu þessu svo að vinir þínir geti deilt skrám með þér:",
    "Bluesky" : "Bluesky",
    "Facebook" : "Facebook",
    "Mastodon" : "Mastodon",
    "Add to your website" : "Bæta við vefsvæðið þitt",
    "Share with me via {productName}" : "Deila með mér í gegnum {productName}",
    "HTML Code:" : "HTML-kóði:",
    "Cancel" : "Hætta við",
    "Add remote share" : "Bæta við fjartengdri sameign",
    "Remote share" : "Fjartengd sameign",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Viltu bæta við fjartengdri sameign {name} frá {owner}@{remote}?",
    "Remote share password" : "Lykilorð fjartengdrar sameignar",
    "Incoming share could not be processed" : "Ekki var hægt að vinna með innkomandi sameign",
    "X (formerly Twitter)" : "X (fyrrum Twitter)",
    "formerly Twitter" : "fyrrum Twitter"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
