OC.L10N.register(
    "dav",
    {
    "Calendar" : "달력",
    "Tasks" : "작업",
    "Personal" : "개인",
    "{actor} created calendar {calendar}" : "{actor} 님이 달력 {calendar}을(를) 생성함",
    "You created calendar {calendar}" : "달력 {calendar}을(를) 생성함",
    "{actor} deleted calendar {calendar}" : "{actor} 님이 달력 {calendar}을(를) 삭제함",
    "You deleted calendar {calendar}" : "달력 {calendar}을(를) 삭제함",
    "{actor} updated calendar {calendar}" : "{actor} 님이 달력 {calendar}을(를) 업데이트함",
    "You updated calendar {calendar}" : "달력 {calendar}을(를) 업데이트함",
    "{actor} restored calendar {calendar}" : "{actor}님이 달력 {calendar}을(를) 복구함",
    "You restored calendar {calendar}" : "달력 {calendar}을(를) 복구함",
    "You shared calendar {calendar} as public link" : "달력 {calendar}을(를) 공개 링크로 공유함",
    "You removed public link for calendar {calendar}" : "달력 {calendar}의 공개 링크를 삭제함",
    "{actor} shared calendar {calendar} with you" : "{actor} 님이 내게 달력 {calendar}을(를) 공유함",
    "You shared calendar {calendar} with {user}" : "{user} 님과 달력 {calendar}을(를) 공유함",
    "{actor} shared calendar {calendar} with {user}" : "{actor} 님이 {user} 님과 달력 {calendar}을(를) 공유함",
    "{actor} unshared calendar {calendar} from you" : "{actor} 님이 달력 {calendar}의 공유를 중단함",
    "You unshared calendar {calendar} from {user}" : "{user} 님과 달력 {calendar}의 공유를 중단함",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} 님이 {user} 님과 {calendar} 달력의 공유를 중단함",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} 님이 달력 {calendar}의 공유를 해제함",
    "You shared calendar {calendar} with group {group}" : "달력 {calendar}을(를) 그룹 {group}와(과) 공유함",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} 님이 달력 {calendar}을(를) 그룹 {group}와(과) 공유함",
    "You unshared calendar {calendar} from group {group}" : "달력 {calendar}을(를) 그룹 {group}와(과) 공유하지 않음",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} 님이 달력 {calendar}을(를) 그룹 {group}와(과) 공유하지 않음",
    "Untitled event" : "제목 없는 일정",
    "{actor} created event {event} in calendar {calendar}" : "{actor} 님이 행사 {event}을(를) 달력 {calendar}에 생성함",
    "You created event {event} in calendar {calendar}" : "행사 {event}을(를) 달력 {calendar}에 생성함",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} 님이 행사 {event}을(를) 달력 {calendar}에서 삭제함",
    "You deleted event {event} from calendar {calendar}" : "행사 {event}을(를) 달력 {calendar}에서 삭제함",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} 님이 달력 {calendar}의 행사 {event}을(를) 업데이트함",
    "You updated event {event} in calendar {calendar}" : "달력 {calendar}의 행사 {event}을(를) 업데이트함",
    "{actor} moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "{actor}님이 행사 {event}을(를) 달력 {sourceCalendar}에서 달력 {targetCalendar}(으)로 옮김",
    "You moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "행사 {event}을(를) 달력 {sourceCalendar}에서 달력 {targetCalendar}(으)로 옮김",
    "{actor} restored event {event} of calendar {calendar}" : "{actor}님이 행사 {event}을(를) 달력 {calendar}에 복구함",
    "You restored event {event} of calendar {calendar}" : "행사 {event}을(를) 달력 {calendar}에 복구함",
    "Busy" : "바쁨",
    "{actor} created to-do {todo} in list {calendar}" : "{actor}님이 목록 {calendar}에 할 일 {todo}을(를) 생성함",
    "You created to-do {todo} in list {calendar}" : "목록 {calendar}에 할 일 {todo}을(를) 생성함",
    "{actor} deleted to-do {todo} from list {calendar}" : "{actor}님이 목록 {calendar}에서 할 일 {todo}을(를) 삭제함",
    "You deleted to-do {todo} from list {calendar}" : "목록 {calendar}에서 할 일 {todo}을(를) 삭제함",
    "{actor} updated to-do {todo} in list {calendar}" : "{actor}님이 목록 {calendar}의 할 일 {todo}을(를) 업데이트함",
    "You updated to-do {todo} in list {calendar}" : "목록 {calendar}의 할 일 {todo}을(를) 업데이트함",
    "{actor} solved to-do {todo} in list {calendar}" : "{actor}님이 목록 {calendar}의 할 일 {todo}을(를) 끝냄",
    "You solved to-do {todo} in list {calendar}" : "목록 {calendar}의 할 일 {todo}을(를) 끝냄",
    "{actor} reopened to-do {todo} in list {calendar}" : "{actor}님이 목록 {calendar}의 할 일 {todo}을(를) 다시 엶",
    "You reopened to-do {todo} in list {calendar}" : "목록 {calendar}의 할 일 {todo}을(를) 다시 엶",
    "{actor} moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "{actor}님이 할 일 {todo}을(를) 목록 {sourceCalendar}에서 목록 {targetCalendar}(으)로 옮김",
    "You moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "할 일 {todo}을(를) 목록 {sourceCalendar}에서 목록 {targetCalendar}(으)로 옮김",
    "Calendar, contacts and tasks" : "달력, 연락처 및 작업",
    "A <strong>calendar</strong> was modified" : "<strong>달력</strong>이 수정됨",
    "A calendar <strong>event</strong> was modified" : "달력 <strong>행사</strong>가 수정됨",
    "A calendar <strong>to-do</strong> was modified" : "달력 <strong>할 일</strong>이 수정됨",
    "Contact birthdays" : "연락처에 등록된 생일",
    "Death of %s" : "%s의 기일",
    "Accept" : "수락",
    "Decline" : "거절",
    "Untitled calendar" : "제목없는 달력",
    "Calendar:" : "달력:",
    "Date:" : "날짜:",
    "Where:" : "장소:",
    "Description:" : "설명:",
    "_%n year_::_%n years_" : ["%n년"],
    "_%n month_::_%n months_" : ["%n개월"],
    "_%n day_::_%n days_" : ["%n일"],
    "_%n hour_::_%n hours_" : ["%n시간"],
    "_%n minute_::_%n minutes_" : ["%n분"],
    "%s (in %s)" : "%s(%s 후)",
    "%s (%s ago)" : "%s(%s 지남)",
    "Calendar: %s" : "달력: %s",
    "Date: %s" : "날짜: %s",
    "Description: %s" : "설명: %s",
    "Where: %s" : "장소: %s",
    "%1$s via %2$s" : "%1$s(%2$s 경유)",
    "Cancelled: %1$s" : "취소됨:  %1$s",
    "\"%1$s\" has been canceled" : "\"%1$s\"이(가) 취소되었습니다",
    "Re: %1$s" : "Re: %1$s",
    "%1$s has accepted your invitation" : "%1$s이(가) 초대를 수락했습니다",
    "%1$s has tentatively accepted your invitation" : "%1$s이(기) 초대를 잠정 수락했습니다",
    "%1$s has declined your invitation" : "%1$s이(가) 초대를 거절했습니다",
    "%1$s has responded to your invitation" : "%1$s이(가) 초대에 응답했습니다",
    "Invitation updated: %1$s" : "초대 갱신됨: %1$s",
    "%1$s updated the event \"%2$s\"" : "%1$s님이 일정 \"%2$s\"을(를) 갱신했습니다",
    "Invitation: %1$s" : "초대: %1$s",
    "%1$s would like to invite you to \"%2$s\"" : "%1$s님이 나를 \"%2$s\"에 초대했습니다",
    "Organizer:" : "주최자:",
    "Attendees:" : "참석자:",
    "Title:" : "제목:",
    "When:" : "일시:",
    "Location:" : "위치:",
    "Link:" : "링크:",
    "More options …" : "더 많은 옵션 …",
    "More options at %s" : "%s에 더 많은 옵션 있음",
    "Monday" : "월요일",
    "Tuesday" : "화요일",
    "Wednesday" : "수요일",
    "Thursday" : "목요일",
    "Friday" : "금요일",
    "Saturday" : "토요일",
    "Sunday" : "일요일",
    "January" : "1월",
    "February" : "2월",
    "March" : "3월",
    "April" : "4월",
    "May" : "5월",
    "June" : "6월",
    "July" : "7월",
    "August" : "8월",
    "September" : "9월",
    "October" : "10월",
    "November" : "11월",
    "December" : "12월",
    "Contacts" : "연락처",
    "{actor} created address book {addressbook}" : "{actor}님이 주소록 {addressbook}을(를) 생성함",
    "You created address book {addressbook}" : "주소록 {addressbook}을(를) 생성함",
    "{actor} deleted address book {addressbook}" : "{actor}님이 주소록 {addressbook}을(를) 제거함",
    "You deleted address book {addressbook}" : "주소록 {addressbook}을(를) 제거함",
    "{actor} updated address book {addressbook}" : "{actor}님이 주소록 {addressbook}을(를) 갱신함",
    "You updated address book {addressbook}" : "주소록 {addressbook}을(를) 갱신함",
    "{actor} shared address book {addressbook} with you" : "{actor}님이 나와 주소록 {addressbook}을(를) 공유함",
    "You shared address book {addressbook} with {user}" : "{user}님과 주소록 {addressbook}을(를) 공유함",
    "{actor} shared address book {addressbook} with {user}" : "{actor}님이 {user}님과 주소록 {addressbook}을(를) 공유함",
    "{actor} unshared address book {addressbook} from you" : "{actor}님이 주소록 {addressbook}의 공유를 해제함",
    "You unshared address book {addressbook} from {user}" : "{user}님과 주소록 {addressbook}의 공유를 해제함",
    "{actor} unshared address book {addressbook} from {user}" : "{actor}님이 {user}님과 주소록 {addressbook}의 공유를 해제함",
    "{actor} unshared address book {addressbook} from themselves" : "{actor}님이 자신과 주소록 {addressbook}의 공유를 해제함",
    "You shared address book {addressbook} with group {group}" : "그룹 {group}과(와) 주소록 {addressbook}을(를) 공유함",
    "{actor} shared address book {addressbook} with group {group}" : "{actor}님이 그룹 {group}과(와) 주소록 {addressbook}을(를) 공유함",
    "You unshared address book {addressbook} from group {group}" : "그룹 {group}과(와) 주소록 {addressbook}의 공유를 해제함",
    "{actor} unshared address book {addressbook} from group {group}" : "{actor}님이 그룹 {group}과(와) 주소록 {addressbook}의 공유를 해제함",
    "{actor} created contact {card} in address book {addressbook}" : "{actor}님이 연락처 {card}을(를) 주소록 {addressbook}에 생성함",
    "You created contact {card} in address book {addressbook}" : "연락처 {card}을(를) 주소록 {addressbook}에 생성함",
    "{actor} deleted contact {card} from address book {addressbook}" : "{actor}님이 연락처 {card}을(를) 주소록 {addressbook}에서 제거함",
    "You deleted contact {card} from address book {addressbook}" : "연락처 {card}을(를) 주소록 {addressbook}에서 제거함",
    "{actor} updated contact {card} in address book {addressbook}" : "{actor}님이 주소록 {addressbook}의 연락처 {card}을(를) 갱신함",
    "You updated contact {card} in address book {addressbook}" : "주소록 {addressbook}의 연락처 {card}을(를) 갱신함",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "<strong>연락처</strong> 또는 <strong>주소록</strong>이 변경됨",
    "Accounts" : "계정",
    "System address book which holds all accounts" : "시스템 주소록이 모든 계정 정보를 보유합니다",
    "File is not updatable: %1$s" : "파일을 갱신할 수 없습니다: %1$s",
    "Could not write to final file, canceled by hook" : "후크에 의해 취소되어 최종 파일에 쓸 수 없음",
    "Could not write file contents" : "파일 내용을 쓸 수 없음",
    "_%n byte_::_%n bytes_" : ["%n 바이트"],
    "Error while copying file to target location (copied: %1$s, expected filesize: %2$s)" : "파일을 대상 위치로 복사하는 동안 오류 발생 (복사됨: %1$s, 예상 파일 크기: %2$s)",
    "Expected filesize of %1$s but read (from Nextcloud client) and wrote (to Nextcloud storage) %2$s. Could either be a network problem on the sending side or a problem writing to the storage on the server side." : "예상 파일 크기는 %1$s이지만 읽고(Nextcloud 클라이언트에서) 및 쓴(Nextcloud 스토리지로) 크기는 %2$s입니다. 보내는 쪽의 네트워크 문제이거나 서버 쪽의 저장소에 쓰는 데 문제가 있을 수 있습니다.",
    "Could not rename part file to final file, canceled by hook" : "후크에 의해 취소되어 부분 파일의 이름을 최종 파일로 바꿀 수 없음",
    "Could not rename part file to final file" : "부분 파일의 이름을 최종 파일로 바꿀 수 없음",
    "Failed to check file size: %1$s" : "파일 크기 확인 실패: %1$s",
    "Encryption not ready: %1$s" : "암호화가 준비되지 않음: %1$s",
    "Failed to open file: %1$s" : "파일을 열 수 없음: %1$s",
    "Failed to unlink: %1$s" : "파일을 삭제할 수 없음: %1$s",
    "Failed to write file contents: %1$s" : "파일 내용을 쓸 수 없음: %1$s",
    "File not found: %1$s" : "파일을 찾을 수 없음: %1$s",
    "System is in maintenance mode." : "시스템이 유지 보수 모드입니다.",
    "Upgrade needed" : "업그레이드 필요",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "iOS/macOS에서 CalDAV 및 CardDAV를 사용하려면 %s에서 HTTPS를 사용하도록 설정해야 합니다.",
    "Configures a CalDAV account" : "CalDAV 계정 설정",
    "Configures a CardDAV account" : "CardDAV 계정 설정",
    "Events" : "일정",
    "Untitled task" : "제목없는 작업",
    "Completed on %s" : "%s에 완료됨",
    "Due on %s by %s" : "%s일 %s에 만료됨",
    "Due on %s" : "%s에 만료됨",
    "DAV system address book" : "DAV 시스템 주소록",
    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "DAV 시스템 주소록 동기화가 아직 작동하지 않았습니다. 이는 인스턴스의 사용자가 1000명을 초과하거나 오류가 발생했기 때문입니다. occ dav:sync-system-addressbook 명령어를 통해 수동으로 이를 수행하십시오.",
    "WebDAV endpoint" : "WebDAV 종단점",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "WebDAV 인터페이스를 사용할 수 없어서 웹 서버에서 파일 동기화를 사용할 수 있도록 설정할 수 없습니다.",
    "Calendars including events, details and attendees" : "일정, 세부 정보 및 참석자를 포함한 캘린더",
    "Migrated calendar (%1$s)" : "가져온 달력 (%1$s)",
    "Contacts and groups" : "연락처 및 그룹",
    "WebDAV" : "WebDAV",
    "Absence saved" : "부재 상태 저장됨",
    "Failed to save your absence settings" : "부재 상태 설정 저장 실패",
    "Absence cleared" : "부재 상태 비워짐",
    "Failed to clear your absence settings" : "부재 설정 비우기 실패",
    "First day" : "시작일",
    "Last day (inclusive)" : "종료일 (이 날짜까지 포함됨)",
    "Short absence status" : "부재 상태 개요",
    "Long absence Message" : "부재 상태 상세 설명",
    "Save" : "저장",
    "Disable absence" : "부재 상태 비활성화",
    "Failed to load availability" : "시간 조율 설정 불러오기 실패",
    "Saved availability" : "시간 조율 설정 저장함",
    "Failed to save availability" : "시간 조율 설정 저장 실패",
    "to" : "에서",
    "Delete slot" : "시간대 삭제",
    "No working hours set" : "업무 시간이 설정되지 않음",
    "Add slot" : "시간대 추가",
    "Pick a start time for {dayName}" : "{dayName} 시작 시각을 지정하십시오",
    "Pick a end time for {dayName}" : "{dayName} 종료 시각을 지정하십시오",
    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "다른 용무 중일 때 자동으로 사용자를 '방해 금지' 모드로 설정해 모든 알림을 음소거합니다.",
    "Cancel" : "취소",
    "Import" : "가져오기",
    "Error while saving settings" : "설정 저장 중 오류 발생",
    "Reset to default" : "기본값으로 초기화",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "{calendarappstoreopen}달력 앱{linkclose}을 설치하거나 {calendardocopen}동기화할 데스크톱과 모바일 장치를 연결 ↗{linkclose}하십시오.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "{emailopen}이메일 서버{linkclose}가 올바르게 설치되어 있는지 확인하십시오..",
    "Calendar server" : "달력 서버",
    "Send invitations to attendees" : "참석자에게 초대장 보내기",
    "Automatically generate a birthday calendar" : "자동으로 생일 달력 생성",
    "Birthday calendars will be generated by a background job." : "배경 작업으로 생일 달력을 생성합니다.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "생일 달력이 생성되는 데 시간이 걸릴 수도 있습니다.",
    "Send notifications for events" : "일정에 대한 알림을 전송",
    "Notifications are sent via background jobs, so these must occur often enough." : "알림은 배경 작업을 통해 전송되므로, 충분히 자주 표시됩니다.",
    "Send reminder notifications to calendar sharees as well" : "캘린더 공유자에게도 미리 알림 보내기",
    "Reminders are always sent to organizers and attendees." : "미리 알림은 주최자와 참석자에게 항상 전송됩니다.",
    "Enable notifications for events via push" : "일정에 대한 푸시 알림 활성화",
    "Availability" : "시간 조율",
    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "업무 시간을 설정하면, 다른 사람이 회의를 예약할 때 내 부재 중 시간을 확인할 수 있습니다.",
    "Absence" : "부재",
    "Configure your next absence period." : "다음 부재 기간을 설정하십시오.",
    "There was an error updating your attendance status." : "참석 상태를 업데이트하는 중 오류가 발생했습니다.",
    "Please contact the organizer directly." : "주최자에게 직접 연락하십시오.",
    "Are you accepting the invitation?" : "초대를 수락하시겠습니까?",
    "Tentative" : "보류",
    "Your attendance was updated successfully." : "참석 정보를 업데이트했습니다."
},
"nplurals=1; plural=0;");
