OC.L10N.register(
    "office",
    {
    "Office" : "Tanarit",
    "Create new" : "Snulfu-d amaynut",
    "Blank" : "Ilem",
    "Search {category}" : "Nadi deg {category}",
    "Search" : "Nadi",
    "{count} found in {category}" : "{count} ttwafen deg {category}",
    "Filter files" : "Sizdeg ifuyla",
    "All" : "Akk",
    "Mine" : "Inu",
    "No {category} found" : "Ulac {category} yettwafen",
    "Search all in Files" : "Nadi deg akk ifuyla",
    "Create" : "Snulfu-d",
    "Filename" : "Isem n ufaylu",
    "Documents" : "Isemliyen",
    "Filename cannot be empty" : "Isem n ufaylu ulamek ara yili d ilem",
    "{count} {category} found" : "{count} {category} ttwafen"
},
"nplurals=2; plural=(n != 1);");
