OC.L10N.register(
    "circles",
    {
    "Personal" : "Անձնական",
    "Federated" : "Federated",
    "Owner" : "Owner",
    "Invalid file provided" : "Անվավեր նիշք",
    "File is too big" : "Նիշքը չափազանց մեծ է",
    "Invalid image" : "Անվավեր նկար",
    "Unknown filetype" : "Անհայտ նիշքի տեսակ",
    "Open %s" : "Բացել {նիշքիանուն}",
    "Save" : "Save",
    "Connect" : "միացնել",
    "Cancel" : "Cancel",
    "Folder" : "Պանակ",
    "Copy link" : "Պատճենել հղումը",
    "Close" : "Փակել",
    "New folder" : "Նոր պանակ",
    "Folder name" : "Պանակի անուն",
    "Calendar" : "Օրացույց",
    "Description" : "Նկարագրություն",
    "Edit" : "մշակել",
    "User" : "User",
    "Group" : "Խումբ",
    "Email" : "Էլ․փոստ",
    "Groups" : "Խմբեր",
    "No files in here" : "Ֆայլեր չկան այստեղ",
    "Name" : "Անուն",
    "Size" : "Չափս",
    "Modified" : "Փոփոխված"
},
"nplurals=2; plural=(n != 1);");
