OC.L10N.register(
    "app_api",
    {
    "Daemon config not found" : "No s'ha trobat la configuració del dimoni",
    "Error starting install of ExApp" : "S'ha produït un error en iniciar la instal·lació d'ExApp",
    "ExApp failed to register, check the NC logs" : "ExApp no s'ha pogut registrar, comproveu els registres NC",
    "ExApp not found, failed to get status" : "No s'ha trobat ExApp, no s'ha pogut obtenir l'estat",
    "This app is not installed from the AppStore. No extra information available. Only enable/disable and remove actions are allowed." : "Aquesta aplicació no està instal·lada des de l'AppStore. No hi ha informació addicional disponible. Només es permeten les accions d'activació/desactivació i eliminació.",
    "Could not perform installation of ExApp" : "No s'ha pogut realitzar la instal·lació d'ExApp",
    "Failed to enable ExApp" : "No s'ha pogut activar ExApp",
    "Failed to disable ExApp" : "No s'ha pogut desactivar ExApp",
    "Could not update ExApp" : "No s'ha pogut actualitzar ExApp",
    "Error starting update of ExApp" : "S'ha produït un error en iniciar l'actualització d'ExApp",
    "Could not perform update of ExApp" : "No s'ha pogut realitzar l'actualització d'ExApp",
    "ExApp not found, failed to get logs" : "No s'ha trobat ExApp, no s'han pogut obtenir els registres",
    "Failed to get container logs. Note: Downloading Docker container works only for containers with the json-file or journald logging driver. Error: %s" : "No s'han pogut obtenir els registres del contenidor. Nota: la descàrrega del contenidor Docker només funciona per a contenidors amb el controlador de registre json-file o journald. Error: %s",
    "ExApp not found, failed to get deploy options" : "No s'ha trobat ExApp, no s'han pogut obtenir les opcions de desplegament",
    "AppAPI authentication failed" : "Ha fallat l'autenticació de l'AppAPI",
    "AppAPI ExApp notifier" : "Notificador AppAPI ExApp",
    "AppAPI" : "AppAPI",
    "AI Integration Team" : "Equip d'integració d'IA",
    "ExApps Settings" : "Configuració d'ExApps",
    "Nextcloud AppAPI" : "Nextcloud AppAPI",
    "External Apps management" : "Gestió d'Apps externes",
    "Admin options saved" : "Opcions d'administració desades",
    "Failed to save admin options" : "No s'han pogut desar les opcions d'administració",
    "ExApp init timeout (minutes)" : "Temps d'espera d'inici ExApp (minuts)",
    "ExApp initialization process timeout after which AppAPI will mark it as failed" : "Temps d'espera del procés d'inicialització de l'ExApp després del qual AppAPI el marcarà com a fallat",
    "ExApp init timeout" : "Temps d'espera d'inici ExApp",
    "ExApp container restart policy" : "Política de reinici del contenidor ExApp",
    "Cancel" : "Cancelar",
    "Delete" : "Suprimir",
    "Password confirmation failed" : "La confirmació de la contrasenya ha fallat",
    "Default" : "Per defecte",
    "Set as default" : "Estableix com a predeterminat",
    "Test deploy" : "Prova de desplegament",
    "Edit" : "Edició",
    "Daemon connection successful" : "La connexió del dimoni ha estat correcta",
    "Unlimited" : "Il·limitat",
    "Default daemon. ExApps will be installed on it" : "Dimoni per defecte. S'hi instal·laran ExApps",
    "ExApps installed" : "ExApps instal·lades",
    "Name" : "Nom",
    "Protocol" : "Protocol",
    "Host" : "Servidor",
    "Deploy options" : "Opcions de desplegament",
    "Docker network" : "Xarxa Docker",
    "Nextcloud URL" : "Nextcloud URL",
    "HaProxy password" : "Contrasenya HaProxy",
    "Memory limit" : "Límit de memòria",
    "Additional options" : "Opcions addicionals",
    "Check connection" : "Comproveu la connexió",
    "Registered Deploy daemons list" : "Llista de dimonis de desplegament registrats",
    "Register ExApp in Nextcloud" : "Registreu ExApp a Nextcloud",
    "Check if the ExApp is registered in Nextcloud before deployment" : "Comproveu si l'ExApp està registrada a Nextcloud abans del desplegament",
    "Image pull" : "Tirada d'imatge",
    "Check if the image is successfully pulled" : "Comproveu si la imatge s'ha extret correctament",
    "Container started" : "El contenidor va començar",
    "Check if the image successfully pulled and container is created and started" : "Comproveu si la imatge s'ha extret correctament i el contenidor està creat i iniciat",
    "Heartbeat" : "Batec del cor",
    "Check for the heartbeat is finished and healthy" : "Comproveu que el batec del cor estigui acabat i saludable",
    "Init step" : "Pas inicial",
    "Wait for initialization step to finish" : "Espereu que finalitzi el pas d'inicialització",
    "Enabled" : "Habilitat",
    "Check if ExApp successfully handled the enabled event and registered all stuff properly" : "Comproveu si ExApp ha gestionat correctament l'esdeveniment habilitat i ha registrat totes les coses correctament",
    "Only if ExApp container is preset" : "Només si el contenidor ExApp està predefinit",
    "Deploy test passed successfully!" : "La prova de desplegament s'ha superat correctament!",
    "Deploy test failed at step \"{step}\"" : "La prova de desplegament ha fallat al pas \"{step}\"",
    "More information" : "Més informació",
    "Download ExApp logs" : "Baixeu els registres d'ExApp",
    "Remove" : "Suprimeix",
    "From" : "De",
    "To" : "A",
    "Add" : "Afegeix",
    "AppAPI Docker Socket Proxy authentication password" : "Contrasenya d'autenticació del servidor intermediari de l'AppAPI Docker Socket",
    "DaemonConfig successfully registered" : "DaemonConfig s'ha registrat correctament",
    "Failed to register DaemonConfig. Check the logs" : "No s'ha pogut registrar DaemonConfig. Comproveu els registres",
    "DaemonConfig successfully updated" : "DaemonConfig s'ha actualitzat correctament",
    "Failed to update DaemonConfig. Check the logs" : "No s'ha pogut actualitzar DaemonConfig. Comproveu els registres",
    "Failed to connect to Daemon. Check the logs" : "No s'ha pogut connectar amb Daemon. Comproveu els registres",
    "Failed to check connection to Daemon. Check the logs" : "No s'ha pogut comprovar la connexió amb Daemon. Comproveu els registres",
    "Daemon configuration template" : "Plantilla de configuració del dimoni",
    "Daemon registration form" : "Formulari de registre de Daemon",
    "Display name" : "Nom de visualització",
    "Deployment method" : "Mètode de desplegament",
    "Daemon host" : "Servidor del dimoni",
    "Compute device" : "Dispositiu de computació",
    "Add additional option" : "Afegeix una opció addicional",
    "Option key (unique)" : "Tecla d'opció (única)",
    "Option key (unique, e.g. my_key)" : "Clau d'opció (única, per exemple, my_key)",
    "Option key is required" : "La clau d'opció és necessària",
    "Option value" : "Valor de l'opció",
    "Option value is required" : "El valor de l'opció és obligatori",
    "Confirm" : "Confirma",
    "Save" : "Desar",
    "Register" : "Registra",
    "External Apps" : "Apps externes",
    "### Boost your Nextcloud with AppAPI and its specially designed applications.\n\n\nThe AppAPI is a project within the Nextcloud ecosystem designed to streamline and enhance the process of\napplication development, deployment, and management.\n\nIt introduces a new methodology that allows developers to create\napplications using a variety of programming languages, not limited to PHP, which was traditionally used in Nextcloud development.\n\n### Bundled App\n\n**Starting with Nextcloud 30.0.1, this application is included in the default Nextcloud package.**\n\n### Support\n\nWe appreciate any support for this project:\n\n- ⭐ Star our work on GitHub\n- ❗ Create an Issue or feature request\n- 💁 Resolve an Issue and create a Pull Request\n- 🧑‍💻 Develop your own application using AppAPI\n\nWe are genuinely excited about the future of the AppAPI project and its potential to transform\nthe way applications are developed and experienced within Nextcloud.\n\nAs we embark on this journey, we warmly invite you - developers, thinkers, creators, and visionaries -\nto join us in shaping a more versatile, stable, and secure app landscape.\n\n*Your insights, suggestions, and contributions are invaluable to us.*" : "### Potencia el teu Nextcloud amb AppAPI i les seves aplicacions especialment dissenyades.\n\n\nL'AppAPI és un projecte dins de l'ecosistema Nextcloud dissenyat per racionalitzar i millorar el procés de\ndesenvolupament, desplegament i gestió d'aplicacions.\n\nIntrodueix una nova metodologia que permet als desenvolupadors crear\naplicacions que utilitzen una varietat de llenguatges de programació, no limitats a PHP, que s'utilitzava tradicionalment en el desenvolupament de Nextcloud.\n\n### Aplicació empaquetada\n\n**A partir de Nextcloud 30.0.1, aquesta aplicació s'inclou al paquet per defecte de Nextcloud.**\n\n### Suport\n\nAgraïm qualsevol suport a aquest projecte:\n\n- ⭐ Destaca el nostre treball a GitHub\n- ❗ Crear un problema o sol·licitud de funció\n- 💁 Resoldre un problema i crear una sol·licitud d'extracció\n- 🧑‍💻 Desenvolupa la teva pròpia aplicació mitjançant AppAPI\n\nEstem realment entusiasmats amb el futur del projecte AppAPI i el seu potencial de transformació\nla manera com es desenvolupen i s'experimenten les aplicacions a Nextcloud.\n\nA mesura que ens embarquem en aquest viatge, us convidem cordialment: desenvolupadors, pensadors, creadors i visionaris.\nper unir-nos a la creació d'un panorama d'aplicacions més versàtil, estable i segur.\n\n*Els vostres coneixements, suggeriments i contribucions són inestimables per a nosaltres.*",
    "The AppAPI Project is an exciting initiative that aims to revolutionize the way applications are developed for Nextcloud." : "El projecte AppAPI és una iniciativa emocionant que pretén revolucionar la manera com es desenvolupen les aplicacions per a Nextcloud.",
    "Deploy Daemons" : "Desplega els dimonis",
    "Deploy Daemon (DaemonConfig) is an ExApps orchestration daemon." : "Deploy Daemon (DaemonConfig) és un dimoni d'orquestració d'ExApps.",
    "Deploy Daemons. Deploy Daemon (DaemonConfig) is an ExApps orchestration daemon." : "Desplega els dimonis. Deploy Daemon (DaemonConfig) és un dimoni d'orquestració d'ExApps.",
    "Default Deploy Daemon is not accessible. Please verify its configuration" : "El dimoni de desplegament predeterminat no és accessible. Verifiqueu-ne la configuració",
    "Specify container restart policy, e.g. 'always' to ensure ExApp running after daemon server reboot" : "Especifiqueu la política de reinici del contenidor, p.ex. 'always' per garantir que ExApp s'executi després del reinici del servidor del dimoni",
    "This settings changes are reflected only for newly created containers" : "Els canvis d'aquesta configuració només es reflecteixen als contenidors de nova creació",
    "{license}-licensed" : "sota la llicència - {license}",
    "Update to {version}" : "Actualització a la versió {version}",
    "Delete data on remove" : "Suprimir dades en eliminar",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Aquesta aplicació no té cap versió mínima de Nextcloud assignada. Això serà un error en el futur.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Aquesta aplicació no té cap versió màxima de Nextcloud assignada. Això serà un error en el futur.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Aquesta aplicació no es pot instal·lar perquè les següents dependències no es compleixen:",
    "View in store" : "Mostra-ho a la botiga",
    "Visit website" : "Visita el lloc web",
    "Report a bug" : "Informa d'un error",
    "User documentation" : "Documentació per a usuaris",
    "Admin documentation" : "Documentació per a administradors",
    "Developer documentation" : "Documentació per a desenvolupadors",
    "This app is not registered in AppStore. No extra information available. Only enable/disable and remove actions are allowed." : "Aquesta aplicació no està registrada a AppStore. No hi ha informació addicional disponible. Només es permeten les accions d'activació/desactivació i eliminació.",
    "This app is supported via your current Nextcloud subscription." : "Aquesta aplicació és compatible amb la vostra subscripció actual a Nextcloud.",
    "Supported" : "Compatible",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Les aplicacions destacades es desenvolupen per i dins de la comunitat. Ofereixen funcionalitats centrals i estan preparades per ser emprades en producció.",
    "Featured" : "Destacada",
    "Update to {update}" : "Actualitza a {update}",
    "All ExApps are up-to-date." : "Totes les ExApps estan actualitzades.",
    "Default Deploy daemon is not accessible" : "El dimoni de desplegament predeterminat no és accessible",
    "Icon" : "Icona",
    "Version" : "Versió",
    "Daemon" : "Dimoni",
    "Level" : "Nivell",
    "Actions" : "Accions",
    "Results from other categories" : "Resultats d'altres categories",
    "No apps found" : "No s'ha trobat cap aplicació",
    "_%n ExApp has an update available_::_%n apps have an update available_" : ["%n ExApp té una actualització disponible","%n apps tenen una actualització disponible"],
    "_Update_::_Update all_" : ["Actualitza","Actualitza-les totes"],
    "Deploy Daemon" : "Desplega Dimoni",
    "Type" : "Tipus",
    "Display Name" : "Nom d'usuari",
    "GPUs support" : "Suport de GPU",
    "Are you sure you want delete Deploy Daemon" : "Esteu segur que voleu suprimir Deploy Daemon",
    "All ExApps on this daemon will be removed" : "S'eliminaran totes les ExApps d'aquest dimoni",
    "All ExApps installed on this daemon will be removed" : "S'eliminaran totes les ExApps instal·lades en aquest dimoni",
    "\"manual-install\" Deploy Daemon cannot be set as default" : "\"manual-install\" Deploy Daemon no es pot establir com a predeterminat",
    "Failed to save admin options. Check the logs" : "No s'han pogut desar les opcions d'administració. Comproveu els registres",
    "Deploy daemon config details" : "Desplegueu els detalls de configuració del dimoni",
    "Manual install daemon usually used for development. It cannot be set as default daemon." : "El dimoni d'instal·lació manual s'utilitza normalment per al desenvolupament. No es pot establir com a dimoni per defecte.",
    "Deploy config" : "Desplega la configuració",
    "Verify connection" : "Verifica la connexió",
    "No Deploy daemons configured" : "No s'ha configurat cap dimoni de desplegament",
    "Register a custom one or setup from available templates" : "Registreu-ne un personalitzat o configureu-ne a partir de les plantilles disponibles",
    "Register Daemon" : "Registre Daemon",
    "AppAPI will try to install small skeleton ExApp to verify Daemon configured correctly and deployment steps are passing." : "L'AppAPI intentarà instal·lar l'ExApp d'esquelet petit per verificar que Daemon està configurat correctament i que s'estan passant els passos de desplegament.",
    "The following Deploy test checks must be passed to succeed:" : "Per tenir èxit, s'han de superar les comprovacions de prova de desplegament següents:",
    "More info" : "Més informació",
    "Remove test ExApp" : "Elimina la prova ExApp",
    "Start Deploy test" : "Inicieu la prova de desplegament",
    "Stop Deploy test" : "Atura la prova de desplegament",
    "ExApp is unregistered and container is removed on \"Stop deploy test\"" : "ExApp no està registrada i el contenidor s'elimina a \"Atura la prova de desplegament\"",
    "Hostname to access ExApps" : "Nom de servidor per accedir a ExApps",
    "Hostname or path to access Docker daemon (e.g. nextcloud-appapi-dsp:2375, /var/run/docker.sock)" : "Nom de servidor o camí per accedir al dimoni Docker (p. ex. nextcloud-appapi-dsp:2375, /var/run/docker.sock)",
    "Daemon with this name already exists" : "El dimoni amb aquest nom ja existeix",
    "Password must be at least 12 characters long" : "La contrasenya ha de tenir com a mínim 12 caràcters",
    "With https enabled network is set to host" : "Amb https habilitat, la xarxa està configurada com a host",
    "Changes would be applied only for newly installed ExApps. For existing ExApps, Docker containers should be recreated." : "Els canvis només s'aplicarien a les ExApps recentment instal·lades. Per a les ExApps existents, els contenidors Docker s'han de tornar a crear.",
    "URL should start with http:// or https://" : "L'URL hauria de començar per http:// o https://",
    "For HTTPS daemon, Nextcloud URL should be HTTPS" : "Per al dimoni HTTPS, l'URL de Nextcloud hauria de ser HTTPS",
    "All available GPU devices on daemon host will be requested to be enabled in ExApp containers by Docker." : "Docker sol·licitarà que tots els dispositius GPU disponibles a l'amfitrió del dimoni estiguin habilitats als contenidors ExApp.",
    "Edit Deploy Daemon" : "Edita Deploy Daemon",
    "Register Deploy Daemon" : "Registre Deploy Daemon",
    "Select daemon configuration template" : "Seleccioneu la plantilla de configuració del dimoni",
    "Unique Deploy Daemon Name" : "Nom únic del dimoni de desplegament",
    "Select daemon deploy method" : "Seleccioneu el mètode de desplegament del dimoni",
    "Set daemon as default" : "Estableix el dimoni com a predeterminat",
    "Set as default daemon" : "Estableix com a dimoni predeterminat",
    "Enable https" : "Activa https",
    "Show deploy config" : "Mostra la configuració de desplegament",
    "Hide deploy config" : "Amaga la configuració de desplegament",
    "Network" : "Xarxa",
    "Docker network name" : "Nom de la xarxa Docker",
    "Additional option" : "Opció addicional",
    "by {author}\n{license}" : "{author}\n{license}",
    "Your apps" : "Les vostres aplicacions",
    "Documentation" : "Documentació",
    "Details" : "Detalls",
    "Changelog" : "Registre de canvis",
    "Active apps" : "Aplicacions actives",
    "Disabled apps" : "Aplicacions inhabilitades",
    "Updates" : "Actualitzacions",
    "Featured apps" : "Aplicacions destacades",
    "Supported apps" : "Aplicacions compatibles",
    "manual-install apps cannot be updated" : "les aplicacions d'instal·lació manual no es poden actualitzar",
    "{progress}% Deploying" : "{progress}% de desplegament",
    "{progress}% Initializing" : "{progress}% d'inicialització",
    "Healthchecking" : "Control de salut",
    "Deploy and Enable" : "Desplega i activa",
    "Enable" : "Activa",
    "Disable" : "Inhabilita",
    "Allow untested app" : "Permet l'aplicació no provada",
    "Default Deploy daemon is not accessible. Please verify configuration" : "El dimoni de desplegament predeterminat no és accessible. Verifiqueu la configuració",
    "The app will be downloaded from the App Store and deployed on default Deploy Daemon" : "L'aplicació es baixarà des de l'App Store i es desplegarà de manera predeterminada Deploy Daemon",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Aquesta aplicació no està marcada com a compatible amb la vostra versió de Nextcloud. Si continueu, encara podreu instal·lar l’aplicació. Tingueu en compte que pot ser que l’aplicació no funcioni correctament.",
    "Your ExApps" : "Les teves ExApps",
    "An error occurred during the request. Unable to proceed." : "S'ha produït un error durant la sol·licitud. No es pot continuar.",
    "The app has been enabled but needs to be updated." : "L'aplicació s'ha habilitat, però s'ha d'actualitzar.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Error: aquesta aplicació no es pot habilitar perquè fa que el servidor sigui inestable",
    "### Boost your Nextcloud with AppAPI and its specially designed applications.\n\n\nThe AppAPI is a project within the Nextcloud ecosystem designed to streamline and enhance the process of\napplication development, deployment, and management.\n\nIt introduces a new methodology that allows developers to create\napplications using a variety of programming languages, not limited to PHP, which was traditionally used in Nextcloud development.\n\n\n### List of applications that require AppAPI:\n\n- [talk_bot_ai_example](https://github.com/cloud-py-api/talk_bot_ai_example)\n- [upscaler_example](https://github.com/cloud-py-api/upscaler_example)\n- [image_to_text_example](https://github.com/cloud-py-api/file_to_text_example)\n- [ai_image_generator_bot](https://github.com/cloud-py-api/ai_image_generator_bot)\n- [SummarAI](https://github.com/nextcloud/sumupbot)\n\n_If you wish to develop an application, we will gladly help and assist you._\n\n### Support\n\nWe appreciate any support for this project:\n\n- ⭐ Star our work on GitHub\n- ❗ Create an Issue or feature request\n- 💁 Resolve an Issue and create a Pull Request\n- 🧑‍💻 Develop your own application using AppAPI\n\nWe are genuinely excited about the future of the AppAPI project and its potential to transform\nthe way applications are developed and experienced within Nextcloud.\n\nAs we embark on this journey, we warmly invite you - developers, thinkers, creators, and visionaries -\nto join us in shaping a more versatile, stable, and secure app landscape.\n\n*Your insights, suggestions, and contributions are invaluable to us.*" : "### Potencia el teu Nextcloud amb AppAPI i les seves aplicacions especialment dissenyades.\n\n\nL'AppAPI és un projecte dins de l'ecosistema Nextcloud dissenyat per racionalitzar i millorar el procés de\ndesenvolupament, desplegament i gestió d'aplicacions.\n\nIntrodueix una nova metodologia que permet als desenvolupadors crear\naplicacions que utilitzen una varietat de llenguatges de programació, no limitats a PHP, que s'utilitzava tradicionalment en el desenvolupament de Nextcloud.\n\n\n### Llista d'aplicacions que requereixen AppAPI:\n\n- [talk_bot_ai_example](https://github.com/cloud-py-api/talk_bot_ai_example)\n- [exemple_upscaler](https://github.com/cloud-py-api/exemple_upscaler)\n- [image_to_text_example](https://github.com/cloud-py-api/file_to_text_example)\n- [ai_image_generator_bot](https://github.com/cloud-py-api/ai_image_generator_bot)\n- [SummarAI](https://github.com/nextcloud/sumupbot)\n\n_Si voleu desenvolupar una aplicació, estarem encantats d'ajudar-vos i ajudar-vos._\n\n### Suport\n\nAgraïm qualsevol suport a aquest projecte:\n\n- ⭐ Destaca el nostre treball a GitHub\n- ❗ Crear un problema o sol·licitud de funció\n- 💁 Resoldre un problema i crear una sol·licitud d'extracció\n- 🧑‍💻 Desenvolupa la teva pròpia aplicació mitjançant AppAPI\n\nEstem realment entusiasmats amb el futur del projecte AppAPI i el seu potencial de transformació\nla manera com es desenvolupen i s'experimenten les aplicacions a Nextcloud.\n\nA mesura que ens embarquem en aquest viatge, us convidem cordialment: desenvolupadors, pensadors, creadors i visionaris.\nper unir-nos a la creació d'un panorama d'aplicacions més versàtil, estable i segur.\n\n*Els vostres coneixements, suggeriments i contribucions són inestimables per a nosaltres.*"
},
"nplurals=2; plural=(n != 1);");
