OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "Волшебник при прво стартување",
    "Add your profile information! For example your email is needed to receive notifications." : "Додадете ги вашите информации на сметката! Како пример вашата е-пошта адресата е потребна за добивање на известувања.",
    "Add your profile information! For example your email is needed to receive notifications and reset your password." : "Додадете ги вашите информации на сметката! Како пример вашата е-пошта адресата е потребна за добивање на известувања и ресетирање на вашата лозинка.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Додадете ги вашите информации на сметката! Поставете слика на профилот и целосно име и презиме за едноставно препознавање при користење на сите можности.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Додадете ги вашите информации на сметката! Поставете целосно име и презиме за едноставно препознавање при користење на сите можности.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Додадете ги вашите информации на сметката! Поставете слика на профилот за едноставно препознавање при користење на сите можности.",
    "Schedule work & meetings, synced with all your devices." : "Работни задачи & состаноци, синхронизирани со сите ваши уреди.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Чувајте ги вашите колеги и пријатели на едно место без да ги разоткривате нивните приватни информации.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Едноставна апликација за е-пошта интегрирана со Датотеки, Контакти, Календар.",
    "App recommendation: Tasks" : "Препорака за апликација: Задачи",
    "Sync tasks from various devices with your Nextcloud and edit them online." : "Синхронизирајте од различни уреди и уредувајте ги онлајн.",
    "App recommendation: Deck" : "Препорака за апликација: Deck",
    "Kanban style organization for personal planning and team projects." : "Организација во стил Канбан за лично планирање и тимски проекти.",
    "App recommendation: Forms" : "Препорака за апликација: Форми",
    "Simple surveys and questionnaires, self-hosted" : "Едноставни анкети и прашалници, самостојно хостирани",
    "App recommendation: Recognize" : "Препорака за апликација: Препознавање",
    "Smart media tagging for Nextcloud" : "Паметно означување на медиа датотеките",
    "App recommendation: Group folders" : "Препорака за апликација: Групни папки",
    "Admin-configured folders shared by everyone in a group." : "Споделена папка од администратор за сите во една група.",
    "Connect your calendar" : "Поврзете го вашикот календар",
    "Connect your contacts" : "Поврзете ги вашите контакти",
    "Access files via WebDAV" : "Пристапи до датотеките преку WebDAV",
    "Download macOS/iOS configuration profile" : "Преземете macOS/iOS конфигурациски профил",
    "Desktop client" : "Клиент за компјутер",
    "Android app on Google Play Store" : "Android апликација на Google Play Store",
    "Android app on F-Droid" : "Android апликација на F-Droid",
    "iOS app" : "iOS апликација",
    "A welcome and introduction wizard for Nextcloud" : "Добредојдовте и волшебник со инструкциски за Nextcloud",
    "This application enables a pop-up window when a user first logs into Nextcloud. This window welcomes new users to Nextcloud, and contains links to the standard desktop client, Android app, and the iOS app. The window also shows a link for accessing Nextcloud via WebDAV. At any time, the first run wizard can be opened again via link \"About\" on settings menu.\nThe First run wizard can be customized to meet specific design goals, or to change links and messages. Create an appropriate theme following the Theming documentation, and changes to the look and feel of this Wizard are simple. More information is available in the first run wizard documentation, as well as the theming documentation." : "Оваа апликација овозможува скокачки прозор кога корисник за првпат ќе се најави на Nextcloud. Овој прозорец ги поздравува новите корисници во Nextcloud, и содржи линкови до стандардните клиенти за компјутер, апликација за Android и апликација iOS. Прозорецот исто така покажува линк за пристап до Nextcloud преку WebDAV. Во секое време, волшебникот може да се отвори повторно преку линкот \"За\" во менито за поставки.\nВолшебникот може да се прилагоди за специфични цели на дизајн или за промена на врски и пораки. Создадете соодветна тема, и промените во изгледот на овој Волшебник се едноставни. Повеќе информации се достапни во документацијата за волшебникот, како и во документацијата за темите.",
    "Close" : "Затвори",
    "Welcome to {cloudName}!" : "Добредојдовте во {cloudName}!",
    "Skip" : "Прескокни",
    "Privacy" : "Приватност",
    "Community" : "Заедница",
    "Share via email" : "Сподели преку е-пошта",
    "Get the apps to sync your files" : "Преземете апликации за синхронизирање на вашите датотеки",
    "Server address" : "Адреса на серверот",
    "Use this link to connect your apps and desktop client to this server:" : "Користете го овој линк за да ги поврзете вашите апликации со серверот:",
    "What's new?" : "Што е ново"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
