const y="modulepreload",g=function(i,c){return new URL(i,c).href},h={},v=function(i,c,u){let e=Promise.resolve();if(c&&c.length>0){let n=function(r){return Promise.all(r.map(l=>Promise.resolve(l).then(d=>({status:"fulfilled",value:d}),d=>({status:"rejected",reason:d}))))};const o=document.getElementsByTagName("link"),m=document.querySelector("meta[property=csp-nonce]"),p=m?.nonce||m?.getAttribute("nonce");e=n(c.map(r=>{if(r=g(r,u),r in h)return;h[r]=!0;const l=r.endsWith(".css"),d=l?'[rel="stylesheet"]':"";if(u)for(let a=o.length-1;a>=0;a--){const f=o[a];if(f.href===r&&(!l||f.rel==="stylesheet"))return}else if(document.querySelector(`link[href="${r}"]${d}`))return;const s=document.createElement("link");if(s.rel=l?"stylesheet":y,l||(s.as="script"),s.crossOrigin="",s.href=r,p&&s.setAttribute("nonce",p),document.head.appendChild(s),l)return new Promise((a,f)=>{s.addEventListener("load",a),s.addEventListener("error",()=>f(new Error(`Unable to preload CSS for ${r}`)))})}))}function t(n){const o=new Event("vite:preloadError",{cancelable:!0});if(o.payload=n,window.dispatchEvent(o),!o.defaultPrevented)throw n}return e.then(n=>{for(const o of n||[])o.status==="rejected"&&t(o.reason);return i().catch(t)})};(function(){const i=document.createElement("link").relList;if(i&&i.supports&&i.supports("modulepreload"))return;for(const e of document.querySelectorAll('link[rel="modulepreload"]'))u(e);new MutationObserver(e=>{for(const t of e)if(t.type==="childList")for(const n of t.addedNodes)n.tagName==="LINK"&&n.rel==="modulepreload"&&u(n)}).observe(document,{childList:!0,subtree:!0});function c(e){const t={};return e.integrity&&(t.integrity=e.integrity),e.referrerPolicy&&(t.referrerPolicy=e.referrerPolicy),e.crossOrigin==="use-credentials"?t.credentials="include":e.crossOrigin==="anonymous"?t.credentials="omit":t.credentials="same-origin",t}function u(e){if(e.ep)return;e.ep=!0;const t=c(e);fetch(e.href,t)}})();export{v as _};
//# sourceMappingURL=modulepreload-polyfill-CBWYtosv.chunk.mjs.map
