OC.L10N.register(
    "support",
    {
    "Link:" : "Tengill:",
    "Password:" : "Lykilorð:",
    "Generating system report failed." : "Gerð kerfisskýrslu mistókst.",
    "Subscription notifications" : "Tilkynningar um áskriftir",
    "Nextcloud Subscription" : "Nextcloud áskrift",
    "Your server has no Nextcloud Subscription or your Subscription has expired." : "Þjónninn þinn er ekki með neina Nextcloud-áskrift eða að áskriftin þín er útrunnin.",
    "Your Nextcloud Subscription has expired!" : "Nextcloud áskriftin þín er útrunnin!",
    "Your server has no Nextcloud Subscription" : "Þjónninn þinn er ekki með neina Nextcloud-áskrift",
    "Learn more now" : "Læra meira núna",
    "Dear admin," : "Kæri stjórnandi,",
    "Thank you," : "Bestu þakkir,",
    "Your Nextcloud team" : "Nextcloud teymið þitt",
    "Support" : "Aðstoð",
    "Getting support and help for your Nextcloud" : "Fáðu stuðning og hjálp fyrir Nextcloud-skýið þitt",
    "Basic subscription" : "Einföld áskrift",
    "Standard subscription" : "Venjuleg áskrift",
    "Subscription" : "Áskrift",
    "Valid subscription" : "Gild áskrift",
    "Expired subscription" : "Útrunnin áskrift",
    "Subscription key:" : "Áskriftarlykill:",
    "_For %n users_::_For %n users_" : ["Fyrir %n notanda","Fyrir %n notendur"],
    "_currently at %n user_::_currently at %n users_" : ["núna með %n notanda","núna með %n notendur"],
    "Includes support for %s" : "Innifelur aðstoð fyrir %s",
    "Includes support for %1$s & %2$s" : "Innifelur aðstoð fyrir %1$s & %2$s",
    "Includes support for %1$s, %2$s & %3$s" : "Innifelur aðstoð fyrir %1$s, %2$s & %3$s",
    "Update subscription key" : "Uppfæra áskriftarlykil",
    "System information" : "Kerfisupplýsingar",
    "Generate system report" : "Útbúa kerfisskýrslu",
    "Unsupported" : "Óstutt",
    "Advantages" : "Kostir",
    "Get a quote" : "Fáðu tilboð",
    "More information" : "Nánari upplýsingar",
    "Pricing" : "Verðskrá",
    "Forum" : "Vefspjall",
    "Nextcloud forum" : "Nextcloud spjallsvæði",
    "GitHub" : "GitHub",
    "Nextcloud at GitHub" : "Nextcloud á GitHub",
    "Subscription key" : "Áskriftarlykill",
    "Set subscription key" : "Setja áskriftarlykil",
    "The subscription key was invalid." : "Áskriftarlykillinn er ógildur.",
    "News" : "Fréttir",
    "Like our Facebook page" : "Líkaðu við Facebook-síðuna okkar",
    "Follow us on Twitter" : "Fylgstu með okkur á Twitter",
    "Check out our blog" : "Kíktu á bloggið okkar",
    "Subscribe to our newsletter" : "Gerstu áskrifandi að fréttabréfinu okkar"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
