OC.L10N.register(
    "notifications",
    {
    "We want to keep offering our push notification service for free, but large number of users overload our infrastructure. For this reason we have to rate-limit the use of push notifications. If you need this feature, consider using Nextcloud Enterprise." : "Gure push jakinarazpen zerbitzua doan eskaintzen jarraitu nahi dugu, baina erabiltzaile kopuru handiek gure azpiegiturak gainkargatzen dituzte. Hori dela eta, push jakinarazpenen erabilera mugatu behar dugu. Ezaugarri hau behar baduzu, Nextcloud Enterprise erabili.",
    "User not found" : "Ez da erabiltzailea aurkitu",
    "An unexpected error occurred, ask your administration to check the logs." : "Ezusteko akats bat gertatu da. Eskatu zure administrazioari egunkariak egiaztatzeko.",
    "Hello %s" : "Kaixo %s",
    "Hello %s," : "Kaixo %s,",
    "_New notification for %s_::_%n new notifications for %s_" : ["Jakinarazpen berria %s(r)entzat","%n jakinarazpen berri %s(r)entzat"],
    "_You have a new notification for %s_::_You have %n new notifications for %s_" : ["Jakinarazpen berri bat duzu %s(r)entzat","%n jakinarazpen berri dituzu %s(r)entzat"],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "E-posta hauen maiztasuna aldatu edo desgaitu ditzakezu <a href=\"%s\">ezarpenetan</a>.",
    "You can change the frequency of these emails or disable them in the settings: %s" : "E-posta hauen maiztasuna aldatu edo desgaitu ditzakezu ezarpenetan: %s",
    "Admin notifications" : "Administratzailearen jakinarazpenak",
    "Notifications" : "Jakinarazpenak",
    "Push notifications - Fair use policy" : "Push jakinarazpenak - Bidezko erabilpen-politika ",
    "Nextcloud GmbH sponsors a free push notification gateway for private users. To ensure good service, the gateway limits the number of push notifications per server and the limit was reached for this server. For enterprise users, a more scalable gateway is available." : "Nextcloud GmbH-k erabiltzaile pribatuentzako doako push jakinarazpen-sarbide bat babesten du. Zerbitzu ona bermatzeko, sarbide horrek zerbitzari bakoitzeko push jakinarazpen kopurua mugatzen du. Enpresa erabiltzaileentzat, badago sarbide eskalagarriago bat.",
    "This app provides a backend and frontend for the notification API available in Nextcloud." : "Aplikazio honek Nextclouden dagoen jakinarazpen APIaren backend eta frontend zerbitzua eskaintzen du.",
    "This app provides a backend and frontend for the notification API available in Nextcloud.\n\t\tThe API is used by other apps to notify users in the web UI and sync clients about various things. Some examples are:\n\n📬 Federated file sharing: You received a new remote share\n\n📑 Comments: Another user mentioned you in a comment on a file\n\n🚢 Update notification: Available update for an app or nextcloud itself\n\n📣 Announcement center: An announcement was posted by an admin" : "Aplikazio honek Nextclouden jakinarazpenen APIaren backend eta frontend zerbitzua eskaintzen du.\n\t\tAPIa beste aplikazio batzuk erabiltzen dute erabiltzaileei webgunean edo sinkronizazio bezeroetan hainbat gauzaren inguruko jakinarazpenak bidaltzeko. Adibidez:\n\n📬 Federatutako partekatzea: urruneko partekatze bat jaso duzu\n\n📑 Iruzkinak: beste erabiltzaile batek fitxategi baten egin duen iruzkin baten aipatu egin zaitu\n\n🚢 Eguneraketen jakinarazpena: aplikazio baten edo Nextcloud beraren eguneraketa bat dago\n\n📣 Iragarpenen zentroa: kudeatzaile batek iragarpen bat argitaratu du",
    "Failed to perform action" : "Huts egin du ekintza burutzean",
    "Failed to dismiss notification" : "Huts egin du jakinarazpena baztertzean",
    "Dismiss" : "Baztertu",
    "Contact Nextcloud GmbH" : "Jarri harremanetan Nextcloud GmbH-rekin",
    "in {path}" : "{path} -en",
    "Push notifications might be unreliable" : "Push jakinarazpenek fidagarritasun gutxi izan dezakete",
    "Nextcloud GmbH sponsors a free push notification gateway for private users. To ensure good service, the gateway limits the number of push notifications per server. For enterprise users, a more scalable gateway is available. Contact Nextcloud GmbH for more information." : "Nextcloud GmbH-k erabiltzaile pribatuentzako doako push jakinarazpen-sarbide bat babesten du. Zerbitzu ona bermatzeko, sarbide horrek zerbitzari bakoitzeko push jakinarazpen kopurua mugatzen du. Enpresa erabiltzaileentzat, badago sarbide eskalagarriago bat. Jarri harremanetan Nextcloud GmbH-rekin informazio gehiago lortzeko.",
    "Requesting browser permissions to show notifications" : "Jakinarazpenak erakusteko nabigatzaileari baimena eskatzen",
    "No notifications" : "Ez dago jakinarazpenik",
    "Failed to dismiss all notifications" : "Huts egin du jakinarazpen guztiak baztertzean",
    "Dismiss all notifications" : "Baztertu jakinarazpen guztiak",
    "Never" : "Inoiz ez",
    "1 hour" : "Ordu 1",
    "3 hours" : "3 ordu",
    "1 day" : "egun 1",
    "1 week" : "Aste 1",
    "Your settings have been updated." : "Zure ezarpenak eguneratu dira.",
    "An error occurred while updating your settings." : "Errore bat gertatu da ezarpenak eguneratzean.",
    "Notifications defaults" : "Jakinarazpen lehenetsiak",
    "Configure the default notification settings" : "Konfiguratu aurrez zehaztutako jakinarazpenen ezarpenak",
    "Send email reminders about unhandled notifications after:" : "Bidali e-posta abisuak kudeatu gabeko jakinarazpenei buruz honen ondoren:",
    "Play sound when a new notification arrives" : "Erreproduzitu soinua jakinarazpen berri bat iristen denean",
    "Play sound when a call started (requires Nextcloud Talk)" : "Erreproduzitu soinua deia hasten denean (Nextcloud Talk behar da)",
    "Web push settings" : "Web push ezarpenak",
    "Web push is a push notification system that lets web applications send notifications to users´ mobile apps or browser, even when the app is not open in a tab." : "Web push web aplikazioei erabiltzaileen mugikorreko aplikazioetara edo arakatzaileetara jakinarazpenak bidaltzeko aukera ematen dien push jakinarazpen sistema bat da, aplikazioa fitxa batean irekita ez dagoenean ere.",
    "Web push notifications are encrypted but routed through services provided by Mozilla, Microsoft, Apple, Google or user-choosen ones in case of mobile apps. While the content is protected, metadata such as timing and frequency of notifications may be exposed to these providers." : "Web push jakinarazpenak enkriptatuta daude baina Mozillak, Microsoftek, Applek, Googlek edo erabiltzaileak aukeratutako zerbitzuen bidez bideratzen dira mugikorreko aplikazioen kasuan. Edukia babestuta baina metadatuak (adibidez, jakinarazpenen denbora eta maiztasuna bezalako metadatuak) hornitzaile horiek eskura ditzakete.",
    "Allow web push to be used" : "Baimendu web push-aren erabilera",
    "Allow web push for browsers" : "Baimendu web push-ak nabigatzileei",
    "None" : "Bat ere ez",
    "You need to set up your email address before you can receive notification emails." : "Zure helbide elektronikoa konfiguratu behar duzu jakinarazpenak posta elektronikoz jasotzeko.",
    "Also repeat sound on a secondary speaker" : "Errepikatu soinua bigarren mailako bozgorailu batean ere",
    "Selection of the speaker device is currently not supported by Safari" : "Safari-k ez du onartzen bozgorailuaren gailua hautatzea",
    "Select a device" : "Hautatu gailu bat"
},
"nplurals=2; plural=(n != 1);");
