OC.L10N.register(
    "comments",
    {
    "Comments" : "Kommentarer",
    "You commented" : "Du kommenterade",
    "{author} commented" : "{author} kommenterade",
    "You commented on %1$s" : "Du kommenterade %1$s",
    "You commented on {file}" : "Du kommenterade {file}",
    "%1$s commented on %2$s" : "%1$s kommenterade %2$s",
    "{author} commented on {file}" : "{author} kommenterade {file}",
    "<strong>Comments</strong> for files" : "<strong>Kommentarer</strong> för filer",
    "Files" : "Filer",
    "You were mentioned on \"{file}\", in a comment by an account that has since been deleted" : "Du nämndes i en kommentar om \"{file}\" av ett konto som sedan har tagits bort",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} nämnde dig i en kommentar om \"{file}\"",
    "Go to file" : "Gå till fil",
    "Files app plugin to add comments to files" : "Insticksmodul för appen Filer som lägger till kommentarer till filer",
    "Edit comment" : "Redigera kommentar",
    "Delete comment" : "Ta bort kommentar",
    "Cancel edit" : "Avbryt redigering",
    "New comment" : "Ny kommentar",
    "Write a comment …" : "Skriv en kommentar …",
    "Post comment" : "Publicera kommentar",
    "@ for mentions, : for emoji, / for smart picker" : "@ för omnämnanden, : för emojier och / för smartväljaren",
    "Could not reload comments" : "Det gick inte att läsa in kommentarerna på nytt",
    "Failed to mark comments as read" : "Det gick inte att markera kommentarerna som lästa",
    "Unable to load the comments list" : "Det gick inte att läsa in kommentarlistan",
    "No comments yet, start the conversation!" : "Inga kommentarer ännu – inled samtalet!",
    "No more messages" : "Inga fler meddelanden",
    "Retry" : "Försök igen",
    "_1 new comment_::_{unread} new comments_" : ["1 ny kommentar","{unread} nya kommentarer"],
    "Comment" : "Kommentar",
    "An error occurred while trying to edit the comment" : "Ett fel uppstod vid redigering av kommentaren",
    "Comment deleted" : "Kommentar borttagen",
    "An error occurred while trying to delete the comment" : "Ett fel uppstod vid borttagning av kommentaren",
    "An error occurred while trying to create the comment" : "Ett fel uppstod vid skapande av kommentaren",
    "Write a comment …" : "Skriv en kommentar …"
},
"nplurals=2; plural=(n != 1);");
