OC.L10N.register(
    "notifications",
    {
    "We want to keep offering our push notification service for free, but large number of users overload our infrastructure. For this reason we have to rate-limit the use of push notifications. If you need this feature, consider using Nextcloud Enterprise." : "Θέλουμε να συνεχίσουμε να προσφέρουμε την υπηρεσία push ειδοποιήσεων δωρεάν, αλλά μεγάλος αριθμός χρηστών υπερφορτώνει την υποδομή μας. Για αυτόν τον λόγο πρέπει να περιορίσουμε το ρυθμό χρήσης των push ειδοποιήσεων. Εάν χρειάζεστε αυτή τη λειτουργία, εξετάστε τη χρήση του Nextcloud Enterprise.",
    "User not found" : "Ο/Η χρήστης δεν βρέθηκε",
    "An unexpected error occurred, ask your administration to check the logs." : "Προέκυψε ένα μη αναμενόμενο σφάλμα, ζητήστε από τη διαχείριση να ελέγξει τα αρχεία καταγραφής.",
    "Hello %s" : "Γεια σας %s",
    "Hello %s," : "Γεια σας %s,",
    "_New notification for %s_::_%n new notifications for %s_" : ["Νέα ειδοποίηση για %s","%n νέες ειδοποιήσεις για %s"],
    "_You have a new notification for %s_::_You have %n new notifications for %s_" : ["Έχετε μια νέα ειδοποίηση για %s","Έχετε %n νέες ειδοποιήσεις για %s"],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "Μπορείτε να αλλάξετε τη συχνότητα αυτών των email ή να τα απενεργοποιήσετε στις <a href=\"%s\">ρυθμίσεις</a>.",
    "You can change the frequency of these emails or disable them in the settings: %s" : "Μπορείτε να αλλάξετε τη συχνότητα αυτών των email ή να τα απενεργοποιήσετε στις ρυθμίσεις: %s",
    "Admin notifications" : "Ειδοποιήσεις διαχειριστή",
    "Notifications" : "Ειδοποιήσεις",
    "Push notifications - Fair use policy" : "Push ειδοποιήσεις - Πολιτική δίκαιης χρήσης",
    "Nextcloud GmbH sponsors a free push notification gateway for private users. To ensure good service, the gateway limits the number of push notifications per server and the limit was reached for this server. For enterprise users, a more scalable gateway is available." : "Η Nextcloud GmbH χορηγεί ένα δωρεάν gateway push ειδοποιήσεων για ιδιώτες χρήστες. Για να διασφαλιστεί καλή εξυπηρέτηση, το gateway περιορίζει τον αριθμό των push ειδοποιήσεων ανά διακομιστή και το όριο επιτεύχθηκε για αυτόν τον διακομιστή. Για επιχειρηματικούς χρήστες, είναι διαθέσιμο ένα πιο επεκτάσιμο gateway.",
    "This app provides a backend and frontend for the notification API available in Nextcloud." : "Αυτή η εφαρμογή παρέχει ένα backend και frontend για το API ειδοποιήσεων που είναι διαθέσιμο στο Nextcloud.",
    "This app provides a backend and frontend for the notification API available in Nextcloud.\n\t\tThe API is used by other apps to notify users in the web UI and sync clients about various things. Some examples are:\n\n📬 Federated file sharing: You received a new remote share\n\n📑 Comments: Another user mentioned you in a comment on a file\n\n🚢 Update notification: Available update for an app or nextcloud itself\n\n📣 Announcement center: An announcement was posted by an admin" : "Αυτή η εφαρμογή παρέχει ένα backend και frontend για το API ειδοποιήσεων που είναι διαθέσιμο στο Nextcloud.\n\t\tΤο API χρησιμοποιείται από άλλες εφαρμογές για την ειδοποίηση των χρηστών στη διεπαφή ιστού και στους πελάτες συγχρονισμού για διάφορα θέματα. Κάποια παραδείγματα είναι:\n\n📬 Ομοσπονδιακή κοινή χρήση αρχείων: Λάβατε μια νέα απομακρυσμένη κοινή χρήση\n\n📑 Σχόλια: Ένας άλλος χρήστης σας ανέφερε σε ένα σχόλιο σε ένα αρχείο\n\n🚢 Ειδοποίηση ενημέρωσης: Διαθέσιμη ενημέρωση για μια εφαρμογή ή το ίδιο το Nextcloud\n\n📣 Κέντρο ανακοινώσεων: Δημοσιεύτηκε μια ανακοίνωση από έναν διαχειριστή",
    "Failed to perform action" : "Αποτυχία εκτέλεσης ενέργειας",
    "Failed to dismiss notification" : "Αποτυχία απόρριψης της ειδοποίησης",
    "Dismiss" : "Απόρριψη",
    "Contact Nextcloud GmbH" : "Επικοινωνία με Nextcloud GmbH",
    "in {path}" : "στο {path}",
    "Push notifications might be unreliable" : "Οι ειδοποιήσεις push μπορεί να είναι αναξιόπιστες",
    "Nextcloud GmbH sponsors a free push notification gateway for private users. To ensure good service, the gateway limits the number of push notifications per server. For enterprise users, a more scalable gateway is available. Contact Nextcloud GmbH for more information." : "Η Nextcloud GmbH χορηγεί μια δωρεάν πύλη ειδοποιήσεων push για ιδιώτες χρήστες. Για να διασφαλιστεί η καλή εξυπηρέτηση, η πύλη περιορίζει τον αριθμό των ειδοποιήσεων push ανά διακομιστή. Για εταιρικούς χρήστες, είναι διαθέσιμη μια πιο επεκτάσιμη πύλη. Επικοινωνήστε με την Nextcloud GmbH για περισσότερες πληροφορίες.",
    "Requesting browser permissions to show notifications" : "Αίτηση άδειας φυλλομετρητή για εμφάνιση ειδοποιήσεων",
    "No notifications" : "Καμία ειδοποίηση",
    "Failed to dismiss all notifications" : "Αποτυχία απόρριψης όλων των ειδοποιήσεων",
    "Dismiss all notifications" : "Απόρριψη όλων των ειδοποιήσεων",
    "Never" : "Ποτέ",
    "1 hour" : "1 ώρα",
    "3 hours" : "3 ώρες",
    "1 day" : "1 ημέρα",
    "1 week" : "1 εβδομάδα",
    "Your settings have been updated." : "Οι ρυθμίσεις σας έχουν ενημερωθεί.",
    "An error occurred while updating your settings." : "Παρουσιάστηκε σφάλμα κατά την ενημέρωση των ρυθμίσεών σας.",
    "Notifications defaults" : "Προεπιλογές ειδοποιήσεων",
    "Configure the default notification settings" : "Διαμόρφωση των προεπιλεγμένων ρυθμίσεων ειδοποιήσεων",
    "Send email reminders about unhandled notifications after:" : "Αποστολή υπενθυμίσεων μέσω email για μη χειριζόμενες ειδοποιήσεις μετά από:",
    "Play sound when a new notification arrives" : "Αναπαραγωγή ήχου όταν φτάσει μια νέα ειδοποίηση",
    "Play sound when a call started (requires Nextcloud Talk)" : "Αναπαραγωγή ήχου κατά την έναρξη μιας κλήσης (απαιτείται το Nextcloud Talk)",
    "Web push settings" : "Ρυθμίσεις web push",
    "Web push is a push notification system that lets web applications send notifications to users´ mobile apps or browser, even when the app is not open in a tab." : "Το Web push είναι ένα σύστημα ειδοποιήσεων push που επιτρέπει στις εφαρμογές ιστού να στέλνουν ειδοποιήσεις στις εφαρμογές κινητού ή στον φυλλομετρητή των χρηστών, ακόμη και όταν η εφαρμογή δεν είναι ανοιχτή σε μια καρτέλα.",
    "Web push notifications are encrypted but routed through services provided by Mozilla, Microsoft, Apple, Google or user-choosen ones in case of mobile apps. While the content is protected, metadata such as timing and frequency of notifications may be exposed to these providers." : "Οι ειδοποιήσεις web push είναι κρυπτογραφημένες αλλά δρομολογούνται μέσω υπηρεσιών που παρέχονται από τη Mozilla, τη Microsoft, την Apple, τη Google ή επιλεγμένες από τον χρήστη στην περίπτωση εφαρμογών για κινητά. Παρόλο που το περιεχόμενο είναι προστατευμένο, μεταδεδομένα όπως ο χρόνος και η συχνότητα των ειδοποιήσεων ενδέχεται να εκτεθούν σε αυτούς τους παρόχους.",
    "Allow web push to be used" : "Να επιτρέπεται η χρήση του web push",
    "Allow web push for browsers" : "Να επιτρέπεται το web push για φυλλομετρητές",
    "None" : "Κανένα",
    "You need to set up your email address before you can receive notification emails." : "Πρέπει να ρυθμίσετε τη διεύθυνση email σας για να μπορείτε να λαμβάνετε μηνύματα ηλεκτρονικού ταχυδρομείου ειδοποίησης.",
    "Also repeat sound on a secondary speaker" : "Επανάληψη ήχου και σε δευτερεύον ηχείο",
    "Selection of the speaker device is currently not supported by Safari" : "Η επιλογή συσκευής ηχείου δεν υποστηρίζεται προς το παρόν από το Safari",
    "Select a device" : "Επιλογή συσκευής"
},
"nplurals=2; plural=(n != 1);");
