OC.L10N.register(
    "photos",
    {
    "Public link" : "ລິ້ງສາທາລະນະ",
    "Photos" : "ຮູບພາບ",
    "Videos" : "ວິດີໂອ",
    "Albums" : "ອະລະບໍ້າ",
    "People" : "ບຸກຄົນ",
    "Folders" : "Folders",
    "Favorites" : "ລາຍການທີ່ມັກ",
    "On this day" : "ໃນມື້ນີ້",
    "Shared with you" : "ແບ່ງປັບກັບທ່ານ",
    "Tags" : "ປ້າຍກຳກັບ",
    "Places" : "Places",
    "Map" : "ແຜນທີ່",
    "This name is already in use." : "This name is already in use.",
    "\"{char}\" is not allowed inside a filename." : "\"{char}\" is not allowed inside a filename.",
    "Invalid filename." : "Invalid filename.",
    "Name of the album" : "ຊື່ອາລະບ້ຳ",
    "Location of the album" : "ທີ່ຕັ້ງຂອງອະລະບໍ້າ",
    "Back" : "ຫຼັງ",
    "Add collaborators" : "ເພີ່ມຜູ້ຮ່ວມມື",
    "Save" : "ບັນທຶກ",
    "Create album" : "ສ້າງອະລະບໍ້າ",
    "Shared by" : "ແບ່ງປັນໂດຍ",
    "Create new album" : "ສ້າງອະລະບໍ້າໃໝ່",
    "New album" : "ອະລະບໍ້າໃໝ່",
    "Failed to fetch collaborators list." : "ບໍ່ສາມາດດຶງລາຍຊື່ຜູ້ຮ່ວມມືໄດ້.",
    "Failed to update album." : "ບໍ່ສາມາດອັບເດດອະລະບໍ້າໄດ້.",
    "Add people or groups who can edit your album" : "ເພີ່ມບຸກຄົນ ຫຼື ກຸ່ມທີ່ສາມາດແກ້ໄຂອະລະບໍ້າຂອງທ່ານ",
    "Search people or groups" : "ຄົ້ນຫາບຸກຄົນ ຫຼື ກຸ່ມ",
    "No recommendations. Start typing." : "ບໍ່ມີຄຳແນະນຳ. ເລີ່ມພິມໄດ້ເລີຍ.",
    "Copy the public link" : "ສຳເນົາລິ້ງສາທາລະນະ",
    "Public link copied!" : "ສຳເນົາລິ້ງສາທາລະນະແລ້ວ!",
    "Copy public link" : "Copy public link",
    "Delete the public link" : "ລຶບລິ້ງສາທາລະນະ",
    "Share via public link" : "ແບ່ງປັນຜ່ານລິ້ງສາທາລະນະ",
    "An error occurred" : "An error occurred",
    "Favorite" : "ລາຍການທີ່ມັກ",
    "Go back" : "Go back",
    "Date range" : "ຊ່ວງວັນທີ",
    "Add to {destination}" : "Add to {destination}",
    "_{years} year ago_::_{years} years ago_" : ["{years} years ago"],
    "All folders" : "All folders",
    "Add folder" : "Add folder",
    "Home" : "ໜ້າຫຼັກ",
    "General" : "ທົ່ວໄປ",
    "Edit album details" : "ແກ້ໄຂລາຍລະອຽດອະລະບໍ້າ",
    "Save collaborators for this album." : "ບັນທຶກຜູ້ຮ່ວມມືສຳລັບອາລະບ້ຳນີ້.",
    "Rename person" : "ປ່ຽນຊື່ບຸກຄົນ",
    "Merge with different person" : "ຮວມກັບບຸກຄົນອື່ນ",
    "Remove from favorites" : "ຍ້າຍຈາກລາຍການທີ່ມັກ",
    "Remove person" : "ລຶບບຸກຄົນ",
    "Add to album" : "ເພີ່ມໃສ່ອະລະບໍ້າ",
    "Delete selection" : "Delete selection",
    "Unassigned faces" : "ໃບໜ້າທີ່ຍັງບໍ່ໄດ້ກຳນົດ",
    "Last week" : "Last week",
    "Failed to create {collectionFileName}" : "ສ້າງ {collectionFileName} ບໍ່ສຳເລັດ",
    "Group" : "Group",
    "Remove {collaboratorLabel} from the collaborators list" : "ລຶບ {collaboratorLabel} ອອກຈາກລາຍຊື່ຜູ້ຮ່ວມມື",
    "View" : "ເບິ່ງ",
    "Details" : "ລາຍລະອຽດ",
    "Cancel" : "ຍົກເລີກ",
    "Confirm" : "ຢືນຢັນ"
},
"nplurals=1; plural=0;");
