OC.L10N.register(
    "circles",
    {
    "Personal" : "ส่วนตัว",
    "System" : "ระบบ",
    "Visible" : "มองเห็นได้",
    "Open" : "เปิด",
    "Password protected" : "ใส่รหัสผ่านไว้",
    "Hidden" : "ซ่อนอยู่",
    "Local" : "ต้นทาง",
    "Root" : "รูท",
    "Federated" : "ที่ติดต่อกับภายนอก",
    "App" : "แอป",
    "Email address" : "ที่อยู่อีเมล",
    "Admin" : "ผู้ดูแล",
    "Owner" : "เจ้าของ",
    "Open »%s«" : "เปิด »%s«",
    "Accept" : "ยอมรับ",
    "Invalid file provided" : "ไฟล์ที่ระบุไม่ถูกต้อง",
    "File is too big" : "ไฟล์ใหญ่เกินไป",
    "Invalid image" : "รูปภาพไม่ถูกต้อง",
    "Unknown filetype" : "ชนิดไฟล์ที่ไม่รู้จัก",
    "%s" : "%s",
    "Open %s" : "เปิด %s",
    "Unlimited" : "ไม่จำกัด",
    "Default quota" : "ค่าโควต้าเริ่มต้น",
    "Select default quota" : "เลือกค่าโควต้าเริ่มต้น",
    "Save" : "Save",
    "Connect" : "เชื่อมต่อ",
    "Cancel" : "Cancel",
    "Next" : "ถัดไป",
    "Folder" : "โฟลเดอร์",
    "you" : "คุณ",
    "Copy link" : "คัดลอกลิงก์",
    "Close" : "ปิด",
    "New folder" : "โฟลเดอร์ใหม่",
    "Folder name" : "ชื่อโฟลเดอร์",
    "Calendar" : "ปฏิทิน",
    "New calendar" : "สร้างปฏิทินใหม่",
    "Description" : "คำอธิบาย",
    "Edit" : "แก้ไข",
    "Create" : "สร้าง",
    "Apply" : "นำไปใช้",
    "Remove {type}" : "ลบ {type} ออก",
    "No results" : "ไม่มีผลลัพธ์",
    "Pending" : "รอดำเนินการ",
    "Add to {team}" : "เพิ่มไปยัง {team}",
    "Loading" : "กำลังโหลด",
    "Go back" : "กลับไป",
    "Loading…" : "กำลังโหลด…",
    "User" : "ผู้ใช้",
    "Group" : "กลุ่ม",
    "Email" : "อีเมล",
    "Federation" : "ที่ติดต่อกับภายนอก",
    "Privacy" : "ความเป็นส่วนตัว",
    "Users" : "ผู้ใช้",
    "Groups" : "กลุ่ม",
    "Contacts" : "รายชื่อผู้ติดต่อ",
    "No files in here" : "ไม่มีไฟล์ที่นี่",
    "No entries found in this folder" : "ไม่พบรายการในโฟลเดอร์นี้",
    "Name" : "ชื่อ",
    "Size" : "ขนาด",
    "Modified" : "แก้ไขเมื่อ"
},
"nplurals=1; plural=0;");
