OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Անձնական գործունեության ցանկ %s ֊ի համար",
    "Your feed URL is invalid" : "Ցանկի URL-ը վավեր չէ",
    "Activity feed" : "Գործունեության ցանկ",
    "Your settings have been updated." : "Ձեր կարգավորումներն թարմացվել են։",
    "Settings have been updated." : "Կարգավորումներ թարմացվել են։",
    "Recent activity" : "Վերջին գործունեությունը",
    "No activities" : "Ակտիվություններ առկա չեն",
    "More activities" : "Ավելի շատ գործունեություն",
    "Daily activity summary for %s" : "Օրական գործունեության ամփոփ %s ֊ի համար",
    "All activities" : "Բոլոր ակտիվությունները",
    "By others" : "Մյուսների կողմից",
    "By you" : "Ձեր կողմից",
    "Activity at %s" : "%s ֊ի գործունեությունը",
    "Hello %s" : "Բարև %s",
    "Hello %s," : "Բարև %s,",
    "There was some activity at %s" : "%s ֊ում նկատվել է որոշ ակտիվություն ",
    "_and %n more _::_and %n more _" : ["և %n ավելի","և"],
    "Mail" : "Փոստ",
    "Push" : "Սեղմել",
    "Activity" : "Գործունեություն",
    "Notifications" : "Ծանուցում",
    "This application enables people to view a log of activities about them, their files or other data." : "Այս հավելվածը հասանելի է դարձնում մարդկանց կողմից կատարված գործունեության, նիշքերի և այլ տվյալների մասին գրառումների ցուցակը։",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Այս հավելվածը հնարավորություն է տալիս մարդկանց դիտելու իրենց նիշքերի ու տվյալների հետ կապված գործողությունները Nextcloud֊ում։\n\t\t Յուրաքանչյուրը կարա անհատականացնի այդ կարգավորումն իր անձնական կարգավորումներ բաժնից,\n\t\t նշելով, որ տեսակի գործունեությունն պետք է ծանուցվի սմարտֆոնի կամ էլ․փոստի վրա\n\t\tկամ արդյոք պետք է ստանալ օրական ամփոփն ամեն առավոտ։\n\t\tԱվելին իմանալու համար ուսումնասիրեք Գործունեության փաստաթուղթը։",
    "Today" : "Այսօր",
    "Send email" : "Ուղարկել փոստ",
    "Send push notification" : "Ուղարկել ծանուցում",
    "Activity notification configuration" : "Գործունեության ծանուցման կարգավորում",
    "Yesterday" : "Երեկ",
    "You need to set up your email address before you can receive notification emails." : "Փոստի վրա ծանուցումն ստանալու համար անհրաժեշտ է կարգավորել էլ․հասցեն։",
    "Send activity emails" : "Ուղարկել գործունեության էլ․ նամակներ",
    "As soon as possible" : "Որքան հնարավոր է արագ",
    "Hourly" : "Ժամային",
    "Daily" : "Օրական",
    "Weekly" : "Շաբաթական",
    "Open {filename}" : "Բացել {նիշքիանուն}",
    "in {path}" : "դեպի {ուղի}",
    "Home" : "Սկիզբ",
    "This stream will show events like additions, changes & shares" : "Այս հոսքը ցույց կտա այնպիսի իրադարձություններ, ինչպիսիք են հավելումները, փոփոխությունները և համօգտագործումները։",
    "No activity yet" : "Գործունեություն առկա չէ",
    "Activity settings" : "Գործունեության կարգավորումներ",
    "Enable RSS feed" : "Միացնել RSS ցանկի սնուցումը",
    "RSS feed" : "RSS սնուցում",
    "Personal notification settings" : "Անհատական ծանուցման կարգավորումներ",
    "Unable to load the activity list" : "Չի ստացվում բեռնել գործունեության ցուցակը",
    "Choose for which activities you want to get an email or push notification." : "Ընտրել թե որ տեսակի գործունեության համար եք ցանկանում միացնել փոստային կամ հաղորդագրությամբ ծանուցումները",
    "Choose for which activities you want to get a push notification." : "Ընտրել թե որ տեսակի գործունեության համար եք ցանկանում ստանալ հաղոդրագրության ծանուցումը։",
    "Notification" : "Ծանուցում",
    "Enable notification emails" : "Միացնել ծանուցման էլ․ նամակները",
    "Daily activity summary" : "Օրական գործունեության ամփոփ",
    "Send daily activity summary in the morning" : "Ուղարկել օրական գործունեության ամփոփը մշտադիտարկման",
    "Default settings" : "Լռելայն կարգավորումներ",
    "Configure the default notification settings for new accounts." : "Կարգաբերել ծանուցման լռելայն կարգավորումները նոր հաշիվների համար։",
    "Unable to save the settings" : "Չի ստացվում պահել կարգավորումները",
    "No more events to load" : "Առկա չէ այլ իրադարձություններ բեռնելու համար"
},
"nplurals=2; plural=(n != 1);");
