OC.L10N.register(
    "files_pdfviewer",
    {
    "Failed to load settings" : "Nalaganje nastavitev je spodletelo.",
    "Failed to save settings" : "Shranjevanje nastavitev je spodletelo"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
