OC.L10N.register(
    "sharebymail",
    {
    "Shared with {email}" : "Compartit amb {email}",
    "Shared with {email} by {actor}" : "Compartit amb {email} per {actor}",
    "Unshared from {email}" : "No compartit de {email}",
    "Unshared from {email} by {actor}" : "No compartit de {email} per {actor}",
    "Password for mail share sent to {email}" : "Contrasenya per compartició per correu enviada a {email}",
    "Password for mail share sent to you" : "Contrasenya per compartició per correu que us han enviat",
    "You shared {file} with {email} by mail" : "Heu compartit {file} amb {email} per correu electrònic",
    "{actor} shared {file} with {email} by mail" : "{actor} ha compartit {file} amb {email} per correu electrònic",
    "You unshared {file} from {email} by mail" : "Heu deixat de compartir {file} amb {email} per correu electrònic",
    "{actor} unshared {file} from {email} by mail" : "{actor} ha deixat de compartir {file} amb {email} per correu electrònic",
    "Password to access {file} was sent to {email}" : "S'ha enviat a {email} la contrasenya per a accedir a {file}",
    "Password to access {file} was sent to you" : "Se us ha enviat la contrasenya per a accedir a {file}",
    "Share by mail" : "Comparteix per correu electrònic",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "No s'ha pogut compartir %1$s perquè l'element ja està compartit amb el compte %2$s",
    "We cannot send you the auto-generated password. Please set a valid email address in your personal settings and try again." : "No us podem enviar la contrasenya generada automàticament. Definiu una adreça electrònica vàlida en els paràmetres personals i torneu-ho a provar.",
    "Failed to send share by email. Got an invalid email address" : "No s'ha pogut enviar la compartició per correu electrònic. Teniu una adreça electrònica no vàlida",
    "Failed to send share by email" : "No s'ha pogut enviar l'element compartit per correu electrònic",
    "%1$s shared %2$s with you" : "%1$s ha compartit %2$s amb tu",
    "Note:" : "Nota:",
    "This share is valid until %s at midnight" : "Aquesta compartició és vàlida fins a les %s a mitjanit",
    "Expiration:" : "Expiració:",
    "%1$s via %2$s" : "%1$s mitjançant %2$s",
    "%1$s shared %2$s with you. You should have already received a separate mail with a link to access it." : "%1$s ha compartit %2$s amb tu. Ja hauríeu d'haver rebut un correu separat amb un enllaç per accedir-hi.",
    "Password to access %1$s shared to you by %2$s" : "Contrasenya per accedir a %1$s compartida amb vosaltres per %2$s",
    "Password to access %s" : "Contrasenya per accedir a %s",
    "It is protected with the following password:" : "Està protegit amb la contrasenya següent:",
    "This password will expire at %s" : "Aquesta contrasenya caducarà a les %s",
    "%1$s shared %2$s with you and wants to add:" : "%1$s ha compartit %2$s amb tu i vol afegir:",
    "%1$s shared %2$s with you and wants to add" : "%1$s ha compartit %2$s amb tu i vol afegir",
    "%s added a note to a file shared with you" : "%s ha afegit una nota a un fitxer compartit amb tu",
    "You just shared %1$s with %2$s. The share was already sent to the recipient. Due to the security policies defined by the administrator of %3$s each share needs to be protected by password and it is not allowed to send the password directly to the recipient. Therefore you need to forward the password manually to the recipient." : "Acabeu de compartir %1$s amb %2$s. La compartició ja s'ha enviat al destinatari. A causa de les polítiques de seguretat definides per l'administrador de %3$s, cada compartició ha d'estar protegida amb contrasenya i no es permet enviar la contrasenya directament al destinatari. Per tant, cal reenviar la contrasenya manualment al destinatari.",
    "Password to access %1$s shared by you with %2$s" : "Contrasenya per accedir a %1$s que has compartit amb %2$s",
    "This is the password:" : "La contrasenya és la següent:",
    "You can choose a different password at any time in the share dialog." : "Podeu triar una contrasenya diferent en qualsevol moment en el quadre de diàleg d'ús compartit.",
    "Could not find share" : "No s'ha pogut trobar l'element compartit",
    "Share provider which allows you to share files by mail" : "Proveïdor d'ús compartit que us permet compartir fitxers per correu electrònic",
    "Unable to update share by mail config" : "No s'ha pogut actualitzar la configuració d'ús compartit per correu electrònic",
    "Allows people to share a personalized link to a file or folder by putting in an email address." : "Permet que la gent comparteixi un enllaç personalitzat a un fitxer o carpeta indicant una adreça electrònica.",
    "Send password by mail" : "Envia la contrasenya per correu electrònic",
    "Reply to initiator" : "Respon a l'usuari que comparteix l'element"
},
"nplurals=2; plural=(n != 1);");
