OC.L10N.register(
    "files_sharing",
    {
    "File shares" : "Споделување на датотеки",
    "Downloaded via public link" : "Превемено преку јавен линк",
    "Downloaded by {email}" : "Преземено од {email}",
    "{file} downloaded via public link" : "{file} преземена преку јавен линк",
    "{email} downloaded {file}" : "{email} ја презема {file}",
    "Shared with group {group}" : "Соделено со група {group}",
    "Removed share for group {group}" : "Отстрането споделувањето за групата {group}",
    "{actor} shared with group {group}" : "{actor} сподели со група {group}",
    "{actor} removed share for group {group}" : "{actor} го отстрани споделување за групата {group}",
    "Share for group {group} expired" : "Споделувањето за групата {group} истече",
    "You shared {file} with group {group}" : "Споделивте {file} со група {group}",
    "You removed group {group} from {file}" : "Отстранивте група {group} од {file}",
    "{actor} shared {file} with group {group}" : "{actor} сподели {file} со група {group}",
    "{actor} removed group {group} from {file}" : "{actor} ја отстрани групата {group} од {file}",
    "Share for file {file} with group {group} expired" : "Споделувањето на датотеката {file} со групата {group} истече",
    "Shared as public link" : "Споделена како јавен линк",
    "Removed public link" : "Отстранет јавен линк",
    "Public link expired" : "Истече рокот на јавниот линк",
    "{actor} shared as public link" : "{actor} сподели како јавен линк",
    "{actor} removed public link" : "{actor} отстрани јавен линк",
    "Public link of {actor} expired" : "Истече рокот на јавниот линк на {actor}",
    "You shared {file} as public link" : "Споделивте {file} како јавен линк",
    "You removed public link for {file}" : "Отстранивте јавен линк за {file}",
    "Public link expired for {file}" : "Истече рокот на јавниот линк за {file}",
    "{actor} shared {file} as public link" : "{actor} сподели {file} како јавен линк",
    "{actor} removed public link for {file}" : "{actor} отстрани јавен линк за {file}",
    "Public link of {actor} for {file} expired" : "Истече рокот на јавниот линк на {actor} за {file}",
    "{user} accepted the remote share" : "{user} го прифати далечинското споделување",
    "{user} declined the remote share" : "{user} го одби далечинското споделување",
    "You received a new remote share {file} from {user}" : "Примивте ново далечинско споделување {file} од {user}",
    "{user} accepted the remote share of {file}" : "{user} го прифати далечинското споделување на {file}",
    "{user} declined the remote share of {file}" : "{user} го одби далечинското споделување на {file}",
    "{user} unshared {file} from you" : "{user} го отстрани споделувањето на {file} со вас",
    "Shared with {user}" : "Споделено со {user}",
    "Removed share for {user}" : "Отстрането споделувањето за {user}",
    "You removed yourself" : "Се отстранивте себеси",
    "{actor} removed themselves" : "{actor} отстрани се",
    "{actor} shared with {user}" : "{actor} сподели со {user}",
    "{actor} removed share for {user}" : "{actor} отстрани споделување за {user}",
    "Shared by {actor}" : "Споделено од {actor}",
    "{actor} removed share" : "{actor} отстрани споделување",
    "Share for {user} expired" : "Споделувањето за {user} истече",
    "Share expired" : "Споделувањето истече",
    "You shared {file} with {user}" : "Споделивте {file} со {user}",
    "You removed {user} from {file}" : "Отстранивте  {user} од {file}",
    "You removed yourself from {file}" : "Се отстранивте себеси од {file}",
    "{actor} removed themselves from {file}" : "{actor} отстрани се од {file}",
    "{actor} shared {file} with {user}" : "{actor} сподели {file} со {user}",
    "{actor} removed {user} from {file}" : "{actor} го отстрани {user} од {file}",
    "{actor} shared {file} with you" : "{actor} сподели {file} со вас",
    "{actor} removed you from the share named {file}" : "{actor} Ве отстрани од споделувањето на {file}",
    "Share for file {file} with {user} expired" : "Споделувањето на {file} со {user} истече",
    "Share for file {file} expired" : "Споделувањето на {file} истече",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Датотека или папка споделена преку е-пошта или преку јавен линк е <strong>преземена</strong>",
    "Files have been <strong>uploaded</strong> to a folder shared by mail or by public link" : "<strong>Прикачени се датотеки</strong> во папка која ја споделивте преку е-пошта или јавен линк",
    "A file or folder was shared from <strong>another server</strong>" : "Датотека или папка е споделена од <strong>друг сервер</strong>",
    "Sharing" : "Споделување",
    "A file or folder has been <strong>shared</strong>" : "Датотека или папка беше <strong>споделена</strong>",
    "Shared link" : "Споделен линк",
    "Wrong share ID, share does not exist" : "Погрешно ID на споделување, споделувањето не постои",
    "Could not delete share" : "Неможе да се избрише споделувањето",
    "Please specify a file or folder path" : "Изберете датотека или патека до папка",
    "Wrong path, file/folder does not exist" : "Погрешна патека, датотеката/папката не постои",
    "Could not create share" : "Неможе да се креира споделување",
    "Please specify a valid account to share with" : "Ве молиме наведете валидна сметка за споделување",
    "Please specify a valid group" : "Изберете група",
    "Please specify a valid email address" : "Наведете важечка адреса за е-пошта",
    "Sharing %s sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "Неуспешно испраќање на лозинка за споделувањето %s преку разговор бидејќи разговорот не е овозможен",
    "Please specify a valid federated account ID" : "Ве молиме наведете важечки ID на федерирана сметка",
    "Please specify a valid federated group ID" : "Внесете валидно федерално групно ИД",
    "You cannot share to a Team if the app is not enabled" : "Не можете да споделувате со тим ако апликацијата не е овозможена",
    "Please specify a valid team" : "Ве молиме наведете валиден тим",
    "Sharing %s failed because the back end does not support room shares" : "Споделувањето на %s е неуспешно бидејќи позадината не дозволува споделувања во соби со разговори",
    "Unknown share type" : "Непознат вид на споделување",
    "Not a directory" : "Не е директориум",
    "Could not lock node" : "Не можам да го заклучам јазолот",
    "Public upload is only possible for publicly shared folders" : "Јавно прикачување е возможно само на јавно споделени папки",
    "Share must at least have READ or CREATE permissions" : "Споделувањето мора барем да има дозволи за ЧИТАЊЕ или СОДАВАЊЕ",
    "Share must have READ permission if UPDATE or DELETE permission is set" : "Споделувањето мора да има дозвола за ЧИТАЊЕ ако е поставена дозвола за АЖУРИРАЊЕ или БРИШЕЊЕ",
    "Could not lock path" : "Неможе да се заклучи патеката",
    "no sharing rights on this item" : "немате право за споделување на оваа ставка",
    "You are not allowed to edit incoming shares" : "Не ви е дозволено да ги уредувате дојдовните споделувања",
    "Wrong or no update parameter given" : "Погрешни или нема зададено параметри за ажурирање",
    "\"Sending the password by Nextcloud Talk\" for sharing a file or folder failed because Nextcloud Talk is not enabled." : "„Испраќањето на лозинката преку Talk“ за споделување датотека или папка не успеа бидејќи Talk не е овозможен.",
    "Custom share link tokens have been disabled by the administrator" : "Администраторот ги оневозможи приспособените токени за линкови за споделување",
    "Tokens must be between 1 and %s characters long and may only contain letters, numbers, or a hyphen" : "Токените мора да бидат долги помеѓу 1 и %s карактерии и може да содржат само букви, бројки или цртичка",
    "Invalid date. Format must be YYYY-MM-DD" : "Невалиден датум. Форматот мора да биде ГГГГ-ММ-ДД",
    "No sharing rights on this item" : "Немате право за споделување на оваа ставка",
    "Invalid share attributes provided: \"%s\"" : "Обезбедени неважечки атрибути за споделување: \"%s\"",
    "You are not allowed to send mail notifications" : "Не сте овластени да испраќате известувања на е-пошта",
    "No mail notification configured for this share type" : "Нема конфигурирано известување по е-пошта за овој тип на споделување",
    "Wrong password" : "Погрешна лозинка",
    "Error while sending mail notification" : "Грешка при испраќање на известување на е-пошта",
    "Failed to generate a unique token" : "Неуспешно генерирање на уникатен токен",
    "This share does not exist or is no longer available" : "Споделувањето не постои или не е повеќе достапно",
    "shared by %s" : "споделено од %s",
    "Download" : "Преземи",
    "Add to your %s" : "Додади на твојот %s",
    "Direct link" : "Директен линк",
    "Share API is disabled" : "API-то за споделување е оневозможено",
    "File sharing" : "Споделување на датотеки",
    "Share will expire tomorrow" : "Споделувањето ќе истече утре",
    "Your share of {node} will expire tomorrow" : "Твоето споделување од {node} ќе истече утре",
    "You received {share} as a share by {user}" : "Примивте {share} како споделување од {user}",
    "You received {share} to group {group} as a share by {user}" : "Примивте {share} во групата {group} како споделување од {user}",
    "Accept" : "Прифати",
    "Decline" : "Одбиј",
    "Remember to upload the files to %s" : "Не заборавајте да ги прикачите датотеките на %s",
    "We would like to kindly remind you that you have not yet uploaded any files to the shared folder." : "Сакаме да ве потсетиме дека сè уште не сте поставиле ниедна датотека во споделената папка.",
    "Open \"%s\"" : "Отвори \"%s\"",
    "This application enables people to share files within Nextcloud. If enabled, the admin can choose which groups can share files. The applicable people can then share files and folders with other accounts and groups within Nextcloud. In addition, if the admin enables the share link feature, an external link can be used to share files with other people outside of Nextcloud. Admins can also enforce passwords, expirations dates, and enable server to server sharing via share links, as well as sharing from mobile devices.\nTurning the feature off removes shared files and folders on the server for all share recipients, and also on the sync clients and mobile apps. More information is available in the Nextcloud Documentation." : "Оваа апликација им овозможува на корисниците да споделуваат датотеки во рамките на Nextcloud. Доколку е овозможено, администраторот може да избере кои групи можат да споделуваат датотеки. Применливите корисници потоа можат да споделуваат датотеки и папки со други корисници и групи во рамките на Nextcloud. Покрај тоа, ако администраторот ја овозможи функцијата за далечно споделување, може да се користи надворешна врска за споделување датотеки со други корисници надвор од Nextcloud. Администраторот исто така може да овозможи поставување на лозинки, датуми на истекувања и да овозможи споделување од сервер на сервер преку линкови за споделување, како и споделување од мобилни уреди.\nИсклучувањето на функцијата ги отстранува споделените датотеки и папките на серверот за сите приматели на споделување, а исто така и на клиентите за синхронизација и апликациите за мобилни. Повеќе информации се достапни во Документацијата на Nextcloud.",
    "Filter accounts" : "Филтрирај сметки",
    "you" : "ти",
    "The request will expire on {date} at midnight and will be password protected." : "Барањето ќе истече на {date} на полноќ и ќе биде заштитено со лозинка.",
    "The request will expire on {date} at midnight." : "Барањето ќе истече на {date} на полноќ.",
    "The request will be password protected." : "Барањето ќе биде заштитено со лозинка.",
    "When should the request expire?" : "Кога треба да истече барањето?",
    "Set a submission expiration date" : "Поставете датум за рок на траење",
    "Expiration date" : "Рок на траење",
    "Select a date" : "Избери датум",
    "Your administrator has enforced a {count} days expiration policy." : "Вашиот администратор спроведе политика за рок на траење на минимум {count}дена.",
    "What password should be used for the request?" : "Која лозинка треба да се користи за барањето?",
    "Set a password" : "Постави лозинка",
    "Password" : "Лозинка",
    "Enter a valid password" : "Внесете валидна лозинка",
    "Generate a new password" : "Генерирај нова лозинка",
    "Your administrator has enforced a password protection." : "Вашиот администратор спроведе политика за заштита со лозинка на споделувањата.",
    "Automatically copying failed, please copy the share link manually" : "Неможе да се копира, копирајте го линкот рачно",
    "Link copied" : "Линкот е копиран",
    "Email already added" : "Е-поштата е веќе додадена",
    "Invalid email address" : "Неправилна е-пошта адреса",
    "_The following email address is not valid: {emails}_::_The following email addresses are not valid: {emails}_" : ["Адресата на е-пошта не е валидна: {emails}","Следниве адреси на е-пошта не се валидни: {emails}"],
    "_{count} email address already added_::_{count} email addresses already added_" : ["{count} е-пошта адреса е веќе додадена","{count} е-пошта адреси се веќе додадени"],
    "_{count} email address added_::_{count} email addresses added_" : ["{count} е-пошта адреса е додадена","{count} е-пошта адреси се додадени"],
    "You can now share the link below to allow people to upload files to your directory." : "Испратете го линкот за да им дозволите на луѓето да прикачат датотеки.",
    "Share link" : "Сподели линк",
    "Copy" : "Копирај",
    "Send link via email" : "Испрати линк преку е-пошта",
    "Enter an email address or paste a list" : "Внеси е-пошта адреса или цела листа",
    "Remove email" : "Отстрани е-пошта",
    "Select a destination" : "Изберете дестинација",
    "Select" : "Избери",
    "What are you requesting?" : "Што барате?",
    "Request subject" : "Предмет на барање",
    "Birthday party photos, History assignment…" : "Фотографии, документи ...",
    "Where should these files go?" : "Каде да се зачуваат датотеките?",
    "Upload destination" : "Дестинација на прикачување",
    "Revert to default" : "Врати се на стандардно",
    "The uploaded files are visible only to you unless you choose to share them." : "Прикачените датотеки се видливи само за вас, освен ако не изберете да ги споделите.",
    "Add a note" : "Додади белешка",
    "Note for recipient" : "Белешка до примачот",
    "Add a note to help people understand what you are requesting." : "Додајте белешка за да им помогнете на луѓето да разберат што барате.",
    "You can add links, date or any other information that will help the recipient understand what you are requesting." : "Можете да додадете линкови, датум или која било друга информација што ќе му помогне на примачот да разбере што барате.",
    "Close" : "Затвори",
    "_Send email and close_::_Send {count} emails and close_" : ["Испрати порака на е-пошта и затвори","Испрати {count} пораки на е-пошта и затвори"],
    "Please select a folder, you cannot share the root directory." : "Изберете папка, Неможете да ја споделите главната папка.",
    "File request created" : "Барање за датотека е креирано",
    "_File request created and email sent_::_File request created and {count} emails sent_" : ["Барање за датотека е креирано и испратена е порака на е-пошта","Барање за датотека е креирано и {count} пораки на е-пошта се испратени"],
    "Error creating the share: {errorMessage}" : "Грешка при креирање на споделување: {errorMessage}",
    "Error creating the share" : "Грешка при креирање на споделување",
    "Error sending emails: {errorMessage}" : "Грешка при испраќање {errorMessage} пораки на е-пошта",
    "Error sending emails" : "Грешка при испраќање на е-пошта порака",
    "Create a file request" : "Креирај барање за датотека",
    "Collect files from others even if they do not have an account." : "Прибавете датотеки од други дури и ако немаат сметка.",
    "To ensure you can receive files, verify you have enough storage available." : "За да се осигурате дека можете да примате датотеки, проверете дали имате доволно простор на располагање.",
    "File request" : "Барање за датотека",
    "Previous step" : "Предходен чекор",
    "Cancel" : "Откажи",
    "Cancel the file request creation" : "Откажи барање за датотека",
    "Close without sending emails" : "Затвори без испраќање е-пошта",
    "Continue" : "Продолжи",
    "Error while toggling options" : "Грешка при префрлање опции",
    "Accept shares from other accounts and groups by default" : "Стандардно прифаќај акции од други корисници и групи",
    "Choose a default folder for accepted shares" : "Избери стандардна папка за прифатените споделувања",
    "Invalid path selected" : "Избрана невалидна патека",
    "Unknown error" : "Непозната грешка",
    "Set default folder for accepted shares" : "Постави стандардна папка за прифатените споделувања",
    "Reset" : "Ресетирање",
    "Reset folder to system default" : "Ресетирајте ја папката на стандардниот систем",
    "Share expiration: {date}" : "Рок на траење на споделувањето: {date}",
    "Share Expiration" : "Рок на траење на споделувањето",
    "group" : "група",
    "conversation" : "разговор",
    "remote" : "далечински",
    "remote group" : "оддалечена група",
    "guest" : "гостин",
    "by {initiator}" : "од {initiator}",
    "Shared with the group {user} by {owner}" : "Споделено со група на {user} од {owner}",
    "Shared with the conversation {user} by {owner}" : "Споделено со разговор на {user} од {owner}",
    "Shared with {user} by {owner}" : "Споделено со {user} од {owner}",
    "Open Sharing Details" : "Отвори детали за споделувањето",
    "Added by {initiator}" : "Додадено од {initiator}",
    "Via “{folder}”" : "Преку “{folder}”",
    "Unshare" : "Отстрани споделување",
    "Cannot copy, please copy the link manually" : "Неможе да се копира, копирајте го линкот рачно",
    "Copy internal link" : "Копирај внатрешен линк",
    "For people who already have access" : "За луѓе кој веќе имаат пристап",
    "Internal link" : "Внатрешен линк",
    "{shareWith} by {initiator}" : "{shareWith} од {initiator}",
    "Shared via link by {initiator}" : "Споделено со линк од {initiator}",
    "File request ({label})" : "Барање за датотека ({label})",
    "Mail share ({label})" : "Споделено преку е-пошта ({label})",
    "Share link ({label})" : "Сподели линк ({label})",
    "Mail share" : "Споделување со е-пошта",
    "Share link ({index})" : "Сподели линк ({index})",
    "Create public link" : "Креирај јавен линк",
    "Actions for \"{title}\"" : "Акции за \"{title}\"",
    "Copy public link of \"{title}\"" : "Копирај јавен за \"{title}\"",
    "Error, please enter proper password and/or expiration date" : "Грешка, внесете лозинка и/или рок на траење",
    "Link share created" : "Креиран линк за споделување",
    "Error while creating the share" : "Грешка при креирање на споделување",
    "Your browser does not support copying, please copy the link manually:" : "Вашиот прелистувач не поддржува копирање, копирајте го линкот рачно:",
    "Successfully copied public link" : "Успешно копиран јавен линк",
    "Please enter the following required information before creating the share" : "Внесете ги следниве потребни податоци пред да го креирате споделувањето",
    "Password protection (enforced)" : "Заштитено со лозинка (enforced)",
    "Password protection" : "Заштитено со лозинка",
    "Enter a password" : "Внесете лозинка",
    "Enable link expiration (enforced)" : "Овозможи рок на траење на линк (задолжително)",
    "Enable link expiration" : "Овозможи рок на траење на линк",
    "Enter expiration date (enforced)" : "Внесете датум за рок на траење (задолжително)",
    "Enter expiration date" : "Внесете датум за рок на траење",
    "Create share" : "Ново споделување",
    "Customize link" : "Прилагоди линк",
    "Generate QR code" : "Генерирај QR код",
    "Add another link" : "Додади линк",
    "Create a new share link" : "Креирајте нов линк за споделување",
    "Quick share options, the current selected is \"{selectedOption}\"" : "Опции за брзо споделување за , тековната избрана е \"{selectedOption}\"",
    "View only" : "Само за гледање",
    "Can edit" : "Може да уредува",
    "Custom permissions" : "Прилагодени дозволи",
    "Resharing is not allowed" : "Повторно споделување не е дозволено",
    "Name or email …" : "Име или е-пошта …",
    "Name, email, or Federated Cloud ID …" : "Име, е-пошта или федерален ИД …",
    "Searching …" : "Пребарување …",
    "No elements found." : "Нема пронајдено елементи.",
    "Search everywhere" : "Барај насекаде",
    "Guest" : "Гостин",
    "Group" : "Група",
    "Email" : "Е-пошта",
    "Team" : "Тим",
    "Talk conversation" : "Talk раговор",
    "Deck board" : "Табла",
    "ScienceMesh" : "ScienceMesh",
    "on {server}" : "на {server}",
    "Enter external recipients" : "Внесете надворешни примачи",
    "Search for internal recipients" : "Пребарај внатрешни примачи",
    "Note from" : "Белешка од",
    "Note:" : "Белешка:",
    "File drop" : "Повлечи и прикачи",
    "Upload files to {foldername}." : "Прикачи датотеки во {foldername}.",
    "By uploading files, you agree to the terms of service." : "Со прикачување на датотеки, се согласувате со условите за користење.",
    "Successfully uploaded files" : "Успешно прикачени датотеки",
    "View terms of service" : "Прочитај ги условите за користење",
    "Terms of service" : "Услови за користење",
    "Share with {user}" : "Сподели со {user}",
    "Share with email {email}" : "Сподели со е-пошта {email}",
    "Share with group" : "Сподели со група",
    "Share in conversation" : "Сподели во разговор",
    "Share with {user} on remote server {server}" : "Споделено со {user} на далечен сервер {server}",
    "Share with remote group" : "Сподели со оддалечена група",
    "Share with guest" : "Сподели со гости",
    "Update share" : "Ажурирај споделување",
    "Save share" : "Зачувај споделување",
    "Read" : "Читај",
    "Create" : "Креирај",
    "Edit" : "Уреди",
    "Share" : "Сподели",
    "Delete" : "Избриши",
    "Password field cannot be empty" : "Полето за лозинка неможе да биде празно",
    "Replace current password" : "Заменете ја тековната лозинка",
    "Failed to generate a new token" : "Неуспешно генерирање нов токен",
    "Allow upload and editing" : "Дозволи прикачување и уредување",
    "Allow editing" : "Овозможи уредување",
    "Upload only" : "Само прикачување",
    "Advanced settings" : "Напредни параметри",
    "Share label" : "Ознака на споделувањето",
    "Share link token" : "Сподели токен за линк",
    "Set the public share link token to something easy to remember or generate a new token. It is not recommended to use a guessable token for shares which contain sensitive information." : "Поставете го токенот за јавен линкза споделување на нешто лесно за паметење или генерирајте нов токен. Не се препорачува да се користи токен што може да се погоди за акции што содржат чувствителни информации.",
    "Generating…" : "Се генерира…",
    "Generate new token" : "Генерирај нов токен",
    "Set password" : "Постави лозинка",
    "Password expires {passwordExpirationTime}" : "Лозинката истекува на {passwordExpirationTime}",
    "Password expired" : "Лозинката е истечена",
    "Video verification" : "Верификација со видео",
    "Expiration date (enforced)" : "Рок на траење (enforced)",
    "Set expiration date" : "Постави рок на траење",
    "Hide download" : "Сокриј преземање",
    "Allow download and sync" : "Дозволете преземање и синхронизирање",
    "Note to recipient" : "Белешка до примачот",
    "Enter a note for the share recipient" : "Внесете белешка до примачот на споделуваето",
    "Show files in grid view" : "Прикажи ги датотеките во поглед во мрежа",
    "Delete share" : "Избриши споделување",
    "Others with access" : "Други со пристап",
    "No other accounts with access found" : "Не се најдени други сметки со пристап",
    "Toggle list of others with access to this directory" : "Изберете листата со други корисници со пристап до овој директориум",
    "Toggle list of others with access to this file" : "Изберете листата со други корисници со пристап до оваа датотека",
    "Unable to fetch inherited shares" : "Не можам да ги преземам наследените споделувања",
    "Link shares" : "Споделувања со линк",
    "Shares" : "Споделувања",
    "Share files within your organization. Recipients who can already view the file can also use this link for easy access." : "Сподели датотеки во рамките на твојата организација. Примачите кои веќе имаат пристап до датотеката можат да ја користат и оваа врска за полесен пристап.",
    "Share files with others outside your organization via public links and email addresses. You can also share to {productName} accounts on other instances using their federated cloud ID." : "Сподели датотеки со други лица надвор од твојата организација преку јавни врски и е-поштенски адреси. Исто така можеш да споделуваш со {productName} корисници на други инстанци користејќи го нивниот федерален cloud ID.",
    "Shares from apps or other sources which are not included in internal or external shares." : "Споделувања од апликации или други извори кои не се вклучени во внатрешни или надворешни споделувања.",
    "Type names, teams, federated cloud IDs" : "Внеси имиња, тимови или федерален cloud ID-а",
    "Type names or teams" : "Внеси имиња или тимови",
    "Type a federated cloud ID" : "Внеси федерален cloud ID",
    "Type an email" : "Внеси е-пошта",
    "Type an email or federated cloud ID" : "Внеси е-пошта или федерален ID",
    "Unable to load the shares list" : "Неможе да се вчита листата на споделувања",
    "Expires {relativetime}" : "Истекува {relativetime}",
    "this share just expired." : "ова споделување штотуку истече.",
    "Shared with you by {owner}" : "Споделено со Вас од {owner}",
    "Internal shares" : "Внатрешни споделувања",
    "Internal shares explanation" : "Објаснување за внатрешни споделувања",
    "External shares" : "Надворешни споделувања",
    "External shares explanation" : "Објаснување за надворешни споделувања",
    "Additional shares" : "Дополнителни споделувања",
    "Additional shares explanation" : "Објаснување за додатни споделувања",
    "Link to a file" : "Линк до датотеката",
    "_Accept share_::_Accept shares_" : ["Прифати го споделувањето","Прифати ги споделувањата"],
    "Open in Files" : "Отвори во датотеките",
    "_Reject share_::_Reject shares_" : ["Одбиј го споделувањето","Одбиј ги споделувањата"],
    "_Restore share_::_Restore shares_" : ["Врати споделување","Врати споделувања"],
    "Shared" : "Споделен",
    "Shared by {ownerDisplayName}" : "Споделено од {ownerDisplayName}",
    "Shared multiple times with different people" : "Споделено повеќе пати со различни луѓе",
    "Sharing options" : "Опции за споделување",
    "Shared with others" : "Споделно со други",
    "You do not have enough permissions to share this file." : "Немате дозвола да го споделувате овој документ.",
    "People" : "Луѓе",
    "Create file request" : "Барање за датотека",
    "Upload files to {foldername}" : "Прикачи датотеки во {foldername}",
    "Public file share" : "Јавно споделување датотека",
    "Publicly shared file." : "Јавно споделена датотека.",
    "No file" : "Нема датотека",
    "The file shared with you will show up here" : "Датотеките што другите ги споделуваат со вас ќе се прикажат овде",
    "Public share" : "Јавно споделување",
    "Publicly shared files." : "Јавно споделени датотеки.",
    "No files" : "Нема датотеки",
    "Files and folders shared with you will show up here" : "Датотеките и папките што другите ги споделуваат со вас ќе се прикажат овде",
    "Overview of shared files." : "Преглед на споделени датотеки.",
    "No shares" : "Нема споделувања",
    "Files and folders you shared or have been shared with you will show up here" : "Датотеките и папките што ги споделувате или друг ги споделува со вас ќе се прикажат овде",
    "Shared with you" : "Споделено со вас",
    "List of files that are shared with you." : "Листа на датотеки што се споделени со вас.",
    "Nothing shared with you yet" : "Ништо не е споделено со вас",
    "Files and folders others shared with you will show up here" : "Датотеките и папките што другите ги споделуваат со вас ќе се прикажат овде",
    "List of files that you shared with others." : "Листа на датотеки што ги имате споделено со други.",
    "Nothing shared yet" : "Ништо не е споделено",
    "Files and folders you shared will show up here" : "Датотеките и папките кои ги споделувате ќе се појават тука",
    "Shared by link" : "Споделено со линк",
    "List of files that are shared by link." : "Листа на датотеки што ги имате споделено со линк.",
    "No shared links" : "Нема споделени врски/линкови",
    "Files and folders you shared by link will show up here" : "Датотеките и папките кои ги споделувате со линк ќе се појават тука",
    "File requests" : "Барања за датотеки",
    "List of file requests." : "Листа на барања за датотеки.",
    "No file requests" : "Нема барања за датотеки",
    "File requests you have created will show up here" : "Барањата за датотеки што ги имате креирано ќе се појават овде",
    "Deleted shares" : "Избришани споделувања",
    "List of shares you left." : "Листа на споделувања што ги имате напуштено.",
    "No deleted shares" : "Нема избришани споделувања",
    "Shares you have left will show up here" : "Споделувањата што сте ги напуштиле ќе се појават овде",
    "Pending shares" : "Споделувања на чекање",
    "List of unapproved shares." : "Листа на неодобрени споделувања.",
    "No pending shares" : "Нема споделувања на чекање",
    "Shares you have received but not approved will show up here" : "Листа на споделувањата кој сте ги добиле но не се адобрени ќе се појават овде",
    "Error deleting the share" : "Грешка при отстранување на споделувањето",
    "Error updating the share" : "Грешка при ажурирање на споделувањето",
    "File \"{path}\" has been unshared" : "Датотеката \"{path}\" повеќе не се споделува",
    "Folder \"{path}\" has been unshared" : "Папката \"{path}\" повеќе не се споделува",
    "Could not update share" : "Неможе да се ажурира споделувањето",
    "Share saved" : "Споделувањето е зачувано",
    "Share expiry date saved" : "Зачуван е рок на траење на споделувањето",
    "Share hide-download state saved" : "Зачуван е параметарот на споделувањето",
    "Share label saved" : "Ознаката е зачувана",
    "Share note for recipient saved" : "Белешката на споделувањето до примачот е зачувана",
    "Share password saved" : "Лозинката е зачувана",
    "Share permissions saved" : "Дозволите за споделување се зачувани",
    "To upload files to {folder}, you need to provide your name first." : "За да прикачите датотеки во {folder}, мора да го наведете вашето име.",
    "Upload files to {folder}" : "Прикачи датотеки во {folder}",
    "Please confirm your name to upload files to {folder}" : "Потврдете го вашето име за да прикачите датотеки во {folder}",
    "{ownerDisplayName} shared a folder with you." : "{ownerDisplayName} сподели папка со вас.",
    "Names must not be empty." : "Имињата не можат да бидат празни.",
    "Names must not start with a dot." : "Името неможе да започнува со точка.",
    "\"{char}\" is not allowed inside a name." : "\"{char}\" не е дозволено да содржи во името.",
    "\"{segment}\" is a reserved name and not allowed." : "\"{segment}\" е резервирано име и не е дозволено.",
    "\"{extension}\" is not an allowed name." : "\"{extension}\" не е дозволено име.",
    "Names must not end with \"{extension}\"." : "Името неможе да завршува со \"{extension}\".",
    "Invalid name." : "Невалидно име.",
    "Password created successfully" : "Успрешно е креирана лозинка",
    "Error generating password from password policy" : "Грешка при генерирање на лозинка од политиката на лозинки",
    "Shared with you and the group {group} by {owner}" : "Споделено со Вас и групата {group} од {owner}",
    "Shared with you and {circle} by {owner}" : "Споделено со тебе и {circle} од {owner}",
    "Shared with you and the conversation {conversation} by {owner}" : "Споделено со тебе и во разговорот {conversation} од {owner}",
    "Shared with you in a conversation by {owner}" : "Споделено со тебе и во разговорот од {owner}",
    "Share not found" : "Споделувањето не е пронајдено",
    "Back to %s" : "Врати се на %s",
    "Add to your Nextcloud" : "Додадете во вашиот Cloud",
    "Group sharing is disabled by the administrator" : "Споделување во групата е оневозможено од страна на администраторот",
    "Public link sharing is disabled by the administrator" : "Споделување со јавен линк е оневозможено од страна на администраторот",
    "Sharing %1$s failed because the back end does not allow shares from type %2$s" : "Споделувањето на %1$s е неуспешно бидејќи позадината не дозволува споделувања од видот %2$s",
    "Sharing %s failed because the back end does not support ScienceMesh shares" : "Споделувањето на %s е неуспешно бидејќи серверот не дозволува ScienceMesh споделувања",
    "Public upload disabled by the administrator" : "Јавно прикачување е оневозможено од страна на администраторот",
    "Tokens must contain at least 1 character and may only contain letters, numbers, or a hyphen" : "Токените мора да содржат најмалку 1 знак и може да содржат само букви, бројки или цртичка",
    "Name or email …" : "Име или е-пошта ...",
    "Name, email, or Federated Cloud ID …" : "Име, е-пошта или федерален ИД ...",
    "Searching …" : "Пребарување ..."
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
