OC.L10N.register(
    "files_pdfviewer",
    {
    "Failed to load settings" : "Neizdevās ielādēt iestatījumus",
    "Failed to save settings" : "Neizdevās saglabāt iestatījumus"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
