OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "Protzedura ghiada de primu aviamentu",
    "Add your profile information! For example your email is needed to receive notifications." : "Agiunghe is informatziones tuas a su profilu! Pro nàrrere, s'indiritzu de posta tuo serbit pro retzire is notìficas.",
    "Add your profile information! For example your email is needed to receive notifications and reset your password." : "Agiunghe is informatziones tuas a su profilo! Pro nàrrere, s'indiritzu de posta serbit pro retzire is notìficas e ripristinare sa crae.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Agiunghe is informatziones de su profilu tuo! Cunfigura un'immàgine de su profilu pro un'anàlisi lestra de totu is funtzionalidades.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Agiunghe informatziones a su profilu tuo! Cunfigura unu  nùmene cumpletu pro un'anàlisi lestra de is funtzionalidades.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Agiunghe informatziones a su profilu tuo! Cunfigura una fotografia de su profilu pro un'anàlisi lestra de is funtzionalidades.",
    "Schedule work & meetings, synced with all your devices." : "Programma atividades e addòbios, sincronizados cun is dispositivos tuos.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Mantene is collegas e is amistades tuas in unu logu chene mustrare is datos privados issoro.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Aplicatzione de posta eletrònica simpre e integrada bene cun Archìvios, Cuntatos e Calendàriu.",
    "App recommendation: Tasks" : "Racumandatzione aplicatzione: Tasks",
    "Sync tasks from various devices with your Nextcloud and edit them online." : "Sincroniza in fainas dae vàrios dispositivos cun Nextcloud e modifica·ddas in lìnia.",
    "App recommendation: Deck" : "Racumandatzione aplicatzione: Deck",
    "Kanban style organization for personal planning and team projects." : "Organizatzione istile Kanban pro sa programmatzione personale e pro is progetos de iscuadra.",
    "App recommendation: Group folders" : "Racumandatzione aplicatzione: Cartella de grupu",
    "Admin-configured folders shared by everyone in a group." : "Cartellas cunfiguradas dae s'amministratzione cumpartzidas dae chie chi siat in unu grupu.",
    "Connect your calendar" : "Collega·ti a su calendàriu tuo",
    "Connect your contacts" : "Collega is cuntatos tuos",
    "Access files via WebDAV" : "Intra in is archìvios cun WebDAV",
    "Download macOS/iOS configuration profile" : "Iscàrriga su profilu de cunfiguratzione pro macOS/OS ",
    "Desktop client" : "Cliente de iscrivania",
    "Android app on Google Play Store" : "Aplicatzione pro Android in sa Butega de Google Play",
    "Android app on F-Droid" : "Aplicatzione pro Android in F-Droid",
    "iOS app" : "Aplicatzione iOS",
    "About & What's new" : "Informatziones e noas",
    "A welcome and introduction wizard for Nextcloud" : "Una protzedura ghiada de benebènnida e introdutzione a Nextcloud",
    "This application enables a pop-up window when a user first logs into Nextcloud. This window welcomes new users to Nextcloud, and contains links to the standard desktop client, Android app, and the iOS app. The window also shows a link for accessing Nextcloud via WebDAV. At any time, the first run wizard can be opened again via link \"About\" on settings menu.\nThe First run wizard can be customized to meet specific design goals, or to change links and messages. Create an appropriate theme following the Theming documentation, and changes to the look and feel of this Wizard are simple. More information is available in the first run wizard documentation, as well as the theming documentation." : "Custa aplicatzione ativat una ventana a cumparsa cando un'utente intrat pro sa primu borta in Nextcloud. Custa ventana dat sa benebènnida a is utèntzias noas de Nextcloud e cuntenet ligòngios a is clientes de iscrivania istandard, a s'aplicatzione Android e a s'aplicatzione iOS. Sa ventana mustrat puru unu ligòngiu pro intrare in Nextcloud cun WebDAV. In cale si siat momentu, sa protzedura ghiada de prima intrada si podet abèrrere cun su ligòngiu \"In contu de\" in su menù de cunfiguratzione.\nSa protzedura ghiada de prima intrada si podet personalizare pro rispòndere a obietivos ispetzìficos de disegnu, o pro modificare ligòngios e messàgios. Creare unu tema sighende sa documentatzione de Temas e cambiare sa bista se sa protzedura ghiada est fàtzile. Àteras informatziones sunt a disponimentu in sa documentatzione relativa a sa protzedura ghiada de prima intrada aici comente in sa documentatzione relativa a is temas.",
    "Close" : "Serra",
    "Need help? ↗" : "Boles agiudu?",
    "For large organisations ↗" : "Pro organizatziones mannas",
    "Calendar and contacts ↗" : "Calendàriu e cuntatos ↗",
    "Connect your calendar and contacts with your devices." : "Connete su calendàriu e is cuntatos tuos cun is dispositivos tuos.",
    "Welcome to {cloudName}!" : "Ti damus ssa benebènnida a {cloudName}!",
    "Community" : "Comunidade",
    "New in Nextcloud Hub {version}" : "Nou in Nextcloud Hub {version}",
    "Get the apps to sync your files" : "Iscàrriga is aplicatziones pro sincronizare is archìvios tuos",
    "Server address" : "Indiritzu de su serbidore",
    "Use this link to connect your apps and desktop client to this server:" : "Imprea custu ligòngiu pro collegare is aplicatziones tuas e su cliente de iscrivania a custu serbidore:",
    "What's new?" : "Ite noas?",
    "Share on social media" : "Cumpartzi in is retes sotziales"
},
"nplurals=2; plural=(n != 1);");
