OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Osobní kanál aktivit pro %s",
    "Your feed URL is invalid" : "URL adresa kanálu není platná",
    "Activity feed for %1$s" : "Kanál aktivit pro %1$s",
    "Activity feed" : "Kanál aktivit",
    "Your settings have been updated." : "Vaše nastavení byla zaktualizována.",
    "Settings have been updated." : "Nastavení byla zaktualizována.",
    "remote user" : "vzdálený uživatel",
    "Recent activity" : "Nedávná aktivita",
    "No activities" : "Žádné aktivity",
    "More activities" : "Další aktivity",
    "Daily activity summary for %s" : "Denní souhrn aktivit pro %s",
    "_and %n more…_::_and %n more…_" : ["a %n další …","a %n další …","a %n dalších …","a %n další …"],
    "You can disable daily digest emails in the <a href=\"%s\">settings</a>." : "E-maily s denním souhrnem je možné vypnout v <a href=\"%s\">nastaveních</a>.",
    "You can disable daily digest emails in the settings: %s" : "E-maily s denním souhrnem je možné vypnout v nastaveních: %s",
    "All activities" : "Všechny aktivity",
    "By others" : "Ostatními",
    "By you" : "Vámi",
    "Activity at %s" : "Aktivita na %s",
    "Hello %s" : "Dobrý den %s",
    "Hello %s," : "Dobrý den %s,",
    "There was some activity at %s" : "Na %s došlo k následující aktivitě",
    "_and %n more _::_and %n more _" : ["a %n další","a %n další","a %n dalších","a %n další"],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "Je možné změnit četnost těchto e-mailů nebo je vypnout v <a href=\"%s\">nastavení</a>.",
    "You can change the frequency of these emails or disable them in the settings: %s" : "Je možné změnit četnost těchto e-mailů nebo je vypnout v nastavení: %s",
    "Mail" : "Pošta",
    "Push" : "Služba push",
    "Activity" : "Aktivita",
    "Notifications" : "Upozorňování",
    "This application enables people to view a log of activities about them, their files or other data." : "Tato aplikace lidem umožňuje prohlížet záznamy aktivit vztahujících se k nim, jejich souborům a dalším datům.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Tato aplikace lidem umožňuje zobrazit si akce související s jejich soubory a daty v Nextcloud.\n\t\tKaždá osoba si může vytvořit svá vlastní nastavení ohledně aktivit v osobních nastaveních,\n\t\tzvolit si, které aktivity posílat na mobilní telefony, posílat e-mailem\n\t\tnebo zda každé ráno posílat denní přehled.\n\t\tDalší informace jsou k dispozici v dokumentaci k Aktivitám.",
    "Today" : "Dnes",
    "Last 7 days" : "Uplynulých 7 dnů",
    "Last 30 days" : "Uplynulých 30 dnů",
    "Custom range" : "Uživatelsky určený rozsah",
    "Clear search" : "Vyčistit hledání",
    "Clear filters" : "Vyčistit filtry",
    "From" : "Od",
    "To" : "Do",
    "Send email" : "Odeslat e-mail",
    "Send push notification" : "Odeslat push upozornění",
    "Activity notification configuration" : "Nastavení upozorňování ohledně aktivit",
    "Yesterday" : "Včera",
    "Less" : "Méně",
    "More" : "Další",
    "_Downloaded %n time (%s in the last 30 days)_::_Downloaded %n times (%s in the last 30 days)_" : ["Staženo %nkrát (%skrát v uplynulých 30 dnech)","Staženo %nkrát (%skrát v uplynulých 30 dnech)","Staženo %nkrát (%skrát v uplynulých 30 dnech)","Staženo %nkrát (%skrát v uplynulých 30 dnech)"],
    "_Downloaded %n time_::_Downloaded %n times_" : ["Staženo %nkrát","Staženo %nkrát","Staženo %nkrát","Staženo %nkrát"],
    "You need to set up your email address before you can receive notification emails." : "Pokud chcete dostávat upozornění e-mailem, je nejprve třeba si v profilu zadat svou e-mailovou adresu.",
    "Send activity emails" : "Posílat e-maily ohledně aktivity",
    "As soon as possible" : "Co možná nejdříve",
    "Hourly" : "Každou hodinu",
    "Daily" : "Každý den",
    "Weekly" : "Každý týden",
    "You commented" : "Okomentovali jste",
    "Message deleted by author" : "Autor zprávu smazal",
    "Open {filename}" : "Otevřít {filename}",
    "in {path}" : "v {path}",
    "Home" : "Domů",
    "Could not load activities" : "Nepodařilo se načíst aktivity",
    "Loading activities" : "Načítání aktivit",
    "This stream will show events like additions, changes & shares" : "Tento proud bude zobrazovat události jako přidání, změny a sdílení",
    "No activity yet" : "Zatím žádná aktivita",
    "New activities" : "Nové aktivity",
    "Loading more activities" : "Načítání dalších aktivit",
    "No more activities." : "Žádné další aktivity",
    "Could not enable RSS link" : "Nepodařilo se zapnout RSS odkaz",
    "RSS link copied to clipboard" : "Odkaz na RSS zkopírován do schránky",
    "Could not copy the RSS link, please copy manually:" : "Nepodařilo se zkopírovat odkaz na RSS – zkopírujte ručně:",
    "Activity settings" : "Nastavení pro Aktivity",
    "Enable RSS feed" : "Zapnout RSS kanál",
    "RSS feed" : "RSS kanál",
    "Copy RSS feed link" : "Zkopírovat odkaz na RSS kanál",
    "Personal notification settings" : "Nastavení osobního upozorňování",
    "Clear selection" : "Vyčistit výběr",
    "Unable to load the activity list" : "Nedaří se načíst seznam aktivit",
    "Choose for which activities you want to get an email or push notification." : "Zvolte pro které aktivity chcete dostávat upozornění e-mailem nebo přes službu push.",
    "Choose for which activities you want to get a push notification." : "Zvolte pro které aktivity chcete dostávat upozornění přes službu push.",
    "Notification" : "Upozornění",
    "Enable notification emails" : "Zapnout upozorňování e-mailem",
    "Daily activity summary" : "Denní souhrn aktivit",
    "Send daily activity summary in the morning" : "Každé ráno poslat souhrn denních aktivit",
    "Default settings" : "Výchozí nastavení",
    "Configure the default notification settings for new accounts." : "Nastavte výchozí volby ohledně upozorňování pro nově vytvářené účty.",
    "Unable to save the settings" : "Nastavení se nedaří uložit",
    "No more events to load" : "Žádné další události k načtení"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
