.date-range-picker-dialog[data-v-3b73070f]{height:400px;display:flex;justify-content:center;align-items:flex-start}.date-range-picker-dialog__picker[data-v-3b73070f]{flex-grow:1}.material-design-icon[data-v-c8e429a5]{display:flex;align-self:center;justify-self:center;align-items:center;justify-content:center}.nc-chip[data-v-c8e429a5]{--chip-size: 24px;--chip-radius: calc(var(--chip-size) / 2);height:var(--chip-size);max-width:fit-content;display:flex;flex-direction:row;align-items:center;border-radius:var(--chip-radius);background-color:var(--color-background-hover)}.nc-chip--primary[data-v-c8e429a5]{background-color:var(--color-primary-element);color:var(--color-primary-element-text)}.nc-chip--secondary[data-v-c8e429a5]{background-color:var(--color-primary-element-light);color:var(--color-primary-element-light-text)}.nc-chip--error[data-v-c8e429a5]{background-color:var(--color-error);color:var(--color-error-text)}.nc-chip--warning[data-v-c8e429a5]{background-color:var(--color-warning);color:var(--color-warning-text)}.nc-chip--success[data-v-c8e429a5]{background-color:var(--color-success);color:var(--color-success-text)}.nc-chip--no-actions .nc-chip__text[data-v-c8e429a5]{padding-inline-end:calc(2 * var(--default-grid-baseline))}.nc-chip--no-icon .nc-chip__text[data-v-c8e429a5]{padding-inline-start:calc(2 * var(--default-grid-baseline))}.nc-chip__text[data-v-c8e429a5]{flex:1 auto;overflow:hidden;text-overflow:ellipsis;text-wrap:nowrap}.nc-chip__icon[data-v-c8e429a5]{flex:0 0 var(--chip-size);margin-inline-end:var(--default-grid-baseline);line-height:1;display:flex;align-items:center;justify-content:center;overflow:hidden;height:var(--chip-size);width:var(--chip-size)}.nc-chip__actions[data-v-c8e429a5]{flex:0 0 var(--chip-size);--default-clickable-area: var(--chip-size);--border-radius-element: var(--chip-radius)}.place__preview[data-v-e05d44dd]{width:20px;height:20px;border-radius:100%}.photos-filters-display__filter[data-v-db72611f]{display:flex;align-items:flex-start}.photos-filters-display__filter__options-container[data-v-db72611f]{display:flex;flex-wrap:wrap;gap:4px}.photos-filters-display__filter__options-container__option[data-v-db72611f]{margin:4px 0}.photos-filters-input[data-v-cd233c90]{display:flex;flex-direction:column;justify-content:center;padding:8px 8px 0}[data-v-cd233c90] .vs__dropdown-toggle{background-color:var(--color-main-background)}
