OC.L10N.register(
    "office",
    {
    "Create new" : "Yangi yaratish",
    "Search" : "Qidirish",
    "All" : "Barchasi",
    "Create" : "Yaratish",
    "Filename" : "Fayl nomi"
},
"nplurals=1; plural=0;");
