OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "Невалиден Federated Cloud ID",
    "Server to server sharing is not enabled on this server" : "Споделяне между сървъри не е разрешено на този сървър.",
    "Couldn't establish a federated share." : "Неуспешно осъществяване на федерално споделяне",
    "Couldn't establish a federated share, maybe the password was wrong." : "Неуспешно осъществяване на федерално споделяне, можеби паролата е грепна.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Заявката за Федерирано споделяне е изпратена, ще получите покана. Проверете вашите известия.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Не можа да се установи федерирано споделяне, изглежда, че сървърът за федериране е твърде стар (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "Не е разрешено изпращането на федерирани групови споделяния от този сървър.",
    "Federated shares require read permissions" : "Обединените споделяния изискват права за четене",
    "File is already shared with %s" : "Файлът е вече споделен с %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Неуспешно споделяне на %1$s, не можа да се намери %2$s, може би сървърът в момента е недостъпен или използва самоподписан сертификат.",
    "Could not find share" : "Споделянето не можа да се намери",
    "Federated sharing" : "Федерално споделяне",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Получихте {share} като отдалечено споделяне от {user} (от името на {behalf})",
    "You received {share} as a remote share from {user}" : "Получихте {share}, като отдалечено споделяне от {user}",
    "Accept" : "Приемам",
    "Decline" : "Отхвърляне",
    "Federated Cloud Sharing" : "Федерирано споделяне в облак",
    "Sharing" : "Споделяне",
    "Federated file sharing" : "Федерирано споделяне на файлове",
    "Provide federated file sharing across servers" : "Осигуряване на федерирано споделяне на файлове между сървъри",
    "When enabled, all account properties (e.g. email address) with scope visibility set to \"published\", will be automatically synced and transmitted to an external system and made available in a public, global address book." : "Когато тази опция е включена, всички потребителски полета (напр. е-мейл адреси), които са със зададена видимост \"Публично\" ще бъдат автоматично синхронизирани и изпратени към външна система, която да ги направи достъпни чрез публична, глобална адресна книга.",
    "Unable to update federated files sharing config" : "Не може да се актуализира конфигурацията за споделяне на обединени файлове",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Споделете с мен чрез моя #Nextcloud Federated Cloud ID, вижте {url}",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Споделете с мен, чрез моя #Nextcloud Federated Cloud ID",
    "Share with me via Nextcloud" : "Споделете с мен, чрез Nextcloud",
    "Copy" : "Копие",
    "Copied!" : "Копирано!",
    "Federated Cloud" : "Федериран облак",
    "Share it so your friends can share files with you:" : "Споделете, за да могат приятелите ви да споделят файлове, с вас:",
    "Bluesky" : "Bluesky",
    "Facebook" : "Фейсбук",
    "Mastodon" : "Mastodon",
    "Add to your website" : "Добавете към вашия уеб сайт",
    "HTML Code:" : "HTML код:",
    "Cancel" : "Отказ",
    "Add remote share" : "Добави отдалечено споделяне",
    "Remote share" : "Отдалечено споделяне",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Искате ли да добавите отдалечено споделяне {name} от {owner}@{remote}?",
    "Remote share password" : "Парола за отдалечено споделяне",
    "X (formerly Twitter)" : "X (преди Twitter)"
},
"nplurals=2; plural=(n != 1);");
