OC.L10N.register(
    "settings",
    {
    "{actor} added you to group {group}" : "{actor} lade till dig i gruppen {group}",
    "You added {user} to group {group}" : "Du lade till {user} i gruppen {group}",
    "{actor} added {user} to group {group}" : "{actor} lade till {user} i gruppen {group}",
    "An administrator added you to group {group}" : "En administratör lade till dig i gruppen {group}",
    "An administrator added {user} to group {group}" : "En administratör lade till {user} i gruppen {group}",
    "{actor} removed you from group {group}" : "{actor} tog bort dig från gruppen {group}",
    "You removed {user} from group {group}" : "Du tog bort {user} från gruppen {group}",
    "{actor} removed {user} from group {group}" : "{actor} tog bort {user} från gruppen {group}",
    "An administrator removed you from group {group}" : "En administratör tog bort dig från gruppen {group}",
    "An administrator removed {user} from group {group}" : "En administratör tog bort {user} från gruppen {group}",
    "Your <strong>group memberships</strong> were modified" : "Dina <strong>gruppmedlemskap</strong> ändrades",
    "{actor} changed your password" : "{actor} ändrade ditt lösenord",
    "You changed your password" : "Du ändrade ditt lösenord",
    "Your password was reset by an administrator" : "Ditt lösenord återställdes av en administratör",
    "Your password was reset" : "Ditt lösenord återställdes",
    "{actor} changed your email address" : "{actor} ändrade din e-postadress",
    "You changed your email address" : "Du ändrade din e-postadress",
    "Your email address was changed by an administrator" : "Din e-postadress ändrades av en administratör",
    "You created an app password for a session named \"{token}\"" : "Du skapade ett applösenord för en session med namnet \"{token}\"",
    "An administrator created an app password for a session named \"{token}\"" : "En administratör skapade ett applösenord för en session med namnet \"{token}\"",
    "You deleted app password \"{token}\"" : "Du tog bort applösenordet \"{token}\"",
    "You deleted app password \"{token}\" and cancelled its pending remote wipe" : "Du tog bort applösenordet \"{token}\" och avbröt den väntande fjärrensningen",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Du bytte namn på applösenordet \"{token}\" till \"{newToken}\"",
    "You granted filesystem access to app password \"{token}\"" : "Du gav applösenordet \"{token}\" åtkomst till filsystemet",
    "You revoked filesystem access from app password \"{token}\"" : "Du återkallade applösenordet \"{token}\" åtkomst till filsystemet",
    "Security" : "Säkerhet",
    "You successfully logged in using two-factor authentication (%1$s)" : "Du loggade in med tvåfaktorautentisering (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Ett inloggningsförsök med tvåfaktorautentisering misslyckades (%1$s)",
    "Remote wipe was started on %1$s" : "Fjärrensning startades på %1$s",
    "Remote wipe has finished on %1$s" : "Fjärrensning slutfördes på %1$s",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Ditt <strong>lösenord</strong> eller din <strong>e-postadress</strong> ändrades",
    "One time login" : "Engångsinloggning",
    "QR Code login" : "Inloggning med QR-kod",
    "Wrong password" : "Fel lösenord",
    "Unable to change personal password" : "Det gick inte att byta personligt lösenord",
    "Saved" : "Sparat",
    "No Login supplied" : "Ingen inloggning angiven",
    "Unable to change password" : "Det gick inte att ändra lösenord",
    "Unable to change password. Password too long." : "Det gick inte att byta lösenord. Lösenord för långt.",
    "Authentication error" : "Fel vid autentisering",
    "Please provide an admin recovery password; otherwise, all account data will be lost." : "Ange ett lösenord för administratörsåterställning; annars kommer all kontodata att gå förlorad.",
    "Wrong admin recovery password. Please check the password and try again." : "Felaktigt återställningslösenord för administratör. Kontrollera lösenordet och prova igen.",
    "Backend does not support password change, but the encryption of the account key was updated." : "Bakänden stöder inte lösenordsbyte, men krypteringen av kontonyckeln uppdaterades.",
    "Administrator documentation" : "Administratörsdokumentation",
    "User documentation" : "Användardokumentation",
    "Nextcloud help overview" : "Översikt över Nextcloud-hjälpen",
    "Invalid SMTP password." : "Ogiltigt SMTP-lösenord.",
    "Email setting test" : "Test av e-postinställningar",
    "Well done, %s!" : "Bra gjort, %s!",
    "If you received this email, the email configuration seems to be correct." : "Om du har fått detta e-postmeddelande verkar e-postinställningarna vara korrekta.",
    "Email could not be sent. Check your mail server log" : "E-postmeddelandet kunde inte skickas. Kontrollera e-postserverns logg.",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Ett problem uppstod när e-postmeddelandet skulle skickas. Kontrollera inställningarna. (Fel: %s)",
    "You need to set your account email before being able to send test emails. Go to %s for that." : "Du måste ange en e-postadress för kontot innan du kan skicka testmeddelanden. Gå till %s för att göra det.",
    "Recently active" : "Nyligen aktiv",
    "Disabled accounts" : "Inaktiverade konton",
    "Settings" : "Inställningar",
    "Invalid account" : "Ogiltigt konto",
    "Invalid mail address" : "Ogiltig e-postadress",
    "Settings saved" : "Inställningar sparade",
    "Unable to change full name" : "Det gick inte att ändra namn",
    "Unable to change email address" : "Det gick inte att ändra e-postadress",
    "Unable to set invalid phone number" : "Det gick inte att ange det ogiltiga telefonnumret",
    "Unable to set invalid website" : "Det gick inte att ange den ogiltiga webbplatsen",
    "Some account data was invalid" : "Vissa kontouppgifter var ogiltiga",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Publicera följande inlägg på Twitter för att verifiera ditt Twitter-konto. Se till att det inte innehåller några radbrytningar:",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "För att verifiera din webbplats, lagra följande innehåll i din webbrot på '.well-known/CloudIdVerificationCode.txt' (säkerställ att hela texten ryms på en rad):",
    "%1$s changed your password on %2$s." : "%1$s ändrade ditt lösenord på %2$s.",
    "Your password on %s was changed." : "Ditt lösenord på %s har ändrats.",
    "Your password on %s was reset by an administrator." : "Ditt lösenord på %s har blivit återställt av en administratör.",
    "Your password on %s was reset." : "Ditt lösenord på %s återställdes.",
    "Password for %1$s changed on %2$s" : "Lösenordet för %1$s ändrades på %2$s",
    "Password changed for %s" : "Lösenord ändrat för %s",
    "If you did not request this, please contact an administrator." : "Kontakta en administratör om du inte begärde detta.",
    "Your email address on %s was changed." : "Din e-postadress på %s har ändrats.",
    "Your email address on %s was changed by an administrator." : "Din e-postadress på %s har ändrats av en administratör.",
    "Email address for %1$s changed on %2$s" : "E-postadressen för %1$s ändrades på %2$s",
    "Email address changed for %s" : "E-postadress ändrad för %s",
    "The new email address is %s" : "Den nya e-postadressen är %s",
    "Appearance and accessibility" : "Utseende och tillgänglighet",
    "Personal settings" : "Personliga inställningar",
    "Administration settings" : "Administrationsinställningar",
    "Accounts" : "Konton",
    "Help & privacy" : "Hjälp och integritet",
    "Your %s account was created" : "Ditt %s-konto skapades",
    "Welcome aboard" : "Välkommen ombord",
    "Welcome aboard %s" : "Välkommen ombord %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Välkommen till ditt %s-konto. Du kan lägga till, skydda och dela dina data.",
    "Your Login is: %s" : "Ditt inloggningsnamn är: %s",
    "Set your password" : "Ange ditt lösenord",
    "Go to %s" : "Gå till %s",
    "Install Client" : "Installera klient",
    "Logged in account must be a sub admin" : "Det inloggade kontot måste vara underadministratör",
    "Personal" : "Personligt",
    "Administration" : "Administration",
    "Users" : "Användare",
    "Additional settings" : "Övriga inställningar",
    "Assistant" : "Assistent",
    "Administration privileges" : "Administratörsbehörigheter",
    "Groupware" : "Grupprogramvara",
    "Office" : "Office",
    "Overview" : "Översikt",
    "Quick presets" : "Snabbförval",
    "Basic settings" : "Grundläggande inställningar",
    "Sharing" : "Delning",
    "Availability" : "Tillgänglighet",
    "Calendar" : "Kalender",
    "Personal info" : "Personlig information",
    "Mobile & desktop" : "Mobil och dator",
    "Artificial Intelligence" : "Artificiell intelligens",
    "None / STARTTLS" : "Ingen / STARTTLS",
    "Email server" : "E-postserver",
    "Mail Providers" : "E-postleverantörer",
    "Mail provider enables sending emails directly through the user's personal email account. At present, this functionality is limited to calendar invitations. It requires Nextcloud Mail 4.1 and an email account in Nextcloud Mail that matches the user's email address in Nextcloud." : "E-postleverantörer gör det möjligt att skicka e-post direkt via användarens personliga e-postkonto. För närvarande är denna funktionalitet begränsad till kalenderinbjudningar. Det kräver Nextcloud Mail 4.1 och ett e-postkonto i Nextcloud Mail som matchar användarens e-postadress i Nextcloud.",
    "Send emails using" : "Skicka e-post med",
    "User's email account" : "Användarens e-postkonto",
    "System email account" : "Systemets e-postkonto",
    "Security & setup checks" : "Säkerhets- och konfigurationskontroller",
    "Settings presets" : "Förinställningar för inställningar",
    "Background jobs" : "Bakgrundsjobb",
    "Unlimited" : "Obegränsat",
    "Verifying" : "Verifierar",
    "Verifying …" : "Verifierar …",
    "Verify" : "Verifiera",
    "Allowed admin IP ranges" : "Tillåtna IP-intervall för administratörer",
    "Admin IP filtering isn't applied." : "IP-filtrering för administratörer tillämpas inte.",
    "Configuration key \"%1$s\" expects an array (%2$s found). Admin IP range validation will not be applied." : "Konfigurationsnyckel \"%1$s\" förväntar sig en array (%2$s hittades). Validering av IP-intervall för administratörer tillämpas inte.",
    "Configuration key \"%1$s\" contains invalid IP range(s): \"%2$s\"" : "Konfigurationsnyckel \"%1$s\" innehåller ogiltiga IP-intervall: \"%2$s\"",
    "Admin IP filtering is correctly configured." : "IP-filtrering för administratörer är korrekt konfigurerad.",
    "App directories owner" : "Ägare till appkataloger",
    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:\n%s" : "Vissa appkataloger ägs av en annan användare än den som äger webbservern. Detta kan vara fallet om appar har installerats manuellt. Kontrollera behörigheterna för följande appkataloger:\n%s",
    "App directories have the correct owner \"%s\"" : "Appkatalogerna har rätt ägare: \"%s\"",
    "Brute-force Throttle" : "Begränsning av brute force-försök",
    "Your remote address could not be determined." : "Din fjärradress kunde inte fastställas.",
    "Your remote address was identified as \"%s\" and is brute-force throttled at the moment slowing down the performance of various requests. If the remote address is not your address this can be an indication that a proxy is not configured correctly." : "Din fjärradress identifierades som \"%s\" och begränsas för närvarande på grund av brute force-försök, vilket gör olika förfrågningar långsammare. Om adressen inte är din kan det tyda på att en proxy är felaktigt konfigurerad.",
    "Your remote address \"%s\" is not brute-force throttled." : "Din fjärradress \"%s\" begränsas inte på grund av brute force-försök.",
    "Old administration imported certificates" : "Äldre certifikat som importerats av administratörer",
    "A background job is pending that checks for administration imported SSL certificates. Please check back later." : "Ett bakgrundsjobb som kontrollerar SSL-certifikat importerade av administratörer väntar på att köras. Försök igen senare.",
    "There are some administration imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Det finns några administrationsimporterade SSL-certifikat som inte längre används med Nextcloud. De kan importeras från kommandoraden via kommandot \"occ security:certificates:import\". Deras sökvägar i datakatalogen visas nedan.",
    "Code integrity" : "Kodintegritet",
    "Integrity checker has been disabled. Integrity cannot be verified." : "Integritetskontrollen har inaktiverats. Integritet kan inte verifieras.",
    "No altered files" : "Inga ändrade filer",
    "Some files have not passed the integrity check. {link1} {link2}" : "Några filer har inte klarat integritetskontrollen. {link1} {link2}",
    "List of invalid files…" : "Lista över ogiltiga filer…",
    "Rescan…" : "Skanna igen …",
    "Cron errors" : "Cron-fel",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:\n%s" : "Det var inte möjligt att utföra cron-jobbet via CLI. Följande tekniska fel har uppstått:\n%s",
    "The last cron job ran without errors." : "Det senaste cron-jobbet kördes utan fel.",
    "Cron last run" : "Senaste cron-körning",
    "Last background job execution ran %s. Something seems wrong. {link}." : "Det senaste bakgrundsjobbet kördes %s. Något verkar vara fel. {link}.",
    "Last background job execution ran %s." : "Det senaste bakgrundsjobbet kördes %s.",
    "Data directory protected" : "Datakatalogen är skyddad",
    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Datakatalogen och filerna kan troligen nås från internet. .htaccess-filen fungerar inte. Vi rekommenderar starkt att du konfigurerar webbservern så att datakatalogen inte längre kan nås eller flyttar datakatalogen utanför webbserverns dokumentrot.",
    "Could not check that the data directory is protected. Please check manually that your server does not allow access to the data directory." : "Det gick inte att kontrollera att datakatalogen är skyddad. Kontrollera manuellt att servern inte tillåter åtkomst till datakatalogen.",
    "Database missing columns" : "Databasen saknar kolumner",
    "Missing optional column \"%s\" in table \"%s\"." : "Saknar valfri kolumn \"%s\" i tabellen \"%s\".",
    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "Databasen saknar några valfria kolumner. Eftersom att lägga till sådana i stora tabeller kan ta en del tid, har det inte gjorts automatiskt. Genom att köra kommandot \"occ db:add-missing-columns\" läggs de saknade kolumnerna till utan att instansen behöver stoppas. Att lägga till de valfria kolumnerna kan förbättra svarstid eller användbarhet.",
    "Database missing indices" : "Databasen saknar index",
    "Missing indices:" : "Saknade index:",
    "\"%s\" in table \"%s\"" : "\"%s\" i tabell \"%s\"",
    "Detected some missing optional indices. Occasionally new indices are added (by Nextcloud or installed applications) to improve database performance. Adding indices can sometimes take awhile and temporarily hurt performance so this is not done automatically during upgrades. Once the indices are added, queries to those tables should be faster. Use the command `occ db:add-missing-indices` to add them." : "Några valfria index saknas. Ibland lägger Nextcloud eller installerade appar till nya index för att förbättra databasprestandan. Det kan ta tid att lägga till index och tillfälligt försämra prestandan, så detta görs inte automatiskt under uppgraderingar. När indexen har lagts till bör frågor mot tabellerna gå snabbare. Kör `occ db:add-missing-indices` för att lägga till dem.",
    "Database missing primary keys" : "Databasen saknar primärnycklar",
    "Missing primary key on table \"%s\"." : "Saknar primärnyckel på tabellen \"%s\".",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "Databasen saknar några primärnycklar. Eftersom att lägga till sådana i stora tabeller kan ta en del tid, har det inte gjorts automatiskt. Genom att köra kommandot \"occ db:add-missing-primary-keys\" läggs de saknade primärnycklarna till utan att instansen behöver stoppas.",
    "Database pending bigint migrations" : "Databasen har väntande bigint-migreringar",
    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline." : "Vissa kolumner i databasen saknar en konvertering till big int. Eftersom att ändra kolumners typer på stora tabeller kan ta tid ändrades de inte automatiskt. Genom att köra \"occ db:convert-filecache-bigint\" kan dessa väntande ändringar appliceras manuellt. Denna operation måste utföras när instansen är offline.",
    "Debug mode" : "Felsökningsläge",
    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "Den här instansen körs i felsökningsläge. Aktivera detta endast för lokal utveckling och inte i produktionsmiljöer.",
    "Debug mode is disabled." : "Felsökningsläget är inaktiverat.",
    "Default phone region" : "Standardregion för telefonnummer",
    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective ISO 3166-1 code of the region to your config file." : "Din installation har ingen standardregion för telefon inställd. Detta krävs för att validera telefonnummer i profilinställningarna utan landskod. För att tillåta nummer utan landskod, lägg till \"default_phone_region\" med respektive ISO 3166-1-kod för regionen i din konfigurationsfil.",
    "Email test" : "E-posttest",
    "Mail delivery is disabled by instance config \"%s\"." : "E-postleverans är inaktiverad av instanskonfigurationen \"%s\".",
    "Email test was successfully sent" : "E-posttestet har skickats",
    "You have not set or verified your email server configuration, yet. Please head over to the \"Basic settings\" in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "Du har ännu inte angett eller verifierat e-postserverns inställningar. Gå till \"Grundläggande inställningar\" för att ange dem. Verifiera sedan inställningarna med knappen \"Skicka e-post\" under formuläret.",
    "Transactional File Locking" : "Transaktionell fillåsning",
    "Transactional File Locking is disabled. This is not a a supported configuraton. It may lead to difficult to isolate problems including file corruption. Please remove the `'filelocking.enabled' => false` configuration entry from your `config.php` to avoid these problems." : "Transaktionell fillåsning är inaktiverad. Detta är inte en konfiguration som stöds. Det kan leda till problem som är svåra att isolera, inklusive filkorruption. Ta bort konfigurationsposten `'filelocking.enabled' => false` från din `config.php` för att undvika dessa problem.",
    "The database is used for transactional file locking. To enhance performance, please configure memcache, if available." : "Databasen används till transaktionsbaserad fillåsning. För att förbättra prestandan, konfigurera memcache om det finns tillgängligt.",
    "Forwarded for headers" : "Forwarded-for-rubriker",
    "Your \"trusted_proxies\" setting is not correctly set, it should be an array." : "Din inställning för \"trusted_proxies\" är inte korrekt inställd, det borde vara en array.",
    "Your \"trusted_proxies\" setting is not correctly set, it should be an array of IP addresses - optionally with range in CIDR notation." : "Din inställning för \"trusted_proxies\" är inte korrekt inställd. Den ska vara en array med IP-adresser – eventuellt med intervall i CIDR-notation.",
    "The reverse proxy header configuration is incorrect. This is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud." : "Konfigurationen av rubriker för omvänd proxy är felaktig. Det är ett säkerhetsproblem som kan göra det möjligt för en angripare att förfalska IP-adressen som visas för Nextcloud.",
    "Your IP address was resolved as %s" : "Din IP-adress identifierades som %s",
    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud." : "Konfigurationen av rubriker för omvänd proxy är felaktig, eller så ansluter du till Nextcloud från en betrodd proxy. Om så inte är fallet är detta ett säkerhetsproblem som kan göra det möjligt för en angripare att förfalska IP-adressen som visas för Nextcloud.",
    "HTTPS access and URLs" : "HTTPS-åtkomst och URL:er",
    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead. Without it some important web functionality like \"copy to clipboard\" or \"service workers\" will not work!" : "Osäker åtkomst till webbplatsen via HTTP. Vi rekommenderar att du konfigurerar din server så att den kräver HTTPS istället. Utan det kommer vissa viktiga webbfunktioner som \"kopiera till urklipp\" eller \"service workers\" inte att fungera!",
    "Accessing site insecurely via HTTP." : "Osäker åtkomst till webbplatsen via HTTP.",
    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This likely means that your instance is behind a reverse proxy and the Nextcloud `overwrite*` config values are not set correctly." : "Du ansluter till instansen via en säker anslutning, men instansen genererar osäkra URL:er. Det innebär troligen att instansen finns bakom en omvänd proxy och att Nextclouds konfigurationsvärden för `overwrite*` inte är korrekt angivna.",
    "Your instance is generating insecure URLs. If you access your instance over HTTPS, this likely means that your instance is behind a reverse proxy and the Nextcloud `overwrite*` config values are not set correctly." : "Instansen genererar osäkra URL:er. Om du ansluter via HTTPS innebär det troligen att instansen finns bakom en omvänd proxy och att Nextclouds konfigurationsvärden för `overwrite*` inte är korrekt angivna.",
    "You are accessing your instance over a secure connection, and your instance is generating secure URLs." : "Du ansluter till din instans via en säker anslutning, och din instans genererar säkra URL:er.",
    "Internet connectivity" : "Internetanslutning",
    "Internet connectivity is disabled in configuration file." : "Internetanslutning är inaktiverad i konfigurationsfilen.",
    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Den här servern har ingen fungerande internetanslutning: Flera slutpunkter kunde inte nås. Det betyder att vissa av funktionerna som montering av extern lagring, aviseringar om uppdateringar eller installation av tredjepartsappar inte kommer att fungera. Att komma åt filer på distans och skicka e-postmeddelanden kanske inte heller fungerar. Upprätta en anslutning från denna server till internet för att kunna nyttja alla funktioner.",
    "JavaScript modules support" : "Stöd för JavaScript-moduler",
    "Unable to run check for JavaScript support. Please remedy or confirm manually if your webserver serves `.mjs` files using the JavaScript MIME type." : "Det gick inte att genomföra kontrollen för JavaScript-stöd. Åtgärda eller bekräfta manuellt om din webbserver hanterar `.mjs`-filer med JavaScript MIME-typen.",
    "Your webserver does not serve `.mjs` files using the JavaScript MIME type. This will break some apps by preventing browsers from executing the JavaScript files. You should configure your webserver to serve `.mjs` files with either the `text/javascript` or `application/javascript` MIME type." : "Din webbserver hanterar inte `.mjs`-filer med hjälp av JavaScript MIME-typen. Detta kommer att orsaka problem för vissa appar genom att förhindra att webbläsare kör JavaScript-filerna. Du bör konfigurera din webbserver att hantera `.mjs`-filer med antingen `text/javascript`- eller `application/javascript`-MIME-typen.",
    "JavaScript source map support" : "Stöd för JavaScript \"source map\"",
    "Your webserver is not set up to serve `.js.map` files. Without these files, JavaScript Source Maps won't function properly, making it more challenging to troubleshoot and debug any issues that may arise." : "Din webbserver är inte konfigurerad för att hantera `.js.map`-filer. Utan dessa filer fungerar inte JavaScript Source Maps korrekt, vilket gör det svårare att felsöka och åtgärda eventuella problem som kan uppstå.",
    "Old server-side-encryption" : "Gammal serverkryptering",
    "Disabled" : "Inaktiverad",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "Det gamla krypteringsformatet på servern är aktiverat. Vi rekommenderar att du inaktiverar detta.",
    "Logging level" : "Loggnivå",
    "The %1$s configuration option must be a valid integer value." : "Konfigurationsalternativet %1$s måste vara ett giltigt heltal.",
    "The logging level is set to debug level. Use debug level only when you have a problem to diagnose, and then reset your log level to a less-verbose level as it outputs a lot of information, and can affect your server performance." : "Loggning är inställd på felsökning. Använd endast felsökning när du har ett problem att diagnostisera och återställ sedan loggning till en mindre utförlig nivå då den skriver ut mycket information och kan påverka serverns prestanda.",
    "Logging level configured correctly." : "Loggnivå är korrekt konfigurerad.",
    "Maintenance window start" : "Underhållsfönster startar",
    "Server has no maintenance window start time configured. This means resource intensive daily background jobs will also be executed during your main usage time. We recommend to set it to a time of low usage, so users are less impacted by the load caused from these heavy tasks." : "Servern har ingen konfigurerad starttid för underhållsfönster. Detta innebär att resurskrävande dagliga bakgrundsjobb också kommer att köras under din huvudsakliga användningstid. Vi rekommenderar att du ställer in det till en tid med låg användning, så att användarna påverkas mindre av belastningen som orsakas av dessa tunga uppgifter.",
    "Maintenance window to execute heavy background jobs is between {start}:00 UTC and {end}:00 UTC" : "Underhållsfönstret för att utföra tunga bakgrundsjobb är mellan {start}:00 UTC och {end}:00 UTC",
    "Memcache" : "Memcache",
    "Memcached is configured as distributed cache, but the wrong PHP module (\"memcache\") is installed. Please install the PHP module \"memcached\"." : "Memcached är konfigurerad som distribuerad cache, men fel PHP-modul (\"memcache\") är installerad. Installera PHP-modulen \"memcached\".",
    "Memcached is configured as distributed cache, but the PHP module \"memcached\" is not installed. Please install the PHP module \"memcached\"." : "Memcached är konfigurerad som distribuerad cache, men PHP-modulen \"memcached\" är inte installerad. Installera PHP-modulen \"memcached\".",
    "No memory cache has been configured. To enhance performance, please configure a memcache, if available." : "Inget minnescache har konfigurerats. För att förbättra prestanda, vänligen konfigurera en memcache, om tillgänglig.",
    "Failed to write and read a value from local cache." : "Det gick inte att skriva och läsa ett värde i den lokala cachen.",
    "Failed to write and read a value from distributed cache." : "Det gick inte att skriva och läsa ett värde i den distribuerade cachen.",
    "Configured" : "Konfigurerad",
    "Mimetype migrations available" : "Migreringar av \"mimetyper\" tillgängliga",
    "One or more mimetype migrations are available. Occasionally new mimetypes are added to better handle certain file types. Migrating the mimetypes take a long time on larger instances so this is not done automatically during upgrades. Use the command `occ maintenance:repair --include-expensive` to perform the migrations." : "En eller flera migreringar av \"mimetyper\" är tillgängliga. Ibland läggs nya \"mimetyper\" till för att bättre hantera vissa filtyper. Att migrera \"mimetyperna\" tar lång tid på större instanser, så detta görs inte automatiskt under uppgraderingar. Använd kommandot `occ maintenance:repair --include-expensive` för att utföra migreringarna.",
    "MySQL row format" : "MySQL radformat",
    "You are not using MySQL" : "Du använder inte MySQL",
    "None of your tables use ROW_FORMAT=Compressed" : "Ingen av dina tabeller använder ROW_FORMAT=Compressed",
    "Incorrect row format found in your database. ROW_FORMAT=Dynamic offers the best database performances for Nextcloud. Please update row format on the following list: %s." : "Felaktigt radformat hittades i din databas. ROW_FORMAT=Dynamic erbjuder den bästa databasprestandan för Nextcloud. Uppdatera radformatet i följande lista: %s.",
    "MySQL Unicode support" : "MySQL-stöd för Unicode",
    "MySQL is used as database and does support 4-byte characters" : "MySQL används som databas och stöder 4-byte-tecken",
    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL." : "MySQL används som databas men stöder inte 4-byte-tecken. För att kunna hantera 4-byte-tecken (som emojier) utan problem i till exempel filnamn eller kommentarer rekommenderas det att aktivera 4-byte-stöd i MySQL.",
    "OCS provider resolving" : "Uppslagning av OCS-leverantör",
    "Could not check if your web server properly resolves the OCM and OCS provider URLs." : "Det gick inte att kontrollera om webbservern löser URL:erna för OCM- och OCS-leverantörerna korrekt.",
    "Your web server is not properly set up to resolve %1$s.\nThis is most likely related to a web server configuration that was not updated to deliver this folder directly.\nPlease compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx.\nOn Nginx those are typically the lines starting with \"location ~\" that need an update." : "Din webbserver är inte korrekt konfigurerad för att hantera %1$s.\nDet beror troligen på att webbserverkonfigurationen inte har uppdaterats för att leverera den här mappen direkt.\nJämför konfigurationen med omskrivningsreglerna i \".htaccess\" för Apache eller reglerna i dokumentationen för Nginx.\nI Nginx är det vanligtvis raderna som börjar med \"location ~\" som behöver uppdateras.",
    "Overwrite CLI URL" : "Skriv över CLI-URL",
    "The \"overwrite.cli.url\" option in your config.php is correctly set to \"%s\"." : "\"overwrite.cli.url\" i din config.php är korrekt inställt till \"%s\".",
    "The \"overwrite.cli.url\" option in your config.php is set to \"%s\" which is a correct URL. Suggested URL is \"%s\"." : "\"overwrite.cli.url\" i din config.php är inställt till \"%s\" vilket är en korrekt URL. Föreslagen URL är \"%s\".",
    "Please make sure to set the \"overwrite.cli.url\" option in your config.php file to the URL that your users mainly use to access this Nextcloud. Suggestion: \"%s\". Otherwise there might be problems with the URL generation via cron. (It is possible though that the suggested URL is not the URL that your users mainly use to access this Nextcloud. Best is to double check this in any case.)" : "Ställ in konfigurationsalternativet \"overwrite.cli.url\" i din config.php-fil till den URL som dina användare huvudsakligen använder för att komma åt detta Nextcloud. Förslag: \"%s\". Annars kan det uppstå problem med URL-genereringen via cron. (Det är dock möjligt att den föreslagna URL:en inte är den URL som dina användare huvudsakligen använder för att komma åt detta Nextcloud. Bäst är att dubbelkolla detta i alla fall.)",
    "PHP APCu configuration" : "PHP-konfiguration för APCu",
    "Your APCu cache has been running full, consider increasing the apc.shm_size php setting." : "Din APCu-cache har nått sitt gränsvärde. Öka värdet för inställningen \"apc.shm_size\" i PHP.",
    "Your APCu cache is almost full at %s%%, consider increasing the apc.shm_size php setting." : "Din APCu-cache är nästan full (%s%%). Överväg att höja PHP-inställningen apc.shm_size.",
    "PHP default charset" : "PHP:s standardteckenuppsättning",
    "PHP configuration option \"default_charset\" should be UTF-8" : "PHP-inställningen \"default_charset\" bör vara UTF-8",
    "PHP set_time_limit" : "PHP set_time_limit",
    "The function is available." : "Funktionen är tillgänglig.",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "PHP-funktionen \"set_time_limit\" är inte tillgänglig. Detta kan leda till att skript stoppas i mitten av utförandet och bryter din installation. Aktivering av denna funktion rekommenderas starkt.",
    "Freetype" : "Freetype",
    "Supported" : "Stöds",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Din PHP har inte FreeType-stöd, vilket resulterar i brott i profilbilder och inställningsgränssnittet.",
    "PHP getenv" : "PHP getenv",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP verkar inte vara korrekt inställd för att fråga efter systemmiljövariabler. Testet med getenv(\"PATH\") ger bara ett tomt svar.",
    "PHP file size upload limit" : "PHP-gräns för filuppladdning",
    "The PHP upload_max_filesize is too low. A size of at least %1$s is recommended. Current value: %2$s." : "PHP-parametern \"upload_max_filesize\" är för lågt inställd. Minst %1$s rekommenderas. Aktuellt värde: %2$s.",
    "The PHP post_max_size is too low. A size of at least %1$s is recommended. Current value: %2$s." : "PHP-parametern \"post_max_size\" är för lågt inställd. Minst %1$s rekommenderas. Aktuellt värde: %2$s.",
    "The PHP max_input_time is too low. A time of at least %1$s is recommended. Current value: %2$s." : "PHP-parametern \"max_input_time\" är för lågt inställd. Minst %1$s rekommenderas. Aktuellt värde: %2$s.",
    "The PHP max_execution_time is too low. A time of at least %1$s is recommended. Current value: %2$s." : "PHP-parametern \"max_execution_time\" är för lågt inställd. Minst %1$s rekommenderas. Aktuellt värde: %2$s.",
    "PHP memory limit" : "PHP:s minnesgräns",
    "The PHP memory limit is below the recommended value of %s. Some features or apps - including the Updater - may not function properly." : "Allokerat minne för PHP är under det rekommenderade värdet på %s. Vissa funktioner eller appar – inklusive Uppdateraren – kommer kanske inte att fungera korrekt.",
    "PHP modules" : "PHP-moduler",
    "increases language translation performance and fixes sorting of non-ASCII characters" : "ökar prestandan för språköversättningar och korrigerar sortering av tecken som inte är ASCII",
    "for Argon2 for password hashing and Ed25519 signature verification for RFC 9421 http message signatures" : "för Argon2-lösenordshashning och Ed25519-verifiering av HTTP-meddelandesignaturer enligt RFC 9421",
    "required for SFTP storage and recommended for WebAuthn performance" : "krävs för SFTP-lagring och rekommenderas för WebAuthn-prestanda",
    "for picture rotation in server and metadata extraction in the Photos app" : "för bildrotation på servern och metadataextrahering i appen Foton",
    "This instance is missing some required PHP modules. It is required to install them: %s." : "Den här instansen saknar några nödvändiga PHP-moduler. Det är nödvändigt att installera dem: %s.",
    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them:\n%s" : "Instansen saknar några rekommenderade PHP-moduler. För bättre prestanda och kompatibilitet rekommenderas starkt att de installeras:\n%s",
    "PHP opcache" : "PHP opcache",
    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "PHP OPcache-modulen är inte laddad. För bättre prestanda rekommenderas det att ladda den i din PHP-installation.",
    "OPcache is disabled. For better performance, it is recommended to apply \"opcache.enable=1\" to your PHP configuration." : "OPcache är inaktiverat. För bättre prestanda rekommenderas att \"opcache.enable=1\" anges i PHP-konfigurationen.",
    "The shared memory based OPcache is disabled. For better performance, it is recommended to apply \"opcache.file_cache_only=0\" to your PHP configuration and use the file cache as second level cache only." : "OPcache baserat på delat minne är inaktiverat. För bättre prestanda rekommenderas att \"opcache.file_cache_only=0\" anges i PHP-konfigurationen och att filcachen endast används som sekundär cache.",
    "OPcache is not working as it should, opcache_get_status() returns false, please check configuration." : "OPcache fungerar inte som det ska: opcache_get_status() returnerar false. Kontrollera konfigurationen.",
    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be kept in the cache, it is recommended to apply \"opcache.max_accelerated_files\" to your PHP configuration with a value higher than \"%s\"." : "Det maximala antalet OPcache-nycklar är på gränsen att överskridas. För att säkerställa att alla skript kan sparas i cachen rekommenderas det att sätta \"opcache.max_accelerated_files\" till ett värde högre än \"%s\" i PHP-konfigurationen.",
    "The OPcache buffer is nearly full. To assure that all scripts can be hold in cache, it is recommended to apply \"opcache.memory_consumption\" to your PHP configuration with a value higher than \"%s\"." : "OPcache-bufferten är nästan full. För att säkerställa att alla skript kan lagras i cache, rekommenderas det att tillämpa \"opcache.memory_consumption\" till ett högre värde än \"%s\" i PHP-konfigurationen.",
    "The OPcache interned strings buffer is nearly full. To assure that repeating strings can be effectively cached, it is recommended to apply \"opcache.interned_strings_buffer\" to your PHP configuration with a value higher than \"%s\"." : "OPcaches buffert för internerade strängar är nästan full. För att återkommande strängar ska kunna cachelagras effektivt rekommenderas att \"opcache.interned_strings_buffer\" anges till ett värde högre än \"%s\" i PHP-konfigurationen.",
    "OPcache is configured to remove code comments. With OPcache enabled, \"opcache.save_comments=1\" must be set for Nextcloud to function." : "OPcache är konfigurerat för att ta bort kodkommentarer. När OPcache är aktiverat måste \"opcache.save_comments=1\" anges för att Nextcloud ska fungera.",
    "Nextcloud is not allowed to use the OPcache API. With OPcache enabled, it is highly recommended to include all Nextcloud directories with \"opcache.restrict_api\" or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud får inte använda OPcache-API:t. När OPcache är aktiverat rekommenderas starkt att alla Nextcloud-kataloger inkluderas med \"opcache.restrict_api\" eller att inställningen tas bort för att inaktivera API-begränsningarna. Det förhindrar fel vid uppgraderingar av Nextcloud-kärnan eller appar.",
    "Checking from CLI, OPcache checks have been skipped." : "Kontrollen körs från kommandoraden, så OPcache-kontrollerna hoppades över.",
    "The PHP OPcache module is not properly configured. %s." : "PHP OPcache-modulen är inte korrekt konfigurerad. %s.",
    "Correctly configured" : "Korrekt konfigurerad",
    "PHP version" : "PHP-version",
    "You are currently running PHP %1$s. PHP %2$s is deprecated since Nextcloud %3$s. Nextcloud %4$s may require at least PHP %5$s. Please upgrade to one of the officially supported PHP versions provided by the PHP Group as soon as possible." : "Du använder PHP %1$s. PHP %2$s har varit föråldrat sedan Nextcloud %3$s. Nextcloud %4$s kan kräva minst PHP %5$s. Uppgradera så snart som möjligt till en officiellt stödd PHP-version från PHP Group.",
    "You are currently running PHP %s." : "Du kör för närvarande PHP %s.",
    "PHP \"output_buffering\" option" : "PHP-alternativet \"output_buffering\"",
    "PHP configuration option \"output_buffering\" must be disabled" : "PHP-inställningen \"output_buffering\" måste vara inaktiverad",
    "Push service" : "Push-tjänst",
    "Valid enterprise license" : "Giltig Enterprise-licens",
    "Free push service" : "Kostnadsfri push-tjänst",
    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications are limited to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at {link}." : "Det här är den communityversion av Nextcloud som saknar support. Med tanke på instansens storlek kan prestanda, tillförlitlighet och skalbarhet inte garanteras. Pushaviseringar begränsas för att inte överbelasta den kostnadsfria tjänsten. Läs mer om fördelarna med Nextcloud Enterprise på {link}.",
    "Random generator" : "Slumpgenerator",
    "No suitable source for randomness found by PHP which is highly discouraged for security reasons." : "Ingen lämplig källa för slumpmässighet hittades av PHP, vilket starkt avråds av säkerhetsskäl.",
    "Secure" : "Säker",
    "Configuration file access rights" : "Åtkomsträttigheter för konfigurationsfilen",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Den skrivskyddade konfigurationen har aktiverats. Detta förhindrar att vissa konfigurationer ställs in via webbgränssnittet. Dessutom måste filen göras skrivbar manuellt för varje uppdatering.",
    "Nextcloud configuration file is writable" : "Nextcloud-konfigurationsfilen är skrivbar",
    "Sanitize and merge duplicate system tags available" : "Duplicerade systemtaggar kan rensas och slås samman",
    "One or more system tags need to be sanitized or merged. This can take a long time on larger instances so this is not done automatically during upgrades. Use the command `occ maintenance:repair --include-expensive` to perform the migrations." : "En eller flera systemtaggar behöver rensas eller slås samman. Det kan ta lång tid på större instanser och görs därför inte automatiskt vid uppgraderingar. Kör kommandot `occ maintenance:repair --include-expensive` för att utföra migreringarna.",
    "Scheduling objects table size" : "Tabellstorlek för schemaläggningsobjekt",
    "You have more than %s rows in the scheduling objects table. Please run the expensive repair jobs via occ maintenance:repair --include-expensive." : "Tabellen med schemaläggningsobjekt innehåller fler än %s rader. Kör de resurskrävande reparationsjobben med `occ maintenance:repair --include-expensive`.",
    "Scheduling objects table size is within acceptable range." : "Storleken på tabellen med schemaläggningsobjekt ligger inom ett godtagbart intervall.",
    "HTTP headers" : "HTTP-rubriker",
    "- The `%1$s` HTTP header is not set to `%2$s`. Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "- HTTP-rubriken `%1$s` är inte inställd på `%2$s`. Vissa funktioner kanske därför inte fungerar korrekt. Vi rekommenderar att inställningen justeras.",
    "- The `%1$s` HTTP header is not set to `%2$s`. This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "- HTTP-rubriken `%1$s` är inte inställd på `%2$s`. Det innebär en möjlig säkerhets- eller integritetsrisk. Vi rekommenderar att inställningen justeras.",
    "- The `%1$s` HTTP header is not set to `%2$s`, `%3$s`, `%4$s`, `%5$s` or `%6$s`. This can leak referer information. See the {w3c-recommendation}." : "- HTTP-rubriken `%1$s` är inte inställd på `%2$s`, `%3$s`, `%4$s`, `%5$s` eller `%6$s`. Det kan läcka hänvisningsinformation. Se {w3c-recommendation}.",
    "- The `Strict-Transport-Security` HTTP header is not set to at least `%d` seconds (current value: `%d`). For enhanced security, it is recommended to use a long HSTS policy." : "- HTTP-rubriken `Strict-Transport-Security` är inte inställd på minst `%d` sekunder (aktuellt värde: `%d`). För bättre säkerhet rekommenderas en långvarig HSTS-policy.",
    "- The `Strict-Transport-Security` HTTP header is malformed: `%s`. For enhanced security, it is recommended to enable HSTS." : "- HTTP-rubriken `Strict-Transport-Security` är felaktigt utformad: `%s`. För bättre säkerhet rekommenderas att HSTS aktiveras.",
    "- The `Strict-Transport-Security` HTTP header is not set (should be at least `%d` seconds). For enhanced security, it is recommended to enable HSTS." : "- HTTP-rubriken `Strict-Transport-Security` är inte inställd (bör vara minst `%d` sekunder). För bättre säkerhet rekommenderas att HSTS aktiveras.",
    "Some headers are not set correctly on your instance" : "Vissa HTTP-rubriker är inte korrekt inställda på instansen",
    "Could not check that your web server serves security headers correctly. Please check manually." : "Det gick inte att kontrollera att webbservern skickar säkerhetsrubriker korrekt. Kontrollera detta manuellt.",
    "Could not check that your web server serves security headers correctly, unable to query `%s`" : "Det gick inte att kontrollera att webbservern skickar säkerhetsrubriker korrekt eftersom `%s` inte kunde anropas.",
    "Your server is correctly configured to send security headers." : "Servern är korrekt konfigurerad för att skicka säkerhetsrubriker.",
    "Configuration server ID" : "Konfigurationsserver-ID",
    "Server identifier isn’t configured. It is recommended if your Nextcloud instance is running on several PHP servers. Add a server ID in your configuration." : "Server-ID är inte konfigurerat. Det rekommenderas om din Nextcloud-instans körs på flera PHP-servrar. Lägg till ett server-ID i din konfiguration.",
    "\"%d\" is not a valid server identifier. It must be between 0 and 511." : "\"%d\" är inte en giltig serveridentifierare. Den måste vara mellan 0 och 511.",
    "Server identifier is configured and valid." : "Serveridentifieraren är konfigurerad och giltig.",
    "Database version" : "Databasversion",
    "MariaDB version 10.6 detected, this version is end-of-life and only supported as part of Ubuntu 22.04. MariaDB >=%1$s and <=%2$s is suggested for best performance, stability and functionality with this version of Nextcloud." : "MariaDB version 10.6 identifierades. Denna version har nått slutet av sin livscykel och stöds endast som en del av Ubuntu 22.04. MariaDB >=%1$s och <=%2$s rekommenderas för bästa prestanda, stabilitet och funktionalitet med denna version av Nextcloud.",
    "MariaDB version \"%1$s\" detected. MariaDB >=%2$s and <=%3$s is suggested for best performance, stability and functionality with this version of Nextcloud." : "MariaDB version \"%1$s\" används. MariaDB >=%2$s och <=%3$s rekommenderas för bästa prestanda, stabilitet och funktionalitet med den här versionen av Nextcloud.",
    "MySQL version \"%1$s\" detected. MySQL >=%2$s and <=%3$s is suggested for best performance, stability and functionality with this version of Nextcloud." : "MySQL version \"%1$s\" används. MySQL >=%2$s och <=%3$s rekommenderas för bästa prestanda, stabilitet och funktionalitet med den här versionen av Nextcloud.",
    "PostgreSQL version \"%1$s\" detected. PostgreSQL >=%2$s and <=%3$s is suggested for best performance, stability and functionality with this version of Nextcloud." : "PostgreSQL version \"%1$s\" används. PostgreSQL >=%2$s och <=%3$s rekommenderas för bästa prestanda, stabilitet och funktionalitet med den här versionen av Nextcloud.",
    "Nextcloud %d does not support your current version, so be sure to update the database before updating your Nextcloud Server." : "Nextcloud %d stöder inte din nuvarande version. Uppdatera databasen innan du uppdaterar din Nextcloud-server.",
    "Oracle version \"%1$s\" detected. Oracle >=%2$s and <=%3$s is suggested for best performance, stability and functionality with this version of Nextcloud." : "Oracle version \"%1$s\" används. Oracle >=%2$s och <=%3$s rekommenderas för bästa prestanda, stabilitet och funktionalitet med den här versionen av Nextcloud.",
    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend. This is particularly recommended when using the desktop client for file synchronisation. To migrate to another database use the command line tool: \"occ db:convert-type\"." : "SQLite används för närvarande som databas. För större installationer rekommenderas konvertering till en annan databas. Detta rekommenderas särskilt när skrivbordsklienten för filsynkronisering används. För att migrera till en annan databas, använd kommandoradsverktyget: \"occ db:convert-type\".",
    "Unknown database platform" : "Okänd databasplattform",
    "Architecture" : "Arkitektur",
    "64-bit" : "64-bit",
    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit!" : "Det verkar som att du använder en 32-bitarsversion av PHP. Nextcloud behöver 64 bitar för att fungera väl. Uppgradera operativsystemet och PHP till 64 bitar.",
    "Task Processing pickup speed" : "Hämtningshastighet för uppgifter",
    "_No scheduled tasks in the last day._::_No scheduled tasks in the last %n days._" : ["Inga schemalagda uppgifter den senaste dagen.","Inga schemalagda uppgifter de senaste %n dagarna."],
    "_The task pickup speed has been ok in the last day._::_The task pickup speed has been ok in the last %n days._" : ["Uppgifter har hämtats i normal takt under det senaste dygnet.","Uppgifter har hämtats i normal takt under de senaste %n dagarna."],
    "_The task pickup speed has been slow in the last day. Many tasks took longer than 4 minutes to be picked up. Consider setting up a worker to process tasks in the background._::_The task pickup speed has been slow in the last %n days. Many tasks took longer than 4 minutes to be picked up. Consider setting up a worker to process tasks in the background._" : ["Uppgifter har hämtats långsamt under det senaste dygnet. Många uppgifter väntade längre än 4 minuter innan de hämtades. Överväg att konfigurera en bakgrundsprocess för uppgiftsbearbetning.","Uppgifter har hämtats långsamt under de senaste %n dagarna. Många uppgifter väntade längre än 4 minuter innan de hämtades. Överväg att konfigurera en bakgrundsprocess för uppgiftsbearbetning."],
    "Task Processing success rate" : "Andel lyckade uppgifter",
    "_No scheduled tasks in the last %n day._::_No scheduled tasks in the last %n days._" : ["Inga schemalagda uppgifter under den senaste %n dagen.","Inga schemalagda uppgifter under de senaste %n dagarna."],
    "_Most tasks were successful in the last %n day._::_Most tasks were successful in the last %n days._" : ["De flesta uppgifterna slutfördes utan fel under den senaste %n dagen.","De flesta uppgifterna slutfördes utan fel under de senaste %n dagarna."],
    "_A lot of tasks failed in the last day. Consider checking the nextcloud log for errors and investigating whether the AI provider apps have been set up correctly._::_A lot of tasks failed in the last %n days. Consider checking the nextcloud log for errors and investigating whether the AI provider apps have been set up correctly._" : ["Många uppgifter misslyckades under det senaste dygnet. Kontrollera Nextcloud-loggen efter fel och undersök om apparna för AI-leverantörer har konfigurerats korrekt.","Många uppgifter misslyckades under de senaste %n dagarna. Kontrollera Nextcloud-loggen efter fel och undersök om apparna för AI-leverantörer har konfigurerats korrekt."],
    "Task Processing worker status" : "Status för uppgiftsbearbetaren",
    "_The Task Processing worker has run in the last %n minute._::_The Task Processing worker has run in the last %n minutes._" : ["Uppgiftsbearbetaren har körts under den senaste %n minuten.","Uppgiftsbearbetaren har körts under de senaste %n minuterna."],
    "The Task Processing worker does not seem to be running. The last run was at %s." : "Uppgiftsbearbetaren verkar inte vara igång. Den kördes senast %s.",
    "The Task Processing worker does not seem to be running. It seems it has never run so far." : "Uppgiftsbearbetaren verkar inte vara igång. Den verkar aldrig ha körts.",
    "Temporary space available" : "Tillfälligt utrymme tillgängligt",
    "Error while checking the temporary PHP path - it was not properly set to a directory. Returned value: %s" : "Fel vid kontroll av den tillfälliga PHP-sökvägen - den är inte korrekt inställd till en katalog. Returnerat värde: %s",
    "The PHP function \"disk_free_space\" is disabled, which prevents the check for enough space in the temporary directories." : "PHP-funktionen \"disk_free_space\" är inaktiverad, vilket förhindrar kontrollen av ledigt utrymme i de tillfälliga katalogerna.",
    "Error while checking the available disk space of temporary PHP path or no free disk space returned. Temporary path: %s" : "Fel vid kontroll av tillgängligt diskutrymme för tillfällig PHP-sökväg eller \"ledigt diskutrymme saknas\" returnerades. Tillfällig sökväg: %s",
    "- %.1f GiB available in %s (PHP temporary directory)" : "- %.1f GiB tillgängligt för %s (PHP temporär lagring)",
    "- %.1f GiB available in %s (Nextcloud temporary directory)" : "- %.1f GiB tillgängligt för %s (Nextcloud temporär lagring)",
    "Temporary directory is correctly configured:\n%s" : "Konfigurerad temporär lagring: %s",
    "This instance uses an S3 based object store as primary storage, and has enough space in the temporary directory.\n%s" : "Den här instansen använder ett S3-baserat objektarkiv som primär lagring och har tillräckligt med utrymme i den temporära katalogen.\n%s",
    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GiB of free space available in the temp directory of PHP. To improve this please change the temporary directory in the php.ini or make more space available in that path. \nChecking the available space in the temporary path resulted in %.1f GiB instead of the recommended 50 GiB. Path: %s" : "Den här instansen använder ett S3-baserat objektlager som primär lagring. De uppladdade filerna lagras tillfälligt på servern och därför rekommenderas det att ha 50 GiB ledigt utrymme i PHP:s temporära katalog. För att förbättra detta, ändra den temporära katalogen i php.ini eller frigör mer utrymme i den sökvägen.\nKontroll av tillgängligt utrymme i den tillfälliga sökvägen resulterade i %.1f GiB istället för de rekommenderade 50 GiB. Sökväg: %s",
    "Database transaction isolation level" : "Databasens transaktionsisoleringsnivå",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Databasen körs inte med transaktionsisoleringsnivån \"READ COMMITTED\". Det kan orsaka problem när flera aktiviteter körs parallellt.",
    "Was not able to get transaction isolation level: %s" : "Det gick inte att hämta transaktionsisoleringsnivån: %s",
    "Second factor configuration" : "Konfiguration av andra faktor",
    "This instance has no second factor provider available." : "Instansen har ingen leverantör av en andra autentiseringsfaktor.",
    "Second factor providers are available but two-factor authentication is not enforced." : "Leverantörer av en andra autentiseringsfaktor finns, men tvåfaktorautentisering krävs inte.",
    "Second factor providers are available and enforced: %s." : "Följande leverantörer av en andra autentiseringsfaktor finns och krävs: %s.",
    ".well-known URLs" : ".well-known-URL:er",
    "`check_for_working_wellknown_setup` is set to false in your configuration, so this check was skipped." : "`check_for_working_wellknown_setup` är inställt på false i konfigurationen, så kontrollen hoppades över.",
    "Could not check that your web server serves `.well-known` correctly. Please check manually." : "Det gick inte att kontrollera att webbservern hanterar `.well-known`-URL:er korrekt. Kontrollera detta manuellt.",
    "Your web server is not properly set up to resolve `.well-known` URLs, failed on:\n`%s`" : "Webbservern är inte korrekt konfigurerad för att hantera `.well-known`-URL:er. Felet inträffade för:\n`%s`",
    "Your server is correctly configured to serve `.well-known` URLs." : "Servern är korrekt konfigurerad för att hantera `.well-known`-URL:er.",
    "Font file loading" : "Inläsning av typsnittsfiler",
    "Could not check for {extension} loading support. Please check manually if your webserver serves `.{extension}` files." : "Det gick inte att kontrollera stödet för att läsa in {extension}. Kontrollera manuellt om webbservern hanterar `.{extension}`-filer.",
    "Your web server is not properly set up to deliver .{extension} files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustment to also deliver .{extension} files. Compare your Nginx configuration to the recommended configuration in our documentation." : "Din webbserver är inte korrekt konfigurerad för att leverera .{extension}-filer. Detta beror vanligtvis på Nginx-konfigurationen. För Nextcloud 15 måste den justeras så att även .{extension}-filer levereras. Jämför Nginx-konfigurationen med den rekommenderade konfigurationen i vår dokumentation.",
    "Profile information" : "Profilinformation",
    "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Profilbild, fullständigt namn, e-post, telefonnummer, adress, webbplats, Twitter, organisation, roll, rubrik, biografi och om din profil är aktiverad",
    "Nextcloud settings" : "Nextcloud-inställningar",
    "Generate text" : "Skapa text",
    "Unified task processing" : "Enhetlig uppgiftsbearbetning",
    "AI tasks can be implemented by different apps. Here you can set which app should be used for which task." : "AI-uppgifter kan implementeras av olika appar. Här kan du ange vilken app som ska användas för respektive uppgift.",
    "Allow AI usage for guest users" : "Tillåt AI-användning för gästanvändare",
    "Provider for Task types" : "Leverantör för uppgiftstyper",
    "Enable" : "Aktivera",
    "None of your currently installed apps provide Task processing functionality" : "Ingen av de installerade apparna tillhandahåller funktioner för uppgiftsbearbetning",
    "Hide legacy provider settings" : "Dölj inställningar för äldre leverantörer",
    "Show legacy provider settings" : "Visa inställningar för äldre leverantörer",
    "Machine translation (Legacy)" : "Maskinöversättning (äldre)",
    "Machine translation can be implemented by different apps. Here you can define the precedence of the machine translation apps you have installed at the moment." : "Maskinöversättning kan implementeras av olika appar. Här kan du definiera prioritet för de maskinöversättningsappar som du har installerade.",
    "This API is deprecated. Install apps that provide Unified task processing to get the best experience." : "Detta API är föråldrat. Installera appar som tillhandahåller enhetlig uppgiftsbearbetning för bästa möjliga upplevelse.",
    "Learn more about AI providers" : "Läs mer om AI-leverantörer",
    "Image generation (Legacy)" : "Bildgenerering (äldre)",
    "Image generation can be implemented by different apps. Here you can set which app should be used." : "Bildgenerering kan implementeras av olika appar. Här kan du ställa in vilken app som ska användas.",
    "None of your currently installed apps provide image generation functionality" : "Ingen av dina för närvarande installerade appar tillhandahåller bildgenereringsfunktioner",
    "Text processing (Legacy)" : "Textbehandling (äldre)",
    "Text processing tasks can be implemented by different apps. Here you can set which app should be used for which task." : "Textbearbetningsuppgifter kan implementeras av olika appar. Här kan du ställa in vilken app som ska användas för vilken uppgift.",
    "Task:" : "Uppgift:",
    "None of your currently installed apps provide text processing functionality using the Text Processing API." : "Inga av dina installerade appar tillhandahåller textbehandlingsfunktioner med hjälp av Text Processing API.",
    "Here you can decide which group can access certain sections of the administration settings." : "Här kan du bestämma vilken grupp som har tillgång till vissa delar av administrationsinställningarna.",
    "Unable to modify setting" : "Det gick inte att ändra inställningen",
    "None" : "Ingen",
    "Changed disclaimer text" : "Friskrivningstexten ändrades",
    "Deleted disclaimer text" : "Friskrivningstexten togs bort",
    "Could not set disclaimer text" : "Det gick inte att ange friskrivningstext",
    "Allow apps to use the Share API" : "Tillåt appar att använda delnings-API:t",
    "Allow resharing" : "Tillåt vidaredelning",
    "Allow sharing with groups" : "Tillåt delning med grupper",
    "Restrict users to only share with users in their groups" : "Begränsa användare till att endast dela med användare i sina grupper",
    "Ignore the following groups when checking group membership" : "Ignorera följande grupper när du kontrollerar gruppmedlemskap",
    "Allow users to preview files even if download is disabled" : "Tillåt användare att förhandsgranska filer även om hämtning är inaktiverad",
    "Users will still be able to screenshot or record the screen. This does not provide any definitive protection." : "Användare kommer fortfarande att kunna ta skärmdumpar eller spela in skärmen. Detta ger inget definitivt skydd.",
    "Allow users to share via link and emails" : "Tillåt användare att dela via länk och e-post",
    "Allow public uploads" : "Tillåt offentlig uppladdning",
    "Allow public shares to be added to other clouds by federation." : "Tillåt att offentliga delningar läggs till i andra moln genom federerad delning.",
    "This will add share permissions to all newly created link shares." : "Detta lägger till behörigheter för alla nyskapade länkdelningar.",
    "Always ask for a password" : "Fråga alltid efter lösenord",
    "Enforce password protection" : "Tillämpa lösenordskydd",
    "Exclude groups from password requirements" : "Undanta grupper från lösenordskrav",
    "Exclude groups from creating link shares" : "Undanta grupper från att skapa länkdelningar",
    "Allow users to set custom share link tokens" : "Tillåt användare att ange anpassade token för delningslänkar",
    "Shares with custom tokens will continue to be accessible after this setting has been disabled" : "Delningar med anpassade token är fortfarande tillgängliga efter att inställningen har inaktiverats",
    "Shares with guessable tokens may be accessed easily" : "Delningar med lättgissade token kan enkelt nås",
    "Limit sharing based on groups" : "Begränsa delning baserat på grupper",
    "Allow sharing for everyone (default)" : "Tillåt delning för alla (standard)",
    "Exclude some groups" : "Undanta vissa grupper",
    "Allow some groups" : "Tillåt vissa grupper",
    "Groups allowed to share" : "Grupper som får dela",
    "Groups excluded from sharing" : "Grupper som inte får dela",
    "Not allowed groups will still be able to receive shares, but not to initiate them." : "Grupper som inte är tillåtna kan fortfarande ta emot delningar, men inte initiera dem.",
    "Set default expiration date for internal shares" : "Ange standardutgångsdatum för interna delningar",
    "Enforce expiration date" : "Tillämpa utgångsdatum",
    "Default expiration time of new shares in days" : "Standardutgångstid för nya delningar i dagar",
    "Expire shares after x days" : "Delningar förfaller efter x dagar",
    "Set default expiration date for shares to other servers" : "Ange standardutgångsdatum för delningar till andra servrar",
    "Enforce expiration date for remote shares" : "Tillämpa utgångsdatum för fjärrdelningar",
    "Default expiration time of remote shares in days" : "Standardutgångstid för fjärrdelningar i dagar",
    "Expire remote shares after x days" : "Fjärrdelningar förfaller efter x dagar",
    "Set default expiration date for shares via link or mail" : "Ange standardutgångsdatum för delningar via länk eller e-post",
    "Enforce expiration date for link or mail shares" : "Kräv utgångsdatum för länk- och e-postdelningar",
    "Default expiration time of shares in days" : "Standardutgångstid för delningar i dagar",
    "Privacy settings for sharing" : "Sekretessinställningar för delning",
    "Allow account name autocompletion in share dialog and allow access to the system address book" : "Tillåt automatisk ifyllning av kontonamn i delningsdialogrutan och tillåt åtkomst till systemets adressbok",
    "Sharing autocompletion restrictions" : "Begränsningar för automatisk ifyllning vid delning",
    "If autocompletion restrictions for both \"same group\" and \"phonebook integration\" are enabled, a match in either is enough to show the user." : "Om begränsningarna för både \"samma grupp\" och \"telefonboksintegration\" är aktiverade räcker en träff i någon av dem för att användaren ska visas.",
    "Restrict account name autocompletion and system address book access to users within the same groups" : "Begränsa automatisk ifyllning av kontonamn och åtkomst till systemets adressbok till användare i samma grupper",
    "Restrict account name autocompletion to users based on their phonebook" : "Begränsa automatisk ifyllning av kontonamn till användare utifrån deras telefonbok",
    "Allow autocompletion to full match when entering the full name (ignoring restrictions like group membership or missing phonebook match)" : "Tillåt automatisk ifyllning vid fullständig matchning när hela namnet anges (begränsningar som gruppmedlemskap eller avsaknad av matchning i telefonboken ignoreras)",
    "Full match autocompletion restrictions" : "Begränsningar för automatisk ifyllning vid fullständig matchning",
    "Also allow autocompletion on full match of the user ID" : "Tillåt även automatisk ifyllning vid fullständig matchning av användar-ID:t",
    "Also allow autocompletion on full match of the display name" : "Tillåt även automatisk ifyllning vid fullständig matchning av visningsnamnet",
    "Also allow autocompletion on full match of the user email" : "Tillåt även automatisk ifyllning vid fullständig matchning av användarens e-postadress",
    "Do not use second user displayname for full match" : "Använd inte användarens sekundära visningsnamn vid fullständig matchning",
    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Visa friskrivningstext på den offentliga uppladdningssidan (visas endast när fillistan är dold)",
    "Disclaimer text" : "Friskrivningstext",
    "This text will be shown on the public link upload page when the file list is hidden." : "Texten visas på den offentliga uppladdningssidan när fillistan är dold.",
    "Default share permissions" : "Standardbehörigheter för delningar",
    "Two-Factor Authentication" : "Tvåfaktorsautentisering",
    "Two-factor authentication can be enforced for all accounts and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Tvåfaktorsautentisering kan krävas för alla konton eller specifika grupper. Om de inte har någon tvåfaktorsautentisering konfigurerad kommer de inte kunna logga in.",
    "Enforce two-factor authentication" : "Kräv tvåfaktorautentisering",
    "Limit to groups" : "Begränsa till grupper",
    "Enforcement of two-factor authentication can be set for certain groups only." : "Krav på tvåfaktorautentisering kan begränsas till vissa grupper.",
    "Two-factor authentication is enforced for all members of the following groups." : "Tvåfaktorautentisering krävs för alla medlemmar i följande grupper.",
    "Enforced groups" : "Grupper där tvåfaktorautentisering krävs",
    "Two-factor authentication is not enforced for members of the following groups." : "Tvåfaktorautentisering krävs inte för medlemmar i följande grupper.",
    "Excluded groups" : "Undantagna grupper",
    "When groups are selected/excluded, they use the following logic to determine if an account has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If an account is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "När grupper väljs eller undantas används följande logik för att avgöra om tvåfaktorautentisering krävs för ett konto: Om inga grupper väljs krävs tvåfaktorautentisering för alla utom medlemmar i de undantagna grupperna. Om grupper väljs krävs tvåfaktorautentisering för alla medlemmar i dessa grupper. Om ett konto ingår i både en vald och en undantagen grupp har den valda gruppen företräde och tvåfaktorautentisering krävs.",
    "Save changes" : "Spara ändringar",
    "Failed to load groups" : "Det gick inte att läsa in grupper",
    "Failed to create group" : "Det gick inte att skapa gruppen",
    "List of groups. This list is not fully populated for performance reasons. The groups will be loaded as you navigate or search through the list." : "Lista över grupper. Av prestandaskäl läses inte hela listan in på en gång. Grupperna läses in när du navigerar eller söker i listan.",
    "Groups" : "Grupper",
    "Creating group…" : "Skapar grupp …",
    "Create group" : "Skapa grupp",
    "Group name" : "Gruppnamn",
    "Please enter a valid group name" : "Ange ett giltigt gruppnamn",
    "Loading groups…" : "Läser in grupper …",
    "Google Chrome for Android" : "Google Chrome för Android",
    "{productName} iOS app" : "{productName}-appen för iOS",
    "{productName} Android app" : "{productName}-appen för Android",
    "{productName} Talk for iOS" : "{productName} Talk för iOS",
    "{productName} Talk for Android" : "{productName} Talk för Android",
    "Sync client" : "Synkklient",
    "This session" : "Den här sessionen",
    "{client} - {version} ({system})" : "{client} - {version} ({system})",
    "{client} - {version}" : "{client} - {version}",
    "Confirm wipe" : "Bekräfta fjärrensning",
    "Do you really want to wipe your data from this device?" : "Vill du verkligen rensa dina data från den här enheten?",
    "Wipe device" : "Rensa enhet",
    "Cancel" : "Avbryt",
    "Device name" : "Enhetsnamn",
    "Cancel renaming" : "Avbryt namnändring",
    "Save new name" : "Spara det nya namnet",
    "Marked for remote wipe" : "Markerad för fjärrensning",
    "Device settings" : "Enhetsinställningar",
    "Allow filesystem access" : "Tillåt åtkomst till filsystemet",
    "Rename" : "Byt namn",
    "Revoke" : "Återkalla",
    "Revoking this token might prevent the wiping of your device if it has not started the wipe yet." : "Återkallning kan förhindra att enheten rensas om inte rensningen redan har startat.",
    "Revoke and cancel pending wipe?" : "Återkalla och avbryta väntande fjärrensning?",
    "Only continue if you no longer need the device to be wiped." : "Fortsätt endast om enheten inte längre behöver fjärrensas.",
    "Revoke and cancel wipe" : "Återkalla och avbryt fjärrensning",
    "Revoke app password?" : "Återkalla applösenordet?",
    "The app or device will lose access on its next sync. This cannot be undone." : "Appen eller enheten förlorar åtkomsten vid nästa synkronisering. Detta går inte att ångra.",
    "Remote wipe has not started yet." : "Fjärrensningen har inte startat ännu.",
    "Revoking now cancels the wipe. The device keeps its synced data." : "Om du återkallar nu avbryts fjärrensningen. Enheten behåller sina synkroniserade data.",
    "Device" : "Enhet",
    "Last activity" : "Senaste aktivitet",
    "Actions" : "Åtgärder",
    "Devices & sessions" : "Enheter och sessioner",
    "Web, desktop and mobile clients currently logged in to your account." : "Webb-, skrivbords- och mobila klienter som är inloggade på ditt konto just nu.",
    "Error while creating device token" : "Fel vid skapande av enhetstoken",
    "App name" : "Appnamn",
    "Create new app password" : "Skapa nytt applösenord",
    "App password copied!" : "Applösenordet har kopierats!",
    "Copy app password" : "Kopiera applösenord",
    "Login name copied!" : "Inloggningsnamnet har kopierats!",
    "Copy login name" : "Kopiera inloggningsnamnet",
    "Could not copy app password. Please copy it manually." : "Det gick inte att kopiera applösenordet. Kopiera det manuellt.",
    "Could not copy login name. Please copy it manually." : "Det gick inte att kopiera inloggningsnamnet. Kopiera det manuellt.",
    "New app password" : "Nytt applösenord",
    "Use the credentials below to configure your app or device. For security reasons this password will only be shown once." : "Använd inloggningsuppgifterna nedan för att konfigurera din app eller enhet. Av säkerhetsskäl kommer detta lösenord endast att visas en gång.",
    "Login" : "Inloggningsnamn",
    "Password" : "Lösenord",
    "Show QR code for mobile apps" : "Visa QR-kod för mobila appar",
    "Use system cron service to call the cron.php file every 5 minutes." : "Använd systemets cron-tjänst för att anropa cron.php var femte minut.",
    "The cron.php needs to be executed by the system account \"{user}\"." : "cron.php måste köras av systemkontot \"{user}\".",
    "The PHP POSIX extension is required. See {linkstart}PHP documentation{linkend} for more details." : "PHP POSIX-tillägget krävs. Se {linkstart}PHP-dokumentationen{linkend} för mer information.",
    "Unable to update background job mode" : "Det gick inte att uppdatera bakgrundsjobbläget",
    "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information." : "För att servern ska fungera korrekt är det viktigt att konfigurera bakgrundsjobb korrekt. Cron är den rekommenderade inställningen. Se dokumentationen för mer information.",
    "Last job execution ran {time}. Something seems wrong." : "Det senaste jobbet kördes {time}. Något verkar vara fel.",
    "Last job ran {relativeTime}." : "Det senaste jobbet kördes {relativeTime}.",
    "Background job did not run yet!" : "Bakgrundsjobbet har inte körts ännu!",
    "AJAX" : "AJAX",
    "Execute one task with each page loaded. Use case: Single account instance." : "Kör en uppgift varje gång en sida läses in. Användningsfall: instans med ett enda konto.",
    "Webcron" : "Webcron",
    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 accounts depending on the usage)." : "cron.php har registrerats hos en webcron-tjänst som anropar filen var femte minut via HTTP. Användningsfall: mycket liten instans (1–5 konton beroende på användning).",
    "Cron (Recommended)" : "Cron (Rekommenderad)",
    "Unable to update profile default setting" : "Det gick inte att uppdatera profilens standardinställning",
    "Unable to update profile picker setting" : "Det gick inte att uppdatera inställningen för profilväljaren",
    "Profile" : "Profil",
    "Enable or disable profile by default for new accounts." : "Aktivera eller inaktivera profil som standard för nya konton.",
    "Enable the profile picker" : "Aktivera profilväljaren",
    "Enable or disable the profile picker in the Smart Picker and the profile link previews." : "Aktivera eller inaktivera profilväljaren i smartväljaren och förhandsvisningar av profillänkar.",
    "Password confirmation is required" : "Lösenordsbekräftelse krävs",
    "Failed to save setting" : "Det gick inte att spara inställningen",
    "{app}'s declarative setting field: {name}" : "Deklarativt inställningsfält för {app}: {name}",
    "Unable to update server side encryption config" : "Det gick inte att uppdatera konfigurationen för kryptering på serversidan",
    "Server-side encryption" : "Kryptering på serversidan",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Kryptering på serversidan gör det möjligt att kryptera filer som laddas upp till servern. Det medför begränsningar, bland annat sämre prestanda, så aktivera funktionen endast vid behov.",
    "To encrypt all existing files run this OCC command:" : "Kör följande OCC-kommando för att kryptera alla befintliga filer:",
    "Enable server-side encryption" : "Aktivera kryptering på serversidan",
    "Disabling server side encryption is only possible using OCC, please refer to the documentation." : "Kryptering på serversidan kan endast inaktiveras med OCC. Mer information finns i dokumentationen.",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Ingen krypteringsmodul har lästs in. Aktivera en krypteringsmodul i appmenyn.",
    "Select default encryption module:" : "Välj standardmodul för kryptering:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}" : "Du måste migrera krypteringsnycklarna från den gamla krypteringen (ownCloud <= 8.0) till den nya. Aktivera \"Standardmodul för kryptering\" och kör {command}.",
    "Cancel encryption" : "Avbryt kryptering",
    "Enable encryption" : "Aktivera kryptering",
    "Confirm enabling encryption" : "Bekräfta aktivering av kryptering",
    "Please read carefully before activating server-side encryption:" : "Läs noga innan du aktiverar kryptering på serversidan:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "När kryptering har aktiverats krypteras alla filer som därefter laddas upp till servern när de lagras. Krypteringen kan senare endast inaktiveras om den aktiva krypteringsmodulen stöder det och alla förutsättningar är uppfyllda, till exempel att en återställningsnyckel har angetts.",
    "By default a master key for the whole instance will be generated. Please check if that level of access is compliant with your needs." : "Som standard genereras en huvudnyckel för hela instansen. Kontrollera om den åtkomstnivån uppfyller dina behov.",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Enbart kryptering garanterar inte systemets säkerhet. Dokumentationen innehåller mer information om hur krypteringsappen fungerar och vilka användningsfall som stöds.",
    "Be aware that encryption always increases the file size." : "Observera att kryptering alltid ökar filstorleken.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Det är alltid bra att regelbundet säkerhetskopiera dina data. Om kryptering används måste även krypteringsnycklarna säkerhetskopieras tillsammans med data.",
    "Refer to the admin documentation on how to manually also encrypt existing files." : "Se dokumentationen för information om hur du manuellt krypterar befintliga filer.",
    "This is the final warning: Do you really want to enable encryption?" : "Detta är en slutgiltig varning: Vill du verkligen aktivera kryptering?",
    "Failed to delete group \"{group}\"" : "Det gick inte att ta bort gruppen \"{group}\"",
    "Please confirm the group removal" : "Bekräfta borttagning av gruppen",
    "You are about to delete the group \"{group}\". The accounts will NOT be deleted." : "Du håller på att ta bort gruppen \"{group}\". Kontona tas INTE bort.",
    "Confirm" : "Bekräfta",
    "Submit" : "Skicka",
    "Rename group" : "Byt namn på grupp",
    "Delete group" : "Ta bort grupp",
    "Current password" : "Nuvarande lösenord",
    "New password" : "Nytt lösenord",
    "Change password" : "Byt lösenord",
    "Choose your profile picture" : "Välj din profilbild",
    "Please select a valid png or jpg file" : "Välj en giltig png- eller jpg-fil",
    "Error setting profile picture" : "Fel vid inställning av profilbild",
    "Error cropping profile picture" : "Det gick inte att beskära profilbilden",
    "Error saving profile picture" : "Det gick inte att spara profilbilden",
    "Error removing profile picture" : "Det gick inte att ta bort profilbilden",
    "Your profile picture" : "Din profilbild",
    "Upload profile picture" : "Ladda upp profilbild",
    "Choose profile picture from Files" : "Välj profilbild från filer",
    "Remove profile picture" : "Ta bort profilbild",
    "The file must be a PNG or JPG" : "Filen måste vara en PNG eller JPG",
    "Picture provided by original account" : "Bild från det ursprungliga kontot",
    "Set as profile picture" : "Använd som profilbild",
    "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "Observera att det kan ta upp till 24 timmar för din profilbild att uppdateras överallt.",
    "Your biography. Markdown is supported." : "Din biografi. Markdown stöds.",
    "Unable to update date of birth" : "Det gick inte att uppdatera födelsedatum",
    "Enter your date of birth" : "Ange ditt födelsedatum",
    "Bluesky handle" : "Bluesky-användarnamn",
    "You are using {s}{usage}{/s}" : "Du använder {s}{usage}{/s}",
    "You are using {s}{usage}{/s} of {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})" : "Du använder {s}{usage}{/s} av {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})",
    "Details" : "Detaljer",
    "You are a member of the following groups:" : "Du är medlem i följande grupper:",
    "Your full name" : "Ditt fullständiga namn",
    "Unable to update primary email address" : "Det gick inte att uppdatera den primära e-postadressen",
    "Unable to delete additional email address" : "Det gick inte att ta bort den ytterligare e-postadressen",
    "No email address set" : "Ingen e-postadress angiven",
    "Email options" : "Alternativ för e-postadress",
    "Options for additional email address {index}" : "Alternativ för den ytterligare e-postadressen {index}",
    "Remove primary email" : "Ta bort den primära e-postadressen",
    "Delete email" : "Ta bort e-postadressen",
    "This address is not confirmed" : "Denna adress är inte verifierad",
    "Unset as primary email" : "Ta bort som primär e-postadress",
    "Set as primary email" : "Ange som primär e-postadress",
    "Additional email address {index}" : "Ytterligare e-postadress {index}",
    "Unable to delete primary email address" : "Det gick inte att ta bort den primära e-postadressen",
    "Unable to add additional email address" : "Det gick inte att lägga till en ytterligare e-postadress",
    "Unable to update additional email address" : "Det gick inte att uppdatera den ytterligare e-postadressen",
    "Primary email for password reset and notifications" : "Primär e-postadress för lösenordsåterställning och aviseringar",
    "Your handle" : "Ditt kontonamn",
    "Derived from your locale ({weekDayName})" : "Härledd från din språkvariant ({weekDayName})",
    "Unable to update first day of week" : "Det gick inte att uppdatera veckans första dag",
    "Day to use as the first day of week" : "Dag att använda som första veckodag",
    "Your headline" : "Din rubrik",
    "No language set" : "Inget språk angivet",
    "Unable to update language" : "Det gick inte att uppdatera språk",
    "Languages" : "Språk",
    "Help translate" : "Hjälp till med översättningarna",
    "No locale set" : "Ingen språkvariant angiven",
    "Unable to update locale" : "Det gick inte att uppdatera språkvarianten",
    "Locales" : "Språkvarianter",
    "Week starts on {firstDayOfWeek}" : "Veckan börjar på {firstDayOfWeek}",
    "Your city" : "Din stad",
    "Your organisation" : "Din organisation",
    "Your phone number" : "Ditt telefonnummer",
    "Edit your Profile visibility" : "Ändra synligheten för din profil",
    "Unable to update profile enabled state" : "Det gick inte att uppdatera om profilen är aktiverad",
    "Enable profile" : "Aktivera profil",
    "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "Den mest restriktiva inställningen för synlighet eller omfattning gäller för profilen. Om synligheten exempelvis är \"Visa för alla\" och omfattningen är \"Privat\" gäller \"Privat\".",
    "Unable to update visibility of {displayId}" : "Det gick inte att uppdatera synlighet för {displayId}",
    "she/her" : "hon/henne",
    "he/him" : "han/honom",
    "they/them" : "de/dem",
    "Your pronouns. E.g. {pronounsExample}" : "Dina pronomen. T.ex. {pronounsExample}",
    "Your role" : "Din roll",
    "Timezone" : "Tidszon",
    "Your X (formerly Twitter) handle" : "Ditt användarnamn på X (tidigare Twitter)",
    "Your website" : "Din webbplats",
    "Invalid value" : "Ogiltigt värde",
    "Unable to update {property}" : "Det gick inte att uppdatera {property}",
    "No {property} set" : "Ingen {property} inställd",
    "Change scope level of {property}, current scope is {scope}" : "Ändra omfattningsnivå för {property}, nuvarande omfattning är {scope}",
    "Unable to update federation scope of the primary {property}" : "Det gick inte att uppdatera federeringsomfattningen för den primära {property}",
    "Unable to update federation scope of additional {property}" : "Det gick inte att uppdatera federeringsomfattningen för ytterligare {property}",
    "Add additional email" : "Lägg till ytterligare e-postadress",
    "Add" : "Lägg till",
    "Create" : "Skapa",
    "Change" : "Ändra",
    "Delete" : "Ta bort",
    "Reshare" : "Dela vidare",
    "Default config values" : "Standardvärden för konfigurationen",
    "Applications config" : "Appkonfiguration",
    "User config" : "Användarkonfiguration",
    "Bundled applications" : "Medföljande appar",
    "Enabled applications" : "Aktiverade appar",
    "Disabled applications" : "Inaktiverade appar",
    "Large organization" : "Mycket stor organisation",
    "Big organization" : "Stor organisation",
    "Small organization" : "Liten organisation",
    "Hosting company" : "Webbhotell",
    "University" : "Universitet",
    "School" : "Skola",
    "Club or association" : "Klubb eller förening",
    "Family" : "Familj",
    "Personal use" : "Personligt bruk",
    "Default" : "Standard",
    "Setup errors" : "Konfigurationsfel",
    "Setup warnings" : "Konfigurationsvarningar",
    "Setup recommendations" : "Konfigurationsrekommendationer",
    "Default language" : "Standardspråk",
    "Common languages" : "Vanliga språk",
    "Other languages" : "Andra språk",
    "Password change is disabled because the master key is disabled" : "Lösenordsbyte är inaktiverat eftersom huvudnyckeln är inaktiverad",
    "No accounts" : "Inga konton",
    "Loading accounts …" : "Läser in konton …",
    "List of accounts. This list is not fully rendered for performance reasons. The accounts will be rendered as you navigate through the list." : "Lista över konton. Av prestandaskäl visas inte hela listan på en gång. Kontona visas när du navigerar i listan.",
    "Account name" : "Kontonamn",
    "Account updated" : "Kontot har uppdaterats",
    "Failed to update account" : "Det gick inte att uppdatera kontot",
    "Edit account" : "Redigera konto",
    "Saving …" : "Sparar …",
    "Save" : "Spara",
    "Account name will be autogenerated" : "Kontonamnet genereras automatiskt",
    "Account name (required)" : "Kontonamn (obligatoriskt)",
    "Password (required)" : "Lösenord (obligatoriskt)",
    "Email (required)" : "E-post (obligatoriskt)",
    "Email" : "E-post",
    "New account" : "Nytt konto",
    "Adding new account …" : "Lägger till nytt konto …",
    "Add new account" : "Lägg till nytt konto",
    "Display name" : "Visningsnamn",
    "Either password or email is required" : "Antingen lösenord eller e-post krävs",
    "Member of the following groups (required)" : "Medlem i följande grupper (obligatoriskt)",
    "Member of the following groups" : "Medlem i följande grupper",
    "Failed to search groups" : "Det gick inte att söka efter grupper",
    "Set account groups" : "Ange kontogrupper",
    "Admin of the following groups" : "Administratör för följande grupper",
    "Set account as admin for …" : "Ange kontot som administratör för …",
    "Language" : "Språk",
    "Set default language" : "Ange standardspråk",
    "Manager" : "Hanterare",
    "Search for a manager…" : "Sök efter en chef…",
    "Quota" : "Kvot",
    "Set account quota" : "Ange kontots kvot",
    "_{userCount} account …_::_{userCount} accounts …_" : ["{userCount} konto …","{userCount} konton …"],
    "_{userCount} account_::_{userCount} accounts_" : ["{userCount} konto","{userCount} konton"],
    "Total rows summary" : "Sammanfattning av antalet rader",
    "Scroll to load more rows" : "Rulla för att läsa in fler rader",
    "Avatar" : "Avatar",
    "Group admin for" : "Gruppadministratör för",
    "Account backend" : "Kontobakände",
    "Storage location" : "Lagringsplats",
    "First login" : "Första inloggningen",
    "Last login" : "Senaste inloggningen",
    "Account actions" : "Kontoåtgärder",
    "Unknown" : "Okänd",
    "Never" : "Aldrig",
    "{size} used" : "{size} används",
    "Delete account" : "Ta bort konto",
    "Disconnect all devices and delete local data" : "Koppla från alla enheter och ta bort lokala data",
    "Disable account" : "Inaktivera konto",
    "Enable account" : "Aktivera konto",
    "Resend welcome email" : "Skicka välkomstmeddelandet igen",
    "In case of lost device or exiting the organization, this can remotely wipe the {productName} data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Om en enhet tappas bort eller någon lämnar organisationen kan detta fjärrensa {productName}-data från alla enheter som är kopplade till {userid}. Funktionen fungerar endast när enheterna är anslutna till internet.",
    "Remote wipe of devices" : "Fjärrensning av enheter",
    "Wipe {userid}'s devices" : "Rensa enheter för {userid}",
    "Wiped {userid}'s devices" : "Rensade enheter för {userid}",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "Ta bort kontot för {userid} permanent, inklusive alla personliga filer, appdata med mera.",
    "Account deletion" : "Borttagning av konto",
    "Delete {userid}'s account" : "Ta bort konto för {userid}",
    "Welcome mail sent!" : "Välkomstmeddelandet har skickats!",
    "Loading account …" : "Laddar konto …",
    "Toggle account actions menu" : "Visa eller dölj menyn med kontoåtgärder",
    "Edit" : "Redigera",
    "Account management settings" : "Inställningar för kontohantering",
    "Visibility" : "Synlighet",
    "Show language" : "Visa språk",
    "Show account backend" : "Visa kontobakände",
    "Show storage path" : "Visa lagringssökväg",
    "Show first login" : "Visa första inloggningen",
    "Show last login" : "Visa senaste inloggningen",
    "Sorting" : "Sortering",
    "The system config enforces sorting the groups by name. This also disables showing the member count." : "Systemkonfigurationen tvingar sortering av grupper efter namn. Detta inaktiverar också visning av medlemsantal.",
    "Group list sorting" : "Sortering av grupplistan",
    "Sorting only applies to the currently loaded groups for performance reasons. Groups will be loaded as you navigate or search through the list." : "Sortering gäller endast de grupper som för närvarande är inlästa av prestandaskäl. Grupper laddas när du navigerar eller söker i listan.",
    "By member count" : "Efter antal medlemmar",
    "By name" : "Efter namn",
    "Send email" : "Skicka e-post",
    "Send welcome email to new accounts" : "Skicka ett välkomstmeddelande till nya konton",
    "Defaults" : "Standardvärden",
    "Default quota" : "Standardkvot",
    "Select default quota" : "Välj standardkvot",
    "Search" : "Sök",
    "Focus search" : "Fokusera sökfältet",
    "Help" : "Hjälp",
    "Show those shortcuts" : "Visa dessa kortkommandon",
    "Server error while trying to complete WebAuthn device registration" : "Serverfel när du försökte slutföra registreringen av en WebAuthn-enhet",
    "Passwordless authentication requires a secure connection." : "Lösenordsfri autentisering kräver en säker anslutning.",
    "Add WebAuthn device" : "Lägg till WebAuthn-enhet",
    "Please authorize your WebAuthn device." : "Godkänn din WebAuthn-enhet.",
    "Adding your device …" : "Lägger till din enhet ….",
    "Unnamed device" : "Namnlös enhet",
    "Passwordless Authentication" : "Lösenordsfri autentisering",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "Ställ in ditt konto för lösenordsfri autentisering som följer FIDO2-standarden.",
    "No devices configured." : "Inga enheter konfigurerade.",
    "The following devices are configured for your account:" : "Följande enheter är konfigurerade för ditt konto:",
    "Your browser does not support WebAuthn." : "Din webbläsare stöder inte WebAuthn.",
    "Email sent successfully" : "E-postmeddelandet har skickats",
    "Failed to send email" : "Det gick inte att skicka e-postmeddelandet",
    "Failed to save email settings" : "Det gick inte att spara e-postinställningarna",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Det är viktigt att konfigurera den här servern för att kunna skicka e-post, till exempel för återställning av lösenord och aviseringar.",
    "The server configuration is read-only so the mail settings cannot be changed using the web interface." : "Serverkonfigurationen är skrivskyddad så e-postinställningarna kan inte ändras med hjälp av webbgränssnittet.",
    "Mail delivery is disabled by instance config \"{config}\"." : "E-postleverans är inaktiverad av instanskonfigurationen \"{config}\".",
    "Send mode" : "Sändningsläge",
    "Encryption" : "Kryptering",
    "Sendmail mode" : "Sendmail-läge",
    "Disable certificate verification (insecure)" : "Inaktivera certifikatverifiering (osäkert)",
    "From address" : "Avsändaradress",
    "Domain" : "Domän",
    "Server address" : "Serveradress",
    "Host" : "Värd",
    "Port" : "Port",
    "Authentication" : "Autentisering",
    "Authentication required" : "Autentisering krävs",
    "Sending test email…" : "Skickar testmeddelande…",
    "Send test email" : "Skicka ett testmeddelande",
    "Saving…" : "Sparar…",
    "Save settings" : "Spara inställningar",
    "Please double check the {linkStartInstallationGuides}installation guides{linkEnd}, and check for any errors or warnings in the {linkStartLog}log{linkEnd}." : "Läs {linkStartInstallationGuides}installationsguiderna{linkEnd} noggrant och kontrollera om det finns fel eller varningar i {linkStartLog}loggen{linkEnd}.",
    "Check the security of your {productName} over {linkStart}our security scan{linkEnd}." : "Kontrollera säkerheten för {productName} med {linkStart}vår säkerhetsskanning{linkEnd}.",
    "Security & setup warnings" : "Säkerhets- och konfigurationsvarningar",
    "It is important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Det är viktigt för säkerhet och prestanda att allt är korrekt konfigurerat. För att hjälpa dig med det gör vi några automatiska kontroller. Se den länkade dokumentationen för mer information.",
    "Checking your server …" : "Kontrollerar din server …",
    "Failed to run setup checks" : "Det gick inte att köra konfigurationskontrollerna",
    "Try again" : "Försök igen",
    "All checks passed." : "Alla kontroller godkändes.",
    "There are some errors regarding your setup." : "Det finns fel i konfigurationen.",
    "There are some warnings regarding your setup." : "Det finns varningar i konfigurationen.",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Som administratör kan du finjustera delningsbeteendet. Mer information finns i dokumentationen.",
    "You need to enable the File sharing App." : "Du måste aktivera appen Fildelning.",
    "Failed to save selected preset." : "Det gick inte att spara den valda förinställningen.",
    "Select a configuration preset for easy setup." : "Välj en förinställning för enkel konfiguration.",
    "Apply" : "Tillämpa",
    "All accounts" : "Alla konton",
    "Admins" : "Administratörer",
    "Account group: {group}" : "Kontogrupp: {group}",
    "Account management" : "Kontohantering",
    "Search accounts and groups…" : "Sök efter konton och grupper…",
    "For performance reasons, when you enable encryption on a {productName} server only new and changed files are encrypted." : "Av prestandaskäl krypteras endast nya och ändrade filer när kryptering aktiveras på en {productName}-server.",
    "Location" : "Plats",
    "Profile picture" : "Profilbild",
    "About" : "Om",
    "Date of birth" : "Födelsedatum",
    "Full name" : "Fullständigt namn",
    "Additional email" : "Ytterligare e-postadress",
    "Fediverse (e.g. Mastodon)" : "Fediverse (t.ex. Mastodon)",
    "Headline" : "Rubrik",
    "Organisation" : "Organisation",
    "Phone number" : "Telefonnummer",
    "Pronouns" : "Pronomen",
    "Role" : "Roll",
    "X (formerly Twitter)" : "X (tidigare Twitter)",
    "Bluesky" : "Bluesky",
    "Website" : "Webbplats",
    "Profile visibility" : "Profilsynlighet",
    "Locale" : "Språkvariant",
    "First day of week" : "Första dagen i veckan",
    "timezone" : "Tidszon",
    "Private" : "Privat",
    "Only visible to people matched via phone number integration through Talk on mobile" : "Endast synlig för personer som matchats via telefonnummerintegreringen i Talk på mobilen",
    "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Inte tillgängligt eftersom egenskapen krävs för grundläggande funktioner, bland annat fildelning och kalenderinbjudningar",
    "Local" : "Lokal",
    "Only visible to people on this instance and guests" : "Endast synlig för personer på den här instansen och gäster",
    "Federated" : "Federerad",
    "Only synchronize to trusted servers" : "Synkronisera endast med betrodda servrar",
    "Not available as federation has been disabled for your account, contact your system administration if you have any questions" : "Inte tillgängligt eftersom federerad delning har inaktiverats för kontot. Kontakta systemadministratören om du har frågor.",
    "Published" : "Publicerad",
    "Synchronize to trusted servers and the global and public address book" : "Synkronisera med betrodda servrar och den globala och offentliga adressboken",
    "Not available as publishing account specific data to the lookup server is not allowed, contact your system administration if you have any questions" : "Inte tillgängligt eftersom kontospecifika data inte får publiceras till uppslagsservern. Kontakta systemadministratören om du har frågor.",
    "Discover" : "Upptäck",
    "Your apps" : "Dina appar",
    "Active apps" : "Aktiva appar",
    "Disabled apps" : "Inaktiverade appar",
    "Updates" : "Uppdateringar",
    "App bundles" : "Appaket",
    "Featured apps" : "Utvalda appar",
    "Supported apps" : "Appar med support",
    "Show to everyone" : "Visa för alla",
    "Show to logged in accounts only" : "Visa endast för inloggade konton",
    "Hide" : "Dölj",
    "Could not register device: Network error" : "Det gick inte att registrera enheten: nätverksfel",
    "Could not register device: Probably already registered" : "Det gick inte att registrera enheten: den är förmodligen redan registrerad",
    "Could not register device" : "Det gick inte att registrera enheten",
    "Could not delete the app token" : "Det gick inte att ta bort apptoken",
    "Error while wiping the device with the token" : "Fel uppstod vid rensning av enheten",
    "Error while updating device token name" : "Fel vid uppdatering av enhetstokens namn",
    "Error while updating device token scope" : "Fel vid uppdatering av enhetstokens omfång",
    "An error occurred during the request. Unable to proceed." : "Ett fel uppstod under begäran. Det gick inte att fortsätta.",
    "Could not set group sorting" : "Det gick inte att ange gruppsortering",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Det kom för många förfrågningar från ditt nätverk. Försök senare eller kontakta din administratör om detta är ett fel.",
    "Error" : "Fel",
    "Account documentation" : "Kontodokumentation",
    "Administration documentation" : "Administratörsdokumentation",
    "Documentation" : "Dokumentation",
    "Forum" : "Forum",
    "Nextcloud help & privacy resources" : "Resurser för Nextcloud-hjälp och integritet",
    "General documentation" : "Allmän dokumentation",
    "Legal notice" : "Juridisk information",
    "Privacy policy" : "Integritetspolicy",
    "Version" : "Version",
    "Reasons to use Nextcloud in your organization" : "Anledningar att använda Nextcloud i din organisation",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Utvecklat av {communityopen}Nextcloud-gemenskapen{linkclose}. {githubopen}Källkoden{linkclose} licensieras under {licenseopen}AGPL{linkclose}.",
    "Like our Facebook page" : "Gilla vår Facebook-sida",
    "Follow us on Bluesky" : "Följ oss på Bluesky",
    "Follow us on Mastodon" : "Följ oss på Mastodon",
    "Check out our blog" : "Kolla in vår blogg",
    "Subscribe to our newsletter" : "Prenumerera på vårt nyhetsbrev",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Den här communityversionen av Nextcloud saknar support och direktaviseringar är inte tillgängliga.",
    "Open documentation" : "Öppna dokumentationen",
    "Use a second factor besides your password to increase security for your account." : "Använd en andra faktor utöver ditt lösenord för att öka säkerheten för ditt konto.",
    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Om du använder tredjepartsappar för att ansluta till Nextcloud ska du skapa och konfigurera ett applösenord för var och en innan tvåfaktorautentisering aktiveras.",
    "Very weak password" : "Väldigt svagt lösenord",
    "Weak password" : "Svagt lösenord",
    "So-so password" : "Måttligt lösenord",
    "Good password" : "Bra lösenord",
    "Strong password" : "Starkt lösenord",
    "Group list is empty" : "Grupplistan är tom",
    "Unable to retrieve the group list" : "Det gick inte att hämta grupplistan",
    "Could not remove app." : "Det gick inte att ta bort appen.",
    "Could not update app." : "Det gick inte att uppdatera appen.",
    "Apps" : "Appar",
    "for Argon2 for password hashing" : "för lösenordshashning med Argon2",
    "MariaDB version 10.3 detected, this version is end-of-life and only supported as part of Ubuntu 20.04. MariaDB >=%1$s and <=%2$s is suggested for best performance, stability and functionality with this version of Nextcloud." : "MariaDB 10.3 har upptäckts. Versionen har nått slutet av sin livscykel och stöds endast som en del av Ubuntu 20.04. MariaDB >=%1$s och <=%2$s rekommenderas för bästa prestanda, stabilitet och funktionalitet med den här versionen av Nextcloud.",
    "_Most tasks were successful in the last day._::_Most tasks were successful in the last %n days._" : ["De flesta uppgifterna slutfördes utan fel under det senaste dygnet.","De flesta uppgifterna slutfördes utan fel under de senaste %n dagarna."],
    "_The Task Processing worker has run in the last minute._::_The Task Processing worker has run in the last %n minutes._" : ["Uppgiftsbearbetaren har körts under den senaste minuten.","Uppgiftsbearbetaren har körts under de senaste %n minuterna."],
    "Machine translation" : "Maskinöversättning",
    "Image generation" : "Bildgenerering",
    "Text processing" : "Textbehandling",
    "Exclude some groups from sharing" : "Uteslut vissa grupper från att dela",
    "Limit sharing to some groups" : "Begränsa delning till vissa grupper",
    "Also allow autocompletion on full match of the user id" : "Tillåt även automatisk ifyllning vid fullständig matchning av användar-ID:t",
    "Choose Deploy Daemon for {appName}" : "Välj driftsättningsdemon för {appName}",
    "Registered Deploy daemons list" : "Lista över registrerade driftsättningsdemoner",
    "No Deploy daemons configured" : "Inga driftsättningsdemoner har konfigurerats",
    "Register a custom one or setup from available templates" : "Registrera en anpassad demon eller konfigurera en från de tillgängliga mallarna",
    "Manage Deploy daemons" : "Hantera driftsättningsdemoner",
    "Show details for {appName} app" : "Visa detaljer för appen {appName}",
    "Update to {update}" : "Uppdatera till {update}",
    "Remove" : "Ta bort",
    "Featured" : "Utvald",
    "This app is supported via your current Nextcloud subscription." : "Den här appen stöds via ditt nuvarande Nextcloud-abonnemang.",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Utvalda appar utvecklas av och inom gemenskapen. De erbjuder central funktionalitet och är redo för produktionsanvändning.",
    "Community rating: {score}/5" : "Gemenskapsbetyg: {score}/5",
    "Disable all" : "Inaktivera alla",
    "Download and enable all" : "Hämta och aktivera alla",
    "All apps are up-to-date." : "Alla appar är uppdaterade.",
    "Icon" : "Ikon",
    "Name" : "Namn",
    "Level" : "Nivå",
    "Results from other categories" : "Resultat från andra kategorier",
    "No apps found for your version" : "Inga appar hittades för din version",
    "_%n app has an update available_::_%n apps have an update available_" : ["%n app har en tillgänglig uppdatering","%n appar har tillgängliga uppdateringar"],
    "_Update_::_Update all_" : ["Uppdatera","Uppdatera alla"],
    "Search groups…" : "Sök grupper…",
    "Could not load app discover section" : "Det gick inte att läsa in avsnittet för appupptäckt",
    "Could not render element" : "Det gick inte att återge elementet",
    "Nothing to show" : "Inget att visa",
    "Could not load section content from app store." : "Det gick inte att läsa in avsnittets innehåll från appbutiken.",
    "Loading" : "Läser in",
    "Fetching the latest news…" : "Hämtar de senaste nyheterna …",
    "Carousel" : "Bildkarusell",
    "Previous slide" : "Föregående bild",
    "Next slide" : "Nästa bild",
    "Choose slide to display" : "Välj bild att visa",
    "{index} of {total}" : "{index} av {total}",
    "Daemon" : "Demonprocess",
    "Deploy Daemon" : "Driftsättningsdemon",
    "Type" : "Typ",
    "Display Name" : "Visningsnamn",
    "GPUs support" : "GPU-stöd",
    "Compute device" : "Beräkningsenhet",
    "Advanced deploy options" : "Avancerade driftsättningsalternativ",
    "Edit ExApp deploy options before installation" : "Redigera ExAppens driftsättningsalternativ före installationen",
    "Configured ExApp deploy options. Can be set only during installation" : "Konfigurerade driftsättningsalternativ för ExAppen. De kan endast anges under installationen",
    "Learn more" : "Läs mer",
    "Environment variables" : "Miljövariabler",
    "ExApp container environment variables" : "Miljövariabler för ExApp-containern",
    "No environment variables defined" : "Inga miljövariabler är definierade",
    "Mounts" : "Monteringspunkter",
    "Define host folder mounts to bind to the ExApp container" : "Ange monteringar av värdmappar som ska bindas till ExApp-containern",
    "Must exist on the Deploy daemon host prior to installing the ExApp" : "Måste finnas på driftsättningsdemonens värd innan ExAppen installeras",
    "Host path" : "Värdsökväg",
    "Container path" : "Containersökväg",
    "Read-only" : "Skrivskyddad",
    "Remove mount" : "Ta bort montering",
    "New mount" : "Ny montering",
    "Enter path to host folder" : "Ange sökvägen till värdmappen",
    "Enter path to container folder" : "Ange sökvägen till containermappen",
    "Toggle read-only mode" : "Växla skrivskyddat läge",
    "Confirm adding new mount" : "Bekräfta att den nya monteringen ska läggas till",
    "Cancel adding mount" : "Avbryt tillägg av montering",
    "Add mount" : "Lägg till montering",
    "ExApp container mounts" : "Monteringar för ExApp-containern",
    "No mounts defined" : "Inga monteringar har definierats",
    "Description" : "Beskrivning",
    "View in store" : "Visa i appbutiken",
    "Visit website" : "Besök webbplats",
    "Usage documentation" : "Användningsdokumentation",
    "Admin documentation" : "Administratörsdokumentation",
    "Developer documentation" : "Utvecklardokumentation",
    "All" : "Alla",
    "Limit app usage to groups" : "Begränsa appanvändning till grupper",
    "No results" : "Inga resultat",
    "Update to {version}" : "Uppdatera till {version}",
    "Deploy options" : "Driftsättningsalternativ",
    "Default Deploy daemon is not accessible" : "Standarddemonen för driftsättning går inte att nå",
    "Delete data on remove" : "Ta bort data när appen tas bort",
    "This app has no minimum {productName} version assigned. This will be an error in the future." : "Appen har ingen lägsta version av {productName} angiven. Detta kommer att ge ett fel i framtiden.",
    "This app has no maximum {productName} version assigned. This will be an error in the future." : "Appen har ingen högsta version av {productName} angiven. Detta kommer att ge ett fel i framtiden.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Den här appen kan inte installeras eftersom följande beroenden inte är uppfyllda:",
    "Latest updated" : "Senast uppdaterade",
    "Author" : "Författare",
    "Categories" : "Kategorier",
    "Resources" : "Resurser",
    "Interact" : "Engagera dig",
    "Report a bug" : "Rapportera ett problem",
    "Request feature" : "Föreslå en funktion",
    "Ask questions or discuss" : "Ställ frågor eller diskutera",
    "Rate the app" : "Betygsätt appen",
    "Rate" : "Betygsätt",
    "Changelog" : "Ändringslogg",
    "Loading accounts …" : "Läser in konton …",
    "Set line manager" : "Ange närmaste chef",
    "Set account as admin for …" : "Ange kontot som administratör för …",
    "_{userCount} account …_::_{userCount} accounts …_" : ["{userCount} konto …","{userCount} konton …"],
    "Password or insufficient permissions message" : "Meddelande om lösenord eller otillräckliga behörigheter",
    "Failed to load groups with details" : "Det gick inte att läsa in grupper med detaljer",
    "Failed to load sub admin groups with details" : "Det gick inte att läsa in underadministratörsgrupper med detaljer",
    "Failed to update line manager" : "Det gick inte att uppdatera närmaste chef",
    "Display name was successfully changed" : "Visningsnamnet har ändrats",
    "Password can't be empty" : "Lösenord får inte vara tomt",
    "Password was successfully changed" : "Lösenordet har ändrats",
    "Email can't be empty" : "E-post får inte vara tomt",
    "Email was successfully changed" : "E-postadressen har ändrats",
    "Loading account …" : "Laddar konto …",
    "Change display name" : "Ändra visningsnamn",
    "Set new password" : "Ange nytt lösenord",
    "You do not have permissions to see the details of this account" : "Du har inte behörighet att se detaljerna för detta konto.",
    "Set new email address" : "Ange en ny e-postadress",
    "Add account to group" : "Lägg till kontot i gruppen",
    "Set account as admin for" : "Ange kontot som administratör för",
    "Select account quota" : "Välj kontots kvot",
    "Set the language" : "Ange språk",
    "Done" : "Klar",
    "Adding your device …" : "Lägger till enheten …",
    "App Store" : "Appbutik",
    "Loading app list" : "Läser in applistan",
    "Loading categories" : "Läser in kategorier",
    "Version {version}, {license}-licensed" : "Version {version}, {license}-licensierad",
    "Version {version}" : "Version {version}",
    "Sending…" : "Skickar …",
    "Email sent" : "E-postmeddelandet har skickats",
    "Manually installed apps cannot be updated" : "Manuellt installerade appar kan inte uppdateras",
    "{progress}% Deploying …" : "{progress}% Driftsätter …",
    "{progress}% Initializing …" : "{progress}% Initierar …",
    "Health checking" : "Kontrollerar hälsostatus",
    "Deploy and Enable" : "Driftsätt och aktivera",
    "Download and enable" : "Hämta och aktivera",
    "Disable" : "Inaktivera",
    "Allow untested app" : "Tillåt otestad app",
    "The app will be downloaded from the App Store" : "Appen hämtas från appbutiken",
    "This app is not marked as compatible with your {productName} version." : "Appen är inte markerad som kompatibel med din version av {productName}.",
    "If you continue you will still be able to install the app. Note that the app might not work as expected." : "Om du fortsätter kommer appen att installeras. Observera att appen kanske inte fungerar som förväntat.",
    "The app has been enabled but needs to be updated." : "Appen har aktiverats men behöver uppdateras.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Fel: Appen kan inte aktiveras eftersom den gör servern instabil",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Appen har aktiverats men måste uppdateras. Du kommer att omdirigeras till uppdateringssidan om 5 sekunder.",
    "None/STARTTLS" : "Ingen/STARTTLS",
    "SSL" : "SSL",
    "Credentials" : "Inloggningsuppgifter",
    "SMTP Login" : "SMTP-inloggning",
    "SMTP Password" : "SMTP-lösenord",
    "Test and verify email settings" : "Testa och verifiera e-postinställningarna",
    "Office suite switching is managed through the Nextcloud All-in-One interface." : "Byte av kontorssvit hanteras via gränssnittet för Nextcloud All-in-One.",
    "Please use the AIO interface to switch between office suites." : "Använd AIO-gränssnittet för att växla mellan kontorssviter.",
    "Select your preferred office suite. Please note that installing requires manual server setup." : "Välj önskad kontorssvit. Observera att installation kräver manuell serverkonfiguration.",
    "installed" : "installerad",
    "Disable office suites" : "Inaktivera kontorssviter",
    "All office suites disabled" : "Alla kontorssviter är inaktiverade",
    "{name} enabled" : "{name} har aktiverats",
    "Best Nextcloud integration" : "Bäst integration med Nextcloud",
    "Open source" : "Öppen källkod",
    "Good performance" : "Bra prestanda",
    "Best security: documents never leave your server" : "Bäst säkerhet: dokumenten lämnar aldrig din server",
    "Best ODF compatibility" : "Bäst ODF-kompatibilitet",
    "Best support for legacy files" : "Bäst stöd för äldre filformat",
    "Good Nextcloud integration" : "Bra integration med Nextcloud",
    "Open core" : "Öppen kärna",
    "Best performance" : "Bäst prestanda",
    "Limited ODF compatibility" : "Begränsad ODF-kompatibilitet",
    "Best Microsoft compatibility" : "Bäst kompatibilitet med Microsoft",
    "{progress}% Deploying …" : "{progress}% Driftsätter …",
    "{progress}% Initializing …" : "{progress}% Initierar …"
},
"nplurals=2; plural=(n != 1);");
