OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "İlk çalıştırma yardımcısı",
    "Add your profile information! For example your email is needed to receive notifications." : "Profil bilgilerinizi yazın! Örneğin bildirimleri alabilmeniz için e-posta adresiniz gereklidir.",
    "Add your profile information! For example your email is needed to receive notifications and reset your password." : "Profil bilgilerinizi yazın! Örneğin bildirimleri alabilmeniz ya da parolanızı sıfırlayabilmeniz için e-posta adresiniz gereklidir.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Profil bilgilerinizi ekleyin! Bir profil görseli ekleyerek ve tam adınızı yazarak tüm özellikler tarafından kolayca tanının.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Profil bilgilerinizi ekleyin! Tam adınızı yazarak tüm özellikler tarafından kolayca tanının.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Profil bilgilerinizi ekleyin! Bir profil görseli ekleyerek tüm özellikler tarafından kolayca tanının.",
    "App recommendation: Calendar" : "Önerilen uygulama: Takvim",
    "Schedule work & meetings, synced with all your devices." : "İşlerinizi ve toplantılarınızı planlayın ve tüm aygıtlarınızla eşitleyin.",
    "App recommendation: Contacts" : "Önerilen uygulama: Kişiler",
    "Keep your colleagues and friends in one place without leaking their private info." : "İş arkadaşlarınızın ve tanıdıklarınızın kayıtlarını kişisel bilgilerini sızdırmadan tek bir yerde tutun.",
    "App recommendation: Mail" : "Önerilen uygulama: E-posta",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Dosyalar, Kişiler ve Takvim uygulamaları ile bir arada çalışan basit bir e-posta uygulaması.",
    "App recommendation: Tasks" : "Önerilen uygulama: Görevler",
    "Sync tasks from various devices with your Nextcloud and edit them online." : "Nextcloud üzerindeki görevlerinizi farklı aygıtlar arasında eşitleyin ve çevrim içi olarak düzenleyin.",
    "App recommendation: Deck" : "Önerilen uygulama: Tahta",
    "Kanban style organization for personal planning and team projects." : "Kanban tarzında bir kişisel planlama ve takım projeleri yönetimi uygulaması.",
    "App recommendation: Forms" : "Önerilen uygulama: Formlar",
    "Simple surveys and questionnaires, self-hosted" : "Basit anketler ve değerlendirmeler, yerel olarak barındırılır",
    "App recommendation: Recognize" : "Önerilen uygulama: Tanıma",
    "Smart media tagging for Nextcloud" : "Nextcloud için akıllı ortam etiketleme",
    "App recommendation: Group folders" : "Önerilen uygulama: Grup klasörleri",
    "Admin-configured folders shared by everyone in a group." : "Yönetici tarafından gruptaki herkesin görebilmesi için yapılandırılmış klasörler.",
    "App recommendation: Whiteboard" : "Önerilen uygulama: Beyaz Tahta",
    "Create and share whiteboards with others and collaborate in real-time." : "Beyaz tahtalar oluşturun, başkalarıyla paylaşın ve gerçek zamanlı olarak iş birliği yapın.",
    "Connect your calendar" : "Takviminizi bağlayın",
    "Connect your contacts" : "Kişilerinizi bağlayın",
    "Access files via WebDAV" : "WebDAV üzerinden dosyalarınıza erişin",
    "Download macOS/iOS configuration profile" : "macOS/iOS yapılandırma profilini indir",
    "Desktop client" : "Bilgisayar istemcisi",
    "Android app on Google Play Store" : "Google Play Store üzerindeki Android uygulaması",
    "Android app on F-Droid" : "F-Droid üzerindeki Android uygulaması",
    "iOS app" : "iOS uygulaması",
    "About & What's new" : "Hakkında ve yenilikler",
    "A welcome and introduction wizard for Nextcloud" : "Nextcloud için karşılama ve tanıtım yardımcısı",
    "This application enables a pop-up window when a user first logs into Nextcloud. This window welcomes new users to Nextcloud, and contains links to the standard desktop client, Android app, and the iOS app. The window also shows a link for accessing Nextcloud via WebDAV. At any time, the first run wizard can be opened again via link \"About\" on settings menu.\nThe First run wizard can be customized to meet specific design goals, or to change links and messages. Create an appropriate theme following the Theming documentation, and changes to the look and feel of this Wizard are simple. More information is available in the first run wizard documentation, as well as the theming documentation." : "Bu uygulama, bir kullanıcının Nextcloud oturumunu ilk kez açmasında açılan bir pencere görüntülenmesini sağlar. Bu pencerede kullanıcı karşılama iletisi görüntülenir ve standart bilgisayar istemcisi ile Android ve iOS uygulamalarına bağlantılar bulunur. Ayrıca WebDAV üzerinden Nextcloud erişimi için de bir bağlantı görüntülenir. İlk kez çalıştırma yardımcısı, istenildiği zaman ayarlar menüsündeki \"Hakkında\" bağlantısı kullanılarak yeniden görüntülenebilir.\nİlk çalıştırma yardımcısı belirli amaçları gerçekleştirmek için özelleştirilebilir ve bağlantılar ile yazılar değiştirilebilir. Tema oluşturma belgelerine bakılarak istenilen bir tema oluşturulabilir ve bu yardımcının görünüşünü kolayca değiştirilebilir. Ayrıntılı bilgi almak için ilk çalıştırma yardımcısı ve tema oluşturma belgelerine bakabilirsiniz.",
    "Download on Apple app store" : "Apple App Store üzerinden indir",
    "Download on Google play store" : "Google Play üzerinden indir",
    "Go to previous page" : "Önceki sayfaya git",
    "Close" : "Kapat",
    "More about Nextcloud" : "Nextcloud ile ilgili ayrıntılı bilgi",
    "Explore more apps ↗" : "Diğer uygulamalara bakın ↗",
    "Extend the functionality of Nextcloud with hundreds of community-developed apps." : "Topluluk tarafından geliştirilen yüzlerce uygulamayla Nextcloud özelliklerini artırın.",
    "Get involved! ↗" : "Katkıda bulunun! ↗",
    "Be a part of the community that helps build, design, translate and promote Nextcloud!" : "Nextcloud projesini oluşturan, tasarlayan, çeviren ve tanıtan topluluğun bir parçası olun!",
    "Need help? ↗" : "Yardım mı gerekiyor? ↗",
    "Find out more about your Nextcloud setup with the admin, user or developer documentation." : "Yönetici, kullanıcı veya geliştirici belgelerini kullanarak Nextcloud kurulumunuz ile ilgili ayrıntılı bilgi alın.",
    "For large organisations ↗" : "Büyük kuruluşlar için ↗",
    "Get Nextcloud Enterprise for mission critical environments where advanced security and compliance are important." : "Gelişmiş güvenlik ve uyumluluğun önemli olduğu kritik görev ortamlarında Nextcloud Enterprise kullanın.",
    "Seamless integration with your devices." : "Aygıtlarınız arasında kesintisiz bütünleştirme.",
    "Sync your files across your devices with the desktop and mobile apps, and connect your calendar and contacts." : "Dosyalarınızı bilgisayar ve mobil uygulamalarla aygıtlarınız arasında eşitleyin, takviminizi ve kişilerinizi ilişkilendirin.",
    "Desktop app ↗" : "Bilgisayar uygulaması ↗",
    "Download For Windows, Mac OS and Linux." : "Windows, Mac OS ve Linux için indirin.",
    "Calendar and contacts ↗" : "Takvimler ve kişiler ↗",
    "Connect your calendar and contacts with your devices." : "Takviminizi ve kişilerinizi aygıtlarınızla ilişkilendirin.",
    "Welcome to {cloudName}!" : "{cloudName} platformuna hoş geldiniz!",
    "Skip" : "Atla",
    "This Nextcloud is on version {version}" : "Bu Nextcloud sürümü {version}",
    "A collaboration platform that puts you in control" : "Sizin kontrolunuzda olan iş birliği platformu",
    "Privacy" : "Gizlilik",
    "Host your data and files where you decide." : "Veri ve dosyalarınızı istediğiniz yerde barındırın.",
    "Productivity" : "Üretkenlik",
    "Collaborate and communicate across any platform." : "Herhangi bir platformla iş birliği yapın ve iletişim kurun.",
    "Interoperability" : "Birlikte çalışabilirlik",
    "Import and export anything you want with open standards." : "İstediğiniz her şeyi açık standartlarla içe ve dışa aktarın.",
    "Community" : "Topluluk",
    "Enjoy constant improvements from a thriving open-source community." : "Gelişen bir açık kaynak topluluğunun sürekli iyileştirmelerinin keyfini sürün.",
    "Nextcloud Hub {version} release" : "Nextcloud Merkez {version} yayınlandı",
    "Read more about it on the Nextcloud Hub {version} blog" : "Nextcloud Merkez {version} günlüğünden ayrıntılı bilgi alın",
    "Find out more on the blog" : "Günlüğümüzden ayrıntılı bilgi alabilirsiniz",
    "Read the Nextcloud Hub {version} blog" : "Nextcloud Merkez {version} günlüğünü okuyun",
    "Share your opinion about Nextcloud Hub {version}" : "Nextcloud Merkez {version} ile ilgili düşüncelerinizi paylaşın",
    "Share via email" : "E-posta ile paylaşın",
    "Share on {socialMedia}" : "{socialMedia} üzerinde paylaşın",
    "New in Nextcloud Hub {version}" : "Nextcloud Merkez {version} yenilikleri",
    "Connect other apps to {productName}" : "{productName} ile diğer uygulamaları bağlayın",
    "Besides the mobile apps and desktop client you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to {productName}." : "Mobil ve bilgisayar istemci uygulamaları yanında WebDAV/CalDAV/CardDAV iletişim kurallarını destekleyen uygulamalar da {productName} ile bağlantı kurabilir.",
    "Apps to connect to {productName}" : "{productName} ile bağlanacak uygulamalar",
    "Set up sync clients using an {linkStart}app password{linkEnd}. That way you can make sure you are able to revoke access in case you lose that device." : "Bir {linkStart}uygulama parolası{linkEnd} kullanan eşitleme istemcilerini kurun. Böylece aygıtınızı kaybederseniz erişimi geçersiz kılabileceğinden emin olursunuz.",
    "Get the apps to sync your files" : "Dosyalarınızı eşitlemek için uygulamaları indirin",
    "{productName} gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "{productName} dosyalarınıza istediğiniz her yerden erişme olanağı sunar. Kullanımı kolay bilgisayar ve mobil uygulamalarımız yaygın tüm platformlar için bulunabilir ve herhangi bir ücret ödemeden kullanılabilir.",
    "App for syncing" : "Eşitleme uygulaması",
    "URL copied" : "Adres kopyalandı",
    "Could not copy the URL, please copy manually" : "Adres kopyalanamadı. Lütfen el ile kopyalayın",
    "Server address" : "Sunucu adresi",
    "Use this link to connect your apps and desktop client to this server:" : "Uygulamalarınızı ve bilgisayar istemcinizi bu sunucuya bağlamak için şu adresi kullanın:",
    "Refined design, optimized performance" : "İyileştirilmiş tasarım ve başarım",
    "Empowering developers with an open platform" : "Geliştiriciler için açık platform gücü",
    "Your choice: Nextcloud Office powered by Collabora or Euro-Office" : "Sizin seçiminiz: Nextcloud Office, Collabora ya da Euro-Office ile desteklenir",
    "Delegate calendars, meetings and mail boxes for better collaboration" : "Daha iyi iş birliği sağlamak için takvimler, görüşmeler ve e-posta kutuları",
    "Gantt charts, dependencies & more in Nextcloud Deck" : "Nextcloud Tahta içinde Gantt çizelgeleri, ilişkili görevler ve diğer yenilikler",
    "More agency: let the Assistant work for you across files, emails, forms, and more" : "Daha fazla yetki: Yardımcının, dosyalar, e-postalar, formlar ve diğer şeyler üzerinde sizin için çalışmasına izin verin.",
    "Pexip, Matrix, and more updates in integrations" : "Bütünleştirmelerde Pexip, Matrix ve diğer güncellemeler",
    "… and many more improvements in all apps!" : "… ve tüm uygulamalarda pek çok iyileştirme!",
    "Experience the brand new Nextcloud Hub!" : "Yepyeni Nextcloud Hub deneyimi!",
    "Get to know the new features of Hub {version}" : "Yeni Merkez {version} özellikleri ile ilgili bilgi alın",
    "Time to own your collaboration: Meet Nextcloud Hub 26 Spring! 🚀" : "Kendi iş birliğinizi yapma zamanı: Nextcloud Hub 26 Spring ile tanışın! 🚀",
    "What's new?" : "Yenilikler neler?",
    "Nextcloud on all your devices" : "Nextcloud tüm aygıtlarınızda",
    "Nextcloud Hub {version}" : "Nextcloud Merkez {version}",
    "Share on social media" : "Sosyal ağ üzerinde paylaş",
    "Get started!" : "Başlayın!",
    "Global redesign and usability lift" : "Genel yeniden tasarım ve kullanılabilirlik iyileştirmeleri",
    "New Office UI: colors, tabs, bars" : "Yeni ofis kullanıcı arayüzü: Renkler, sekmeler, çubuklar",
    "Performance and stability boost" : "Başarım ve kararlılık iyileştirmeleri",
    "New AI Agency tools unlocked" : "Yeni yapay zeka aracısı araçları kullanıma açıldı",
    "Talk threads & live transcription" : "Konuş yazışmaları ve canlı yazıya dönüştürme",
    "Calendar: date poll for participants" : "Takvim: Katılımcılar için tarih anketi",
    "Intuitive file search" : "Sezgisel dosya arama",
    "Teams 2.0 & quick Guest accounts" : "Takımlar 2.0 ve hızlı konuk hesapları",
    "Quick presets & many other admin updates" : "Hızlı hazır ayarlar ve diğer pek çok yönetici güncellemeleri",
    "Vue3, WebSockets and more OpenAPI for devs" : "Geliştiriciler için Vue3, WebSockets ve diğer OpenAPI",
    "… and much more!" : "… ve pek çok özellik daha!",
    "Nextcloud Hub 25 Autumn – Your digital workspace, ready in no time ⚡" : "Nextcloud Hub 25 Autumn – Dijital çalışma alanınız, anında hazır ⚡",
    "Growing sovereignty: new federation features, improved data export and import" : "Egemenliği genişletmek: Yeni birlik özellikleri, geliştirilmiş dışa ve içe veri aktarımı",
    "Nextcloud Talk: live translations, pinned messages, scheduling" : "Nextcloud Talk: Canlı çeviriler, sabitlenmiş iletiler, zamanlama",
    "Office document comparison" : "Ofis belgeleri karşılaştırması",
    "Whiteboard: comments, reactions, timers" : "Beyaz tahta: Yorumlar, tepkiler, geri sayımlar",
    "Nextcloud Assistant performance upgrade and AI labeling" : "Nextcloud Yardımcı başarımında iyileştirmeler ve yapay zeka ile etiketleme",
    "Powerful E2EE in the web interface" : "İnternet arayüzünde güçlü uçtan uca şifreleme",
    "Speed-up with ADA engine" : "ADA işleyici ile hızlandırma",
    "Time to own your collaboration: Meet Nextcloud Hub 26 Winter! 🚀" : "İş birliği yapma zamanı: Nextcloud Hub 26 Winter ile tanışın! 🚀"
},
"nplurals=2; plural=(n > 1);");
