OC.L10N.register(
    "files_external",
    {
    "Storage with ID \"%d\" not found" : "Nun s'atopó l'almacenamientu cola ID «%d»",
    "Forbidden to manage local mounts" : "Prohíbese xestionar montaxes llocales",
    "Invalid backend or authentication mechanism class" : "El backend o la clas del mecanismu d'autienticación son inválidos",
    "Invalid mount point" : "El puntu de montaxe ye inválidu",
    "Objectstore forbidden" : "Prohíbese l'Objectstore",
    "Invalid storage backend \"%s\"" : "El backend d'almacenamientu «%s» ye inválidu",
    "Not permitted to use backend \"%s\"" : "Nun se permite usar el backend «%s»",
    "Not permitted to use authentication mechanism \"%s\"" : "Nun se permite usar el mecanismu d'autenticación «%s»",
    "Unsatisfied backend parameters" : "Hai parámetros del backend que nun se satisfacen",
    "Unsatisfied authentication mechanism parameters" : "Hai parámetros del mecanismu d'autenticación que nun se satisfacen",
    "Insufficient data: %s" : "Nun hai abondos datos: %s",
    "Storage with ID \"%d\" is not editable by non-admins" : "Les cuentes que nun son de l'alministración nun puen editar l'almacenamientu cola ID «%d»",
    "Builtin" : "Integrada",
    "None" : "Nada",
    "OpenStack v2" : "OpenStack v2",
    "Login" : "Aniciar la sesión",
    "Password" : "Contraseña",
    "Tenant name" : "Nome d'inquilín",
    "Identity endpoint URL" : "URL del estremu de la identidá",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "Dominiu",
    "Rackspace" : "Rackspace",
    "API key" : "Clave de l'API",
    "Global credentials" : "Credenciales globales",
    "Log-in credentials, save in database" : "Credenciales p'aniciar la sesión, guardaes na base de datos",
    "Login and password" : "Cuenta y contraseña",
    "Log-in credentials, save in session" : "Credenciales p'aniciar la sesión, guardaes na sesión",
    "Global credentials, manually entered" : "Credenciales globales, introducíes manualmente",
    "Manually entered, store in database" : "Introducío manualmente, guardao na base de datos",
    "RSA public key" : "Clave pública RSA",
    "Public key" : "Clave pública",
    "RSA private key" : "Clave privada RSA",
    "Private key" : "Clave privada",
    "Kerberos default realm, defaults to \"WORKGROUP\"" : "L'equipu predetermináu de Kerberos, por defeutu ye «WORKGROUP»",
    "Kerberos ticket Apache mode" : "Mou Apache de ticket de Kerberos",
    "Kerberos ticket" : "Ticket de Kerberos",
    "Bucket" : "Bucket",
    "Hostname" : "Agospiador",
    "Port" : "Puertu",
    "Proxy" : "Proxy",
    "Region" : "Rexón",
    "Storage Class" : "Clas d'almacenamientu",
    "Enable multipart copy" : "Activar la copia múltiple",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Socarpeta remota",
    "Secure https://" : "https://",
    "Host" : "Agospiador",
    "Secure ftps://" : "ftps://",
    "Location" : "Llocalización",
    "Root" : "Raigañu",
    "Share" : "Compartir",
    "Show hidden files" : "Amosar los ficheros anubríos",
    "Case sensitive file system" : "Sistema de ficheros qu'estrema mayúscules y minúscules",
    "Disabling it will allow to use a case insensitive file system, but comes with a performance penalty" : "Al desactivar la opción, va permitise l'usu d'un sistema de ficheros sensible a mayúscules, más va amenorgar el rindimientu",
    "Verify ACL access when listing files" : "Verificar l'accesu d'ACL al detectar ficheros",
    "Check the ACL's of each file or folder inside a directory to filter out items where the account has no read permissions, comes with a performance penalty" : "Comprueba l'ACL de cada ficheru o carpeta d'un direutoriu pa peñerar los elementos pa los que la cuenta nun tien permisu de llectura, más amenorga'l rindimientu",
    "Timeout" : "Escosa del tiempu d'espera",
    "Login as share" : "Aniciar la sesión como elementu compartíu",
    "Service name" : "Nome del serviciu",
    "Request timeout (seconds)" : "Tiempu d'espera de les solicitúes (segundos)",
    "External storage" : "Almacenamientu esternu",
    "External storage support" : "Compatibilidá con almacenamientos esternos",
    "Adds basic external storage support" : "Amiesta compatibilidá básica p'almacenamientos esternos",
    "This application enables administrators to configure connections to external storage providers, such as FTP servers, S3 or SWIFT object stores, other Nextcloud servers, WebDAV servers, and more. Administration can choose which types of storage to enable and can mount these storage locations for an account, a group, or the entire system. Users will see a new folder appear in their root Nextcloud directory, which they can access and use like any other Nextcloud folder. External storage also allows people to share files stored in these external locations. In these cases, the credentials for the owner of the file are used when the recipient requests the file from external storage, thereby ensuring that the recipient can access the shared file.\n\nExternal storage can be configured using the GUI or at the command line. This second option provides the administration with more flexibility for configuring bulk external storage mounts and setting mount priorities. More information is available in the external storage GUI documentation and the external storage Configuration File documentation." : "Esta aplicación permite a l'alministración configurar les conexones a fornidores d'almacenamientu esternu, como sirvidores FTP, S3 o almacenes d'oxetos SWIFT, otros sirvidores Nextcloud, sirvidores WebDAV y munchos más. L'alministración pue escoyer los tipos d'almacenamientu qu'activa y pue montalos pa una cuenta, un grupu o tol sistema. Los usuarios van ver qu'apaez una carpeta neuva nel direutoriu raigañu de Nextcloud, al que puen acceder y usar como otra carpeta cualquiera. L'almacenamientu esternu tamién permite a les persones compartir ficheros atroxaos nestos llugares esternos. Nesos casos, úsense les credenciales del propietariu del ficheru cuando'l destinatariu solicita el ficheru del almacenamientu esternu, d'esti mou asegúrase de que'l destinatariu pue acceder al ficheru compartíu.\n\nPues configurar l'almacenamientu esternu cola GUI o la llinia de comandos. Esta postrer opción forne una alministración más flexible pa configurar grupos de montaxes d'almacenamientu esternu y configurar les prioridaes del montaxe. Tienes más información disponible na documentación de la GUI d'almacenamientos esternos y la documentación de los ficheros de configuración de los almacenamientos esternos.",
    "Add storage" : "Amestar un almacenamientu",
    "Folder name" : "Nome de la carpeta",
    "Authentication" : "Autenticación",
    "Cancel" : "Cancel",
    "Edit" : "Editar",
    "Create" : "Crear",
    "Never" : "Enxamás",
    "Once every direct access" : "Una vegada cada accesu directu",
    "Always" : "Siempres",
    "Read only" : "Namás llectura",
    "Enable previews" : "Activar les previsualizaciones",
    "Enable sharing" : "Activar la compartición",
    "Enable encryption" : "Activar el cifráu",
    "Compatibility with Mac NFD encoding (slow)" : "Compatiblidá cola codificación NFD de Mac (opción lenta)",
    "External storages" : "Almacenamientos internos",
    "Status" : "Estáu",
    "Actions" : "Aiciones",
    "Delete" : "Desaniciar",
    "Saved" : "Guardóse",
    "Error while saving" : "Hebo un error mentanto se guardaba",
    "Allow people to mount external storage" : "Permitir a otros montar l'almacenamientu esternu",
    "Error generating key pair" : "Hebo un error al xenerar el par de claves",
    "Key size" : "Tamañu de clave",
    "Generate keys" : "Xenerar les claves",
    "Confirm" : "Confirmar",
    "Global credentials can be used to authenticate with multiple external storages that have the same credentials." : "Pues usar les credenciales globales p'autenticate en múltiples almacenamientos esternos que tengan les meses credenciales.",
    "Save" : "Guardar",
    "Unable to update this external storage config. {statusMessage}" : "Nun ye posible anovar la configuración d'esti almacenamientu esternu. {statusMessage}",
    "New configuration successfully saved" : "La configuración nueva guardóse correutamente",
    "Enter missing credentials" : "Instroduz les credenciales que falten",
    "There was an error with this external storage." : "Hebo un error con esti almacenamientu esternu.",
    "We were unable to check the external storage {basename}" : "Nun fuimos a comprobar l'almacenamientu esternu «{basename}»",
    "Examine this faulty external storage configuration" : "Esaminar esta configuración defectuosa del almacenamientu esternu",
    "Open in Files" : "Abrir en Ficheros",
    "External mount error" : "Error del montaxe esternu",
    "There was an error with this external storage. Do you want to review this mount point config in the settings page?" : "Hebo un error con esti almacenamientu esternu. ¿Quies revisar la configuración d'esti puntu de montaxe na páxina de configuración?",
    "Open settings" : "Abrir la configuración",
    "List of external storage." : "Llista del almacenamientu esternu.",
    "There is no external storage configured. You can configure them in your Personal settings." : "Nun hai nengún almacenamientu esternu configuráu. Pues configurar unu na configuración personal.",
    "There is no external storage configured and you don't have the permission to configure them." : "Nun hai nengún almacenamientu esternu configuráu y tampoco tienes permisu pa configuralos.",
    "No external storage" : "Nun hai nengún almacenamientu esternu",
    "Storage type" : "Tipu d'almacenamientu",
    "Unknown" : "Desconocí­u",
    "Scope" : "Ámbitu",
    "Personal" : "Personal",
    "System" : "Sistema",
    "Error" : "Error",
    "Network error" : "Fallu de rede",
    "Grant access" : "Conceder l'accesu",
    "Error configuring OAuth2" : "Hebo un error al configurar l'OAuth2",
    "%s" : "%s",
    "Access key" : "Clave d'accesu",
    "Secret key" : "Clave del secretu",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID de veceru",
    "Client secret" : "Secretu de veceru",
    "Enable SSL" : "Activar el SSL",
    "Enable Path Style" : "Activar l'estilu de caminos",
    "Legacy (v2) authentication" : "Activar l'autenticación heredada (v2)",
    "FTP" : "FTP",
    "Local" : "Llocal",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "SFTP with secret key login" : "SFTP con cuenta de clave secreta",
    "SMB/CIFS" : "SMB/CIFS",
    "SMB/CIFS using OC login" : "SMB/CIFS con cuenta OC",
    "OpenStack Object Storage" : "Almacenamientu d'oxetos d'OpenStack",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "La compatibilidá de cURL en PHP nun ta activada o instalada. Nun ye posible montar «%s», Pidi a l'alministración del sistema que la instale.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "La compatibilidá de PHP en PHP nun ta activada o instalada. Nun ye posible montar «%s», Pidi a l'alministración del sistema que la instale.",
    "\"%1$s\" is not installed. Mounting of %2$s is not possible. Please ask your system administrator to install it." : "«%1$s» nun ya instaláu. El montaxe de «%2$s» nun ye posible. Pídi-y a l'alministración del sistema que lu instale.",
    "Type to select account or group." : "Escribi pa seleicionar una cuenta o un grupu",
    "(Group)" : "(Grupu)",
    "Check for changes" : "Comprobar los cambeos",
    "Disconnect" : "Desconectar",
    "Admin defined" : "Opción definida pola alministración",
    "Automatic status checking is disabled due to the large number of configured storages, click to check status" : "La comprobación del estáu automática ta desactivada pola mor del númberu grande d'almacenamientos configuraos, cala pa comprobar l'estáu",
    "Delete storage?" : "¿Quies desaniciar l'almacenamientu?",
    "Click to recheck the configuration" : "Calca pa volver comprobar la configuración",
    "Saving …" : "Guardando…",
    "No external storage configured or you don't have the permission to configure them" : "Nun se configuró nengún almacenamientu esternu y tampoco tienes permisu pa configuralos",
    "Open documentation" : "Abrir la documentación",
    "External storage enables you to mount external storage services and devices as secondary Nextcloud storage devices. You may also allow people to mount their own external storage services." : "L'almacenamientu esternu permítete montar servicios y preseos d'almacenamientu esternos como preseos d'almacenamientu esternu. Tamién pues permitir a otros que monten los sos servicios d'almacenamientu esternos.",
    "Configuration" : "Configuración",
    "Available for" : "Disponible pa",
    "All people" : "Toles persones",
    "Advanced settings" : "Configuración avanzada"
},
"nplurals=2; plural=(n != 1);");
