OC.L10N.register(
    "circles",
    {
    "You created the team {circle}" : "Utworzyłeś zespół {circle}",
    "{author} created the team {circle}" : "{author} utworzył zespół {circle}",
    "You deleted {circle}" : "Usunąłeś {circle}",
    "{author} deleted {circle}" : "{author} usunął {circle}",
    "You made {member} join {circle}" : "Zmusiłeś {member} do przyłączenia się do {circle}",
    "{author} made {member} join {circle}" : "{author} zmusił {member} do przyłączenia się do {circle}",
    "You added team {member} as member to {circle}" : "Dodałeś zespół {member} jako członka do {circle}",
    "{author} added team {member} as member to {circle}" : "{author} dodał zespół {member} jako członka do {circle}",
    "You made {member} leave {circle}" : "Zmusiłeś {member} do opuszczenia {circle}",
    "{author} made {member} leave {circle}" : "{author} zmusił {member} do opuszczenia {circle}",
    "You removed {member} from {circle}" : "Usunąłeś {member} z {circle}",
    "{author} removed {member} from {circle}" : "{author} usunął {member} z {circle}",
    "You joined {circle}" : "Dołączyłeś do {circle}",
    "{member} joined {circle}" : "{member} dołączył do {circle}",
    "You accepted the invitation to join {circle}" : "Zaakceptowałeś zaproszenie o dołączenie do {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} zaakceptował zaproszenie o dołączenie do {circle}",
    "You added {member} as member to {circle}" : "Dodałeś {member} do członków {circle}",
    "You have been added as member to {circle} by {author}" : "Zostałeś dodany jako członek do kręgu {circle} przez {author}",
    "{member} has been added as member to {circle} by {author}" : "{member} został dodany do kręgu {circle} przez {author}",
    "You added {external} to {circle}" : "Dodałeś {external} do kręgu {circle}",
    "{external} has been added to {circle} by {author}" : "{external} został dodany do kręgu {circle} przez {author}",
    "You accepted {member}'s request to join {circle}" : "Zaakceptowałeś prośbę o dołączenie {member} do {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Twoja prośba o dołączenie do {circle} została zaakceptowana przez {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "Prośba {member} o dołączenie do {circle} została zaakceptowana przez {author}",
    "You left {circle}" : "Opuściłeś {circle}",
    "{member} left {circle}" : "{member} opuścił {circle}",
    "You declined the invitation to join {circle}" : "Odrzuciłeś zaproszenie o dołączenie do kręgu {circle}",
    "{member} declined an invitation to join {circle}" : "{member} odrzucił zaproszenie o dołączenie do kręgu {circle}",
    "You cancelled your request to join {circle}" : "Anulowałeś prośbę o dołączenie do kręgu {circle}",
    "{member} cancelled a request to join {circle}" : "{member} anulował prośbę o dołączenie do {circle}",
    "You have been removed from {circle} by {author}" : "Zostałeś usunięty z kręgu {circle} przez {author}",
    "{member} has been removed from {circle} by {author}" : "{member} został usunięty z kręgu {circle} przez {author}",
    "You removed {external} from {circle}" : "Usunąłeś {external} z kręgu {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} został usunięty z kręgu {circle} przez {author}",
    "You cancelled {member}'s invitation to join {circle}" : "Anulowałeś zaproszenie {member} o dołączenie do kręgu {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "Twoje zaproszenie o dołączenie do kręgu {circle} zostało anulowane przez {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} anulował zaproszenie {member} o dołączenie do kręgu {circle}",
    "You dismissed {member}'s request to join {circle}" : "Odrzuciłeś prośbę {member} o dołączenie do kręgu {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "Twoja prośba o dołączenie do kręgu {circle} została odrzucona przez {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "Prośba {member} o dołączenie do kręgu {circle} została odrzucona przez {author}",
    "You invited {member} to join {circle}" : "Zaprosiłeś {member} do dołączenia do kręgu {circle}",
    "You have been invited to join {circle} by {author}" : "Zostałeś zaproszony do dołączenia do kręgu {circle} przez {author}",
    "{member} has been invited to join {circle} by {author}" : "{member} został zaproszony do dołączenia do kręgu {circle} przez {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Zmieniłeś poziom użytkownika {member} w {circle} na %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} zmienił Twój poziom {circle} na %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} zmienił poziom {member} w {circle} na %1$s",
    "You sent a request to join {circle}" : "Wysłałeś prośbę o dołączenie do kręgu {circle}",
    "{member} sent a request to join {circle}" : "{member} wysłał prośbę o dołączenie do kręgu {circle}",
    "You are the new owner of {circle}" : "Jesteś nowym właścicielem {circle}",
    "{member} is the new owner of {circle}" : "{member} został nowym właścicielem {circle}",
    "Teams" : "Zespoły",
    "On events happening in a <strong>team</strong> of which you are a member" : "O wydarzeniach w <strong>zespole</strong>, którego jesteś członkiem",
    "Any important event in a <strong>team</strong> you are moderating" : "Każde ważne wydarzenie w <strong>zespole</strong>, który moderujesz",
    "On global events happening in any <strong>team</strong>" : "O wydarzeniach globalnych w dowolnym <strong>zespole</strong>",
    "Single" : "Jednoosobowy",
    "Personal" : "Osobisty",
    "System" : "System",
    "Visible" : "Widoczny",
    "Open" : "Otwórz",
    "Invite" : "Zaproś",
    "Join request" : "Prośba o dołączenie",
    "Friends" : "Przyjaciele",
    "Password protected" : "Zabezpieczone hasłem",
    "No Owner" : "Brak właściciela",
    "Hidden" : "Ukryty",
    "Backend" : "Zaplecze",
    "Local" : "Lokalny",
    "Root" : "Root",
    "Team invite" : "Zaproszenie do zespołu",
    "Federated" : "Sfederowany",
    "Mount point" : "Punkt montowania",
    "App" : "Aplikacja",
    "Nextcloud Account" : "Konto Nextcloud",
    "Nextcloud Group" : "Grupa Nextcloud",
    "Email address" : "Adres e-mail",
    "Contact" : "Kontakt",
    "Team" : "Zespół",
    "Nextcloud App" : "Aplikacja Nextcloud",
    "Teams App" : "Aplikacja Teams",
    "Admin Command Line" : "Administracyjny wiersz poleceń",
    "Member" : "Członek",
    "Moderator" : "Moderator",
    "Admin" : "Administrator",
    "Owner" : "Właściciel",
    "%s shared »%s« with you." : "%s udostępnił Tobie »%s«.",
    "%s shared »%s« with \"%s\"." : "%s udostępnił »%s« z \"%s\".",
    "%s on %s" : "%s na %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s udostępnił »%2$s«.\nPowinieneś już otrzymać oddzielną wiadomość zawierającą link do udostępnionego zasobu.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s udostępnił »%2$s«. Powinieneś już otrzymać oddzielną wiadomość zawierającą link do udostępnionego zasobu.",
    "Password to access »%1$s« shared to you by %2$s" : "Hasło dostępu do »%1$s« udostępnionego przez %2$s",
    "Password to access »%s«" : "Hasło dostępu do »%s«",
    "It is protected with the following password:" : "Zasób chroniony jest następującym hasłem:",
    "%1$s via %2$s" : "%1$s przez %2$s",
    "Click the button below to open it." : "Kliknij przycisk poniżej, aby go otworzyć.",
    "Open »%s«" : "Otwórz »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s udostępnił Tobie wiele plików.\nPowinieneś otrzymać osobną wiadomość e-mail z linkiem do nich.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s udostępnił Tobie wiele plików. Powinieneś otrzymać osobną wiadomość e-mail z linkiem do nich.",
    "Password to access files shared to you by %1$s" : "Hasło dostępu do plików udostępnionych Tobie przez %1$s",
    "Password to access files" : "Hasło dostępu do plików",
    "%s shared multiple files with \"%s\"." : "%s udostępnił wiele plików z \"%s\".",
    "%s shared multiple files with you." : "%s udostępnił Tobie wiele plików.",
    "Boot up" : "Uruchom",
    "Nextcloud Initialization" : "Inicjalizacja Nextcloud",
    "Teams App Initialization" : "Inicjalizacja aplikacji Teams",
    "Fresh installation status" : "Stan nowej instalacji",
    "Building Local Database" : "Tworzenie lokalnej bazy danych",
    "Testing Basic Team Creation" : "Testowanie podstawowego tworzenia zespołu",
    "Adding local users and moderators" : "Dodawanie lokalnych użytkowników i moderatorów",
    "Show all teams" : "Pokaż wszystkie zespoły",
    "Create a new team" : "Utwórz nowy zespół",
    "Files" : "Pliki",
    "This feature is not available for personal teams" : "Ta funkcja nie jest dostępna dla zespołów osobistych",
    "The team is not federated" : "Zespół nie jest sfederowany",
    "You cannot join this team" : "Nie możesz dołączyć do tego zespołu",
    "This member is not a moderator" : "Ten członek nie jest moderatorem",
    "Insufficient privileges" : "Niewystarczające uprawnienia",
    "This member does not exist" : "Ten członek nie istnieje",
    "This member is the owner of the team" : "Ten członek jest właścicielem zespołu",
    "Level cannot be changed for this type of member" : "Nie można zmienić poziomu dla tego typu członka",
    "You are already a member of this team" : "Jesteś już członkiem tego zespołu",
    "You have been blocked from this team" : "Zostałeś zablokowany w tym zespole",
    "The account is already a member of this team" : "To konto jest już członkiem tego zespołu",
    "The account has already been invited into this team" : "To konto zostało już zaproszone do tego zespołu",
    "%s (Team owned by %s)" : "%s (Zespół należący do %s)",
    "You are now a member of the Team \"%2$s\"" : "Jesteś teraz członkiem zespołu „%2$s”",
    "You have been invited by %1$s into the Team \"%2$s\"" : "Zostałeś zaproszony przez %1$s do zespołu „%2$s”",
    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$s wysłał prośbę o dołączenie do zespołu \"%2$s\"",
    "Accept" : "Akceptuj",
    "Refuse" : "Odrzuć",
    "Leave the team" : "Opuść zespół",
    "No image file provided" : "Nie wskazano pliku obrazu",
    "Invalid file provided" : "Podano nieprawidłowy plik",
    "File is too big" : "Plik jest za duży",
    "Invalid image" : "Nieprawidłowy obraz",
    "Unknown filetype" : "Nieznany typ pliku",
    "%s" : "%s",
    "Personal team" : "Zespół osobisty",
    "%s owned by %s" : "%s należący do %s",
    "You have no permission to create a new team" : "Nie masz uprawnień do tworzenia nowego zespołu",
    "Insufficient permissions to perform this action" : "Niewystarczające uprawnienia do wykonania tej operacji",
    "%s shared a file with \"%s\"." : "%s udostępnił plik z \"%s\".",
    "%s shared a file with you." : "%s udostępnił Tobie plik.",
    "%1$s shared %2$s with %3$s" : "%1$s udostępnia %2$s z %3$s",
    "%1$s shared %2$s with \"%3$s\"" : "%1$s udostępnia %2$s z \"%3$s\"",
    "Open %s" : "Otwórz %s",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s udostępnił Tobie niektóre treści.\nPowinieneś już otrzymać osobną wiadomość e-mail z linkiem, aby uzyskać do niego dostęp.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s udostępnił Tobie niektóre treści. Powinieneś już otrzymać osobną wiadomość e-mail z linkiem, aby uzyskać do niego dostęp.",
    "Password to access content shared with you by %1$s" : "Hasło dostępu do treści udostępnionej Tobie przez %1$s",
    "Password to access content" : "Hasło dostępu do treści",
    "Federated Teams" : "Zespoły federacyjne",
    "This item is already shared with this team" : "Ten element został już udostępniony temu zespołowi",
    "Bring cloud-users closer together." : "Integruje użytkowników chmury.",
    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Zespoły umożliwiają tworzenie własnych grup osób/współpracowników/przyjaciół.\nTe grupy osób mogą być następnie wykorzystywane przez dowolną inną aplikację do celów udostępniania.",
    "Unable to update federated teams config" : "Nie można zaktualizować konfiguracji zespołów federacyjnych",
    "Invalid URL format. Please provide a valid URL." : "Nieprawidłowy format URL. Podaj prawidłowy adres URL.",
    "Changed frontal cloud URL" : "Zmieniono czołowy URL chmury ",
    "Federation allows you to share teams with other trusted servers and make them discoverable across instances." : "Federacja umożliwia udostępnianie zespołów innym zaufanym serwerom oraz ich wykrywanie między instancjami.",
    "Enable federated teams" : "Włącz zespoły federacyjne",
    "Frontal URL" : "Czołowy URL ",
    "https://…" : "https://…",
    "The public URL used by other instances to discover and connect to your teams." : "Publiczny adres URL używany przez inne instancje do wykrywania i łączenia się z Twoimi zespołami.",
    "Unlimited" : "Bez limitu",
    "Default quota" : "Domyślny limit",
    "Select default quota" : "Wybierz domyślny limit",
    "Save" : "Zapisz",
    "Reconnect" : "Połącz ponownie",
    "Connect" : "Połącz",
    "New team" : "Nowy zespół",
    "Search teams" : "Wyszukaj zespoły",
    "Overview" : "Przegląd",
    "No teams found" : "Nie znaleziono żadnych zespołów",
    "Try a different search." : "Spróbuj wyszukać inaczej.",
    "Create a team to get started." : "Utwórz zespół, aby rozpocząć.",
    "Members" : "Członkowie",
    "_%n resource_::_%n resources_" : ["%n zasób","%n zasobów","%n zasobów","%n zasoby"],
    "Team \"{name}\" created" : "Utworzono zespół \"{name}\" ",
    "Could not create the team" : "Nie udało się utworzyć zespołu",
    "Cancel" : "Anuluj",
    "Next" : "Następna",
    "Back" : "Poprzednia",
    "Create team" : "Utwórz zespół",
    "Team name" : "Nazwa zespołu",
    "e.g. Design" : "np. Projektowanie",
    "Search for people to add" : "Wyszukaj osoby do dodania",
    "Switch to list view" : "Przełącz na widok listy",
    "Switch to grid view" : "Przełącz na widok siatki",
    "Folder" : "Katalog",
    "Team owner" : "Właściciel zespołu",
    "you" : "Ciebie",
    "Manage team" : "Zarządzaj zespołem",
    "Copy link" : "Kopiuj link",
    "Leave team" : "Opuść zespół",
    "Delete team" : "Usuń zespół",
    "An error happened during the config change" : "Wystąpił błąd podczas zmiany konfiguracji",
    "Confirm enabling federation" : "Potwierdź włączenie federacji",
    "Enabling this will prevent {circle} from being a member of other teams.\nAre you sure?" : "Włączenie tej opcji uniemożliwi {circle} członkostwo w innych zespołach. \nCzy na pewno chcesz kontynuować?",
    "Enable federation" : "Włącz federację",
    "Copied" : "Skopiowane",
    "Could not copy" : "Nie udało się skopiować",
    "Create link" : "Utwórz link",
    "Enforce password protection on files shared to this team" : "Wymagaj ochrony hasłem dla plików udostępnianych temu zespołowi",
    "Use a unique password for all shares to this team" : "Używaj unikalnego hasła dla wszystkich udostępnień do tego zespołu",
    "Unique password …" : "Unikalne hasło...",
    "Change unique password" : "Zmień unikalne hasło",
    "Failed to save password. Please try again later." : "Nie udało się zapisać hasła. Spróbuj ponownie później.",
    "Close" : "Zamknij",
    "Choose a team picture" : "Wybierz zdjęcie zespołu",
    "There is no description for this team" : "Ten zespół nie ma opisu",
    "Enter a description for the team" : "Wprowadź opis zespołu",
    "New folder" : "Nowy katalog",
    "Folder name" : "Nazwa katalogu",
    "Talk conversation" : "Rozmowa Talk",
    "New Talk conversation" : "Nowa rozmowa Talk",
    "Conversation name" : "Nazwa konwersacji",
    "Collective" : "Kolektyw",
    "Calendar" : "Kalendarz",
    "New calendar" : "Nowy kalendarz",
    "Calendar name" : "Nazwa kalendarza",
    "Unknown resource type" : "Nieznany typ zasobu",
    "Team calendar \"{resourceName}\" created and shared with team" : "Kalendarz zespołu \"{resourceName}\" został utworzony i udostępniony zespołowi",
    "{resourceType} \"{resourceName}\" created and shared with team" : "{resourceType} \"{resourceName}\" został utworzony i udostępniony zespołowi",
    "A calendar named \"{name}\" already exists. Please choose a different name." : "Kalendarz o nazwie \"{name}\" już istnieje. Wybierz inną nazwę.",
    "Failed to create {resourceType}: {error}" : "Nie udało się utworzyć {resourceType}: {error}",
    "Please select a valid png or jpg file" : "Wybierz prawidłowy plik PNG lub JPG",
    "Error picking team picture" : "Błąd podczas wybierania zdjęcia zespołu",
    "Error cropping avatar picture" : "Błąd podczas przycinania zdjęcia awatara",
    "An error happened while saving {fields}" : "Wystąpił błąd podczas zapisywania {fields}",
    "Description" : "Opis",
    "Upload team picture" : "Prześlij zdjęcie zespołu",
    "Choose from Nextcloud Files" : "Wybierz z plików Nextcloud",
    "Delete picture" : "Usuń zdjęcie",
    "Edit" : "Edycja",
    "Request to join" : "Poproś o dołączenie",
    "Create" : "Utwórz",
    "Show in Calendar" : "Pokaż w kalendarzu",
    "Your request to join this team is pending approval" : "Twoja prośba o dołączenie do tego zespołu oczekuje na zatwierdzenie",
    "You are not a member of {circle}" : "Nie jesteś członkiem {circle}",
    "Add" : "Dodaj",
    "Edit team picture" : "Edytuj zdjęcie zespołu",
    "Apply" : "Zastosuj",
    "Remove {type}" : "Usuń {type}",
    "Add to group" : "Dodaj do grupy",
    "Add members to group" : "Dodaj członków do grupy",
    "Search {types}" : "Szukaj w {types}",
    "Add guest" : "Dodaj gościa",
    "Loading …" : "Ładowanie ...",
    "No results" : "Brak wyników",
    "Add {type}" : "Dodaj {type}",
    "Promote as sole owner" : "Awansuj na jedynego właściciela",
    "Promote to {level}" : "Awansuj do poziomu {level}",
    "Demote to {level}" : "Degraduj do poziomu {level}",
    "Are you sure you want to leave this team? This action cannot be undone." : "Czy na pewno chcesz opuścić ten zespół? Tej operacji nie można cofnąć.",
    "Leave team failed." : "Nie udało się opuścić zespołu.",
    "Could not delete the member {displayName}" : "Nie udało się usunąć członka {displayName}",
    "Could not change the member level to {level}" : "Nie udało się zmienić poziomu uprawnień członka na {level}",
    "Could not accept membership request" : "Nie udało się zaakceptować prośby o członkostwo",
    "Accept membership request" : "Zaakceptuj prośbę o członkostwo",
    "Reject membership request" : "Odrzuć prośbę o członkostwo",
    "Manage level" : "Zarządzaj poziomem uprawnień",
    "Remove member" : "Usuń członka",
    "Pending" : "Oczekujące",
    "Unable to get the results" : "Nie udało się pobrać wyników",
    "Some members could not be added" : "Nie udało się dodać niektórych członków",
    "There was an issue adding members to the team" : "Wystąpił problem podczas dodawania członków do zespołu",
    "The list of members is only visible to members of this team" : "Lista członków jest widoczna tylko dla członków tego zespołu",
    "Role" : "Rola społeczna",
    "Loading members list …" : "Ładowanie listy członków...",
    "You currently have no access to the member list" : "Obecnie nie masz dostępu do listy członków",
    "Add to {team}" : "Dodaj do {team}",
    "Invite members to {team}" : "Zaproś członków do {team}",
    "Your teams and everything shared with them across Nextcloud." : "Twoje zespoły i wszystko, co zostało z nimi udostępnione w Nextcloud",
    "Could not load teams" : "Nie udało się wczytać zespołów",
    "Something went wrong while loading your teams." : "Wystąpił błąd podczas wczytywania Twoich zespołów",
    "Try again" : "Spróbuj ponownie",
    "No teams yet" : "Nie ma jeszcze żadnych zespołów",
    "Create your first team to start collaborating." : "Utwórz swój pierwszy zespół, aby rozpocząć współpracę",
    "Create your first team" : "Utwórz swój pierwszy zespół",
    "Your teams" : "Twoje zespoły",
    "Loading" : "Wczytywanie",
    "Go back" : "Wstecz",
    "Join" : "Dołącz",
    "Could not load the team" : "Nie udało się wczytać zespołu",
    "Team not found" : "Nie znaleziono zespołu",
    "This team may have been removed." : "Ten zespół mógł zostać usunięty",
    "Failed to load teams" : "Nie udało się wczytać zespołów",
    "Join or create teams to see them here." : "Dołącz lub utwórz zespoły, aby je tutaj zobaczyć.",
    "Loading…" : "Wczytywanie…",
    "More teams" : "Więcej zespołów",
    "Link copied to the clipboard" : "Link został skopiowany do schowka",
    "Could not copy link to the clipboard" : "Nie udało się skopiować linku do schowka",
    "Are you sure you want to leave {team}?" : "Czy na pewno chcesz opuścić zespół {team}?",
    "You left \"{name}\"" : "Opuściłeś(-aś) zespół \"{name}\"",
    "Could not leave the team" : "Nie udało się opuścić zespołu",
    "Are you sure you want to delete {team}? This cannot be undone." : "Czy na pewno chcesz usunąć zespół {team}? Tej operacji nie można cofnąć.",
    "Team deleted" : "Zespół został usunięty",
    "Could not delete the team" : "Nie udało się usunąć zespołu",
    "Join team" : "Dołącz do zespołu",
    "You are about to leave {circle}.\nAre you sure?" : "Za chwilę opuścisz zespół {circle}. \nCzy na pewno?",
    "Please confirm team leave" : "Potwierdź opuszczenie zespołu",
    "Could not leave the team {displayName}" : "Nie udało się opuścić zespołu {displayName}",
    "Unable to join the team" : "Nie można dołączyć do zespołu",
    "You are about to delete {circle}.\nAre you sure?" : "Za chwilę usuniesz zespół {circle}.\nCzy na pewno?",
    "Please confirm team deletion" : "Potwierdź usunięcie zespołu",
    "Unable to delete the team" : "Nie można usunąć zespołu",
    "Could not copy link to the clipboard." : "Nie udało się skopiować linku do schowka",
    "All contacts" : "Wszystkie kontakty",
    "Not grouped" : "Bez grupowania",
    "Recently contacted" : "Ostatnio skontaktowano się",
    "Organization chart" : "Schemat organizacyjny",
    "Contacts settings" : "Ustawienia kontaktów",
    "Create your own teams for sharing. Add Nextcloud users, contacts, or anyone via email." : "Twórz własne zespoły do udostępniania. Dodawaj użytkowników Nextcloud, kontakty lub dowolne osoby za pomocą adresu e-mail",
    "User" : "Użytkownik",
    "Group" : "Grupa",
    "Email" : "E-mail",
    "Invites" : "Zaproszenia",
    "Anyone can request membership" : "Każdy może poprosić o członkostwo",
    "Members need to accept invitation" : "Członkowie muszą zaakceptować zaproszenie",
    "Memberships must be confirmed/accepted by a Moderator (requires \"Anyone can request membership\")" : "Członkostwo musi zostać potwierdzone/zatwierdzone przez moderatora (wymaga opcji „Każdy może poprosić o członkostwo”)",
    "Members can also invite" : "Członkowie mogą również zapraszać innych",
    "Membership" : "Członkostwo",
    "Prevent teams from being a member of another team" : "Uniemożliw zespołom członkostwo w innych zespołach",
    "Federation" : "Federacja",
    "Allow federated members" : "Zezwalaj na członków federacyjnych",
    "Privacy" : "Prywatność",
    "Visible to everyone" : "Widoczne dla wszystkich",
    "users" : "użytkownicy",
    "Users" : "Użytkownicy",
    "groups" : "grupy",
    "Groups" : "Grupy",
    "federated users" : "użytkownicy federacyjni",
    "Federated users" : "Użytkownicy federacyjni",
    "teams" : "zespoły",
    "email addresses" : "adresy e-mail",
    "Email addresses" : "Adresy e-mail",
    "contacts" : "kontakty",
    "Contacts" : "Kontakty",
    "An error has occurred in team(s). Check the console for more details." : "Wystąpił błąd w zespole (lub zespołach). Sprawdź konsolę, aby uzyskać więcej szczegółów.",
    "Unable to create team {circleName}" : "Nie udało się utworzyć zespołu {circleName}",
    "Unable to delete team {circleId}" : "Nie udało się usunąć zespołu {circleId}",
    "No files in here" : "Brak plików tutaj",
    "No entries found in this folder" : "Brak wpisów w tym katalogu",
    "Name" : "Nazwa",
    "Size" : "Rozmiar",
    "Modified" : "Zmodyfikowano",
    "Circles App Initialization" : "Inicjalizacja aplikacji Zespołów"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
