OC.L10N.register(
    "provisioning_api",
    {
    "Logged in account must be an administrator or have authorization to edit this setting." : "Inloggat konto måste vara en administratör eller ha behörighet att ändra denna inställning.",
    "Could not create non-existing user ID" : "Det gick inte att skapa ett användar-ID som inte finns",
    "User already exists" : "Användaren finns redan",
    "Group %1$s does not exist" : "Grupp %1$s finns inte",
    "Insufficient privileges for group %1$s" : "Otillräckliga behörigheter för gruppen %1$s",
    "No group specified (required for sub-admins)" : "Ingen grupp har angetts (krävs för underadministratörer)",
    "Sub-admin group does not exist" : "Underadministratörsgruppen finns inte",
    "Cannot create sub-admins for admin group" : "Det går inte att skapa underadministratörer för administratörsgruppen",
    "No permissions to promote sub-admins" : "Ingen behörighet att befordra underadministratörer",
    "Invalid password value" : "Ogiltigt lösenordsvärde",
    "An email address is required, to send a password link to the user." : "En e-postadress krävs för att skicka en lösenordslänk till användaren.",
    "Required email address was not provided" : "Den obligatoriska e-postadressen angavs inte",
    "User creation failed" : "Det gick inte att skapa användaren",
    "Cannot change display name for this user" : "Det går inte att ändra visningsnamnet för den här användaren",
    "Invalid email address" : "Ogiltig e-postadress",
    "Language change is not allowed on this instance" : "Det är inte tillåtet att ändra språk på den här instansen",
    "Invalid language" : "Ogiltigt språk",
    "Insufficient permissions to change quota" : "Otillräcklig behörighet för att ändra kvoten",
    "Insufficient permissions to change groups" : "Otillräcklig behörighet för att ändra grupper",
    "Group %s does not exist" : "Gruppen %s finns inte",
    "Insufficient permissions to change sub-admin groups" : "Otillräcklig behörighet för att ändra underadministratörsgrupper",
    "Insufficient permissions to change manager" : "Otillräcklig behörighet för att ändra ansvarig",
    "Invalid quota value: %1$s" : "Ogiltigt kvotvärde: %1$s",
    "Invalid quota value. %1$s is exceeding the maximum quota" : "Ogiltigt kvotvärde. %1$s överskrider den högsta tillåtna kvoten",
    "Unlimited quota is forbidden on this instance" : "Obegränsad kvot är inte tillåten på den här instansen",
    "Setting the password is not supported by the users backend" : "Användarbackend stöder inte inställning av lösenord",
    "Invalid locale" : "Ogiltigt språkområde",
    "Invalid timezone" : "Ogiltig tidszon",
    "Invalid first day of week" : "Ogiltig första veckodag",
    "Cannot remove yourself from the admin group" : "Du kan inte ta bort dig själv från administratörsgruppen",
    "Cannot remove yourself from this group as you are a sub-admin" : "Du kan inte ta bort dig själv från den här gruppen eftersom du är underadministratör",
    "Not viable to remove user from the last group you are sub-admin of" : "Det går inte att ta bort användaren från den sista gruppen som du är underadministratör för",
    "User does not exist" : "Användaren finns inte",
    "Group does not exist" : "Gruppen finns inte",
    "User is not a sub-admin of this group" : "Användaren är inte underadministratör för den här gruppen",
    "Email address not available" : "E-postadressen är inte tillgänglig",
    "Sending email failed" : "Det gick inte att skicka e-postmeddelandet",
    "Logged in account is not mail address owner" : "Det inloggade kontot äger inte e-postadressen",
    "Email confirmation" : "E-postbekräftelse",
    "To enable the email address %s please click the button below." : "Klicka på knappen nedan för att aktivera e-postadressen %s.",
    "Confirm" : "Bekräfta",
    "Email was already removed from account and cannot be confirmed anymore." : "E-postadressen har redan tagits bort från kontot och kan inte längre bekräftas.",
    "Could not verify mail because the token is expired." : "Det gick inte att verifiera e-postadressen eftersom token har gått ut.",
    "Could not verify mail because the token is invalid." : "Det gick inte att verifiera e-postadressen eftersom token är ogiltig.",
    "An unexpected error occurred. Please contact your admin." : "Ett oväntat fel inträffade. Kontakta administratören.",
    "Email confirmation successful" : "E-postbekräftelsen lyckades",
    "Provisioning API" : "Provisionerings-API",
    "This application enables a set of APIs that external systems can use to manage accounts, groups and apps." : "Den här appen tillhandahåller en uppsättning API:er som externa system kan använda för att hantera konton, grupper och appar.",
    "This application enables a set of APIs that external systems can use to create, edit, delete and query account\n\t\tattributes, query, set and remove groups, set quota and query total storage used in Nextcloud. Group admin accounts\n\t\tcan also query Nextcloud and perform the same functions as an admin for groups they manage. The API also enables\n\t\tan admin to query for active Nextcloud applications, application info, and to enable or disable an app remotely.\n\t\tOnce the app is enabled, HTTP requests can be used via a Basic Auth header to perform any of the functions\n\t\tlisted above. More information is available in the Provisioning API documentation, including example calls\n\t\tand server responses." : "Den här appen tillhandahåller en uppsättning API:er som externa system kan använda för att skapa, redigera, ta bort och söka efter kontoattribut, söka efter, ange och ta bort grupper, ange kvoter samt kontrollera det totala lagringsutrymmet som används i Nextcloud. Gruppadministratörskonton kan också söka i Nextcloud och utföra samma funktioner som en administratör för de grupper som de hanterar. API:et gör det även möjligt för en administratör att söka efter aktiva Nextcloud-appar och appinformation samt att aktivera eller inaktivera en app på distans. När appen har aktiverats kan HTTP-begäranden med ett Basic Auth-huvud användas för att utföra funktionerna ovan. Mer information, inklusive exempelanrop och serversvar, finns i dokumentationen för Provisioning API."
},
"nplurals=2; plural=(n != 1);");
