.album-container[data-v-abfcb917],.album-container[data-v-abfcb917] .collection{height:100%}.album-container__filters[data-v-abfcb917]{display:flex;gap:8px}.album__title[data-v-abfcb917]{width:100%}.album__name[data-v-abfcb917]{overflow:hidden;white-space:nowrap;text-overflow:ellipsis}.album__location[data-v-abfcb917]{margin-inline-start:-4px;display:flex;color:var(--color-text-lighter)}
