OC.L10N.register(
    "app_api",
    {
    "Cancel" : "Cancel",
    "Delete" : "Deler",
    "Edit" : "Modificar",
    "Unlimited" : "Ilimitate",
    "Host" : "Hospite",
    "Enabled" : "Activate",
    "Confirm" : "Confirmar",
    "Save" : "Salveguardar",
    "Visit website" : "Visitar sito web",
    "Report a bug" : "Reportar un defecto",
    "User documentation" : "Documentation de usator",
    "Admin documentation" : "Documentation de administrator",
    "Developer documentation" : "Documentation de disveloppator",
    "Version" : "Version",
    "Actions" : "Actiones",
    "Type" : "Typo",
    "Documentation" : "Documentation",
    "Details" : "Detalios",
    "Disable" : "Disactivar"
},
"nplurals=2; plural=(n != 1);");
