OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "Lembretes de ficheiro",
    "Reminder for {name}" : "Lembrete para {name}",
    "View file" : "Ver ficheiro",
    "View folder" : "Ver cartafol",
    "Files reminder" : "Lembrete de ficheiros",
    "The \"files_reminders\" app can work properly." : "A aplicación «files_reminders» pode funcionar correctamente.",
    "The \"files_reminders\" app needs the notification app to work properly. You should either enable notifications or disable files_reminder." : "A aplicación «files_reminders» necesita que a aplicación de notificación funcione correctamente. Debe activar as notificacións ou desactivar files_reminder.",
    "Set file reminders" : "Definir lembretes de ficheiros",
    "**📣 File reminders**\n\nSet file reminders.\n\nNote: to use the `File reminders` app, ensure that the `Notifications` app is installed and enabled. The `Notifications` app provides the necessary APIs for the `File reminders` app to work correctly." : "**📣 Lembretes de ficheiro**\n\nDefinir lembretes de ficheiro.\n\nNota: para usar a aplicación `Lembretes de ficheiro`, asegúrese de que a aplicación `Notificacións` estea instalada e activada. A aplicación `Notificacións` ofrece as API necesarias para que a aplicación `Lembretes de ficheiro` funcione correctamente.",
    "Please choose a valid date & time" : "Escolla unha data e hora válidas",
    "Reminder set for \"{fileName}\"" : "Lembrete definido para «{fileName}»",
    "Failed to set reminder" : "Produciuse un fallo ao definir o lembrete",
    "Reminder cleared for \"{fileName}\"" : "Limpouse o lembrete para «{fileName}»",
    "Failed to clear reminder" : "Produciuse un fallo ao limpar o lembrete",
    "Reminder at custom date & time" : "Lembrete en data e hora personalizadas",
    "We will remind you of this file" : "Lembrarémoslle este ficheiro",
    "Cancel" : "Cancelar",
    "Clear reminder" : "Limpar o lembrete",
    "Set reminder" : "Definir un lembrete",
    "Set reminder for " : "Definir un lembrete para",
    "Reminder set" : "Definir lembrete",
    "Custom reminder" : "Lembrete personalizado",
    "Later today" : "Hoxe máis tarde",
    "Set reminder for later today" : "Definir un lembrete para hoxe máis tarde",
    "Tomorrow" : "Mañá",
    "Set reminder for tomorrow" : "Definir un lembrete para mañá",
    "This weekend" : "Este fin de semana",
    "Set reminder for this weekend" : "Definir un lembrete para este fin de semana",
    "Next week" : "Semana seguinte",
    "Set reminder for next week" : "Definir un lembrete para a semana seguinte",
    "Set reminder for \"{fileName}\"" : "Definir un lembrete para «{fileName}»"
},
"nplurals=2; plural=(n != 1);");
