OC.L10N.register(
    "files_external",
    {
    "Storage with ID \"%d\" not found" : "Konservejo kun identigilo „%d“ ne trovita",
    "Invalid backend or authentication mechanism class" : "Nevalida interna tipo aŭ aŭtentiga klaso",
    "Invalid mount point" : "Nevalida surmetingo",
    "Objectstore forbidden" : "„Objectstore“ malpermesata",
    "Invalid storage backend \"%s\"" : "Nevalida konserveja interna servo „%s“",
    "Not permitted to use backend \"%s\"" : "Ne permesatas uzi internan servon „%s“",
    "Not permitted to use authentication mechanism \"%s\"" : "Ne permesatas uzi aŭtentigan metodon „%s“",
    "Unsatisfied backend parameters" : "Neplenumitaj internservaj parametroj",
    "Unsatisfied authentication mechanism parameters" : "Neplenumitaj aŭtentigmetodaj parametroj",
    "Insufficient data: %s" : "Nesufiĉaj datumoj: %s",
    "Builtin" : "Interne instalita",
    "None" : "Nenio",
    "OpenStack v2" : "OpenStack v2",
    "Login" : "Ensaluti",
    "Password" : "Pasvorto",
    "Tenant name" : "Nomo de la loĝanto (angle „tenant“)",
    "Identity endpoint URL" : "Retadreso de identeca finpunkto (angle „Identity endpoint“)",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "Domajno",
    "Rackspace" : "Rackspace",
    "API key" : "API-ŝlosilo",
    "Global credentials" : "Ĝeneralaj akreditiloj",
    "Log-in credentials, save in database" : "Ensalutaj akreditiloj, konservi en datumbazo",
    "Log-in credentials, save in session" : "Ensalutaj akreditiloj, konservi en seanco",
    "RSA public key" : "Publika RSA-ŝlosilo",
    "Public key" : "Publika ŝlosilo",
    "RSA private key" : "Privata RSA-ŝlosilo",
    "Private key" : "Privata ŝlosilo",
    "Kerberos ticket" : "Kerberos-bileto (angle „ticket“)",
    "Bucket" : "Ujo (angle „bucket“)",
    "Hostname" : "Gastigonomo",
    "Port" : "Pordo",
    "Region" : "Regiono",
    "WebDAV" : "WebDAV",
    "URL" : "Retadreso",
    "Remote subfolder" : "Fora subdosierujo",
    "Secure https://" : "Sekura https://",
    "Host" : "Gastigo",
    "Secure ftps://" : "Sekura ftps://",
    "Location" : "Loko",
    "Root" : "Radiko",
    "Share" : "Kunhavigi",
    "Show hidden files" : "Montri kaŝitajn dosierojn",
    "Timeout" : "Eltempiĝo",
    "Service name" : "Servonomo",
    "Request timeout (seconds)" : "Eltempiĝo (sekundoj)",
    "External storage" : "Ekstera konservejo",
    "External storage support" : "Subteno de ekstera konservejo",
    "Adds basic external storage support" : "Aldonas bazan subtenon por ekstera konservejo",
    "Add storage" : "Aldoni konservejon",
    "Folder name" : "Dosierujnomo",
    "Authentication" : "Aŭtentigo",
    "Cancel" : "Cancel",
    "Edit" : "Modifi",
    "Never" : "Neniam",
    "Once every direct access" : "Unufoje okaze de senpera aliro",
    "Always" : "Ĉiam",
    "Read only" : "Nurlega",
    "Enable previews" : "Ŝalti antaŭrigardojn",
    "Enable sharing" : "Ŝalti kunhavigadon",
    "Enable encryption" : "Ŝalti ĉifradon",
    "Compatibility with Mac NFD encoding (slow)" : "Kongrueco kun Makintoŝa „NFD“ signara kodoprezento (malrapide)",
    "External storages" : "Eksteraj konservejoj",
    "Actions" : "Agoj",
    "Delete" : "Forigi",
    "Saved" : "Konservita",
    "Error generating key pair" : "Eraro dum generado de ŝlosila paro",
    "Generate keys" : "Generi ŝlosilojn",
    "Confirm" : "Konfirmi",
    "Global credentials can be used to authenticate with multiple external storages that have the same credentials." : "Ĝeneralaj akreditiloj utilas, kiam pluraj eksteraj konservejoj kunuzas la samajn akreditilojn.",
    "Save" : "Konservi",
    "External mount error" : "Eraro de surmetingo ekstera",
    "Storage type" : "Konserveja tipo",
    "Unknown" : "Nekonata",
    "Scope" : "Amplekso",
    "Personal" : "Persona",
    "System" : "Sistemo",
    "Error" : "Eraro",
    "Grant access" : "Doni alirpermeson",
    "Error configuring OAuth2" : "Eraro dum agordo de OAuth2",
    "%s" : "%s",
    "Access key" : "Alira ŝlosilo",
    "Secret key" : "Sekreta ŝlosilo",
    "OAuth2" : "OAuth2",
    "Client ID" : "Klientidentigilo",
    "Client secret" : "Klientosekreto",
    "Enable SSL" : "Ŝalti SSL-on",
    "Enable Path Style" : "Uzi vojan stilon („path style“ angle)",
    "Legacy (v2) authentication" : "Aŭtentigo per malnova v2",
    "FTP" : "FTP",
    "Local" : "Loka",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "SFTP with secret key login" : "SFTP kun sekretoŝlosila ensaluto",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Subteno de cURL en PHP ne estas ebligita aŭ instalita. Surmetado de %s ne eblas. Bv. vidi kun via administranto.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Subteno de FTP en PHP ne estas ebligita aŭ instalita. Surmetado de %s ne eblas. Bv. vidi kun via administranto.",
    "\"%1$s\" is not installed. Mounting of %2$s is not possible. Please ask your system administrator to install it." : "„%1$s“ ne estas instalita. Surmetado de %2$s ne eblas. Bv. vidi kun via administranto.",
    "(Group)" : "(grupo)",
    "Check for changes" : "Serĉi la modifojn",
    "Disconnect" : "Malkonekti",
    "Admin defined" : "Difinita de administranto",
    "Delete storage?" : "Ĉu forigi konservejon?",
    "Click to recheck the configuration" : "Alklaku por rekontroli la agordon",
    "Saving …" : "Konservado...",
    "No external storage configured or you don't have the permission to configure them" : "Neniu ekstera konservejo agordita, aŭ vi ne rajtas agordi ĝin.",
    "Open documentation" : "Malfermi la dokumentaron",
    "Configuration" : "Agordo",
    "Available for" : "Disponebla por",
    "Advanced settings" : "Altanivela agordo"
},
"nplurals=2; plural=(n != 1);");
