OC.L10N.register(
    "contactsinteraction",
    {
    "Recently contacted" : "Paskiausiai susisiekta",
    "Contacts Interaction" : "Sąveika su adresatais",
    "Manages interaction between accounts and contacts" : "Tvarko sąveiką tarp paskyrų ir kontaktų",
    "Collect data about accounts and contacts interactions and provide an address book for the data" : "Rinkti duomenis apie klientų ir kontaktų sąveiką ir pateikti adresų knygą duomenims"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
