OC.L10N.register(
    "contactsinteraction",
    {
    "Recently contacted" : "Yaqinda bog'langan",
    "Contacts Interaction" : "Kontaktlar o'zaro ta'siri",
    "Manages interaction between accounts and contacts" : "Hisoblar va kontaktlar o'rtasidagi o'zaro aloqani boshqaradi",
    "Collect data about accounts and contacts interactions and provide an address book for the data" : "Hisoblar va kontaktlarning o'zaro aloqalari haqida ma'lumotlarni to'plang va ma'lumotlar uchun manzillar kitobini taqdim eting"
},
"nplurals=1; plural=0;");
