OC.L10N.register(
    "profile",
    {
    "View profile" : "View profile",
    "Profile" : "Profil",
    "This application provides the profile" : "Ushbu ilova profilni taqdim etadi",
    "Not found" : "Topilmadi",
    "You have not added any info yet" : "Siz hali hech qanday ma'lumot qo'shmadingiz",
    "{user} has not added any info yet" : "{user} hali hech qanday ma'lumot qo'shmagan",
    "Error opening the user status modal, try hard refreshing the page" : "Foydalanuvchi holati modalini ochishda xato, sahifani yangilashga harakat qiling",
    "The headline and about sections will show up here" : "The headline and about sections will show up here",
    "Profile not found" : "Profil topilmadi",
    "Back to %s" : "%sga qaytish",
    "Provides a customisable user profile interface." : "Moslashtirilgan foydalanuvchi Profil interfeysini taqdim etadi.",
    "Edit Profile" : "Profilni Tahrirlash",
    "The profile does not exist." : "Profil mavjud emas."
},
"nplurals=1; plural=0;");
