OC.L10N.register(
    "profile",
    {
    "View profile" : "Прегледај профил",
    "Profile" : "Профил",
    "Searching …" : "Пребарување …",
    "Not found" : "Не е пронајдено",
    "You have not added any info yet" : "Сè уште немате додадено никакви информации",
    "{user} has not added any info yet" : "{user} нема додадено никакви информации",
    "The headline and about sections will show up here" : "Насловот и за секциите ќе се појават овде",
    "Profile not found" : "Профилот не е пронајден",
    "Back to %s" : "Врати се на %s",
    "Edit Profile" : "Уреди профил",
    "The profile does not exist." : "Профилот на постои"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
