OC.L10N.register(
    "files_sharing",
    {
    "File shares" : "Файл түгээлт",
    "Downloaded via public link" : "Нийтийн холбоосоор татагдсан",
    "Downloaded by {email}" : "{email}-р татагдсан",
    "{file} downloaded via public link" : "{file} нийтийн холбоосоор татагдсан",
    "{email} downloaded {file}" : "{email} {file}-г татсан",
    "Shared with group {group}" : "{group} бүлэгт хуваалцсан",
    "Removed share for group {group}" : "{group} бүлгийн хуваалцалтыг устгасан",
    "{actor} shared with group {group}" : "{actor} {group} бүлэгт хуваалцсан",
    "{actor} removed share for group {group}" : "{actor} {group} бүлгийн хуваалцалтыг устгасан",
    "Share for group {group} expired" : "{group} бүлгийн хуваалцалт дууссан",
    "You shared {file} with group {group}" : "Та {file}-г {group} бүлэгт хуваалцсан",
    "You removed group {group} from {file}" : "Та {group} бүлгийг {file}-с хассан",
    "{actor} shared {file} with group {group}" : "{actor} {file}-г {group} бүлэгт хуваалцсан",
    "{actor} removed group {group} from {file}" : "{actor} {group} бүлгийг {file}-с хассан",
    "Share for file {file} with group {group} expired" : "{file} файлын {group} бүлэгт хуваалцсан хугацаа дууссан",
    "Shared as public link" : "Shared as public link",
    "Removed public link" : "Нийтийн холбоосыг устгасан",
    "Public link expired" : "Нийтийн холбоосын хугацаа дууссан",
    "{actor} shared as public link" : "{actor} нийтийн холбоосоор хуваалцсан",
    "{actor} removed public link" : "{actor} нийтийн холбоосыг устгасан",
    "Public link of {actor} expired" : "{actor}-н нийтийн холбоосын хугацаа дууссан",
    "You shared {file} as public link" : "Та {file}-г нийтийн холбоосоор хуваалцсан",
    "You removed public link for {file}" : "Та {file}-н нийтийн холбоосыг устгасан",
    "Public link expired for {file}" : "{file}-н нийтийн холбоосын хугацаа дууссан",
    "{actor} shared {file} as public link" : "{actor} {file}-г нийтийн холбоосоор хуваалцсан",
    "{actor} removed public link for {file}" : "{actor} {file}-н нийтийн холбоосыг устгасан",
    "Public link of {actor} for {file} expired" : "{actor}-н {file}-д зориулсан нийтийн холбоосын хугацаа дууссан",
    "{user} accepted the remote share" : "{user} алсын хуваалцалтыг зөвшөөрсөн",
    "{user} declined the remote share" : "{user} алсын хуваалцалтыг татгалзсан",
    "You received a new remote share {file} from {user}" : "Та {user}-с {file} шинэ алсын хуваалцалт хүлээн авсан",
    "{user} accepted the remote share of {file}" : "{user} {file}-н алсын хуваалцалтыг зөвшөөрсөн",
    "{user} declined the remote share of {file}" : "{user} {file}-н алсын хуваалцалтыг татгалзсан",
    "{user} unshared {file} from you" : "{user} {file}-н хуваалцалтыг танаас хассан",
    "Shared with {user}" : "{user}-т хуваалцсан",
    "Removed share for {user}" : "{user}-н хуваалцалтыг хассан",
    "You removed yourself" : "Та өөрийгөө хассан",
    "{actor} removed themselves" : "{actor} өөрийгөө хассан",
    "{actor} shared with {user}" : "{actor} {user}-т хуваалцсан",
    "{actor} removed share for {user}" : "{actor} {user}-н хуваалцалтыг хассан",
    "Shared by {actor}" : "{actor}-с хуваалцсан",
    "{actor} removed share" : "{actor} хуваалцалтыг хассан",
    "Share for {user} expired" : "{user}-н хуваалцалтын хугацаа дууссан",
    "Share expired" : "Хуваалцалтын хугацаа дууссан",
    "You shared {file} with {user}" : "Та {file}-г {user}-т хуваалцсан",
    "You removed {user} from {file}" : "Та {user}-г {file}-с хассан",
    "You removed yourself from {file}" : "Та өөрийгөө {file}-с хассан",
    "{actor} removed themselves from {file}" : "{actor} өөрийгөө {file}-с хассан",
    "{actor} shared {file} with {user}" : "{actor} {file}-г {user}-т хуваалцсан",
    "{actor} removed {user} from {file}" : "{actor} {user}-г {file}-с хассан",
    "{actor} shared {file} with you" : "{actor} {file}-г танд хуваалцсан",
    "{actor} removed you from the share named {file}" : "{actor} таныг {file} нэртэй хуваалцалтаас хассан",
    "Share for file {file} with {user} expired" : "{file} файлын {user}-т хуваалцсан хугацаа дууссан",
    "Share for file {file} expired" : "{file} файлын хуваалцалтын хугацаа дууссан",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "И-мэйл эсвэл нийтийн холбоосоор хуваалцсан файл эсвэл хавтасыг <strong>татаж авсан</strong>",
    "Files have been <strong>uploaded</strong> to a folder shared by mail or by public link" : "И-мэйл эсвэл нийтийн холбоосоор хуваалцсан хавтас руу файлуудыг <strong>байршуулсан</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Файл эсвэл хавтас <strong>өөр серверээс</strong> хуваалцагдсан",
    "Sharing" : "Түгээх",
    "A file or folder has been <strong>shared</strong>" : "Файл эсвэл хавтас <strong>хуваалцагдсан</strong>",
    "Shared link" : "Хуваалцсан холбоос",
    "Wrong share ID, share does not exist" : "Буруу хуваалцалтын ID, хуваалцалт байхгүй байна",
    "Could not delete share" : "Хуваалцалтыг устгаж чадсангүй",
    "Please specify a file or folder path" : "Файл эсвэл хавтасны замыг зааж өгнө үү",
    "Wrong path, file/folder does not exist" : "Буруу зам, файл/хавтас байхгүй байна",
    "Could not create share" : "Хуваалцалт үүсгэж чадсангүй",
    "Please specify a valid account to share with" : "Хуваалцах хүчинтэй хаягийг зааж өгнө үү",
    "Please specify a valid group" : "Хүчинтэй бүлгийг зааж өгнө үү",
    "Please specify a valid email address" : "Хүчинтэй имэйл хаягийг зааж өгнө үү",
    "Sharing %s sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "%s-г хуваалцахад Nextcloud Talk-ээр нууц үг илгээх амжилтгүй боллоо, учир нь Nextcloud Talk идэвхжүүлээгүй байна",
    "Please specify a valid federated account ID" : "Хүчинтэй холбогдсон хаягийн ID-г зааж өгнө үү",
    "Please specify a valid federated group ID" : "Хүчинтэй холбогдсон бүлгийн ID-г зааж өгнө үү",
    "You cannot share to a Team if the app is not enabled" : "Апп идэвхгүй бол багт хуваалцах боломжгүй",
    "Please specify a valid team" : "Хүчинтэй багийг зааж өгнө үү",
    "Sharing %s failed because the back end does not support room shares" : "%s хуваалцах амжилтгүй болсон, учир нь систем өрөөний хуваалцалтыг дэмжихгүй байна",
    "Unknown share type" : "Үл мэдэгдэх хуваалцах төрөл",
    "Not a directory" : "Директор биш",
    "Could not lock node" : "Node-г түгжиж чадсангүй",
    "Public upload is only possible for publicly shared folders" : "Нийтийн байршуулалт зөвхөн нийтэд хуваалцсан хавтаснуудад боломжтой",
    "Share must at least have READ or CREATE permissions" : "Хуваалцалт хамгийн багадаа УНШИХ эсвэл ҮҮСГЭХ эрхтэй байх ёстой",
    "Share must have READ permission if UPDATE or DELETE permission is set" : "ШИНЭЧЛЭХ эсвэл УСТГАХ эрх тохируулсан бол хуваалцалт УНШИХ эрхтэй байх ёстой",
    "Could not lock path" : "Замыг түгжиж чадсангүй",
    "no sharing rights on this item" : "энэ зүйл дээр хуваалцах эрх байхгүй",
    "You are not allowed to edit incoming shares" : "Та ирж буй хуваалцалтыг засах эрхгүй байна",
    "Wrong or no update parameter given" : "Буруу эсвэл шинэчлэх параметр өгөгдөөгүй",
    "\"Sending the password by Nextcloud Talk\" for sharing a file or folder failed because Nextcloud Talk is not enabled." : "Файл эсвэл хавтасыг хуваалцахдаа \"Nextcloud Talk-ээр нууц үг илгээх\" амжилтгүй боллоо, учир нь Nextcloud Talk идэвхжүүлээгүй байна.",
    "Custom share link tokens have been disabled by the administrator" : "Өөрчлөн тохируулсан хуваалцах холбоосын токенууд админаар идэвхгүй болгогдсон",
    "Invalid date. Format must be YYYY-MM-DD" : "Буруу огноо. Формат YYYY-MM-DD байх ёстой",
    "No sharing rights on this item" : "Энэ зүйл дээр хуваалцах эрх байхгүй",
    "Invalid share attributes provided: \"%s\"" : "Буруу хуваалцалтын шинж чанар өгөгдсөн: \"%s\"",
    "You are not allowed to send mail notifications" : "Та имэйл мэдэгдэл илгээх эрхгүй байна",
    "No mail notification configured for this share type" : "Энэ хуваалцалтын төрөлд имэйл мэдэгдэл тохируулагдаагүй байна",
    "Wrong password" : "Нууц үг буруу байна",
    "Error while sending mail notification" : "Имэйл мэдэгдэл илгээхэд алдаа гарлаа",
    "Failed to generate a unique token" : "Өвөрмөц токен үүсгэж чадсангүй",
    "This share does not exist or is no longer available" : "Энэ хуваалцалт байхгүй эсвэл ашиглах боломжгүй болсон",
    "shared by %s" : "%s хуваалцсан",
    "Download" : "Татах",
    "Add to your %s" : "Таны %s-д нэмэх",
    "Direct link" : "Шууд холбоос",
    "Share API is disabled" : "Хуваалцах API идэвхгүй болсон",
    "File sharing" : "Файл хуваалцах",
    "Share will expire tomorrow" : "Хуваалцалтын хугацаа маргааш дуусна",
    "Your share of {node} will expire tomorrow" : "Таны {node}-н хуваалцалтын хугацаа маргааш дуусна",
    "You received {share} as a share by {user}" : "Та {user}-с {share} хуваалцалт хүлээн авсан",
    "You received {share} to group {group} as a share by {user}" : "Та {user}-с {group} бүлэгт {share} хуваалцалт хүлээн авсан",
    "Accept" : "Хүлээн зөвшөөрөх",
    "Decline" : "Зөвшөөрөхгүй",
    "Remember to upload the files to %s" : "%s-д файлуудаа байршуулахаа санаарай",
    "We would like to kindly remind you that you have not yet uploaded any files to the shared folder." : "Та хуваалцсан хавтасруу одоог хүртэл ямар ч файл байршуулаагүй байгааг сануулж байна.",
    "Open \"%s\"" : "\"%s\"-г нээх",
    "This application enables people to share files within Nextcloud. If enabled, the admin can choose which groups can share files. The applicable people can then share files and folders with other accounts and groups within Nextcloud. In addition, if the admin enables the share link feature, an external link can be used to share files with other people outside of Nextcloud. Admins can also enforce passwords, expirations dates, and enable server to server sharing via share links, as well as sharing from mobile devices.\nTurning the feature off removes shared files and folders on the server for all share recipients, and also on the sync clients and mobile apps. More information is available in the Nextcloud Documentation." : "Энэ програм нь хэрэглэгчдэд Nextcloud дотор файл хуваалцах боломжийг олгоно. Идэвхжүүлсэн тохиолдолд администратор аль бүлэг файл хуваалцаж болохыг сонгож болно. Холбогдох хэрэглэгчид Nextcloud дотор бусад бүртгэл болон бүлгүүдтэй файл, хавтасаа хуваалцаж чадна. Мөн администратор хуваалцах холбоосын функцийг идэвхжүүлбэл Nextcloud-аас гадуурх хүмүүстэй файл хуваалцахад гадаад холбоос ашиглаж болно. Администраторууд нууц үг, дуусах огноо тогтоох болон серверээс серверт хуваалцах, мобайл төхөөрөмжөөс хуваалцах боломжийг нэмж идэвхжүүлж болно.\nФункцийг унтраавал серверт хадгалагдаж байгаа хуваалцсан файл, хавтасууд бүх хүлээн авагчдад болон синк клиент, мобайл апп дээр устгагдана. Дэлгэрэнгүй мэдээллийг Nextcloud-ийн баримт бичгээс үзнэ үү.",
    "Filter accounts" : "Хаягуудыг шүүх",
    "you" : "та",
    "The request will expire on {date} at midnight and will be password protected." : "Хүсэлт {date}-нд шөнө дунд дуусах бөгөөд нууц үгээр хамгаалагдсан байна.",
    "The request will expire on {date} at midnight." : "Хүсэлтийн хугацаа {date}-д шөнө дунд дуусна.",
    "The request will be password protected." : "Хүсэлт нууц үгээр хамгаалагдсан байна.",
    "When should the request expire?" : "Хүсэлтийн хугацаа хэзээ дуусах вэ?",
    "Set a submission expiration date" : "Илгээлтийн дуусах огноог тохируулах",
    "Expiration date" : "Дуусах огноо",
    "Select a date" : "Огноо сонгох",
    "Your administrator has enforced a {count} days expiration policy." : "Таны админ {count} хоногийн хугацаа дуусах бодлого тогтоосон.",
    "What password should be used for the request?" : "Хүсэлтэд ямар нууц үг ашиглах вэ?",
    "Set a password" : "Нууц үг тохируулах",
    "Password" : "нууц үг",
    "Enter a valid password" : "Хүчинтэй нууц үг оруулна уу",
    "Generate a new password" : "Шинэ нууц үг үүсгэх",
    "Your administrator has enforced a password protection." : "Таны админ нууц үгийн хамгаалалт тогтоосон.",
    "Automatically copying failed, please copy the share link manually" : "Автомат хуулах амжилтгүй болсон, хуваалцах холбоосыг гараар хуулна уу",
    "Link copied" : "Холбоос хуулагдсан",
    "Email already added" : "Имэйл аль хэдийн нэмэгдсэн",
    "Invalid email address" : "Буруу имэйл хаяг",
    "_The following email address is not valid: {emails}_::_The following email addresses are not valid: {emails}_" : ["Дараах имэйл хаяг буруу байна: {emails}","Дараах имэйл хаягууд буруу байна: {emails}"],
    "_{count} email address already added_::_{count} email addresses already added_" : ["{count} имэйл хаяг аль хэдийн нэмэгдсэн","{count} имэйл хаяг аль хэдийн нэмэгдсэн"],
    "_{count} email address added_::_{count} email addresses added_" : ["{count} имэйл хаяг нэмэгдлээ","{count} имэйл хаяг нэмэгдлээ"],
    "You can now share the link below to allow people to upload files to your directory." : "Та доорх холбоосыг хуваалцаж бусад хүмүүст таны санд файл байршуулах боломж олгож болно.",
    "Share link" : "Холбоос хуваалцах",
    "Copy" : "хуулах",
    "Send link via email" : "Холбоосыг имэйлээр илгээх",
    "Enter an email address or paste a list" : "Имэйл хаяг оруулах эсвэл жагсаалт буулгах",
    "Remove email" : "Имэйл устгах",
    "Select a destination" : "Очих газар сонгох",
    "Select" : "Сонгох",
    "What are you requesting?" : "Та юу хүсэж байна вэ?",
    "Request subject" : "Хүсэлтийн гарчиг",
    "Birthday party photos, History assignment…" : "Төрсөн өдрийн зургууд, Түүхийн даалгавар…",
    "Where should these files go?" : "Эдгээр файлууд хаашаа явах вэ?",
    "Upload destination" : "Байршуулах очих газар",
    "Revert to default" : "Анхны утга руу буцах",
    "The uploaded files are visible only to you unless you choose to share them." : "Байршуулагдсан файлууд зөвхөн танд харагдах бөгөөд та хуваалцахаар сонгоогүй бол бусдад харагдахгүй.",
    "Add a note" : "Тэмдэглэл нэмэх",
    "Note for recipient" : "Хүлээн авагчид тэмдэглэл",
    "Add a note to help people understand what you are requesting." : "Таны хүсэлтийг ойлгоход туслах тэмдэглэл нэмнэ үү.",
    "You can add links, date or any other information that will help the recipient understand what you are requesting." : "Та хүлээн авагч таны хүсэлтийг ойлгоход туслах холбоос, огноо эсвэл бусад мэдээллийг нэмж болно.",
    "Close" : "–•–∞–∞—Ö",
    "_Send email and close_::_Send {count} emails and close_" : ["Имэйл илгээж хаах","{count} имэйл илгээж хаах"],
    "Please select a folder, you cannot share the root directory." : "Хавтас сонгоно уу, үндсэн директорыг хуваалцах боломжгүй.",
    "File request created" : "Файлын хүсэлт үүсгэгдсэн",
    "_File request created and email sent_::_File request created and {count} emails sent_" : ["Файлын хүсэлт үүсгэж имэйл илгээгдлээ","Файлын хүсэлт үүсгэж {count} имэйл илгээгдлээ"],
    "Error creating the share: {errorMessage}" : "Хуваалцалт үүсгэхэд алдаа гарлаа: {errorMessage}",
    "Error creating the share" : "Хуваалцалт үүсгэхэд алдаа гарлаа",
    "Error sending emails: {errorMessage}" : "Имэйл илгээхэд алдаа гарлаа: {errorMessage}",
    "Error sending emails" : "Имэйл илгээхэд алдаа гарлаа",
    "Create a file request" : "Файлын хүсэлт үүсгэх",
    "Collect files from others even if they do not have an account." : "Хаяггүй хүмүүсээс ч гэсэн файл цуглуулах.",
    "To ensure you can receive files, verify you have enough storage available." : "Файл хүлээн авах боломжтой эсэхийг баталгаажуулахын тулд хангалттай хадгалах зай байгаа эсэхийг шалгана уу.",
    "File request" : "Файлын хүсэлт",
    "Previous step" : "Өмнөх алхам",
    "Cancel" : "болиулах",
    "Cancel the file request creation" : "Файлын хүсэлт үүсгэхийг цуцлах",
    "Close without sending emails" : "Имэйл илгээхгүйгээр хаах",
    "Continue" : "үргэлжлүүлэх",
    "Error while toggling options" : "Сонголтуудыг солиход алдаа гарлаа",
    "Accept shares from other accounts and groups by default" : "Бусад хаяг болон бүлгүүдээс ирсэн хуваалцалтыг анхдагчаар зөвшөөрөх",
    "Choose a default folder for accepted shares" : "Зөвшөөрсөн хуваалцалтын анхдагч хавтас сонгох",
    "Invalid path selected" : "Буруу зам сонгосон",
    "Unknown error" : "үл мэдэгдэх алдаа",
    "Set default folder for accepted shares" : "Зөвшөөрсөн хуваалцалтын анхдагч хавтас тохируулах",
    "Reset" : "тохируулах",
    "Reset folder to system default" : "Хавтасыг системийн анхдагч руу буцаах",
    "Share expiration: {date}" : "Хуваалцалтын дуусах: {date}",
    "Share Expiration" : "Хуваалцалтын дуусах хугацаа",
    "group" : "бүлэг",
    "conversation" : "харилцан яриа",
    "remote" : "алсын",
    "remote group" : "алсын бүлэг",
    "guest" : "зочин",
    "by {initiator}" : "{initiator}-р",
    "Shared with the group {user} by {owner}" : "{owner}-р {user} бүлэгт хуваалцсан",
    "Shared with the conversation {user} by {owner}" : "{owner}-р {user} харилцан яриад хуваалцсан",
    "Shared with {user} by {owner}" : "{owner}-р {user}-т хуваалцсан",
    "Open Sharing Details" : "Хуваалцалтын дэлгэрэнгүй нээх",
    "Added by {initiator}" : "{initiator}-р нэмэгдсэн",
    "Via “{folder}”" : "\"{folder}\"-аар",
    "Unshare" : "Түгээлтийг зогсоох",
    "Cannot copy, please copy the link manually" : "Хуулах боломжгүй, холбоосыг гараар хуулна уу",
    "Copy internal link" : "Дотоод холбоос хуулах",
    "For people who already have access" : "Аль хэдийн хандах эрхтэй хүмүүст",
    "Internal link" : "Дотоод холбоос",
    "{shareWith} by {initiator}" : "{initiator}-р {shareWith}",
    "Shared via link by {initiator}" : "{initiator}-р холбоосоор хуваалцсан",
    "File request ({label})" : "Файлын хүсэлт ({label})",
    "Mail share ({label})" : "Имэйл хуваалцалт ({label})",
    "Share link ({label})" : "Холбоос хуваалцах ({label})",
    "Mail share" : "Имэйл хуваалцалт",
    "Share link ({index})" : "Холбоос хуваалцах ({index})",
    "Create public link" : "Нийтийн холбоос үүсгэх",
    "Actions for \"{title}\"" : "\"{title}\"-д зориулсан үйлдлүүд",
    "Copy public link of \"{title}\"" : "\"{title}\"-н нийтийн холбоосыг хуулах",
    "Error, please enter proper password and/or expiration date" : "Алдаа, зөв нууц үг болон/эсвэл дуусах огноо оруулна уу",
    "Link share created" : "Холбоосын хуваалцалт үүсгэгдсэн",
    "Error while creating the share" : "Хуваалцалт үүсгэхэд алдаа гарлаа",
    "Your browser does not support copying, please copy the link manually:" : "Таны хөтөч хуулахыг дэмжихгүй байна, холбоосыг гараар хуулна уу:",
    "Successfully copied public link" : "Нийтийн холбоосыг амжилттай хуулсан",
    "Please enter the following required information before creating the share" : "Хуваалцахыг үүсгэхээс өмнө дараах шаардлагатай мэдээллийг оруулна уу",
    "Password protection (enforced)" : "Нууц үгийн хамгаалалт (шаардлагатай)",
    "Password protection" : "Password protection",
    "Enter a password" : "Enter a password",
    "Enable link expiration (enforced)" : "Холбоосын хугацаа дуусгаврыг идэвхжүүлэх (шаардлагатай)",
    "Enable link expiration" : "Холбоосын хугацаа дуусгаврыг идэвхжүүлэх",
    "Enter expiration date (enforced)" : "Дуусах огноо оруулах (шаардлагатай)",
    "Enter expiration date" : "Дуусах огноо оруулах",
    "Create share" : "Хуваалцалт үүсгэх",
    "Customize link" : "Холбоосыг тохируулах",
    "Generate QR code" : "QR код үүсгэх",
    "Add another link" : "Өөр холбоос нэмэх",
    "Create a new share link" : "Шинэ хуваалцах холбоос үүсгэх",
    "Quick share options, the current selected is \"{selectedOption}\"" : "Түргэн хуваалцах сонголтууд, одоогийн сонголт \"{selectedOption}\"",
    "View only" : "Зөвхөн үзэх",
    "Can edit" : "Засах боломжтой",
    "Custom permissions" : "Тусгай эрхүүд",
    "Resharing is not allowed" : "Дахин хуваалцах зөвшөөрөгдөөгүй",
    "Name or email …" : "Нэр эсвэл имэйл …",
    "Name, email, or Federated Cloud ID …" : "Нэр, имэйл, эсвэл Federated Cloud ID …",
    "Searching …" : "Хайж байна …",
    "No elements found." : "Элемент олдсонгүй.",
    "Search everywhere" : "Хаа сайгүй хайх",
    "Guest" : "Зочин",
    "Group" : "Бүлэг",
    "Email" : "Цахим шуудан",
    "Team" : "Баг",
    "Talk conversation" : "Talk яриа",
    "Deck board" : "Deck самбар",
    "ScienceMesh" : "ScienceMesh",
    "on {server}" : "{server} дээр",
    "Enter external recipients" : "Гадаад хүлээн авагчдыг оруулах",
    "Search for internal recipients" : "Дотоод хүлээн авагчдыг хайх",
    "Note from" : "-с тэмдэглэл",
    "Note:" : "Тэмдэглэл:",
    "File drop" : "Файл буулгах",
    "Upload files to {foldername}." : "{foldername}-д файл байршуулах.",
    "By uploading files, you agree to the terms of service." : "Файл байршуулснаар та үйлчилгээний нөхцөлийг зөвшөөрч байна.",
    "Successfully uploaded files" : "Файлууд амжилттай байршуулагдсан",
    "View terms of service" : "Үйлчилгээний нөхцөл харах",
    "Terms of service" : "Үйлчилгээний нөхцөл",
    "Share with {user}" : "{user}-т хуваалцах",
    "Share with email {email}" : "{email} имэйлтэй хуваалцах",
    "Share with group" : "Бүлэгтэй хуваалцах",
    "Share in conversation" : "Харилцан яриад хуваалцах",
    "Share with {user} on remote server {server}" : "{server} алсын сервер дээрх {user}-т хуваалцах",
    "Share with remote group" : "Алсын бүлэгтэй хуваалцах",
    "Share with guest" : "Зочинтой хуваалцах",
    "Update share" : "Хуваалцалтыг шинэчлэх",
    "Save share" : "Хуваалцалтыг хадгалах",
    "Read" : "Уншсан",
    "Create" : "үүсгэх",
    "Edit" : "засварлах",
    "Share" : " Хуваалцах",
    "Delete" : "Устгах",
    "Password field cannot be empty" : "Нууц үгийн талбар хоосон байж болохгүй",
    "Replace current password" : "Одоогийн нууц үгийг солих",
    "Failed to generate a new token" : "Шинэ токен үүсгэж чадсангүй",
    "Allow upload and editing" : "Байршуулж, засварлахыг зөвшөөрөх",
    "Allow editing" : "Засварлахыг зөвшөөрөх",
    "Upload only" : "Зөвхөн байршуулах",
    "Advanced settings" : "Нарийвчилсан тохиргоо",
    "Share label" : "Хуваалцах шошго",
    "Share link token" : "Хуваалцах холбоосын токен",
    "Set the public share link token to something easy to remember or generate a new token. It is not recommended to use a guessable token for shares which contain sensitive information." : "Нийтийн хуваалцах холбоосын токеныг санахад хялбар зүйл болгож тохируулна уу эсвэл шинэ токен үүсгэнэ үү. Нууц мэдээлэл агуулсан хуваалцалтад таахад хялбар токен ашиглахыг зөвлөдөггүй.",
    "Generating…" : "Үүсгэж байна…",
    "Generate new token" : "Шинэ токен үүсгэх",
    "Set password" : "Нууц үг тохируулах",
    "Password expires {passwordExpirationTime}" : "Нууц үгийн хугацаа дуусна {passwordExpirationTime}",
    "Password expired" : "Нууц үгийн хугацаа дууссан",
    "Video verification" : "Видео баталгаажуулалт",
    "Expiration date (enforced)" : "Дуусах огноо (шаардлагатай)",
    "Set expiration date" : "Дуусах хугацааг тохируулах",
    "Hide download" : "Татаж авахыг нуух",
    "Allow download and sync" : "Татах болон синхрончлохыг зөвшөөрөх",
    "Note to recipient" : "Хүлээн авагчид тэмдэглэл",
    "Enter a note for the share recipient" : "Хуваалцалтын хүлээн авагчид тэмдэглэл оруулах",
    "Show files in grid view" : "Файлуудыг торон харагдацаар харуулах",
    "Delete share" : "Хуваалцалт устгах",
    "Others with access" : "Хандах эрхтэй бусад",
    "No other accounts with access found" : "Хандах эрхтэй өөр хаяг олдсонгүй",
    "Toggle list of others with access to this directory" : "Энэ директорт хандах эрхтэй бусдын жагсаалтыг харуулах/нуух",
    "Toggle list of others with access to this file" : "Энэ файлд хандах эрхтэй бусдын жагсаалтыг харуулах/нуух",
    "Unable to fetch inherited shares" : "Удамшсан хуваалцалтуудыг авч чадсангүй",
    "Link shares" : "Холбоосын хуваалцалтууд",
    "Shares" : "Түгээлтүүд",
    "Share files within your organization. Recipients who can already view the file can also use this link for easy access." : "Байгууллагынхаа дотор файл хуваалцаарай. Файлыг аль хэдийн үзэж чадах хүлээн авагчид энэ холбоосыг хялбар хандалтад ашиглаж болно.",
    "Share files with others outside your organization via public links and email addresses. You can also share to {productName} accounts on other instances using their federated cloud ID." : "Нийтийн холбоос болон и-мэйл хаягаар дамжуулан байгууллагынхаа гадуурх хүмүүстэй файл хуваалцаарай. Мөн бусад серверт байгаа {productName} бүртгэлүүдтэй тэдний federated cloud ID-г ашиглан хуваалцаж болно.",
    "Shares from apps or other sources which are not included in internal or external shares." : "Дотоод болон гадаад хуваалцалтад ороогүй апп эсвэл бусад эх сурвалжаас хийсэн хуваалцалтууд.",
    "Type names, teams, federated cloud IDs" : "Нэр, баг, холбогдсон үүл ID бичнэ үү",
    "Type names or teams" : "Нэр эсвэл баг бичнэ үү",
    "Type a federated cloud ID" : "Холбогдсон үүл ID бичнэ үү",
    "Type an email" : "Имэйл бичнэ үү",
    "Type an email or federated cloud ID" : "Имэйл эсвэл холбогдсон үүл ID бичнэ үү",
    "Unable to load the shares list" : "Хуваалцалтын жагсаалтыг ачаалж чадсангүй",
    "Expires {relativetime}" : "{relativetime}-д дуусна",
    "this share just expired." : "энэ хуваалцалтын хугацаа саяхан дууссан.",
    "Shared with you by {owner}" : "{owner}-р танд хуваалцсан",
    "Internal shares" : "Дотоод хуваалцалтууд",
    "Internal shares explanation" : "Дотоод хуваалцалтын тайлбар",
    "External shares" : "Гадаад хуваалцалтууд",
    "External shares explanation" : "Гадаад хуваалцалтын тайлбар",
    "Additional shares" : "Нэмэлт хуваалцалтууд",
    "Additional shares explanation" : "Нэмэлт хуваалцалтын тайлбар",
    "Link to a file" : "Файл руу холбоос",
    "_Accept share_::_Accept shares_" : ["Хуваалцалтыг зөвшөөрөх","Хуваалцалтуудыг зөвшөөрөх"],
    "Open in Files" : "Файлуудад нээх",
    "_Reject share_::_Reject shares_" : ["Хуваалцалтыг татгалзах","Хуваалцалтуудыг татгалзах"],
    "_Restore share_::_Restore shares_" : ["Хуваалцалт сэргээх","Хуваалцалт сэргээх"],
    "Shared" : "Түгээсэн",
    "Shared by {ownerDisplayName}" : "{ownerDisplayName}-р хуваалцсан",
    "Shared multiple times with different people" : "Өөр өөр хүмүүстэй олон удаа хуваалцсан",
    "Sharing options" : "Хуваалцах сонголтууд",
    "Shared with others" : "Бусдад түгээсэн",
    "You do not have enough permissions to share this file." : "Танд энэ файлыг хуваалцах хангалттай эрх байхгүй байна.",
    "People" : "Хүмүүс",
    "Create file request" : "Файлын хүсэлт үүсгэх",
    "Upload files to {foldername}" : "{foldername}-д файл байршуулах",
    "Public file share" : "Нийтийн файл хуваалцалт",
    "Publicly shared file." : "Нийтэд хуваалцсан файл.",
    "No file" : "Файл байхгүй",
    "The file shared with you will show up here" : "Танд хуваалцсан файл энд харагдана",
    "Public share" : "Нийтийн хуваалцалт",
    "Publicly shared files." : "Нийтэд хуваалцсан файлууд.",
    "No files" : "Файл байхгүй",
    "Files and folders shared with you will show up here" : "Танд хуваалцсан файл, хавтаснууд энд харагдана",
    "Overview of shared files." : "Хуваалцсан файлуудын тойм.",
    "No shares" : "Хуваалцалт байхгүй",
    "Files and folders you shared or have been shared with you will show up here" : "Та хуваалцсан эсвэл тантай хуваалцсан файл, хавтаснууд энд харагдана",
    "Shared with you" : "тантай хуваалцсан",
    "List of files that are shared with you." : "Танд хуваалцсан файлуудын жагсаалт.",
    "Nothing shared with you yet" : "Тантай түгээсэн зүйл алга",
    "Files and folders others shared with you will show up here" : "Бусдын танд хуваалцсан файл, хавтаснууд энд харагдана",
    "List of files that you shared with others." : "Таны бусадтай хуваалцсан файлуудын жагсаалт.",
    "Nothing shared yet" : "Түгээсэн зүйл алга",
    "Files and folders you shared will show up here" : "Таны хуваалцсан файл, хавтаснууд энд харагдана",
    "Shared by link" : "Холбоосоор түгээсэн",
    "List of files that are shared by link." : "Холбоосоор хуваалцсан файлуудын жагсаалт.",
    "No shared links" : "Түгээсэн холбоос алга",
    "Files and folders you shared by link will show up here" : "Таны холбоосоор хуваалцсан файл, хавтаснууд энд харагдана",
    "File requests" : "Файлын хүсэлтүүд",
    "List of file requests." : "Файлын хүсэлтүүдийн жагсаалт.",
    "No file requests" : "Файлын хүсэлт байхгүй",
    "File requests you have created will show up here" : "Таны үүсгэсэн файлын хүсэлтүүд энд харагдана",
    "Deleted shares" : "Устгасан хуваалцалтууд",
    "List of shares you left." : "Таны орхисон хуваалцалтуудын жагсаалт.",
    "No deleted shares" : "Устгасан хуваалцалт байхгүй",
    "Shares you have left will show up here" : "Таны орхисон хуваалцалтууд энд харагдана",
    "Pending shares" : "Хүлээгдэж буй хуваалцалтууд",
    "List of unapproved shares." : "Зөвшөөрөгдөөгүй хуваалцалтуудын жагсаалт.",
    "No pending shares" : "Хүлээгдэж буй хуваалцалт байхгүй",
    "Shares you have received but not approved will show up here" : "Таны хүлээн авсан боловч зөвшөөрөөгүй хуваалцалтууд энд харагдана",
    "Error deleting the share" : "Хуваалцалт устгахад алдаа гарлаа",
    "Error updating the share" : "Хуваалцалт шинэчлэхэд алдаа гарлаа",
    "File \"{path}\" has been unshared" : "\"{path}\" файлын хуваалцалт цуцлагдсан",
    "Folder \"{path}\" has been unshared" : "\"{path}\" хавтасны хуваалцалт цуцлагдсан",
    "Could not update share" : "Хуваалцалтыг шинэчлэж чадсангүй",
    "Share saved" : "Хуваалцалт хадгалагдсан",
    "Share expiry date saved" : "Хуваалцалтын дуусах огноо хадгалагдсан",
    "Share hide-download state saved" : "Хуваалцалтын татах-нуух төлөв хадгалагдсан",
    "Share label saved" : "Хуваалцалтын шошго хадгалагдсан",
    "Share note for recipient saved" : "Хүлээн авагчид зориулсан хуваалцалтын тэмдэглэл хадгалагдсан",
    "Share password saved" : "Хуваалцалтын нууц үг хадгалагдсан",
    "Share permissions saved" : "Хуваалцалтын эрхүүд хадгалагдсан",
    "To upload files to {folder}, you need to provide your name first." : "{folder}-д файл байршуулахын тулд эхлээд нэрээ оруулах шаардлагатай.",
    "Upload files to {folder}" : "{folder}-д файл байршуулах",
    "Please confirm your name to upload files to {folder}" : "{folder}-д файл байршуулахын тулд нэрээ баталгаажуулна уу",
    "{ownerDisplayName} shared a folder with you." : "{ownerDisplayName} танд хавтас хуваалцсан.",
    "Names must not be empty." : "Нэрс хоосон байж болохгүй.",
    "Names must not start with a dot." : "Нэрс цэгээр эхлэж болохгүй.",
    "\"{char}\" is not allowed inside a name." : "\"{char}\" нэрэнд ашиглахыг зөвшөөрөхгүй.",
    "\"{segment}\" is a reserved name and not allowed." : "\"{segment}\" нэр нөөцлөгдсөн тул зөвшөөрөгдөхгүй.",
    "\"{extension}\" is not an allowed name." : "\"{extension}\" нэр зөвшөөрөгдөхгүй.",
    "Names must not end with \"{extension}\"." : "Нэрс \"{extension}\"-р төгсөж болохгүй.",
    "Invalid name." : "Буруу нэр.",
    "Password created successfully" : "Нууц үг амжилттай үүсгэгдсэн",
    "Error generating password from password policy" : "Нууц үгийн бодлогоос нууц үг үүсгэхэд алдаа гарлаа",
    "Shared with you and the group {group} by {owner}" : "{owner}-р танд болон {group} бүлэгт хуваалцсан",
    "Shared with you and {circle} by {owner}" : "{owner}-р танд болон {circle}-т хуваалцсан",
    "Shared with you and the conversation {conversation} by {owner}" : "{owner}-р танд болон {conversation} харилцан яриад хуваалцсан",
    "Shared with you in a conversation by {owner}" : "{owner}-р танд харилцан яриагаар хуваалцсан",
    "Share not found" : "Хуваалцалт олдсонгүй",
    "Back to %s" : "%s руу буцах",
    "Add to your Nextcloud" : "Өөрийн Nextcloud-д нэмэх",
    "Group sharing is disabled by the administrator" : "Бүлгийн хуваалцалт админаар идэвхгүй болгогдсон",
    "Public link sharing is disabled by the administrator" : "Нийтийн холбоосын хуваалцалт админаар идэвхгүй болгогдсон",
    "Sharing %1$s failed because the back end does not allow shares from type %2$s" : "%1$s-г хуваалцах амжилтгүй боллоо, учир нь систем %2$s төрлийн хуваалцалтыг зөвшөөрдөггүй",
    "Sharing %s failed because the back end does not support ScienceMesh shares" : "%s-г хуваалцахад алдаа гарлаа, учир нь арын систем ScienceMesh хуваалцалтыг дэмждэггүй",
    "Public upload disabled by the administrator" : "Нийтийн байршуулалт админаар идэвхгүй болгогдсон",
    "Tokens must contain at least 1 character and may only contain letters, numbers, or a hyphen" : "Токен нь дор хаяж 1 тэмдэгт агуулсан байх бөгөөд зөвхөн үсэг, тоо эсвэл зураас агуулж болно",
    "Name or email …" : "Нэр эсвэл имэйл …",
    "Name, email, or Federated Cloud ID …" : "Нэр, имэйл эсвэл Холбогдсон Үүл ID …",
    "Searching …" : "Хайж байна …"
},
"nplurals=2; plural=(n != 1);");
