OC.L10N.register(
    "dav",
    {
    "Calendar" : "Calendario",
    "Tasks" : "Tareas",
    "Personal" : "Personal",
    "{actor} created calendar {calendar}" : "{actor} creó el calendario {calendar}",
    "You created calendar {calendar}" : "Usted creó el calendario {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} eliminó el calendario {calendar}",
    "You deleted calendar {calendar}" : "Usted eliminó el calendario {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} actualizó el calendario {calendar}",
    "You updated calendar {calendar}" : "Usted actualizó el calendario {calendar}",
    "{actor} restored calendar {calendar}" : "{actor} ha restaurado el calendario {calendar}",
    "You restored calendar {calendar}" : "Ud. ha restaurado el calendario {calendar}",
    "You shared calendar {calendar} as public link" : "Has compartido el calendario {calendar} con un enlace público",
    "You removed public link for calendar {calendar}" : "Has eliminado el enlace público al calendario {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} compartió el calendario {calendar} con usted",
    "You shared calendar {calendar} with {user}" : "Usted compartió el calendario {calendar} con {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} compartió el calendario {calendar} con {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} dejó de compartir el calendario {calendar} con usted",
    "You unshared calendar {calendar} from {user}" : "Usted dejó de compartir el calendario {calendar} de {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} dejó de compartir el calendario {calendar} del usuario{user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} dejó de compartir su propio calendario {calendar}",
    "You shared calendar {calendar} with group {group}" : "Usted compartió el calendario {calendar} con el grupo {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} compartió el calendario {calendar} con el grupo {group}",
    "You unshared calendar {calendar} from group {group}" : "Usted dejó de compartir el calendario {calendar} del grupo {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} dejó de compartir el calendario {calendar} del grupo {group}",
    "Untitled event" : "Evento sin título",
    "{actor} created event {event} in calendar {calendar}" : "{actor} creó el evento {event} en el calendario {calendar}",
    "You created event {event} in calendar {calendar}" : "Usted creó el evento {event} en el calendario {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} eliminó el evento {event} del calendario {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Usted eliminó el evento {event} del calendario {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} actualizó el evento {event} en el calendario {calendar}",
    "You updated event {event} in calendar {calendar}" : "Usted actualizó el evento {event} en el calendario {calendar}",
    "{actor} moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "{actor} ha movido el evento {event} del calendario {sourceCalendar} al calendario {targetCalendar}",
    "You moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "Ud. ha movido el evento {event} del calendario {sourceCalendar} al calendario {targetCalendar}",
    "{actor} restored event {event} of calendar {calendar}" : "{actor} ha restaurado el evento {event} del calendario {calendar}",
    "You restored event {event} of calendar {calendar}" : "Ud. ha restaurado el evento {event} del calendario {calendar}",
    "Busy" : "Ocupado",
    "{actor} created to-do {todo} in list {calendar}" : "{actor} ha creado la tarea {todo} en la lista {calendar}",
    "You created to-do {todo} in list {calendar}" : "Ud. ha creado la tarea {todo} en la lista {calendar}",
    "{actor} deleted to-do {todo} from list {calendar}" : "{actor} ha eliminado la tarea{todo} de la lista {calendar}",
    "You deleted to-do {todo} from list {calendar}" : "Ud. ha eliminado la tarea {todo} de la lista {calendar}",
    "{actor} updated to-do {todo} in list {calendar}" : "{actor} ha actualizado la tarea {todo} en la lista {calendar}",
    "You updated to-do {todo} in list {calendar}" : "Ud. ha actualizado la tarea {todo} en la lista {calendar}",
    "{actor} solved to-do {todo} in list {calendar}" : "{actor} ha resuelto la tarea {todo} de la lista {calendar}",
    "You solved to-do {todo} in list {calendar}" : "Ud. ha resuelto la tarea {todo} de la lista {calendar}",
    "{actor} reopened to-do {todo} in list {calendar}" : "{actor} ha reabierto la tarea {todo} en la lista {calendar}",
    "You reopened to-do {todo} in list {calendar}" : "Ud. ha reabierto la tarea {todo} en la lista {calendar}",
    "{actor} moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "{actor} ha movido la tarea {todo} de la lista {sourceCalendar} a la lista{targetCalendar}",
    "You moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "Ud. ha movido la tarea {todo} de la lista {sourceCalendar} a la lista {targetCalendar}",
    "Calendar, contacts and tasks" : "Calendario, contactos y tareas",
    "A <strong>calendar</strong> was modified" : "Un <strong>calendario</strong> fue modificado.",
    "A calendar <strong>event</strong> was modified" : "Un <strong>evento</strong> del calendario fue modificado.",
    "A calendar <strong>to-do</strong> was modified" : "Se ha modificado una <strong>tarea</strong> de calendario",
    "Contact birthdays" : "Cumpleaños del contacto",
    "Death of %s" : "Muerte de %s",
    "Accept" : "Aceptar",
    "Decline" : "Rechazar",
    "Untitled calendar" : "Calendario sin título",
    "Calendar:" : "Calendario:",
    "Date:" : "Fecha:",
    "Where:" : "Dónde:",
    "Description:" : "Descripción:",
    "_%n year_::_%n years_" : ["%n año","%n años","%n años"],
    "_%n month_::_%n months_" : ["%n mes","%n meses","%n meses"],
    "_%n day_::_%n days_" : ["%n día","%n días","%n días"],
    "_%n hour_::_%n hours_" : ["%n hora","%n horas","%n horas"],
    "_%n minute_::_%n minutes_" : ["%n minuto","%n minutos","%n minutos"],
    "%s (in %s)" : "%s (en %s)",
    "%s (%s ago)" : "%s (hace %s)",
    "Calendar: %s" : "Calendario: %s",
    "Date: %s" : "Fecha: %s",
    "Description: %s" : "Descripción: %s",
    "Where: %s" : "Lugar: %s",
    "%1$s via %2$s" : "%1$s vía %2$s",
    "In the past on %1$s for the entire day" : "En el pasado el %1$s durante todo el día",
    "In the past on %1$s between %2$s - %3$s" : "En el pasado el %1$s entre %2$s - %3$s",
    "Could not generate when statement" : "No se pudo generar la declaración de cuándo",
    "Every Day for the entire day" : "Todos los días, durante todo el día",
    "Every Day for the entire day until %1$s" : "Cada día, todo el día hasta el %1$s",
    "Every Day between %1$s - %2$s" : "Todos los días entre %1$s - %2$s",
    "Every Day between %1$s - %2$s until %3$s" : "Todos los días entre %1$s - %2$s hasta %3$s",
    "Every %1$d Days for the entire day" : "Cada %1$d días, durante todo el día",
    "Every %1$d Days for the entire day until %2$s" : "Cada %1$d días, durante todo el día, hasta el %2$s",
    "Every %1$d Days between %2$s - %3$s" : "Cada %1$d días, entre las %2$s y %3$s",
    "Every %1$d Days between %2$s - %3$s until %4$s" : "Cada %1$d días, entre las %2$s y %3$s hasta el %4$s",
    "Could not generate event recurrence statement" : "No se ha podido generar la declaración de recurrencia del evento",
    "Every Week on %1$s for the entire day" : "Cada semana el %1$s, durante todo el día",
    "Every Week on %1$s for the entire day until %2$s" : "Cada %1$s días, durante todo el día, hasta el %2$s",
    "Every Week on %1$s between %2$s - %3$s" : "Cada semana el %1$s entre %2$s y %3$s",
    "Every Week on %1$s between %2$s - %3$s until %4$s" : "Cada semana el %1$s entre %2$s y %3$s hasta el %4$s",
    "Every %1$d Weeks on %2$s for the entire day" : "Cada %1$d semanas el %2$s todo el día",
    "Every %1$d Weeks on %2$s for the entire day until %3$s" : "Cada %1$d semanas el %2$s durante todo el día hasta %3$s",
    "Every %1$d Weeks on %2$s between %3$s - %4$s" : "Cada %1$d semanas el %2$s entre %3$s - %4$s",
    "Every %1$d Weeks on %2$s between %3$s - %4$s until %5$s" : "Cada %1$d semanas el %2$s entre %3$s - %4$s hasta %5$s",
    "Every Month on the %1$s for the entire day" : "Cada mes el día %1$s, durante todo el día",
    "Every Month on the %1$s for the entire day until %2$s" : "Cada mes el día %1$s durante todo el día hasta %2$s",
    "Every Month on the %1$s between %2$s - %3$s" : "Cada mes el día %1$s entre %2$s - %3$s",
    "Every Month on the %1$s between %2$s - %3$s until %4$s" : "Cada mes el día %1$s entre %2$s - %3$s hasta %4$s",
    "Every %1$d Months on the %2$s for the entire day" : "Cada %1$d meses el día %2$s, durante todo el día",
    "Every %1$d Months on the %2$s for the entire day until %3$s" : "Cada %1$d meses el día %2$s, durante todo el día hasta %3$s",
    "Every %1$d Months on the %2$s between %3$s - %4$s" : "Cada %1$d meses el día %2$s entre %3$s - %4$s",
    "Every %1$d Months on the %2$s between %3$s - %4$s until %5$s" : "Cada %1$d meses el día %2$s entre %3$s - %4$s hasta %5$s",
    "Every Year in %1$s on the %2$s for the entire day" : "Cada año en %1$s el día %2$s, durante todo el día",
    "Every Year in %1$s on the %2$s for the entire day until %3$s" : "Cada año en %1$s el día %2$s, durante todo el día, hasta %3$s",
    "Every Year in %1$s on the %2$s between %3$s - %4$s" : "Cada año en %1$s el día %2$s entre %3$s - %4$s.",
    "Every Year in %1$s on the %2$s between %3$s - %4$s until %5$s" : "Cada año en %1$s el día %2$s entre %3$s - %4$s hasta %5$s",
    "Every %1$d Years in %2$s on the %3$s for the entire day" : "Cada %1$d años en %2$s el día %3$s, durante todo el día",
    "Every %1$d Years in %2$s on the %3$s for the entire day until %4$s" : "Cada %1$d años en %2$s el día %3$s, durante todo el día, hasta %4$s",
    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s" : "Cada %1$d años en %2$s el día %3$s entre %4$s - %5$s",
    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s until %6$s" : "Cada %1$d años en %2$s el día %3$s entre %4$s - %5$s hasta %6$s",
    "On specific dates for the entire day until %1$s" : "En fechas específicas, durante todo el día, hasta %1$s",
    "On specific dates between %1$s - %2$s until %3$s" : "En fechas específicas entre %1$s - %2$s hasta %3$s",
    "In the past on %1$s" : "En el pasado el %1$s",
    "In the past on %1$s then on %2$s" : "En el pasado el %1$s y luego el %2$s",
    "In the past on %1$s then on %2$s and %3$s" : "En el pasado el %1$s, luego el %2$s y %3$s",
    "Could not generate next recurrence statement" : "No se ha podido generar la declaración de la siguiente recurrencia",
    "Cancelled: %1$s" : "Cancelado: %1$s",
    "\"%1$s\" has been canceled" : "\"%1$s\" ha sido cancelada",
    "Re: %1$s" : "Re: %1$s",
    "%1$s has accepted your invitation" : "%1$s ha aceptado su invitación",
    "%1$s has tentatively accepted your invitation" : "%1$s ha aceptado su invitación de forma tentativa",
    "%1$s has declined your invitation" : "%1$s ha rechazado su invitación",
    "%1$s has responded to your invitation" : "%1$s ha respondido a su invitación",
    "Invitation updated: %1$s" : "Invitación actualizada: %1$s",
    "%1$s updated the event \"%2$s\"" : "%1$s actualizó el evento \"%2$s\"",
    "Invitation: %1$s" : "Invitación: %1$s",
    "%1$s would like to invite you to \"%2$s\"" : "%1$s desea invitarle a \"%2$s\"",
    "Organizer:" : "Organizador:",
    "Attendees:" : "Asistentes:",
    "Title:" : "Título:",
    "When:" : "Cuándo:",
    "Location:" : "Ubicación:",
    "Link:" : "Enlace:",
    "Occurring:" : "Repetición:",
    "More options …" : "Más opciones...",
    "More options at %s" : "Más opciones en %s",
    "Monday" : "Lunes",
    "Tuesday" : "Martes",
    "Wednesday" : "Miércoles",
    "Thursday" : "Jueves",
    "Friday" : "Viernes",
    "Saturday" : "Sábado",
    "Sunday" : "Domingo",
    "January" : "Enero",
    "February" : "Febrero",
    "March" : "Marzo",
    "April" : "Abril",
    "May" : "Mayo",
    "June" : "Junio",
    "July" : "Julio",
    "August" : "Agosto",
    "September" : "Septiembre",
    "October" : "Octubre",
    "November" : "Noviembre",
    "December" : "Diciembre",
    "First" : "Primero",
    "Second" : "Segundo",
    "Third" : "Tercero",
    "Fourth" : "Cuarto",
    "Fifth" : "Quinto",
    "Last" : "Último",
    "Second Last" : "Penúltima",
    "Third Last" : "Antepenúltima",
    "Fourth Last" : "Ante antepenúltimo",
    "Fifth Last" : "Quinto último",
    "Contacts" : "Contactos",
    "{actor} created address book {addressbook}" : "{actor} ha creado la libreta de direcciones {addressbook}",
    "You created address book {addressbook}" : "Ud. ha creado la libreta de direcciones {addressbook}",
    "{actor} deleted address book {addressbook}" : "{actor} ha eliminado la libreta de direcciones {addressbook}",
    "You deleted address book {addressbook}" : "Ud. ha eliminado la libreta de direcciones {addressbook}",
    "{actor} updated address book {addressbook}" : "{actor} ha actualizado la libreta de direcciones {addressbook}",
    "You updated address book {addressbook}" : "Ud. ha actualizado la libreta de direcciones {addressbook}",
    "{actor} shared address book {addressbook} with you" : "{actor} ha compartido la libreta de direcciones {addressbook} contigo",
    "You shared address book {addressbook} with {user}" : "Ud. ha compartido la libreta de direcciones {addressbook} con {user}",
    "{actor} shared address book {addressbook} with {user}" : "{actor} ha compartido la libreta de direcciones {addressbook} con {user}",
    "{actor} unshared address book {addressbook} from you" : "{actor} ha dejado de compartir la libreta de direcciones {addressbook} con Ud.",
    "You unshared address book {addressbook} from {user}" : "Ud. ha dejado de compartir la libreta de direcciones {addressbook} con {user}",
    "{actor} unshared address book {addressbook} from {user}" : "{actor} ha dejado de compartir la libreta de direcciones {addressbook} con {user}",
    "{actor} unshared address book {addressbook} from themselves" : "{actor} dejó de compartir su propia libreta de direcciones {addressbook}",
    "You shared address book {addressbook} with group {group}" : "Ud. ha compartido la libreta de direcciones  {addressbook} con el grupo {group}",
    "{actor} shared address book {addressbook} with group {group}" : "{actor} ha compartido la libreta de direcciones {addressbook} con el grupo {group}",
    "You unshared address book {addressbook} from group {group}" : "Ud. ha dejado de compartir la libreta de direcciones {addressbook} con el grupo {group}",
    "{actor} unshared address book {addressbook} from group {group}" : "{actor} ha dejado de compartir la libreta de direcciones {addressbook} con el grupo {group}",
    "{actor} created contact {card} in address book {addressbook}" : "{actor} ha creado el contacto {card} en la libreta de direcciones {addressbook}",
    "You created contact {card} in address book {addressbook}" : "Ud. ha creado un contacto {card} en la libreta de direcciones {addressbook}",
    "{actor} deleted contact {card} from address book {addressbook}" : "{actor} ha eliminado el contacto {card} de la libreta de direcciones {addressbook}",
    "You deleted contact {card} from address book {addressbook}" : "Ud. ha eliminado el contacto {card} de la libreta de direcciones {addressbook}",
    "{actor} updated contact {card} in address book {addressbook}" : "{actor} ha actualizado el contacto {card} en la libreta de direcciones {addressbook}",
    "You updated contact {card} in address book {addressbook}" : "Ud. ha actualizado el contacto {card} en la libreta de direcciones {addressbook}",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "Se ha modificado un <strong>contacto</strong> o una <strong>libreta de direcciones</strong>",
    "System address book disabled" : "Libreta de direcciones del sistema deshabilitada",
    "The system contacts address book has been automatically disabled during upgrade. This means that the address book will no longer be available to users in the contacts app or other clients. The system contacts address book was disabled because the amount of contacts in the address book exceeded the maximum recommended number of contacts. This limit is set to prevent performance issues. You can re-enable the system address book with the following command {command}" : "La libreta de direcciones del sistema ha sido automáticamente deshabilitada durante la actualización. Esto significa que la libreta de direcciones no estará disponible para los usuarios en la app de Contactos u otros clientes. La libreta de direcciones del sistema fue deshabilitada por que el número de contactos excedió el número máximo recomendado de contactos. Este límite se establece para evitar problemas de rendimiento. Puede volver a habilitar la libreta de direcciones del sistema con el siguiente comando {command}",
    "Accounts" : "Cuentas",
    "System address book which holds all accounts" : "Libreta de direcciones del sistema que contiene todas las cuentas",
    "File is not updatable: %1$s" : "El archivo no se puede actualizar: %1$s",
    "Failed to get storage for file" : "Error al obtener datos de almacenamiento para el archivo",
    "Could not write to final file, canceled by hook" : "No se pudo escribir en el archivo final, cancelado por el sistema",
    "Could not write file contents" : "No se han podido escribir los contenidos del archivo",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes","%n bytes"],
    "Error while copying file to target location (copied: %1$s, expected filesize: %2$s)" : "Error al copiar el archivo al destino (copiado: %1$s, tamaño esperado: %2$s)",
    "Expected filesize of %1$s but read (from Nextcloud client) and wrote (to Nextcloud storage) %2$s. Could either be a network problem on the sending side or a problem writing to the storage on the server side." : "Se esperaba un tamaño de archivo de %1$s pero se leyó (desde el cliente Nextcloud) y se escribió (en el almacenamiento Nextcloud) %2$s. Podría ser un problema de red en el lado del envío o un problema de escritura en el almacenamiento en el lado del servidor.",
    "Could not rename part file to final file, canceled by hook" : "No se pudo renombrar del archivo parcial como el archivo final, cancelado por el sistema.",
    "Could not rename part file to final file" : "No se ha podido renombrar el archivo parcial como el archivo final",
    "Failed to check file size: %1$s" : "Fallo al comprobar el tamaño del archivo: %1$s",
    "Failed to get size for : %1$s" : "No se pudo obtener el tamaño para: %1$s",
    "Encryption not ready: %1$s" : "El cifrado no está listo: %1$s",
    "Failed to open file: %1$s" : "Fallo al abrir el archivo: %1$s",
    "Failed to unlink: %1$s" : "Fallo al desenlazar: %1$s",
    "Failed to write file contents: %1$s" : "Fallo al escribir el contenido del archivo: %1$s",
    "File not found: %1$s" : "Archivo no encontrado: %1$s",
    "Invalid target path" : "Ruta de destino inválida",
    "System is in maintenance mode." : "Sistema está en modo de mantenimiento.",
    "Upgrade needed" : "Se necesita actualizar",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Tu %s necesita configurarse para usar HTTPS en caso de usar CalDAV y CardDAV con iOS/macOS.",
    "Configures a CalDAV account" : "Configura una cuenta CalDAV",
    "Configures a CardDAV account" : "Configura una cuenta CardDAV",
    "Events" : "Eventos",
    "Untitled task" : "Tarea sin título",
    "Completed on %s" : "Completado el %s",
    "Due on %s by %s" : "Finaliza el %s por %s",
    "Due on %s" : "Finaliza el %s",
    "This is an example contact" : "Este es un contacto de ejemplo",
    "Welcome to Nextcloud Calendar!\n\nThis is a sample event - explore the flexibility of planning with Nextcloud Calendar by making any edits you want!\n\nWith Nextcloud Calendar, you can:\n- Create, edit, and manage events effortlessly.\n- Create multiple calendars and share them with teammates, friends, or family.\n- Check availability and display your busy times to others.\n- Seamlessly integrate with apps and devices via CalDAV.\n- Customize your experience: schedule recurring events, adjust notifications and other settings." : "¡Bienvenido a Nextcloud Calendar!\n\nEste es un evento de ejemplo - ¡explore la flexibilidad de planear con Nextcloud Calendar editando cuantas veces quiera!\n\nCon Nextcloud Calendar, podrá:\n- Crear, editar, y administrar eventos fácilmente.\n- Crear múltiples calendarios y compartirlos con su equipo de trabajo, amigos, o su familia.\n- Verificar la disponibilidad y mostrar sus tiempos de ocupado a otros.\n- Se integra de manera transparente con otras apps y dispositivos via CalDAV.\n- Personalice su experiencia: Programe eventos recurrentes, ajuste las notificaciones, así como otros ajustes.",
    "Example event - open me!" : "Evento de ejemplo - ¡ábralo!",
    "System Address Book" : "Libreta de Direcciones del Sistema",
    "The system address book contains contact information for all users in your instance." : "La libreta de direcciones del sistema contiene la información de contacto de todos los usuarios de su instancia.",
    "Enable System Address Book" : "Habilitar la Libreta de Direcciones del Sistema",
    "DAV system address book" : "Libreta de direcciónes DAV del sistema",
    "No outstanding DAV system address book sync." : "No hay una sincronización pendiente en la libreta de direcciones DAV del sistema.",
    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "La sincronización DAV de la libreta de direcciones del sistema no se ha ejecutado ya que su instancia tiene más de 1000 usuarios o por que ha ocurrido un error. Por favor, ejecútela manualmente llamando al comando: \"occ dav:sync-system-addressbook\".",
    "DAV system address book size" : "Tamaño bajo DAV de la libreta de direcciones del sistema ",
    "The system address book is disabled" : "La libreta de direcciones del sistema está deshabilitada",
    "The system address book is enabled, but contains more than the configured limit of %d contacts" : "La libreta de direcciones del sistema está habilitada, pero, contiene un número mayor de contactos que el límite configurado de %d",
    "The system address book is enabled and contains less than the configured limit of %d contacts" : "La libreta de direcciones del sistema está habilitada y contiene un número menor de contactos que el límite configurado de %d",
    "WebDAV endpoint" : "Endpoint WebDAV",
    "Could not check that your web server is properly set up to allow file synchronization over WebDAV. Please check manually." : "No se pudo verificar si su servidor web está adecuadamente configurado para permitir la sincronización de archivos a través de WebDAV. Por favor, verifique manualmente.",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Su servidor web todavía no está configurado correctamente para permitir la sincronización de archivos, porque la interfaz WebDAV parece estar rota.",
    "Your web server is properly set up to allow file synchronization over WebDAV." : "Su servidor web está adecuadamente configurado para permitir la sincronización de archivos a través de WebDAV.",
    "Calendars including events, details and attendees" : "Calendarios que incluyen eventos, detalles y asistentes",
    "Migrated calendar (%1$s)" : "Se migró el calendario (%1$s)",
    "Contacts and groups" : "Contactos y grupos",
    "WebDAV" : "WebDAV",
    "Absence saved" : "Ausencia guardada",
    "Failed to save your absence settings" : "Error al guardar sus ajustes de ausencia",
    "Absence cleared" : "Ausencia limpiada",
    "Failed to clear your absence settings" : "Error al borrar sus ajustes de ausencia",
    "First day" : "Primer día",
    "Last day (inclusive)" : "Último día (incluido)",
    "Out of office replacement (optional)" : "Sustituto durante vacaciones/ausencia (opcional)",
    "Name of the replacement" : "Nombre del sustituto",
    "Short absence status" : "Estado de ausencia corta",
    "Long absence Message" : "Mensaje de ausencia larga",
    "Save" : "Guardar",
    "Disable absence" : "Deshabilitar ausencia",
    "Failed to load availability" : "No se ha podido cargar la disponibilidad",
    "Saved availability" : "Disponibilidad guardada",
    "Failed to save availability" : "No se ha podido guardar la disponibilidad",
    "to" : "para",
    "Delete slot" : "Eliminar franja de tiempo",
    "No working hours set" : "No se han establecido horas laborales",
    "Add slot" : "Añadir franja horaria",
    "Weekdays" : "Días de semana",
    "Pick a start time for {dayName}" : "Elija una hora de inicio para {dayName}",
    "Pick a end time for {dayName}" : "Elija una hora fin para {dayName}",
    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Cambiar automáticamente el estado del usuario a \"No molestar\" fuera de las horas de disponibilidad para silenciar todas las notificaciones.",
    "Cancel" : "Cancelar",
    "Import" : "Importar",
    "Error while saving settings" : "Error al guardar los ajustes",
    "Contact reset successfully" : "El contacto fue restablecido exitosamente",
    "Error while resetting contact" : "Error al restablecer el contacto",
    "Contact imported successfully" : "El contacto se importó exitosamente",
    "Error while importing contact" : "Error al importar el contacto",
    "Import contact" : "Importar contacto",
    "Reset to default" : "Restablecer a predeterminado",
    "Import contacts" : "Importar contactos",
    "Importing a new .vcf file will delete the existing default contact and replace it with the new one. Do you want to continue?" : "Importar un nuevo archivo .vcf eliminará el contacto predeterminado existente y lo reemplazará con el nuevo. ¿Desea continuar?",
    "Failed to save example event creation setting" : "Fallo al guardar el ajuste de creación de evento de ejemplo",
    "Failed to upload the example event" : "Fallo al cargar el evento de ejemplo",
    "Custom example event was saved successfully" : "El evento de ejemplo personalizado se guardó exitosamente",
    "Failed to delete the custom example event" : "Fallo al guardar el evento de ejemplo personalizado",
    "Custom example event was deleted successfully" : "El evento de ejemplo personalizado se eliminó exitosamente",
    "Import calendar event" : "Importar evento del calendario",
    "Uploading a new event will overwrite the existing one." : "Cargar un evento nuevo sobrescribirá el existente. ",
    "Upload event" : "Cargar evento",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Instale también la {calendarappstoreopen}app de Calendario{linkclose} o {calendardocopen}conecte su escritorio y móvil para sincronizar ↗{linkclose}.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Por favor, asegúrese de configurar correctamente {emailopen}el servidor web{linkclose}",
    "Calendar server" : "Servidor de calendario",
    "Send invitations to attendees" : "Enviar invitaciones a los asistentes",
    "Automatically generate a birthday calendar" : "Generar automáticamente un calendario de cumpleaños",
    "Birthday calendars will be generated by a background job." : "Los calendarios de cumpleaños se generarán mediante un trabajo en segundo plano.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Por ello, no estarán disponibles inmediatamente tras activarlos, sino que aparecerán después de cierto tiempo.",
    "Send notifications for events" : "Enviar notificaciones de los eventos",
    "Notifications are sent via background jobs, so these must occur often enough." : "Las notificaciones son enviadas a través de trabajos en segundo plano, por lo que estos deben ocurrir con suficiente frecuencia.",
    "Send reminder notifications to calendar sharees as well" : "Enviar recordatorio también a los usuarios con los que se comparte el calendario",
    "Reminders are always sent to organizers and attendees." : "Los recordatorios siempre se envían a los organizadores y asistentes.",
    "Enable notifications for events via push" : "Activar notificaciones push para eventos",
    "Example content" : "Contenido de ejemplo",
    "Example content serves to showcase the features of Nextcloud. Default content is shipped with Nextcloud, and can be replaced by custom content." : "El contenido de ejemplo sirve para mostrar las características de Nextcloud. Se proporciona un contenido predeterminado con Nextcloud, y puede ser reemplazado por un contenido personalizado.",
    "Availability" : "Disponibilidad",
    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Si configura sus horas laborales, otras personas verán cuando está fuera de la oficina cuando agenden una reunión.",
    "Absence" : "Ausencia",
    "Configure your next absence period." : "Configure el siguiente periodo en que estará ausente",
    "There was an error updating your attendance status." : "Ha habido un error al actualizar tu estado de asistencia.",
    "Please contact the organizer directly." : "Por favor, contacta directamente con el organizador.",
    "Are you accepting the invitation?" : "¿Aceptas la invitación?",
    "Tentative" : "Provisional",
    "Your attendance was updated successfully." : "Tu asistencia se ha actualizado con éxito.",
    "No results." : "Sin resultados.",
    "Start typing." : "Empiece a escribir."
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
