import{n as s}from"./index-jVniDJU4.chunk.mjs";const t={name:"NcVNodes",props:{vnodes:{type:[Array,Object],default:null}},render(){return this.vnodes||this.$slots?.default||this.$scopedSlots?.default?.()}},o=null,e=null;var l=s(t,o,e,!1,null,null);const r=l.exports;export{r as N};
//# sourceMappingURL=NcVNodes-DYuUXE-A.chunk.mjs.map
