OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "Das Passwort ist abgelaufen, bitte die Methode \"Passwort vergessen\" zum Zurücksetzen verwenden",
    "Password must not have been used recently before." : "Das Passwort darf noch nicht verwendet worden sein.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Das Passwort ist unter den 1.000.000 häufigsten Passwörtern. Bitte wähle ein anderes.",
    "Password is present in compromised password list. Please choose a different password." : "Das Passwort ist in der Liste der kompromittierten Passwörter enthalten. Bitte wähle ein anderes Passwort. ",
    "Password needs to be at least %s characters long." : "Das Passwort muss mindestens %s Zeichen lang sein.",
    "Password needs to contain at least one numeric character." : "Das Passwort muss mindestens eine Zahl beinhalten. ",
    "Password needs to contain at least one special character." : "Das Passwort muss mindestens ein Sonderzeichen beinhalten. ",
    "Password needs to contain at least one lower and one upper case character." : "Das Passwort muss mindestens einen Klein- und einen Großbuchstaben beinhalten. ",
    "Password policy" : "Passwort-Regeln",
    "Allows admins to configure a password policy" : "Ermöglicht der Administration eine Passwortrichtlinie einzurichten",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Ermöglicht der Administration diverse Voreinstellungen für Passwörter vorzunehmen, z. B. die Mindestlänge",
    "General password policies" : "Allgemeine Passwortrichtlinien",
    "Add policy set" : "Richtliniensatz hinzufügen",
    "Login policies" : "Anmelderichtlinien",
    "Password history size" : "Größe des Passwortverlaufs",
    "Number of passwords to keep (securely hashed) to prevent users from reusing previously used passwords." : "Anzahl der zu behaltenden Passwörter (sicher gehasht), um zu verhindern, dass Benutzer zuvor verwendete Passwörter erneut verwenden.",
    "Maximum login attempts" : "Maximale Anmeldeversuche",
    "Number of login attempts before the user account will be disabled until manual action is taken. (0 for no limit)" : "Anzahl der Anmeldeversuche, bevor das Konto so lange deaktiviert wird, bis manuell eingegriffen wird. (0 für kein Limit)",
    "Please note, this option is meant to protect attacked accounts. Disabled accounts have to be re-enabled manually by administration. Attackers that try to guess passwords of accounts will have their IP address blocked by the bruteforce protection independent from this setting." : "Bitte beachte, dass diese Option dem Schutz angegriffener Konten dient. Deaktivierte Konten müssen von der Administration manuell wieder aktiviert werden. Angreifer, die versuchen, Passwörter von Konten zu erraten, werden unabhängig von dieser Einstellung durch den Bruteforce-Schutz blockiert.",
    "Number of days until user password expires" : "Anzahl der Tage bis zum Ablauf des Benutzerpassworts",
    "Password expiration" : "Ablauf des Passworts",
    "Warning: enabling password expiration is nowadays considered a security risk by several security agencies." : "Warnung: Die Aktivierung des Ablaufs von Passwörtern wird heutzutage von mehreren Sicherheitsbehörden als Sicherheitsrisiko betrachtet.",
    "Remove policy" : "Richtlinie entfernen",
    "Minimum password length" : "Minimale Passwortlänge",
    "Forbid common passwords" : "Häufig verwendete Passwörter verbieten",
    "Enforce upper and lower case characters" : "Groß- und Kleinbuchstaben erzwingen",
    "Enforce numeric characters" : "Zahlen erzwingen",
    "Enforce special characters" : "Sonderzeichen erzwingen",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Das Passwort gegen eine Liste von geknackten Passwörtern bei haveibeenpwned.com prüfen.",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Es wird ein Hash des Passwortes erstellt und dessen ersten 5 Zeichen an haveibeenpwned.com gesendet. Danach wird eine Liste aller Hashes empfangen, welche mit diesen 5 Zeichen beginnen. Nextcloud prüft nun, ob der Hash des eingegebenen Passwortes in der Liste der Hashes enthalten ist.",
    "Account password policies" : "Kontopasswortrichtlinien",
    "Share password policies" : "Passwortrichtlinien freigeben"
},
"nplurals=2; plural=(n != 1);");
