OC.L10N.register(
    "office",
    {
    "Office" : "Office",
    "Office overview" : "Office 概覽",
    "Office overview app for Nextcloud" : "Nextcloud 的 Office 概覽應用程式",
    "Create new" : "建立新的",
    "Scroll left" : "向左捲動",
    "Scroll right" : "向右捲動",
    "Blank" : "空白",
    "Search {category}" : "搜尋 {category}",
    "Search" : "搜尋",
    "Failed to create file" : "建立檔案失敗",
    "Failed to load files" : "無法載入檔案",
    "No office suite installed" : "未安裝辦公室套裝軟體",
    "{count} found in {category}" : "在 {category} 中找到 {count} 個",
    "Recent {category}" : "近期 {category}",
    "Filter files" : "篩選檔案",
    "All" : "全部",
    "Mine" : "我的",
    "Shared with me" : "與我分享",
    "Switch to grid view" : "切換到格狀檢視",
    "Switch to list view" : "切換至列表檢視",
    "No {category} found" : "找不到 {category}",
    "Switch to \"All\" to see every file you have access to" : "切換至「全部」以檢視您有權存取的每個檔案",
    "Search all in Files" : "在檔案中搜尋全部",
    "Show all in Files" : "在檔案中顯示全部",
    "Create" : "建立",
    "Filename" : "檔案名稱",
    "Documents" : "文件",
    "Spreadsheets" : "試算表",
    "Presentations" : "簡報",
    "Diagrams" : "圖表",
    "Filename cannot be empty" : "檔案名稱不可為空白",
    "Filename contains invalid characters" : "檔案名稱包含無效字元",
    "{count} {category} found" : "找到 {count} {category}"
},
"nplurals=1; plural=0;");
