OC.L10N.register(
    "office",
    {
    "Office" : "Biuras",
    "Office overview" : "Biuro apžvalga",
    "Office overview app for Nextcloud" : "„Nextcloud“ skirta biuro apžvalgos programėlė",
    "Create new" : "Sukurti naują",
    "Scroll left" : "Slinkite kairėn",
    "Scroll right" : "Slinkite dešinėn",
    "Blank" : "Tuščia",
    "Search {category}" : "Ieškoti {category}",
    "Search" : "Paieška",
    "Failed to create file" : "Nepavyko sukurti failo",
    "Failed to load files" : "Nepavyko įkelti failų",
    "No office suite installed" : "Neįdiegtas biuro paketas",
    "{count} found in {category}" : "{count} rasta {category}",
    "Recent {category}" : "Paskutinė {category}",
    "Filter files" : "Filtruoti failus",
    "All" : "Visos",
    "Mine" : "Mano",
    "Shared with me" : "Bendrinta su manimi",
    "Switch to grid view" : "Perjungti į tinklelio rodinį",
    "Switch to list view" : "Perjungti į sąrašo rodinį",
    "No {category} found" : "Nerasta {category}",
    "Switch to \"All\" to see every file you have access to" : "Perjunkite į „Visi“, kad matytumėte visus failus, prie kurių turite prieigą",
    "Search all in Files" : "Ieškoti viską failuose",
    "Show all in Files" : "Rodyti viską Failuose",
    "Create" : "Sukurti",
    "Filename" : "Failo pavadinimas",
    "Documents" : "Dokumentai",
    "Spreadsheets" : "Skaičiuoklės",
    "Presentations" : "Pateiktys",
    "Diagrams" : "Diagramos",
    "Filename cannot be empty" : "Failo pavadinimas negali būti tuščias",
    "Filename contains invalid characters" : "Failo pavadinime yra neleistinų simbolių",
    "{count} {category} found" : "Rasta {count} {category}"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
