OC.L10N.register(
    "notifications",
    {
    "We want to keep offering our push notification service for free, but large number of users overload our infrastructure. For this reason we have to rate-limit the use of push notifications. If you need this feature, consider using Nextcloud Enterprise." : "Сакаме да продолжиме да ја нудиме нашата услуга за push известување бесплатно, но голем број корисници ја преоптоваруваат нашата инфраструктура. Поради оваа причина, мораме да ја ограничиме употребата на push известувања. Ако ви треба оваа функција, размислете за користење на Nextcloud Enterprise.",
    "User not found" : "Корисникот не е пронајден",
    "An unexpected error occurred, ask your administration to check the logs." : "Се појави неочекувана грешка, побарајте од вашата администрација да ги провери записниците за грешката.",
    "Hello %s" : "Здраво %s",
    "Hello %s," : "Здраво %s,",
    "_New notification for %s_::_%n new notifications for %s_" : ["Ново известување за %s","%n нови известувања за %s"],
    "_You have a new notification for %s_::_You have %n new notifications for %s_" : ["Имате ново известување на %s","Имате %n нови известувања на %s"],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "Можете да ја промените фрекфенцијата на овие е-пораки или да ги оневозможите во <a href=\"%s\">поставките</a>.",
    "You can change the frequency of these emails or disable them in the settings: %s" : "Можете да ја промените фрекфенцијата на овие е-пораки или да ги оневозможите во поставките: %s",
    "Admin notifications" : "Известувања за администраторот",
    "Notifications" : "Известувања",
    "Push notifications - Fair use policy" : "Push известувања - Политика за фер користење",
    "Nextcloud GmbH sponsors a free push notification gateway for private users. To ensure good service, the gateway limits the number of push notifications per server and the limit was reached for this server. For enterprise users, a more scalable gateway is available." : "Nextcloud GmbH спонзорира бесплатен портал за Push известувања за приватни корисници. За да обезбеди добра услуга, портата го ограничува бројот на Push известувања по сервер и границата е достигната за овој сервер. За enterprise корисниците, достапен е поскалабилен портал.",
    "This app provides a backend and frontend for the notification API available in Nextcloud." : "Оваа апликација обезбедува backend и frontend за известувачкиот API достапен во Nextcloud.",
    "This app provides a backend and frontend for the notification API available in Nextcloud.\n\t\tThe API is used by other apps to notify users in the web UI and sync clients about various things. Some examples are:\n\n📬 Federated file sharing: You received a new remote share\n\n📑 Comments: Another user mentioned you in a comment on a file\n\n🚢 Update notification: Available update for an app or nextcloud itself\n\n📣 Announcement center: An announcement was posted by an admin" : "Оваа апликација обезбедува известувања и позадински известувањА И API за известување достапен во Nextcloud.\n\t\tAPI се користи од други апликации за да ги извести корисниците во веб-интерфејсот и да ги синхронизира клиентите за разни работи. Некои примери се:\n\n📬 Федерално споделување датотеки: Добивте ново далечинско споделување\n\n📑 Коментари: Друг корисник ве спомна во коментар на датотека\n\n🚢 Известување за ажурирање: Достапно ажурирање за апликација или за nextcloud\n\n📣 Центар за објава: Објава од администратор",
    "Failed to perform action" : "Неуспешно извршување на акцијата",
    "Failed to dismiss notification" : "Неуспешно отфрлање на известувањето",
    "Dismiss" : "Отфрли",
    "Contact Nextcloud GmbH" : "Контрактирајте со Nextcloud GmbH",
    "in {path}" : "во {path}",
    "Push notifications might be unreliable" : "Push известувањата може да не се несигрни",
    "Nextcloud GmbH sponsors a free push notification gateway for private users. To ensure good service, the gateway limits the number of push notifications per server. For enterprise users, a more scalable gateway is available. Contact Nextcloud GmbH for more information." : "Nextcloud GmbH спонзорира бесплатен портал за push известувања за приватни корисници. За да обезбеди добра услуга, портата го ограничува бројот на push известувања по сервер. За корисниците на претпријатијата, достапен е поскалабилен портал. Контактирајте со Nextcloud GmbH за повеќе информации.",
    "Requesting browser permissions to show notifications" : "Барање на дозвола од прелистувачот за прикажување на известувања.",
    "No notifications" : "Нема известувања",
    "Failed to dismiss all notifications" : "Неуспешно отфрлање на сите известувања",
    "Dismiss all notifications" : "Отфрли ги сите известувања",
    "Never" : "Никогаш",
    "1 hour" : "1 час",
    "3 hours" : "3 часа",
    "1 day" : "1 ден",
    "1 week" : "1 недела",
    "Your settings have been updated." : "Вашите параметри се ажурирани.",
    "An error occurred while updating your settings." : "Настана грешка при обидот за ажурирање на параметрите.",
    "Notifications defaults" : "Стандардни известувања",
    "Configure the default notification settings" : "Конфигурирај ги стандардните параметри за известувања",
    "Send email reminders about unhandled notifications after:" : "Испраќај потсетник по е-пошта за непрегледани известувања после:",
    "Play sound when a new notification arrives" : "Пушти звук кога ќе пристигне ново известување",
    "Play sound when a call started (requires Nextcloud Talk)" : "Пушти звук кога ќе започне нов повик (потребнa е апликација разговор)",
    "None" : "Ништо",
    "You need to set up your email address before you can receive notification emails." : "Треба да ја внесете Вашата адреса на е-пошта за да можете да примате известувања по електронска пошта.",
    "Also repeat sound on a secondary speaker" : "Повтори го звукот на секундарен звучник",
    "Selection of the speaker device is currently not supported by Safari" : "Изборот на уредот со звучници моментално не е поддржан од Safari",
    "Select a device" : "Избери уред"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
