OC.L10N.register(
    "suspicious_login",
    {
    "New login location detected" : "Neuer Anmeldeort erkannt",
    "More info about the suspicious IP address available on %s" : "Weitere Informationen zur verdächtigen IP-Adresse findest du unter %s",
    "A new login into your account was detected. The IP address %s was classified as suspicious by an AI model. If this was you, you can ignore this message, as the AI model did not take any automated actions. Otherwise, you should change your password." : "Es wurde eine neue Anmeldung in deinem Konto festgestellt. Die IP-Adresse %s wurde von einem KI-Modell als verdächtig eingestuft. Falls du es selbst warst, ignoriere diese Meldung, da das KI-Modell keine automatisierten Maßnahmen ergriffen hat. Andernfalls solltest du dein Passwort ändern.",
    "Open %s ↗" : "Öffne %s ↗",
    "Suspicious Login" : "Verdächtige Anmeldung",
    "New login detected" : "Neue Anmeldung erkannt",
    "Detect and warn about suspicious IPs logging into Nextcloud\n\t" : "Erkenne und melde verdächtige Anmeldungen in Nextcloud\n\t",
    "A new login into your account was detected. The IP address %s was classified as suspicious. If this was you, you can ignore this message. Otherwise you should change your password." : "Eine neue Anmeldung mit deinem Konto wurde erkannt. Die IP-Adresse %s wurde als verdächtig eingestuft. Falls du es selbst warst, ignoriere diese Meldung. Andernfalls solltest du dein Passwort ändern."
},
"nplurals=2; plural=(n != 1);");
