.face-cover[data-v-215ef5db]{display:flex;flex-direction:column;padding:10px;border-radius:var(--border-radius-large)}.face-cover__crop-container[data-v-215ef5db]{overflow:hidden;width:128px;height:128px;border-radius:128px;position:relative;background:var(--color-background-darker);--photos-face-width: 128px}@media only screen and (max-width:1020px){.face-cover__crop-container[data-v-215ef5db]{width:95px;height:95px;--photos-face-width: 95px}}.face-cover[data-v-215ef5db]:hover,.face-cover[data-v-215ef5db]:focus{background:var(--color-background-hover)}.face-cover__details[data-v-215ef5db]{display:flex;flex-direction:column;width:128px;margin-top:4px;text-align:center}@media only screen and (max-width:1020px){.face-cover__details[data-v-215ef5db]{width:95px}}.face-cover__details__first-line[data-v-215ef5db]{display:flex;height:2em;overflow:hidden;text-overflow:ellipsis}.face-cover__details__second-line[data-v-215ef5db]{margin-top:6px;color:var(--color-text-maxcontrast)}.face-cover__details__name[data-v-215ef5db]{flex-grow:1;margin:0;font-weight:700;font-size:20px;line-height:30px;color:var(--color-main-text)}.face-cover--small *[data-v-215ef5db]{font-size:15px!important}.face-cover--small .face-cover__details[data-v-215ef5db]{width:60px!important}.face-cover--small .face-cover__crop-container[data-v-215ef5db]{width:60px!important;height:60px!important;--photos-face-width: 60px !important}
