OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "Passordet er utløpt, vennligst bruk glemt passord-metoden for å tilbakestille",
    "Password must not have been used recently before." : "Passord må ikke ha vært brukt nylig tidligere.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Passordet er blant de 1 000 000 mest brukte passordene. Gjør det unikt.",
    "Password is present in compromised password list. Please choose a different password." : "Passord finnes i liste over kompromitterte passord. Vennligst velg et annet passord.",
    "Password needs to be at least %s characters long." : "Passordet må være minst %s tegn langt.",
    "Password needs to contain at least one numeric character." : "Passordet må inneholde minst ett numerisk tegn.",
    "Password needs to contain at least one special character." : "Passordet må inneholde minst ett spesialtegn.",
    "Password needs to contain at least one lower and one upper case character." : "Passordet må inneholde minst en liten og en stor bokstav.",
    "Password policy" : "Passordregler",
    "Allows admins to configure a password policy" : "Lar administratorer konfigurere passordregler",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Tillat admin å definere visse forutsetninger for passord, f.eks. håndheve en minimumslengde",
    "Number of login attempts before the user account will be disabled until manual action is taken. (0 for no limit)" : "Antall påloggingsforsøk før brukerkontoen deaktiveres inntil manuelle tiltak iverksettes. (0 for ingen grense)",
    "Please note, this option is meant to protect attacked accounts. Disabled accounts have to be re-enabled manually by administration. Attackers that try to guess passwords of accounts will have their IP address blocked by the bruteforce protection independent from this setting." : "Vær oppmerksom på at dette alternativet er ment å beskytte angrepne kontoer. Deaktiverte kontoer må aktiveres på nytt manuelt av administrasjonen. Angripere som prøver å gjette passord for kontoer, vil få IP-adressen blokkert av bruteforce-beskyttelsen uavhengig av denne innstillingen.",
    "Number of days until user password expires" : "Antall dager før brukerpassordet utløper",
    "Minimum password length" : "Minimum passordlengde",
    "Forbid common passwords" : "Forby mest brukte passord",
    "Enforce upper and lower case characters" : "Krev stor og liten bokstav",
    "Enforce numeric characters" : "Krev numerisk tegn",
    "Enforce special characters" : "Krev spesialtegn",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Check password against the list of breached passwords from haveibeenpwned.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Denne sjekken oppretter en hash av passordet og sender de første 5 tegnene i denne hashen til haveibeenpwned.com API for å hente en liste over alle hashen som starter med disse. Deretter sjekker den Nextcloud-forekomsten om passordhashen er i resultatsettet."
},
"nplurals=2; plural=(n != 1);");
