OC.L10N.register(
    "appstore",
    {
    "Apps" : "Приложения",
    "App name" : "Име на приложението",
    "Version" : "Версия",
    "Groups" : "Групи",
    "Actions" : "Действия",
    "Show details" : "Показване на подробности",
    "Grid view" : "Решетъчен изглед",
    "Cancel" : "Cancel",
    "Learn more" : "Научете повече",
    "Daemon" : "Системен процес",
    "Deploy Daemon" : "Внедряване на системен процес",
    "Type" : "Тип",
    "Name" : "Име",
    "Display Name" : "Име за визуализация",
    "GPUs support" : "Поддръжка на GPU",
    "Compute device" : "Изчислително устройство",
    "Advanced deploy options" : "Разширени опции за внедряване",
    "Edit ExApp deploy options before installation" : "Редактиране на опциите за внедряване на ExApp преди инсталиране",
    "Configured ExApp deploy options. Can be set only during installation" : "Конфигурирани опции за внедряване на ExApp. Могат да се зададат само по време на инсталацията.",
    "Environment variables" : "Променливи на средата",
    "ExApp container environment variables" : "Променливи на средата на ExApp",
    "No environment variables defined" : "Няма дефинирани променливи на средата",
    "Mounts" : "Монтажи",
    "Define host folder mounts to bind to the ExApp container" : "Дефиниране на монтираните папки на хоста за свързване с ExApp",
    "Must exist on the Deploy daemon host prior to installing the ExApp" : "Трябва да съществува на внедряването на системния процес за разгръщане преди инсталирането на ExApp",
    "Host path" : "Път на хоста",
    "Container path" : "Връзка към контейнер",
    "Read-only" : "Само за четене",
    "Remove mount" : "Премахнете монтажа",
    "New mount" : "Нов монтаж",
    "Enter path to host folder" : "Въведете пътя до папката на хоста",
    "Enter path to container folder" : "Въведете пътя до папката на контейнера",
    "Toggle read-only mode" : "Превключване на режим само за четене",
    "Confirm adding new mount" : "Потвърдете добавянето на нов монтаж",
    "Confirm" : "Потвърдете",
    "Cancel adding mount" : "Отказ от добавяне на монтаж",
    "Add mount" : "Добавяне на монтаж",
    "ExApp container mounts" : "Монтиране на контейнери ExApp",
    "No mounts defined" : "Няма определени монтажи",
    "Description" : "Описание",
    "View in store" : "Преглед в магазина",
    "Visit website" : "Уеб страницата",
    "Usage documentation" : "Документация за употреба",
    "Admin documentation" : "Документация за администратори",
    "Developer documentation" : "Документация за разработчици",
    "Details" : "Подробности",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Приложението не може да бъде инсталирано, защото следните зависимости не са удовлетворени:",
    "Latest updated" : "Последна актуализация",
    "Author" : "Автор",
    "Categories" : "Категории",
    "Resources" : "Ресурси",
    "Changelog" : "Списък на промените",
    "Supported" : "Поддържан",
    "Featured" : "Препоръчани",
    "This app is supported via your current Nextcloud subscription." : "Това приложение се поддържа чрез текущия ви абонамент за Nextcloud.",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Представените приложения са разработени от и в рамките на общността. Те предлагат централна функционалност и са готови за производствена употреба.",
    "Community rating: {score}/5" : "Оценка на общността: {score} /5",
    "Choose Deploy Daemon for {appName}" : "Изберете внедраване на системен поцес за {appName}",
    "No Deploy daemons configured" : "Няма конфигурирани бекграунд процеси",
    "Register a custom one or setup from available templates" : "Регистрирайте персонализиран такъв или го настройте от наличните шаблони",
    "Manage Deploy daemons" : "Управление на бекграунд процеси",
    "Registered Deploy daemons list" : "Списък с регистриран бекграунд списък",
    "Default" : "По подразбиране",
    "Carousel" : "Въртележка",
    "Previous slide" : "Предишен слайд",
    "Next slide" : "Следващ слайд",
    "Choose slide to display" : "Изберете слайд за показване",
    "{index} of {total}" : "{index}на {total}",
    "Limit to groups" : "Ограничен достъп",
    "Save" : "Запиши",
    "Update all" : "Актуализирай всички",
    "Loading app list" : "Списъкът с приложения се зарежда",
    "Search everywhere" : "Търси навсякъде",
    "Download and enable all" : "Изтеглете и активирайте всички",
    "Could not load app discover section" : "Не може да се зареди секцията за откриване на приложения",
    "Could not render element" : "Елементът не можа да се изобрази",
    "Nothing to show" : "Нищо за показване",
    "Could not load section content from app store." : "Не можа да се зареди съдържанието на секцията от магазина за приложения.",
    "Loading" : "Зареждане",
    "Fetching the latest news…" : "Извличане на последните новини…",
    "Loading categories" : "Категории се зареждат",
    "Version {version}, {license}-licensed" : "Версия {version}, {license}-лицензирана",
    "Version {version}" : "Версия {version}",
    "Disable" : "Изключване",
    "Enable" : "Включена",
    "Download and enable" : "Сваляне и включване",
    "Rate the app" : "Оценете приложението",
    "Report a bug" : "Докладване за грешка",
    "Remove" : "Премахване",
    "Update to {version}" : "Актуализирай до {version}",
    "Discover" : "Открийте",
    "Your apps" : "Вашите приложения",
    "Active apps" : "Включени приложения",
    "Disabled apps" : "Изключени приложения",
    "Updates" : "Актуализации",
    "App bundles" : "Пакети с приложения",
    "Featured apps" : "Представени приложения",
    "Supported apps" : "Поддържани приложения",
    "An error occurred during the request. Unable to proceed." : "Възникна грешка по време на заявката. Не може да се продължи."
},
"nplurals=2; plural=(n != 1);");
