OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "Førstegangsveiviser",
    "Add your profile information! For example your email is needed to receive notifications." : "Legg til informasjon i profilen din! For eksempel er e-posten din nødvendig for å motta varsler.",
    "Add your profile information! For example your email is needed to receive notifications and reset your password." : "Legg til informasjon i profilen din! For eksempel er e-posten din nødvendig for å motta varsler og tilbakestille passordet ditt.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Legg til din profilinformasjon. Velg et profilbilde og fullt navn for enklere gjenkjenning på tvers av alle funksjoner.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Legg til din profilinformasjon.Velg fullt navn for enklere gjenkjenning på tvers av alle funksjoner.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Legg til din profilinformasjon. Velg et profilbilde for enklere gjenkjenning på tvers av alle funksjoner.",
    "Schedule work & meetings, synced with all your devices." : "Planlegg jobb og møter, synkronisert med alle dine enheter.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Ha dine kollegaer og venner på en plass uten å lekke deres private info.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Enkel e-post app smidig integrert med Filer, Kontakter og Kalender.",
    "App recommendation: Tasks" : "Appanbefaling: Gjøremål",
    "Sync tasks from various devices with your Nextcloud and edit them online." : "Synkroniser oppgaver fra forskjellige enheter med Nextcloud og rediger dem på nett.",
    "App recommendation: Deck" : "Appanbefaling: Stokk",
    "Kanban style organization for personal planning and team projects." : "Kanban-organisering for personlig planlegging og teamprosjekter.",
    "App recommendation: Forms" : "Appanbefaling: Skjemaer",
    "Simple surveys and questionnaires, self-hosted" : "Enkle undersøkelser og spørreskjemaer, på egen vert.",
    "App recommendation: Recognize" : "Appanbefaling: Gjenkjenne",
    "Smart media tagging for Nextcloud" : "Smart mediamerking for Nextcloud",
    "App recommendation: Group folders" : "Appanbefaling: Gruppemapper",
    "Admin-configured folders shared by everyone in a group." : "Admin-konfigurerte mapper delt av alle i en gruppe",
    "Connect your calendar" : "Koble til din kalender",
    "Connect your contacts" : "Koble til dine kontakter",
    "Access files via WebDAV" : "Få tilgang til filer via WebDAV",
    "Download macOS/iOS configuration profile" : "Last ned macOS/iOS-konfigurasjonsprofilen",
    "Desktop client" : "Skrivebordsklient",
    "Android app on Google Play Store" : "Android-appen i Google Play Store",
    "Android app on F-Droid" : "Android-app på F-Droid",
    "iOS app" : "iOS-app",
    "About & What's new" : "Om og hva er nytt",
    "A welcome and introduction wizard for Nextcloud" : "A welcome and introduction wizard for Nextcloud",
    "This application enables a pop-up window when a user first logs into Nextcloud. This window welcomes new users to Nextcloud, and contains links to the standard desktop client, Android app, and the iOS app. The window also shows a link for accessing Nextcloud via WebDAV. At any time, the first run wizard can be opened again via link \"About\" on settings menu.\nThe First run wizard can be customized to meet specific design goals, or to change links and messages. Create an appropriate theme following the Theming documentation, and changes to the look and feel of this Wizard are simple. More information is available in the first run wizard documentation, as well as the theming documentation." : "Denne applikasjonen aktiverer et sprettopp-vindu når en bruker først logger på Nextcloud. Dette vinduet ønsker nye brukere velkommen til Nextcloud, og inneholder koblinger til standard skrivebordsklient, Android-app og iOS-appen. Vinduet viser også en lenke for tilgang til Nextcloud via WebDAV. Når som helst kan veiviseren for første kjøring åpnes igjen via lenken \"Om\" på innstillingsmenyen.\nVeiviseren for første kjøring kan tilpasses for å oppfylle bestemte utformingsmål, eller for å endre koblinger og meldinger. Opprett et passende tema etter temadokumentasjonen, og endringer i utseendet og virkemåten til denne veiviseren er enkle. Du finner mer informasjon i dokumentasjonen for veiviseren for første kjøring, i tillegg til temadokumentasjonen.",
    "Download on Apple app store" : "Last ned på Apple App Store",
    "Download on Google play store" : "Last ned på Google Play Store",
    "Go to previous page" : "Gå til forrige side",
    "Close" : "Lukk",
    "More about Nextcloud" : "Mer om Nextcloud",
    "Explore more apps ↗" : "Utforsk flere apper ↗",
    "Extend the functionality of Nextcloud with hundreds of community-developed apps." : "Utvid funksjonaliteten til Nextcloud med hundrevis av fellesskapsutviklede apper.",
    "Get involved! ↗" : "Bli involvert! ↗",
    "Be a part of the community that helps build, design, translate and promote Nextcloud!" : "Bli en del av fellesskapet som hjelper til med å bygge, designe, oversette og markedsføre Nextcloud!",
    "Need help? ↗" : "Trenger du hjelp? ↗",
    "Find out more about your Nextcloud setup with the admin, user or developer documentation." : "Finn ut mer om Nextcloud-oppsettet ditt med dokumentasjonen for administrator, bruker eller utvikler.",
    "For large organisations ↗" : "For store organisasjoner ↗",
    "Get Nextcloud Enterprise for mission critical environments where advanced security and compliance are important." : "Skaff deg Nextcloud Enterprise for oppdragskritiske miljøer der avansert sikkerhet og samsvar er viktig.",
    "Seamless integration with your devices." : "Sømløs integrasjon med enhetene dine.",
    "Sync your files across your devices with the desktop and mobile apps, and connect your calendar and contacts." : "Synkroniser filene dine på tvers av enhetene dine med skrivebordsprogrammet og mobilappen, og koble til kalenderen og kontaktene dine.",
    "Desktop app ↗" : "Skrivebordsapp ↗",
    "Download For Windows, Mac OS and Linux." : "Last ned for Windows, Mac OS og Linux.",
    "Calendar and contacts ↗" : "Kalender og kontakter ↗",
    "Connect your calendar and contacts with your devices." : "Koble kalenderen og kontaktene til enhetene dine.",
    "Welcome to {cloudName}!" : "Velkommen til {cloudName}!",
    "Skip" : "Hopp over",
    "This Nextcloud is on version {version}" : "Denne Nextcloud er på versjon {version}",
    "A collaboration platform that puts you in control" : "En samarbeidsplattform som setter deg i førersetet",
    "Privacy" : "Personvern",
    "Host your data and files where you decide." : "Vær vert for dataene og filene dine der du ønsker.",
    "Productivity" : "Produktivitet",
    "Collaborate and communicate across any platform." : "Samarbeid og kommuniser over hvilken som helst plattform.",
    "Interoperability" : "Samspillsevne",
    "Import and export anything you want with open standards." : "Importer og eksporter hva du vil med åpne standarder.",
    "Community" : "Samfunn",
    "Enjoy constant improvements from a thriving open-source community." : "Nyt stadige forbedringer fra et blomstrende åpen kildekode-fellesskap.",
    "Nextcloud Hub {version} release" : "Nextcloud Hub {version} utgivelse",
    "Read more about it on the Nextcloud Hub {version} blog" : "Les mer om det på Nextcloud Hub {version} bloggen",
    "Find out more on the blog" : "Finn ut mer på bloggen",
    "Read the Nextcloud Hub {version} blog" : "Les bloggen Nextcloud Hub {version}",
    "Share your opinion about Nextcloud Hub {version}" : "Del meningen din om Nextcloud Hub {version}",
    "Share via email" : "Del via e-post",
    "Share on {socialMedia}" : "Del på {socialMedia}",
    "New in Nextcloud Hub {version}" : "Nytt i Nextcloud Hub {version}",
    "Connect other apps to {productName}" : "Koble andre apper til {productName}",
    "Besides the mobile apps and desktop client you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to {productName}." : "I tillegg til mobilappene og skrivebordsklienten kan du koble til annen programvare som støtter WebDAV/CalDAV/CardDAV-protokollene til {productName}.",
    "Apps to connect to {productName}" : "Apper å koble til {productName}",
    "Set up sync clients using an {linkStart}app password{linkEnd}. That way you can make sure you are able to revoke access in case you lose that device." : "Sett opp synkroniseringsklienter ved hjelp av et {linkStart}app-passord{linkEnd}. På den måten kan du sørge for at du kan tilbakekalle tilgangen i tilfelle du mister den enheten.",
    "Get the apps to sync your files" : "Hent apper som synkroniserer filene dine",
    "{productName} gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "{productName} gir deg tilgang til filene dine uansett hvor du er. Våre brukervennlige stasjonære og mobile klienter er tilgjengelige for alle større plattformer uten kostnad.",
    "App for syncing" : "App for synkronisering",
    "URL copied" : "URL kopiert",
    "Could not copy the URL, please copy manually" : "Kunne ikke kopiere URL-en, vennligst kopier manuelt",
    "Server address" : "Serveradresse",
    "Use this link to connect your apps and desktop client to this server:" : "Bruk denne koblingen til å koble appene og skrivebordsklienten til denne serveren:",
    "What's new?" : "Hva er nytt?",
    "Nextcloud on all your devices" : "Nextcloud på alle dine enheter",
    "Nextcloud Hub {version}" : "Nextcloud Hub {version}",
    "Share on social media" : "Del på sosiale medier",
    "Get started!" : "Kom i gang!"
},
"nplurals=2; plural=(n != 1);");
