OC.L10N.register(
    "sharebymail",
    {
    "Shared with {email}" : "Gedeeld met {email}",
    "Shared with {email} by {actor}" : "Gedeeld met {email} door {actor}",
    "Unshared from {email}" : "Niet langer gedeeld door {email}",
    "Unshared from {email} by {actor}" : "Niet langer gedeeld met {email} door {actor}",
    "Password for mail share sent to {email}" : "Wachtwoord voor het delen per mail is naar {email}",
    "Password for mail share sent to you" : "Wachtwoord voor het delen per mail is naar je verstuurd",
    "You shared {file} with {email} by mail" : "Je deelde {file} met {email} per mail",
    "{actor} shared {file} with {email} by mail" : "{actor} deelde {file} met {email} per mail",
    "You unshared {file} from {email} by mail" : "Je deelde niet langer {file} met {email} per mail",
    "{actor} unshared {file} from {email} by mail" : "{actor} deelde niet langer {file} met {email} per mail",
    "Password to access {file} was sent to {email}" : "Wachtwoord voor toegang tot {file} is gestuurd naar {email}",
    "Password to access {file} was sent to you" : "Wachtwoord voor toegang tot {file} is naar je verstuurd",
    "Share by mail" : "Delen via email",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "Het delen van%1$s is mislukt, omdat dit item al gedeeld wordt met het account %2$s",
    "We cannot send you the auto-generated password. Please set a valid email address in your personal settings and try again." : "We kunnen je geen automatisch gegenereerd wachtwoord toesturen. Vermeld een geldig e-mailadres in je persoonlijke instellingen en probeer het nogmaals.",
    "Failed to send share by email. Got an invalid email address" : "Het delen van het bestand per e-mail is mislukt. Ongeldig e-mailadres",
    "Failed to send share by email" : "Versturen share per e-mail is mislukt",
    "%1$s shared %2$s with you" : "%1$s deelde %2$s met jou",
    "Note:" : "Notitie:",
    "This share is valid until %s at midnight" : "Deze share is geldig tot %s middernacht",
    "Expiration:" : "Vervaldatum:",
    "Open shared item" : "Gedeeld item openen",
    "%1$s via %2$s" : "%1$s via %2$s",
    "%1$s shared %2$s with you. You should have already received a separate mail with a link to access it." : "%1$s deelde %2$s met jou. Je zou een aparte e-mail hebben moeten ontvangen met een link om er toegang toe te krijgen.",
    "Password to access %1$s shared to you by %2$s" : "Wachtwoord om toegang te krijgen tot %1$sdat met jou gedeeld werd door %2$s",
    "Password to access %s" : "Wachtwoord om toegang te krijgen tot %s",
    "It is protected with the following password:" : "Het is beveiligd met het volgende wachtwoord:",
    "This password will expire at %s" : "Dit wachtwoord verloopt op %s",
    "%1$s shared %2$s with you and wants to add:" : "%1$s deelde %2$s met jou en wil toevoegen:",
    "%1$s shared %2$s with you and wants to add" : "%1$s deelde %2$s met jou en wil toevoegen",
    "%s added a note to a file shared with you" : "%s heeft een notitie toegevoegd aan een bestand dat met jou werd gedeeld",
    "You just shared %1$s with %2$s. The share was already sent to the recipient. Due to the security policies defined by the administrator of %3$s each share needs to be protected by password and it is not allowed to send the password directly to the recipient. Therefore you need to forward the password manually to the recipient." : "Je deelde %1$s met %2$s. Het deling werd al naar de ontvanger gestuurd. Vanwege het beveiligingsbeleid dat is gedefinieerd door de beheerder van %3$s moet elke share worden beveiligd met een wachtwoord en het is niet toegestaan het wachtwoord rechtstreeks naar de ontvanger te sturen. Daarom moet je het wachtwoord handmatig doorsturen naar de ontvanger.",
    "Password to access %1$s shared by you with %2$s" : "Wachtwoord om toegang te krijgen tot %1$s door jou gedeeld met %2$s",
    "This is the password:" : "Dit is het wachtwoord:",
    "You can choose a different password at any time in the share dialog." : "Je kunt in de Delen-dialoog altijd een ander wachtwoord kiezen.",
    "Could not find share" : "Kon gedeeld niet vinden",
    "Share provider which allows you to share files by mail" : "Share provider waarmee je bestanden via de mail kunt delen",
    "Unable to update share by mail config" : "Kan share  niet bijwerken via mailconfiguratie",
    "Allows people to share a personalized link to a file or folder by putting in an email address." : "Hiermee kunnen mensen een gepersonaliseerde link naar een bestand of map delen door een e-mailadres in te voeren.",
    "Send password by mail" : "Wachtwoord per email verzenden",
    "Reply to initiator" : "Antwoord aan oproeper"
},
"nplurals=2; plural=(n != 1);");
