OC.L10N.register(
    "suspicious_login",
    {
    "New login location detected" : "Nueva ubicación de inicio de sesión detectada",
    "More info about the suspicious IP address available on %s" : "Más información sobre la dirección IP sospechosa disponible en%s",
    "Open %s ↗" : "Abrir %s",
    "Suspicious Login" : "Inicio de sesión sospechoso",
    "New login detected" : "Nuevo inicio de sesión detectado",
    "Detect and warn about suspicious IPs logging into Nextcloud\n\t" : "Detectar y advertir sobre IPs sospechosas que ingresan a Nextcloud",
    "A new login into your account was detected. The IP address %s was classified as suspicious. If this was you, you can ignore this message. Otherwise you should change your password." : "Se detectó un nuevo inicio de sesión en tu cuenta. La dirección IP %s fue clasificada como sospechosa. Si fuiste tú, puedes ignorar este mensaje. De lo contrario, deberías cambiar tu contraseña."
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
