OC.L10N.register(
    "office",
    {
    "Office" : "オフィス",
    "Create new" : "新規作成",
    "Blank" : "ブランク",
    "Search {category}" : "{category}を検索",
    "Search" : "検索",
    "All" : "すべて",
    "Switch to grid view" : "グリッド表示へ切り替え",
    "Switch to list view" : "リスト表示へ切り替え",
    "No {category} found" : "{category}が見つかりません",
    "Create" : "作成",
    "Filename" : "ファイル名",
    "Documents" : "ドキュメント",
    "Spreadsheets" : "スプレッドシート",
    "Presentations" : "プレゼンテーション",
    "Filename cannot be empty" : "ファイル名は空にできません"
},
"nplurals=1; plural=0;");
