OC.L10N.register(
    "files_lock",
    {
    "File is currently locked by %s" : "A fájlt jelenleg zárolja %s",
    "File is not locked" : "A fájl nincs zárolva",
    "File can only be unlocked by providing a valid owner lock token" : "A fájlt csak érvényes zártoken megadásával lehet feloldani",
    "File can only be unlocked by the owner of the lock" : "A fájlt csak a zár tulajdonosa oldhatja fel",
    "Desktop client" : "Asztali kliens",
    "iOS client" : "iOS klens",
    "Android client" : "Android kliens",
    "Temporary files lock" : "Ideiglenes fájlzárolás",
    "Temporary lock your files" : "Fájlok ideiglenes zárolása",
    "Allow your users to temporary lock their files to avoid conflicts while working on shared files." : "Lehetővé teszi a felhasználóinak, hogy ideiglenesen zárolják a fájljaikat, hogy elkerüljék az ütközéseket, ha megosztott fájlokon dolgoznak.",
    "Unlock file" : "Fájl feloldása",
    "Lock file" : "Fájl zárolása"
},
"nplurals=2; plural=(n != 1);");
