OC.L10N.register(
    "circles",
    {
    "You created the team {circle}" : "Δημιουργήσατε την ομάδα {circle}",
    "{author} created the team {circle}" : "Ο/Η {author} δημιούργησε την ομάδα {circle}",
    "You deleted {circle}" : "Διαγράψατε την ομάδα {circle}",
    "{author} deleted {circle}" : "Ο/Η {author} διέγραψε την ομάδα {circle}",
    "You made {member} join {circle}" : "Κάνατε τον/την {member} να γίνει μέλος της ομάδας {circle}",
    "{author} made {member} join {circle}" : "Ο/Η {author} έκανε τον/την {member} να γίνει μέλος της ομάδας {circle}",
    "You added team {member} as member to {circle}" : "Προσθέσατε την ομάδα {member} ως μέλος στην ομάδα {circle}",
    "{author} added team {member} as member to {circle}" : "Ο/Η {author} πρόσθεσε την ομάδα {member} ως μέλος στην ομάδα {circle}",
    "You made {member} leave {circle}" : "Κάνατε τον/την {member} να αποχωρήσει από την ομάδα {circle}",
    "{author} made {member} leave {circle}" : "Ο/Η {author} έκανε τον/την {member} να αποχωρήσει από την ομάδα {circle}",
    "You removed {member} from {circle}" : "Αφαιρέσατε τον/την {member} από την ομάδα {circle}",
    "{author} removed {member} from {circle}" : "Ο/Η {author} αφαίρεσε τον/την {member} από την ομάδα {circle}",
    "You joined {circle}" : "Συνδεθήκατε στην ομάδα {circle}",
    "{member} joined {circle}" : "Ο/Η {member} συνδέθηκε στην ομάδα {circle}",
    "You accepted the invitation to join {circle}" : "Αποδεχθήκατε την πρόσκληση για να συμμετάσχετε στην ομάδα {circle}",
    "{member} accepted the invitation to join {circle}" : "Ο/Η {member} αποδέχτηκε την πρόσκληση να συμμετάσχει στην ομάδα {circle}",
    "You added {member} as member to {circle}" : "Προσθέσατε τον/την {member} ως μέλος στην ομάδα {circle}",
    "You have been added as member to {circle} by {author}" : "Προστεθήκατε ως μέλος στην ομάδα {circle} από τον/την {author}",
    "{member} has been added as member to {circle} by {author}" : "Ο/Η {member} πρόσθεσε ως μέλος στην ομάδα {circle} από τον/την {author}",
    "You added {external} to {circle}" : "Προσθέσατε τον/την {external} στην ομάδα {circle}",
    "{external} has been added to {circle} by {author}" : "Ο/Η {external} προστέθηκε στην ομάδα {circle} από τον/την {author}",
    "You accepted {member}'s request to join {circle}" : "Αποδεχθήκατε το αίτημα του/της {member} να συμμετάσχει στην ομάδα {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Το αίτημά σας να συμμετάσχετε στην ομάδα {circle} έγινε δεκτό από τον/την {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "Το αίτημα του/της {member} να συμμετάσχει στην ομάδα {circle} έγινε αποδεκτό από τον/την {author}",
    "You left {circle}" : "Αποχωρήσατε από την ομάδα {circle}",
    "{member} left {circle}" : "Ο/Η {member} αποχώρησε από την ομάδα {circle}",
    "You declined the invitation to join {circle}" : "Απορρίψατε την πρόσκληση να συμμετάσχετε στην ομάδα {circle}",
    "{member} declined an invitation to join {circle}" : "Ο/Η {member} απέρριψε την πρόσκληση για την ομάδα {circle}",
    "You cancelled your request to join {circle}" : "Ακυρώσατε το αίτημα συμμετοχής στην ομάδα {circle}",
    "{member} cancelled a request to join {circle}" : "Ο/Η {member} ακύρωσε ένα αίτημα συμμετοχής στην ομάδα {circle}",
    "You have been removed from {circle} by {author}" : "Αφαιρεθήκατε από την ομάδα {circle} από τον/την {author}",
    "{member} has been removed from {circle} by {author}" : "Ο/Η {member} αφαιρέθηκε από την ομάδα {circle} από τον/την {author}",
    "You removed {external} from {circle}" : "Αφαιρέσατε τον/την {external} από την ομάδα {circle}",
    "{external} has been removed from {circle} by {author}" : "Ο/Η {external} αφαιρέθηκε από την ομάδα {circle} από τον/την {author}",
    "You cancelled {member}'s invitation to join {circle}" : "Ακυρώσατε την πρόσκληση του/της {member} για συμμετοχή στην ομάδα {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "Η πρόσκλησή σας για συμμετοχή στην ομάδα {circle} ακυρώθηκε από τον/την {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "Ο/Η {author} ακύρωσε την πρόσκληση του/της {member} για συμμετοχή στην ομάδα {circle}",
    "You dismissed {member}'s request to join {circle}" : "Απορρίψατε το αίτημα του/της {member} για συμμετοχή στην ομάδα {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "Το αίτημά σας για συμμετοχή στην ομάδα {circle} απορρίφθηκε από τον/την {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "Το αίτημα του/της {member} για συμμετοχή στην ομάδα {circle} απορρίφθηκε από τον/την {author}",
    "You invited {member} to join {circle}" : "Προσκαλέσατε τον/την {member} να συμμετάσχει στην ομάδα {circle}",
    "You have been invited to join {circle} by {author}" : "Προσκληθήκατε να συμμετάσχετε στην ομάδα {circle} από τον/την {author}",
    "{member} has been invited to join {circle} by {author}" : "Ο/Η {member} προσκλήθηκε να συμμετάσχει στην ομάδα {circle} από τον/την {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Αλλάξατε το επίπεδο του/της {member} στην ομάδα {circle} σε %1$s",
    "{author} changed your level in {circle} to %1$s" : "Ο/Η {author} άλλαξε το επίπεδό σας στην ομάδα {circle} σε %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "Ο/Η {author} άλλαξε το επίπεδο του/της {member} στην ομάδα {circle} σε %1$s",
    "You sent a request to join {circle}" : "Στείλατε αίτημα συμμετοχής στην ομάδα {circle}",
    "{member} sent a request to join {circle}" : "Ο/Η {member} έστειλε αίτημα συμμετοχής στην ομάδα {circle}",
    "You are the new owner of {circle}" : "Είστε ο νέος κάτοχος της ομάδας {circle}",
    "{member} is the new owner of {circle}" : "Ο/Η {member} είναι ο νέος κάτοχος της ομάδας {circle}",
    "Teams" : "Ομάδες",
    "On events happening in a <strong>team</strong> of which you are a member" : "Για συμβάντα που προκύπτουν σε μια <strong>ομάδα</strong> της οποίας είστε μέλος",
    "Any important event in a <strong>team</strong> you are moderating" : "Οποιοδήποτε σημαντικό συμβάν σε μια <strong>ομάδα</strong> που συντονίζετε",
    "On global events happening in any <strong>team</strong>" : "Για καθολικά συμβάντα που προκύπτουν σε οποιαδήποτε <strong>ομάδα</strong>",
    "Single" : "Μεμονωμένος",
    "Personal" : "Προσωπικός",
    "System" : "Συστήματος",
    "Visible" : "Ορατός",
    "Open" : "Ανοιχτός",
    "Invite" : "Πρόσκληση",
    "Join request" : "Αίτημα συμμετοχής",
    "Friends" : "Φίλοι",
    "Password protected" : "Προστασία με συνθηματικό",
    "No Owner" : "Χωρίς κάτοχο",
    "Hidden" : "Κρυφός",
    "Backend" : "Backend",
    "Local" : "Τοπικός",
    "Root" : "Ριζικός",
    "Team invite" : "Πρόσκληση ομάδας",
    "Federated" : "Federated",
    "Mount point" : "Σημείο προσάρτησης",
    "App" : "Εφαρμογή",
    "Nextcloud Account" : "Λογαριασμός Nextcloud",
    "Nextcloud Group" : "Ομάδα Nextcloud",
    "Email address" : "Διεύθυνση email",
    "Contact" : "Επαφή",
    "Team" : "Ομάδα",
    "Nextcloud App" : "Εφαρμογή Nextcloud",
    "Teams App" : "Εφαρμογή Ομάδων",
    "Admin Command Line" : "Γραμμή εντολών διαχειριστή",
    "Member" : "Μέλος",
    "Moderator" : "Συντονιστής",
    "Admin" : "Διαχειριστής",
    "Owner" : "Κάτοχος",
    "%s shared »%s« with you." : "Ο/Η %s μοιράστηκε το »%s« μαζί σας.",
    "%s shared »%s« with \"%s\"." : "Ο/Η %s μοιράστηκε το »%s« με το \"%s\".",
    "%s on %s" : "%s στις %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "Ο/Η %1$s μοιράστηκε το »%2$s« μαζί σας.\nΘα πρέπει να έχετε ήδη λάβει ένα ξεχωριστό email με έναν σύνδεσμο για πρόσβαση σε αυτό.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "Ο/Η %1$s μοιράστηκε το »%2$s« μαζί σας. Θα πρέπει να έχετε ήδη λάβει ένα ξεχωριστό email με έναν σύνδεσμο για πρόσβαση σε αυτό.",
    "Password to access »%1$s« shared to you by %2$s" : "Το συνθηματικό για την πρόσβαση στο »%1$s« κοινοποιήθηκε σε εσάς από τον/την %2$s",
    "Password to access »%s«" : "Συνθηματικό για πρόσβαση στο »%s«",
    "It is protected with the following password:" : "Προστατεύεται με το ακόλουθο συνθηματικό:",
    "%1$s via %2$s" : "%1$s μέσω %2$s",
    "Click the button below to open it." : "Κάντε κλικ στο παρακάτω κουμπί για να το ανοίξετε.",
    "Open »%s«" : "Άνοιγμα »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "Ο/Η %1$s μοιράστηκε πολλαπλά αρχεία μαζί σας.\nΘα πρέπει να έχετε ήδη λάβει ένα ξεχωριστό email με έναν σύνδεσμο για πρόσβαση σε αυτά.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "Ο/Η %1$s μοιράστηκε πολλαπλά αρχεία μαζί σας. Θα πρέπει να έχετε ήδη λάβει ένα ξεχωριστό email με έναν σύνδεσμο για πρόσβαση σε αυτά.",
    "Password to access files shared to you by %1$s" : "Συνθηματικό για πρόσβαση στα αρχεία που κοινοποιήθηκαν σε εσάς από τον/την %1$s",
    "Password to access files" : "Συνθηματικό για πρόσβαση στα αρχεία",
    "%s shared multiple files with \"%s\"." : "Ο/Η %s μοιράστηκε πολλαπλά αρχεία με το \"%s\".",
    "%s shared multiple files with you." : "Ο/Η %s μοιράστηκε πολλαπλά αρχεία μαζί σας.",
    "Boot up" : "Εκκίνηση",
    "Nextcloud Initialization" : "Αρχικοποίηση Nextcloud",
    "Teams App Initialization" : "Αρχικοποίηση εφαρμογής Ομάδων",
    "Fresh installation status" : "Κατάσταση νέας εγκατάστασης",
    "Building Local Database" : "Δημιουργία τοπικής βάσης δεδομένων",
    "Testing Basic Team Creation" : "Δοκιμή βασικής δημιουργίας ομάδας",
    "Adding local users and moderators" : "Προσθήκη τοπικών χρηστών και συντονιστών",
    "Show all teams" : "Εμφάνιση όλων των ομάδων",
    "Create a new team" : "Δημιουργία νέας ομάδας",
    "Files" : "Αρχεία",
    "This feature is not available for personal teams" : "Αυτή η δυνατότητα δεν είναι διαθέσιμη για προσωπικές ομάδες",
    "The team is not federated" : "Η ομάδα δεν είναι federated",
    "You cannot join this team" : "Δεν μπορείτε να συμμετάσχετε σε αυτήν την ομάδα",
    "This member is not a moderator" : "Αυτό το μέλος δεν είναι συντονιστής",
    "Insufficient privileges" : "Ανεπαρκή δικαιώματα",
    "This member does not exist" : "Αυτό το μέλος δεν υπάρχει",
    "This member is the owner of the team" : "Αυτό το μέλος είναι ο κάτοχος της ομάδας",
    "Level cannot be changed for this type of member" : "Το επίπεδο δεν μπορεί να αλλάξει για αυτόν τον τύπο μέλους",
    "You are already a member of this team" : "Είστε ήδη μέλος αυτής της ομάδας",
    "You have been blocked from this team" : "Σας έχει αποκλειστεί η πρόσβαση σε αυτή την ομάδα",
    "The account is already a member of this team" : "Ο λογαριασμός είναι ήδη μέλος αυτής της ομάδας",
    "The account has already been invited into this team" : "Έχει ήδη σταλεί πρόσκληση σε αυτόν τον λογαριασμό για αυτή την ομάδα",
    "%s (Team owned by %s)" : "%s (Ομάδα που ανήκει στον/στην %s)",
    "You are now a member of the Team \"%2$s\"" : "Είστε πλέον μέλος της ομάδας \"%2$s\"",
    "You have been invited by %1$s into the Team \"%2$s\"" : "Έχετε προσκληθεί από τον/την %1$s στην ομάδα \"%2$s\"",
    "%1$s sent a request to be a member of the Team \"%2$s\"" : "Ο/Η %1$s έστειλε αίτημα για να γίνει μέλος της ομάδας \"%2$s\"",
    "Accept" : "Αποδοχή",
    "Refuse" : "Απόρριψη",
    "Leave the team" : "Αποχώρηση από την ομάδα",
    "No image file provided" : "Δεν παρέχεται αρχείο εικόνας",
    "Invalid file provided" : "Το αρχείο που παρασχέθηκε δεν είναι έγκυρο",
    "File is too big" : "Το αρχείο είναι πολύ μεγάλο",
    "Invalid image" : "Μη έγκυρη εικόνα",
    "Unknown filetype" : "Άγνωστος τύπος αρχείου",
    "%s" : "%s",
    "Personal team" : "Προσωπική ομάδα",
    "%s owned by %s" : "Η ομάδα %s ανήκει στον/στην %s",
    "You have no permission to create a new team" : "Δεν έχετε δικαίωμα να δημιουργήσετε νέα ομάδα",
    "Insufficient permissions to perform this action" : "Ανεπαρκή δικαιώματα για την εκτέλεση αυτής της ενέργειας",
    "%s shared a file with \"%s\"." : "Ο/Η %s μοιράστηκε ένα αρχείο με το \"%s\".",
    "%s shared a file with you." : "Ο/Η %s μοιράστηκε ένα αρχείο μαζί σας.",
    "%1$s shared %2$s with %3$s" : "Ο/Η %1$s μοιράστηκε το %2$s με τον/την %3$s",
    "%1$s shared %2$s with \"%3$s\"" : "Ο/Η %1$s μοιράστηκε το %2$s με το \"%3$s\"",
    "Open %s" : "Άνοιγμα %s",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "Ο/Η %1$s μοιράστηκε κάποιο περιεχόμενο μαζί σας.\nΘα πρέπει να έχετε ήδη λάβει ένα ξεχωριστό email με έναν σύνδεσμο για πρόσβαση σε αυτό.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "Ο/Η %1$s μοιράστηκε κάποιο περιεχόμενο μαζί σας. Θα πρέπει να έχετε ήδη λάβει ένα ξεχωριστό email με έναν σύνδεσμο για πρόσβαση σε αυτό.",
    "Password to access content shared with you by %1$s" : "Συνθηματικό για πρόσβαση στο περιεχόμενο που μοιράστηκε μαζί σας ο/η %1$s",
    "Password to access content" : "Συνθηματικό για πρόσβαση στο περιεχόμενο",
    "Federated Teams" : "Ομοσπονδιακές Ομάδες",
    "This item is already shared with this team" : "Αυτό το αντικείμενο είναι ήδη διαμοιρασμένο με αυτήν την ομάδα",
    "Bring cloud-users closer together." : "Φέρνει τους χρήστες του cloud πιο κοντά.",
    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Οι Ομάδες επιτρέπουν στους χρήστες να δημιουργούν τις δικές τους ομάδες ατόμων/συναδέλφων/φίλων.\nΑυτές οι ομάδες ατόμων μπορούν στη συνέχεια να χρησιμοποιηθούν από οποιαδήποτε άλλη εφαρμογή για σκοπούς διαμοιρασμού.",
    "Unable to update federated teams config" : "Αδυναμία ενημέρωσης των ρυθμίσεων ομοσπονδιακών ομάδων",
    "Invalid URL format. Please provide a valid URL." : "Μη έγκυρη μορφή URL. Παρακαλούμε εισαγάγετε ένα έγκυρο URL.",
    "Changed frontal cloud URL" : "Το εξωτερικό (frontal) URL του cloud άλλαξε",
    "Federation allows you to share teams with other trusted servers and make them discoverable across instances." : "Η Ομοσπονδία σάς επιτρέπει να διαμοιράζεστε ομάδες με άλλους έμπιστους διακομιστές και να τις καθιστάτε ανιχνεύσιμες μεταξύ διαφορετικών εγκαταστάσεων.",
    "Enable federated teams" : "Ενεργοποίηση ομοσπονδιακών ομάδων",
    "Frontal URL" : "Εξωτερικό URL (Frontal)",
    "https://…" : "https://…",
    "The public URL used by other instances to discover and connect to your teams." : "Το δημόσιο URL που χρησιμοποιείται από άλλες εγκαταστάσεις για την ανίχνευση και τη σύνδεση με τις ομάδες σας.",
    "Unlimited" : "Απεριόριστο",
    "Default quota" : "Προεπιλεγμένη χωρητικότητα",
    "Select default quota" : "Επιλογή προεπιλεγμένης χωρητικότητας",
    "Save" : "Αποθήκευση",
    "Reconnect" : "Επανασύνδεση",
    "Connect" : "Σύνδεση",
    "New team" : "Νέα ομάδα",
    "Search teams" : "Αναζήτηση ομάδων",
    "Overview" : "Επισκόπηση",
    "No teams found" : "Δεν βρέθηκαν ομάδες",
    "Try a different search." : "Δοκιμάστε μια διαφορετική αναζήτηση.",
    "Create a team to get started." : "Δημιουργήστε μια ομάδα για να ξεκινήσετε.",
    "Members" : "Μέλη",
    "_%n resource_::_%n resources_" : ["%n πόρος","%n πόροι"],
    "Team \"{name}\" created" : "Η ομάδα \"{name}\" δημιουργήθηκε",
    "Could not create the team" : "Αδυναμία δημιουργίας της ομάδας",
    "Cancel" : "Ακύρωση",
    "Next" : "Επόμενο",
    "Back" : "Πίσω",
    "Create team" : "Δημιουργία ομάδας",
    "Step {current} of {total}" : "Βήμα {current} από {total}",
    "Team name" : "Όνομα ομάδας",
    "e.g. Design" : "π.χ. Σχεδιασμός",
    "Search for people to add" : "Αναζήτηση ατόμων για προσθήκη",
    "Switch to list view" : "Εναλλαγή σε προβολή λίστας",
    "Switch to grid view" : "Εναλλαγή σε προβολή πλέγματος",
    "Empty folder" : "Άδειος φάκελος",
    "Folder" : "Φάκελος",
    "Team owner" : "Κάτοχος ομάδας",
    "you" : "εσείς",
    "Manage team" : "Διαχείριση ομάδας",
    "Copy link" : "Αντιγραφή συνδέσμου",
    "Leave team" : "Αποχώρηση από την ομάδα",
    "Delete team" : "Διαγραφή ομάδας",
    "An error happened during the config change" : "Προέκυψε σφάλμα κατά την αλλαγή των ρυθμίσεων",
    "Confirm enabling federation" : "Επιβεβαίωση ενεργοποίησης ομοσπονδίας",
    "Enabling this will prevent {circle} from being a member of other teams.\nAre you sure?" : "Η ενεργοποίηση αυτής της επιλογής θα εμποδίσει την ομάδα {circle} από το να γίνει μέλος άλλων ομάδων.\nΕίστε βέβαιοι;",
    "Enable federation" : "Ενεργοποίηση ομοσπονδίας",
    "Copied" : "Αντιγράφηκε",
    "Could not copy" : "Αδυναμία αντιγραφής",
    "Enforce password protection on files shared to this team" : "Επιβολή προστασίας με συνθηματικό στα αρχεία που διαμοιράζονται με αυτήν την ομάδα",
    "Use a unique password for all shares to this team" : "Χρήση μοναδικού συνθηματικού για όλους τους διαμοιρασμούς σε αυτήν την ομάδα",
    "Unique password …" : "Μοναδικό συνθηματικό …",
    "Change unique password" : "Αλλαγή μοναδικού συνθηματικού",
    "Failed to save password. Please try again later." : "Αποτυχία αποθήκευσης συνθηματικού. Παρακαλούμε δοκιμάστε ξανά αργότερα.",
    "Close" : "Κλείσιμο",
    "Choose a team picture" : "Επιλογή εικόνας ομάδας",
    "There is no description for this team" : "Δεν υπάρχει περιγραφή για αυτήν την ομάδα",
    "Enter a description for the team" : "Εισαγάγετε μια περιγραφή για την ομάδα",
    "New folder" : "Νέος φάκελος",
    "Folder name" : "Όνομα φακέλου",
    "Talk conversation" : "Συνομιλία Talk",
    "New Talk conversation" : "Νέα συνομιλία Talk",
    "Conversation name" : "Όνομα συνομιλίας",
    "Collective" : "Συλλογικότητα",
    "Calendar" : "Ημερολόγιο",
    "New calendar" : "Νέο ημερολόγιο",
    "Calendar name" : "Όνομα ημερολογίου",
    "Unknown resource type" : "Άγνωστος τύπος πόρου",
    "Team calendar \"{resourceName}\" created and shared with team" : "Το ημερολόγιο ομάδας \"{resourceName}\" δημιουργήθηκε και διαμοιράστηκε με την ομάδα",
    "{resourceType} \"{resourceName}\" created and shared with team" : "Το στοιχείο {resourceType} με όνομα \"{resourceName}\" δημιουργήθηκε και διαμοιράστηκε με την ομάδα",
    "A calendar named \"{name}\" already exists. Please choose a different name." : "Υπάρχει ήδη ένα ημερολόγιο με το όνομα \"{name}\". Παρακαλούμε επιλέξτε ένα διαφορετικό όνομα.",
    "Failed to create {resourceType}: {error}" : "Αποτυχία δημιουργίας {resourceType}: {error}",
    "Please select a valid png or jpg file" : "Παρακαλούμε επιλέξτε ένα έγκυρο αρχείο png ή jpg",
    "Error picking team picture" : "Σφάλμα κατά την επιλογή εικόνας ομάδας",
    "Error cropping avatar picture" : "Σφάλμα κατά την περικοπή της εικόνας προφίλ",
    "An error happened while saving {fields}" : "Προέκυψε σφάλμα κατά την αποθήκευση των πεδίων {fields}",
    "Description" : "Περιγραφή",
    "Upload team picture" : "Μεταφόρτωση εικόνας ομάδας",
    "Choose from Nextcloud Files" : "Επιλογή από τα Αρχεία Nextcloud",
    "Delete picture" : "Διαγραφή εικόνας",
    "Edit" : "Επεξεργασία",
    "Request to join" : "Αίτημα συμμετοχής",
    "Create" : "Δημιουργία",
    "Show in Calendar" : "Εμφάνιση στο Ημερολόγιο",
    "Your request to join this team is pending approval" : "Το αίτημά σας για συμμετοχή σε αυτήν την ομάδα εκκρεμεί προς έγκριση",
    "You are not a member of {circle}" : "Δεν είστε μέλος της ομάδας {circle}",
    "Add" : "Προσθήκη",
    "Edit team picture" : "Επεξεργασία εικόνας ομάδας",
    "Apply" : "Εφαρμογή",
    "Remove {type}" : "Αφαίρεση {type}",
    "Add to group" : "Προσθήκη σε ομάδα",
    "Add members to group" : "Προσθήκη μελών σε ομάδα",
    "Search {types}" : "Αναζήτηση για {types}",
    "Add guest" : "Προσθήκη επισκέπτη",
    "Loading …" : "Φόρτωση …",
    "No results" : "Κανένα αποτέλεσμα",
    "Add {type}" : "Προσθήκη {type}",
    "Promote as sole owner" : "Προαγωγή ως αποκλειστικός κάτοχος",
    "Promote to {level}" : "Προαγωγή σε {level}",
    "Demote to {level}" : "Υποβιβασμός σε {level}",
    "Are you sure you want to leave this team? This action cannot be undone." : "Είστε βέβαιοι ότι θέλετε να αποχωρήσετε από αυτήν την ομάδα; Αυτή η ενέργεια δεν μπορεί να αναιρεθεί.",
    "Leave team failed." : "Η αποχώρηση από την ομάδα απέτυχε.",
    "Could not delete the member {displayName}" : "Αδυναμία διαγραφής του μέλους {displayName}",
    "Could not change the member level to {level}" : "Αδυναμία αλλαγής του επιπέδου μέλους σε {level}",
    "Could not accept membership request" : "Αδυναμία αποδοχής του αιτήματος συμμετοχής",
    "Accept membership request" : "Αποδοχή αιτήματος συμμετοχής",
    "Reject membership request" : "Απόρριψη αιτήματος συμμετοχής",
    "Manage level" : "Διαχείριση επιπέδου",
    "Remove member" : "Αφαίρεση μέλους",
    "Pending" : "Εκκρεμεί",
    "Unable to get the results" : "Αδυναμία λήψης των αποτελεσμάτων",
    "Some members could not be added" : "Ορισμένα μέλη δεν μπόρεσαν να προστεθούν",
    "There was an issue adding members to the team" : "Παρουσιάστηκε πρόβλημα κατά την προσθήκη μελών στην ομάδα",
    "The list of members is only visible to members of this team" : "Η λίστα των μελών είναι ορατή μόνο στα μέλη αυτής της ομάδας",
    "Role" : "Ρόλος",
    "Loading members list …" : "Φόρτωση λίστας μελών …",
    "You currently have no access to the member list" : "Προς το παρόν δεν έχετε πρόσβαση στη λίστα μελών",
    "Add to {team}" : "Προσθήκη στην ομάδα {team}",
    "Invite members to {team}" : "Πρόσκληση μελών στην ομάδα {team}",
    "Your teams and everything shared with them across Nextcloud." : "Οι ομάδες σας και οτιδήποτε διαμοιράζεται με αυτές σε όλο το Nextcloud.",
    "Could not load teams" : "Αδυναμία φόρτωσης ομάδων",
    "Something went wrong while loading your teams." : "Κάτι πήγε στραβά κατά τη φόρτωση των ομάδων σας.",
    "Try again" : "Δοκιμάστε ξανά",
    "No teams yet" : "Δεν υπάρχουν ομάδες ακόμα",
    "Create your first team to start collaborating." : "Δημιουργήστε την πρώτη σας ομάδα για να ξεκινήσετε τη συνεργασία.",
    "Create your first team" : "Δημιουργήστε την πρώτη σας ομάδα",
    "Your teams" : "Οι ομάδες σας",
    "Loading" : "Φόρτωση",
    "Go back" : "Επιστροφή",
    "Join" : "Συμμετοχή",
    "Could not load the team" : "Αδυναμία φόρτωσης της ομάδας",
    "Team not found" : "Η ομάδα δεν βρέθηκε",
    "This team may have been removed." : "Αυτή η ομάδα ενδέχεται να έχει αφαιρεθεί.",
    "Failed to load teams" : "Αποτυχία φόρτωσης ομάδων",
    "Join or create teams to see them here." : "Γίνετε μέλος ή δημιουργήστε ομάδες για να τις δείτε εδώ.",
    "Loading…" : "Γίνεται φόρτωση…",
    "More teams" : "Περισσότερες ομάδες",
    "Link copied to the clipboard" : "Ο σύνδεσμος αντιγράφηκε στο πρόχειρο",
    "Could not copy link to the clipboard" : "Αδυναμία αντιγραφής του συνδέσμου στο πρόχειρο",
    "Are you sure you want to leave {team}?" : "Είστε βέβαιοι ότι θέλετε να αποχωρήσετε από την ομάδα {team};",
    "You left \"{name}\"" : "Αποχωρήσατε από την ομάδα \"{name}\"",
    "Could not leave the team" : "Αδυναμία αποχώρησης από την ομάδα",
    "Are you sure you want to delete {team}? This cannot be undone." : "Είστε βέβαιοι ότι θέλετε να διαγράψετε την ομάδα {team}; Αυτή η ενέργεια δεν μπορεί να αναιρεθεί.",
    "Team deleted" : "Η ομάδα διαγράφηκε",
    "Could not delete the team" : "Αδυναμία διαγραφής της ομάδας",
    "Join team" : "Συμμετοχή στην ομάδα",
    "You are about to leave {circle}.\nAre you sure?" : "Πρόκειται να αποχωρήσετε από την ομάδα {circle}.\nΕίστε βέβαιοι;",
    "Please confirm team leave" : "Παρακαλούμε επιβεβαιώστε την αποχώρηση από την ομάδα",
    "Could not leave the team {displayName}" : "Αδυναμία αποχώρησης από την ομάδα {displayName}",
    "Unable to join the team" : "Αδυναμία συμμετοχής στην ομάδα",
    "You are about to delete {circle}.\nAre you sure?" : "Πρόκειται να διαγράψετε την ομάδα {circle}.\nΕίστε βέβαιοι;",
    "Please confirm team deletion" : "Παρακαλούμε επιβεβαιώστε τη διαγραφή της ομάδας",
    "Unable to delete the team" : "Αδυναμία διαγραφής της ομάδας",
    "Could not copy link to the clipboard." : "Αδυναμία αντιγραφής του συνδέσμου στο πρόχειρο.",
    "All contacts" : "Όλες οι επαφές",
    "Not grouped" : "Χωρίς ομαδοποίηση",
    "Organization chart" : "Οργανόγραμμα",
    "Contacts settings" : "Ρυθμίσεις επαφών",
    "Create your own teams for sharing. Add Nextcloud users, contacts, or anyone via email." : "Δημιουργήστε τις δικές σας ομάδες για διαμοιρασμό. Προσθέστε χρήστες Nextcloud, επαφές ή οποιονδήποτε άλλον μέσω email.",
    "User" : "Χρήστης",
    "Group" : "Ομάδα",
    "Email" : "Email",
    "Invites" : "Προσκλήσεις",
    "Anyone can request membership" : "Οποιοσδήποτε μπορεί να υποβάλει αίτημα συμμετοχής",
    "Members need to accept invitation" : "Τα μέλη πρέπει να αποδεχτούν την πρόσκληση",
    "Memberships must be confirmed/accepted by a Moderator (requires \"Anyone can request membership\")" : "Η συμμετοχή πρέπει να επιβεβαιωθεί/εγκριθεί από έναν Συντονιστή (απαιτείται η επιλογή \"Οποιοσδήποτε μπορεί να υποβάλει αίτημα συμμετοχής\")",
    "Members can also invite" : "Τα μέλη μπορούν επίσης να προσκαλέσουν",
    "Membership" : "Συμμετοχή μέλους",
    "Prevent teams from being a member of another team" : "Αποτροπή των ομάδων από το να γίνονται μέλη άλλης ομάδας",
    "Federation" : "Ομοσπονδία",
    "Allow federated members" : "Να επιτρέπονται ομοσπονδιακά μέλη",
    "Privacy" : "Ιδιωτικότητα",
    "Visible to everyone" : "Ορατό σε όλους",
    "users" : "χρήστες",
    "Users" : "Χρήστες",
    "groups" : "ομάδες",
    "Groups" : "Ομάδες",
    "federated users" : "ομοσπονδιακοί χρήστες",
    "Federated users" : "Ομοσπονδιακοί χρήστες",
    "teams" : "ομάδες",
    "email addresses" : "διευθύνσεις email",
    "Email addresses" : "Διευθύνσεις email",
    "contacts" : "επαφές",
    "Contacts" : "Επαφές",
    "An error has occurred in team(s). Check the console for more details." : "Προέκυψε σφάλμα στις ομάδες. Ελέγξτε την κονσόλα για περισσότερες λεπτομέρειες.",
    "Unable to create team {circleName}" : "Αδυναμία δημιουργίας της ομάδας {circleName}",
    "Unable to delete team {circleId}" : "Αδυναμία διαγραφής της ομάδας {circleId}",
    "No files in here" : "Δεν υπάρχουν αρχεία εδώ",
    "No entries found in this folder" : "Δεν βρέθηκαν καταχωρίσεις σε αυτόν τον φάκελο",
    "Name" : "Όνομα",
    "Size" : "Μέγεθος",
    "Modified" : "Τροποποιήθηκε",
    "Circles App Initialization" : "Αρχικοποίηση της εφαρμογής Circles"
},
"nplurals=2; plural=(n != 1);");
