OC.L10N.register(
    "files_pdfviewer",
    {
    "Failed to load settings" : "Ha fallat carregar els paràmetres",
    "Failed to save settings" : "No s'han pogut desar els paràmetres"
},
"nplurals=2; plural=(n != 1);");
