OC.L10N.register(
    "files_versions",
    {
    "Block file versioning" : "Blockera filversionshantering",
    "Automatic tag based blocking of file version creation." : "Automatisk taggbaserad blockering av skapandet av filversioner.",
    "No rule given" : "Ingen regel angiven",
    "A new version is created" : "En ny version skapas",
    "Versions" : "Versioner",
    "This application automatically maintains older versions of files that are changed." : "Den här appen bevarar automatiskt äldre versioner av filer som ändras.",
    "This application automatically maintains older versions of files that are changed. When enabled, a hidden versions folder is provisioned in every user's directory and is used to store old file versions. A user can revert to an older version through the web interface at any time, with the replaced file becoming a version. The app automatically manages the versions folder to ensure the account does not run out of Quota because of versions.\n\t\tIn addition to the expiry of versions, the versions app makes certain never to use more than 50% of the account's currently available free space. If stored versions exceed this limit, the app will delete the oldest versions first until it meets this limit. More information is available in the Versions documentation." : "Den här appen bevarar automatiskt äldre versioner av filer som ändras. När den är aktiverad skapas en dold versionsmapp i varje användares katalog, där äldre filversioner lagras. Användaren kan när som helst återgå till en äldre version via webbgränssnittet. Den ersatta filen sparas då som en version. Appen hanterar versionsmappen automatiskt så att kontots kvot inte tar slut på grund av filversioner.\nUtöver att gamla versioner löper ut ser appen till att versionerna aldrig använder mer än 50 % av kontots lediga utrymme. Om de lagrade versionerna överskrider gränsen tar appen bort de äldsta versionerna först tills användningen ligger under gränsen. Mer information finns i dokumentationen för Versioner.",
    "Current version" : "Aktuell version",
    "Initial version" : "Första versionen",
    "You" : "Du",
    "Actions for version from {versionHumanExplicitDate}" : "Åtgärder för version från {versionHumanExplicitDate}",
    "Name this version" : "Namnge denna version",
    "Edit version name" : "Ändra versionsnamn",
    "Compare to current version" : "Jämför med den aktuella versionen",
    "Restore version" : "Återställ version",
    "Download version" : "Hämta version",
    "Delete version" : "Ta bort version",
    "Cancel" : "Avbryt",
    "Remove version name" : "Ta bort versionsnamn",
    "Save version name" : "Spara versionsnamn",
    "Version name" : "Namn på version",
    "Named versions are persisted, and excluded from automatic cleanups when your storage quota is full." : "Namngivna versioner bevaras och undantas från automatisk rensning när lagringskvoten är full.",
    "Initial version restored" : "Ursprunglig version återställd",
    "Version restored" : "Version återställd",
    "Could not restore version" : "Det gick inte att återställa versionen",
    "Could not set version label" : "Det gick inte att ange versionsetiketten",
    "Could not delete version" : "Det gick inte att ta bort versionen",
    "File versions" : "Filversioner"
},
"nplurals=2; plural=(n != 1);");
