OC.L10N.register(
    "files",
    {
    "Added to favorites" : "Добавлено в избранное",
    "Removed from favorites" : "Удалено из избранного",
    "You added {file} to your favorites" : "Вы добавили «{file}» в избранное",
    "You removed {file} from your favorites" : "Вы удалили «{file}» из избранного",
    "Favorites" : "Избранные",
    "File changes" : "Изменения файлов",
    "Created by {user}" : "Создано пользователем {user}",
    "Changed by {user}" : "Изменено пользователем {user}",
    "Deleted by {user}" : "Удалено пользователем {user}",
    "Restored by {user}" : "Восстановлено пользователем {user}",
    "Renamed by {user}" : "Переименовано пользователем {user}",
    "Moved by {user}" : "Перемещено пользователем {user}",
    "\"remote account\"" : "«пользователь другого сервера»",
    "You created {file}" : "Вы создали «{file}»",
    "You created an encrypted file in {file}" : "Вы создали зашифрованный файл в «{file}»",
    "{user} created {file}" : "{user} создал(а) «{file}»",
    "{user} created an encrypted file in {file}" : "{user} создал(а) зашифрованный файл в «{file}»",
    "{file} was created in a public folder" : "«{file}» создан в общедоступом каталоге",
    "You changed {file}" : "Вы изменили «{file}»",
    "You changed an encrypted file in {file}" : "Вы изменили зашифрованный файл в «{file}»",
    "{user} changed {file}" : "{user} изменил(а) «{file}»",
    "{user} changed an encrypted file in {file}" : "{user} изменил(а) зашифрованный файл в «{file}»",
    "You deleted {file}" : "Вы удалили «{file}»",
    "You deleted an encrypted file in {file}" : "Вы удалили зашифрованный файл в «{file}»",
    "{user} deleted {file}" : "{user} удалил(а) «{file}»",
    "{user} deleted an encrypted file in {file}" : " {user} удалил(а) зашифрованный файл в «{file}»",
    "You restored {file}" : "Вы восстановили «{file}»",
    "{user} restored {file}" : "{user} восстановил(а) «{file}»",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Вы переименовали {oldfile} (скрытый) в {newfile} (скрытый)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Вы переименовали {oldfile} (скрытый) в {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Вы переименовали {oldfile} в {newfile} (скрытый)",
    "You renamed {oldfile} to {newfile}" : "Вы переименовали «{oldfile}» в «{newfile}»",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} переименовал(а) {oldfile} (скрытый) в {newfile} (скрытый)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} переименовал(а) {oldfile} (скрытый) в {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} переименовал(а) {oldfile} в {newfile} (скрытый)",
    "{user} renamed {oldfile} to {newfile}" : "{user} переименовал(а) «{oldfile}» в «{newfile}»",
    "You moved {oldfile} to {newfile}" : "Вы переместили «{oldfile}» в «{newfile}»",
    "{user} moved {oldfile} to {newfile}" : "{user} переместил(а) «{oldfile}» в «{newfile}»",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Файл добавлен в <strong>избранное</strong> или удалён оттуда",
    "Files" : "Файлы",
    "A file or folder has been <strong>changed</strong>" : "<strong>Изменён</strong> файл или каталог",
    "A favorite file or folder has been <strong>changed</strong>" : "<strong>Изменён</strong> файл или папка отмеченные как избранное",
    "Failed to authorize" : "Не удалось авторизовать",
    "Invalid folder path" : "Неверный путь к папке",
    "Folder not found" : "Папка не найдена",
    "The file cannot be found" : "Файл не может быть найден",
    "The destination path does not exist: %1$s" : "Конечный путь не существует: %1$s",
    "You do not have permission to create a file at the specified location" : "У вас нет разрешения на создание файла в указанном месте",
    "The file could not be converted." : "Файл не может быть преобразован.",
    "Could not get relative path to converted file" : "Не удалось получить относительный путь к преобразованному файлу",
    "Limit must be a positive integer." : "Предел должен быть положительным целым числом.",
    "The replacement character may only be a single character." : "Заменяющий символ может состоять только из одного символа.",
    "Filename sanitization already started." : "Очистка имени файла уже начата.",
    "No filename sanitization in progress." : "В процессе работы не выполняется очистка имени файла.",
    "Favorite files" : "Избранные файлы",
    "No favorites" : "Нет избранного",
    "More favorites" : "Больше избранного",
    "No read permission on file." : "Нет прав для чтения файла.",
    "Accept" : "Принять",
    "Reject" : "Отклонить",
    "Incoming ownership transfer from {user}" : "Запрос передачи владения от пользователя {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Принять владение {path}?\n\nПримечание: процесс переноса может занять до одного часа.",
    "Ownership transfer denied" : "Передача владения отклонена",
    "Your ownership transfer of {path} was denied by {user}." : "Передача владения {path} отклонена {user}.",
    "Ownership transfer failed" : "Не удалось передать владение",
    "Your ownership transfer of {path} to {user} failed." : "Вам не удалось передать владение «{path}» пользователю {user}.",
    "The ownership transfer of {path} from {user} failed." : "Пользователю {user} не удалось передать владение «{path}».",
    "Ownership transfer done" : "Передача владения завершена",
    "Your ownership transfer of {path} to {user} has completed." : "Завершена передача владения «{path}» от вас пользователю {user}.",
    "The ownership transfer of {path} from {user} has completed." : "Завершена передача владения «{path}» от пользователя {user}.",
    "in %s" : "в %s",
    "Transferred from %1$s on %2$s" : "Передано от %1$s %2$s",
    "Create files" : "Создать файлы",
    "Delete files" : "Удалить файлы",
    "Download files" : "Скачать файлы",
    "When disabled, the option to download will be hidden" : "При отключении, будет скрыта кнопка скачивания",
    "View files" : "Просмотреть файлы",
    "Edit files" : "Редактировать файлы",
    "Show files in grid view" : "Показать файлы в виде сетки",
    "File" : "Файл",
    "File Management" : "Управление файлами",
    "Home" : "Главная",
    "Target folder does not exist any more" : "Каталог больше не существует",
    "Reload current directory" : "Обновить текущий каталог",
    "Go to the \"{dir}\" directory" : "Перейти в каталог \"{dir}\"",
    "Current directory path" : "Текущий путь к каталогу",
    "Share" : "Поделиться",
    "Reload content" : "Обновить содержимое",
    "Your have used your space quota and cannot upload files anymore" : "Вы использовали всё доступное вам место и не можете больше загружать файлы",
    "You do not have permission to upload or create files here." : "У вас нет прав загружать или создавать здесь файлы.",
    "Drag and drop files here to upload" : "Перетаскивайте файлы сюда для загрузки",
    "Favorite" : "Добавить в избранное",
    "Back" : "Назад",
    "Toggle selection for file \"{displayName}\"" : "Установить или снять выделение файла «{displayName}»",
    "Toggle selection for folder \"{displayName}\"" : "Установить или снять выделение папки «{displayName}»",
    "File is loading" : "Файл загружается",
    "Folder is loading" : "Папка загружается",
    "Filename" : "Имя файла",
    "Folder name" : "Имя папки",
    "{displayName} (unavailable)" : "{displayName} (недоступно)",
    "Another entry with the same name already exists." : "Другая запись с таким же именем уже существует.",
    "Invalid filename." : "Недопустимое имя файла.",
    "Rename file" : "Переименовать файл",
    "Recently created" : "Недавно создано",
    "Folder" : "Каталог",
    "Unknown file type" : "Неизвестный тип файла",
    "{ext} image" : "{ext} изображение",
    "{ext} video" : "{ext} видео",
    "{ext} audio" : "{ext} аудио",
    "{ext} text" : "{ext} текст",
    "Pending" : "Ожидается",
    "Unknown date" : "Неизвестная дата",
    "Active filters" : "Активные фильтры",
    "Remove filter" : "Удалить фильтр",
    "Today" : "Сегодня",
    "Last 7 days" : "Последние 7 дней",
    "Last 30 days" : "Последние 30 дней",
    "This year ({year})" : "Этот год ({year})",
    "Last year ({year})" : "Последний год ({year})",
    "Custom range" : "Настраиваемый период",
    "Custom date range" : "Настраиваемый диапазон дат",
    "Search everywhere" : "Искать везде",
    "Documents" : "Документы",
    "Spreadsheets" : "Таблицы",
    "Presentations" : "Презентации",
    "PDFs" : "PDFs",
    "Folders" : "Папки",
    "Audio" : "Звук",
    "Images" : "Изображения",
    "Videos" : "Видео",
    "Filters" : "Фильтры",
    "Back to filters" : "Вернуться к фильтрам",
    "Appearance" : "Внешний вид",
    "Show hidden files" : "Показывать скрытые файлы",
    "Show file type column" : "Показать колонку с типом файла",
    "Show file extensions" : "Показать расширения файлов",
    "Crop image previews" : "Обрезать пред. просмотр",
    "General" : "Основные",
    "Sort favorites first" : "Сначала избранное",
    "Sort folders before files" : "Начинать список с папок",
    "Enable folder tree view" : "Включить просмотр дерева папок",
    "Default view" : "Вид по умолчанию",
    "All files" : "Все файлы",
    "Personal files" : "Личные файлы",
    "Additional settings" : "Дополнительные параметры",
    "Actions" : "Действия",
    "File actions" : "Сценарии файла",
    "Selection" : "Выбор",
    "Select all files" : "Выбрать все файлы",
    "Deselect all" : "Снять выбор со всех",
    "Select or deselect" : "Выбрать или отменить выбор",
    "Select a range" : "Выберите диапазон",
    "Navigation" : "Навигация",
    "Go to parent folder" : "Перейти в родительскую папку",
    "Go to file above" : "Перейдите к файлу, указанному выше",
    "Go to file below" : "Перейдите к файлу ниже",
    "Go left in grid" : "Идите налево по сетке",
    "Go right in grid" : "Идите направо по сетке",
    "View" : "Режим просмотра",
    "Toggle grid view" : "Включить или отключить режим просмотра сеткой",
    "Show those shortcuts" : "Показать ярлыки",
    "Warnings" : "Предупреждения",
    "Warn before changing a file extension" : "Предупреждать перед изменением расширения файла",
    "Warn before deleting a file" : "Предупреждать перед удалением файлов",
    "WebDAV URL" : "Ссылка WebDAV",
    "Create an app password" : "Создать пароль приложения",
    "Required for WebDAV authentication because Two-Factor Authentication is enabled for this account." : "Требуется для подключения по протоколу WebDAV, т.к. для этой учётной записи включена двухфакторная аутентификация.",
    "How to access files using WebDAV" : "Как получить доступ к файлам с помощью WebDAV",
    "Total rows summary" : "Количество строк в общем",
    "Toggle selection for all files and folders" : "Установить или снять выделение всех файлов и папок",
    "Name" : "Имя",
    "File type" : "Тип файла",
    "Size" : "Размер",
    "Modified" : "Изменён",
    "{displayName}: failed on some elements" : "{displayName}: не удалось выполнить некоторые элементы",
    "{displayName}: done" : "{displayName}: сделано",
    "{displayName}: failed" : "{displayName}: сбой",
    "(selected)" : "(выбранный)",
    "List of files and folders." : "Список файлов и каталогов.",
    "You have used your space quota and cannot upload files anymore." : "Вы использовали свою квоту свободного места и больше не можете загружать файлы.",
    "Column headers with buttons are sortable." : "Заголовки столбцов с кнопками можно сортировать.",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Этот список отображается не полностью из соображений производительности. Файлы будут отображаться по мере перемещения по списку.",
    "File not found" : "Файл не найден",
    "_{count} selected_::_{count} selected_" : ["Выбран {count}","Выбрано {count}","Выбрано {count}","Выбрано {count} "],
    "Views" : "Представления",
    "Search everywhere …" : "Искать везде…",
    "Search here …" : "Искать здесь…",
    "Search scope options" : "Настройки области поиска",
    "Search here" : "Искать здесь",
    "Owner" : "Владелец",
    "{usedQuotaByte} used" : "Использовано {usedQuotaByte}",
    "{used} of {quota} used" : "использовано {used} из {quota}",
    "{relative}% used" : "Использовано {relative}%",
    "Could not refresh storage stats" : "Не удалось обновить данные об использовании хранилища",
    "Your storage is full, files can not be updated or synced anymore!" : "Ваше хранилище переполнено, файлы больше не могут быть обновлены или синхронизированы.",
    "Storage information" : "Информация о хранении",
    "Storage quota" : "Квота хранилища",
    "New folder" : "Новая папка",
    "Create new folder" : "Создать папку",
    "This name is already in use." : "Это название уже используется.",
    "Create" : "Создать",
    "Files starting with a dot are hidden by default" : "Файлы, начинающиеся с точки, скрыты по умолчанию",
    "Failed to start filename sanitization." : "Не удалось начать очистку имени файла.",
    "Failed to refresh filename sanitization status." : "Не удалось обновить статус очистки имени файла.",
    "Filename sanitization in progress." : "Выполняется очистка имени файла.",
    "Currently {processedUsers} of {totalUsers} accounts are already processed." : "В настоящее время {processedUsers} из {totalUsers}учётных записей обработаны.",
    "Preparing …" : "Подготовка …",
    "Refresh" : "Обновить",
    "All files have been santized for Windows filename support." : "Все файлы были очищены для поддержки имен файлов Windows.",
    "Some files could not be sanitized, please check your logs." : "Некоторые файлы не удалось очистить, проверьте журналы.",
    "Sanitization errors" : "Ошибка очистки",
    "Not sanitized filenames" : "Не очищенные имена файлов",
    "Windows filename support has been enabled." : "Включена поддержка имен файлов Windows.",
    "While this blocks users from creating new files with unsupported filenames, existing files are not yet renamed and thus still may break sync on Windows." : "Хотя это не позволяет пользователям создавать новые файлы с неподдерживаемыми именами, существующие файлы пока не переименовываются и, следовательно, могут по-прежнему нарушать синхронизацию в Windows.",
    "You can trigger a rename of files with invalid filenames, this will be done in the background and may take some time." : "Вы можете инициировать переименование файлов с недопустимыми именами. Это будет выполнено в фоновом режиме и может занять некоторое время.",
    "Please note that this may cause high workload on the sync clients." : "Обратите внимание, что это может привести к высокой нагрузке на клиентов синхронизации.",
    "Limit" : "Лимит",
    "This allows to configure how many users should be processed in one background job run." : "Это позволяет настроить количество пользователей, которые должны быть обработаны за один запуск фонового задания.",
    "Sanitize filenames" : "Очистить имена файлов",
    "(starting)" : "(старт)",
    "Fill template fields" : "Заполните поля шаблона",
    "Submitting fields …" : "Отправка полей …",
    "Submit" : "Отправить ответ",
    "Choose a file or folder to transfer" : "Выберите файл или папку для передачи",
    "Transfer \"{path}\"" : "Перенос \"{path}\"",
    "Select file or folder" : "Выберите файл или папку",
    "Transfer" : "Передать",
    "Transfer {path} to {userid}" : "Передать {path} пользователю {userid}",
    "Error while opening file picker for transfer ownership" : "Ошибка при открытии средства выбора файлов для передачи права собственности",
    "Error while searching for users" : "Ошибка при поиске пользователей",
    "Ownership transfer request sent" : "Запрос на передачу прав владения отправлен",
    "Cannot transfer ownership of a file or folder you do not own" : "Невозможно передать право владения на файл или каталог, которые вам не принадлежат",
    "Error while sending ownership transfer request" : "Ошибка при отправке запроса на передачу владения",
    "Transfer ownership of a file or folder" : "Изменение владельца файла или папки",
    "File or folder to transfer" : "Файл или папка для передачи",
    "No file or folder selected" : "Ни один файл или папка не выбраны",
    "New owner" : "Новый владелец",
    "You need to select a file or folder to transfer ownership." : "Вам нужно выбрать файл или папку для передачи владения",
    "You need to select a new owner for the file or folder." : "Вам необходимо выбрать нового владельца файла или папки.",
    "Keep {old}" : "Сохранить {old}",
    "Keep without extension" : "Сохранить без расширения",
    "Use {new}" : "Использовать{new}",
    "Remove extension" : "Удалить расширение",
    "Change file extension" : "Изменить расширение файла",
    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "Изменение расширения файла с \"{old}\" на \"{new}\" может сделать файл нечитаемым.",
    "Removing the file extension \"{old}\" may render the file unreadable." : "Удаление расширения файла \"{old}\" может сделать файл нечитаемым.",
    "Adding the file extension \"{new}\" may render the file unreadable." : "Добавление расширения файла \"{new}\" может сделать его нечитаемым.",
    "Do not show this dialog again." : "Больше не показывать это диалоговое окно.",
    "Rename file to hidden" : "Переименуйте файл в скрытый",
    "Prefixing a filename with a dot may render the file hidden." : "Префикс имени файла с точкой может сделать файл скрытым.",
    "Are you sure you want to rename the file to \"{filename}\"?" : "Вы уверены, что хотите переименовать файл в \"{filename}\"?",
    "Cancel" : "Отменить",
    "Rename" : "Переименовать",
    "Select file or folder to link to" : "Выберите файл или папку для создания ссылки",
    "Choose {file}" : "Выберан {file}",
    "Files settings" : "Настройки файлов",
    "Switch to list view" : "Переключение в режим просмотра списка",
    "Switch to grid view" : "Переключиться на режим просмотра сеткой",
    "The file could not be found" : "Файл не найден.",
    "Upload was cancelled by user" : "Загрузка была отменена пользователем",
    "Not enough free space" : "Недостаточно свободного места",
    "Operation is blocked by access control" : "Операция не разрешена модулем контроля доступа",
    "Error during upload: {message}" : "Ошибка при загрузке: {message}",
    "Error during upload, status code {status}" : "Ошибка при передаче на сервер. Сообщение об ошибке: {status}",
    "Unknown error during upload" : "Неизвестная ошибка при загрузке",
    "File list is reloading" : "Повторная загрузка списка файлов…",
    "Loading current folder" : "Загрузка текущей папки",
    "Retry" : "Попробовать снова",
    "No files in here" : "Здесь нет файлов",
    "Upload some content or sync with your devices!" : "Загрузите что-нибудь или синхронизируйте со своими устройствами!",
    "Go back" : "Назад",
    "Loading …" : "Загрузка…",
    "Your files" : "Ваши файлы",
    "Open in files" : "Открыть в приложении Файлы",
    "File cannot be accessed" : "Не удалось получить доступ к файлу",
    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Не удалось найти файл или у вас отсутствуют права на его просмотр.  Попросите отправителя предоставить вам доступ к этому файлу.",
    "No search results for “{query}”" : "Нет результатов поиска по запросу «{query}»",
    "Search for files" : "Поиск файлов",
    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Разрешить ограничения на имена файлов для обеспечения возможности их синхронизации со всеми клиентами. По умолчанию разрешены все имена файлов, допустимые в POSIX (например, в Linux или macOS).",
    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "После включения совместимых с Windows названий файлов, существующие файлы нельзя будет изменить, но они могут быть переименованы их владельцем в допустимые новые имена.",
    "Failed to toggle Windows filename support" : "Не удалось включить поддержку имен файлов в Windows",
    "Files compatibility" : "Совместимость файлов",
    "Enforce Windows compatibility" : "Обеспечить совместимость с Windows",
    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Это позволит блокировать имена файлов, недопустимые в системах Windows, например, использующие зарезервированные имена или специальные символы. Однако это не обеспечит совместимость в части чувствительности к регистру.",
    "Blank" : "Пустой",
    "Unable to create new file from template" : "Не удалось создать файл на основе шаблона",
    "Pick a template for {name}" : "Выбрать шаблон для {name}",
    "Create a new file with the selected template" : "Создать файл на основе шаблона",
    "Creating file" : "Создание файла",
    "Save as {displayName}" : "Сохранить как {displayName}",
    "Save as …" : "Сохранить как…",
    "Converting files …" : "Преобразование файлов…",
    "Failed to convert files: {message}" : "Не удалось преобразовать файлы: {message}",
    "All files failed to be converted" : "Не удалось преобразовать все файлы",
    "One file could not be converted: {message}" : "Один файл не удалось преобразовать: {message}",
    "_%n file could not be converted_::_%n files could not be converted_" : ["%n файл не может быть преобразован","%n файла не могут быть преобразованы","%n файлов не могут быть преобразованы","%n файлов не могут быть преобразованы"],
    "_%n file converted_::_%n files converted_" : ["%n файл преобразован","%n файла преобразованы","%n файлов преобразованы","%n файлов преобразованы"],
    "Files converted" : "Файлы преобразованы",
    "Failed to convert files" : "Не удалось преобразовать файлы",
    "Converting file …" : "Преобразование файла…",
    "File successfully converted" : "Файл успешно преобразован",
    "Failed to convert file: {message}" : "Не удалось преобразовать файл: {message}",
    "Failed to convert file" : "Не удалось преобразовать файл",
    "Delete" : "Удалить",
    "Leave this share" : "Перестать использовать общий ресурс",
    "Leave these shares" : "Отказаться от доступа к общим ресурсам",
    "Disconnect storage" : "Отсоединить хранилище",
    "Disconnect storages" : "Отключить хранилища",
    "Delete permanently" : "Удалить навсегда",
    "Delete and unshare" : "Удалить и закрыть общий доступ",
    "Delete file" : "Удалить файл",
    "Delete folder" : "Удалить папку",
    "Delete folders" : "Удалить папки",
    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Вы собираетесь безвозвратно удалить {count} элемент","Вы собираетесь безвозвратно удалить {count} элемента","Вы собираетесь безвозвратно удалить {count} элементов","Вы собираетесь безвозвратно удалить {count} элементов"],
    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Подтвердите удаление {count} объекта.","Подтвердите удаление {count} объектов","Подтвердите удаление {count} объектов","Подтвердите удаление {count} объектов"],
    "Confirm deletion" : "Подтвердить удаление",
    "Download" : "Скачать",
    "The requested file is not available." : "Запрошенный файл недоступен.",
    "The requested files are not available." : "Запрошенные файлы недоступны.",
    "Add to favorites" : "Добавить в избранное",
    "Remove from favorites" : "Удалить из избранных",
    "Add or remove favorite" : "Добавление или удаление избранного",
    "Move" : "Переместить",
    "Copy" : "Копировать",
    "Move or copy" : "Переместить или копировать",
    "Destination is not a folder" : "Указанное назначение не является папкой",
    "This file/folder is already in that directory" : "Файл или папка уже расположены в этой папке",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "Папка или файл не могут быть перемещены во вложенную папку или в себя",
    "A file or folder with that name already exists in this folder" : "В этой папке уже есть файл или папка с этим именем",
    "The files are locked" : "Файлы заблокированы",
    "The file does not exist anymore" : "Файл больше не существует",
    "Moving \"{source}\" to \"{destination}\" …" : "Перемещение \"{source}\" в \"{destination}\" …",
    "_Moving %n file to \"{destination}\" …_::_Moving %n files to \"{destination}\" …_" : ["Перемещение %n файла в \"{destination}\" …","Перемещение %n файлов в \"{destination}\" …","Перемещение %n файлов в \"{destination}\" …","Перемещение %n файлов в \"{destination}\" …"],
    "Copying \"{source}\" to \"{destination}\" …" : "Копирование \"{source}\" в \"{destination}\" …",
    "_Copying %n file to \"{destination}\" …_::_Copying %n files to \"{destination}\" …_" : ["Копирование %n файла в \"{destination}\" …","Копирование %n файлов в \"{destination}\" …","Копирование %n файлов в \"{destination}\" …","Копирование %n файлов в \"{destination}\" …"],
    "Choose destination" : "Выберите место назначения",
    "Copy to {target}" : "Скопировать в «{target}»",
    "Move to {target}" : "Переместить в «{target}»",
    "Move or copy operation failed" : "Ошибка перемещение или копирования",
    "Open folder" : "Открыть папку",
    "Open folder {displayName}" : "Открыть папку «{displayName}»",
    "Open in Files" : "Открыть в приложении «Файлы»",
    "Open locally" : "Открыть локально",
    "Failed to redirect to client" : "Ошибка перенаправления в клиент",
    "Open file locally" : "Открыть файл локально",
    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Теперь файл должен открыться на вашем устройстве. Если это не произошло, пожалуйста, убедитесь, что у вас установлено настольное приложение.",
    "Retry and close" : "Повторить попытку и закрыть",
    "Open online" : "Открыть онлайн",
    "Details" : "Подробно",
    "Open the details sidebar" : "Открыть боковую панель с подробными сведениями",
    "Unfavorite" : "Убрать из избранного",
    "View in folder" : "Посмотреть в каталоге",
    "Type" : "Тип",
    "Created new folder \"{name}\"" : "Создана новая папка \"{name}\"",
    "Unable to initialize the templates directory" : "Не удалось инициализировать каталог шаблонов",
    "Create templates folder" : "Создать папку шаблонов",
    "Templates" : "Шаблоны",
    "New template folder" : "Новая папка шаблонов",
    "In folder" : "В папке",
    "Pick folder to search in" : "Выбрать папку для поиска",
    "Search in all files" : "Поиск во всех файлах",
    "Search in folder: {folder}" : "Поиск в папке: «{folder}»",
    "One of the dropped files could not be processed" : "Один из перетащенных файлов не может быть обработан",
    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Папки не будут загружены, так как используемый браузер не поддерживает работу с файловой системой.",
    "No files to upload" : "Не выбрано ни одного файла для передачи на сервер",
    "Unable to create the directory {directory}" : "Не удалось создать папку «{directory}»",
    "Some files could not be uploaded" : "Не удалось загрузить некоторые файлы",
    "Files uploaded successfully" : "Файлы успешно обновлены",
    "No files to process" : "Нет файлов для обработки",
    "Files copied successfully" : "Файлы успешно скопированы",
    "Files moved successfully" : "Файлы успешно перемещены",
    "Some files could not be copied" : "Не удалось скопировать некоторые файлы",
    "Some files could not be moved" : "Не удалось переместить некоторые файлы",
    "Conflicts resolution skipped" : "Разрешение конфликтов пропущено",
    "Upload cancelled" : "Передача на сервер отменена",
    "Could not rename \"{oldName}\", it does not exist any more" : "Не удалось переименовать \"{oldName}\", его больше не существует",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Имя «{newName}» уже используется в папке «{dir}». Выберите другое имя.",
    "Could not rename \"{oldName}\"" : "Не удалось переименовать «{oldName}»",
    "This operation is forbidden" : "Операция запрещена",
    "This folder is unavailable, please try again later or contact the administration" : "Эта папка недоступна, пожалуйста, повторите попытку позже или свяжитесь с администрацией",
    "Storage is temporarily not available" : "Хранилище временно недоступно",
    "Unexpected error: {error}" : "Неожиданная ошибка: {error}",
    "Unknown error" : "Неизвестная ошибка",
    "_%n file_::_%n files_" : ["%n файл","%n файла","%n файлов","%n файлов"],
    "_%n folder_::_%n folders_" : ["%n каталог","%n каталога","%n каталогов","%n каталогов"],
    "_%n hidden_::_%n hidden_" : ["скрыто %n","скрыто %n","скрыто %n","скрыто %n"],
    "Folder name must not be empty." : "Имя папки не должно быть пустым.",
    "Filename must not be empty." : "Имя файла не должно быть пустым.",
    "\"{char}\" is not allowed inside a folder name." : "Символ \"{char}\" недопустим в названии папки.",
    "\"{char}\" is not allowed inside a filename." : "не допускается внутри имени файла.",
    "\"{segment}\" is a reserved name and not allowed for folder names." : "\"{segment}\" является зарезервированным именем и не допускается для имён папок.",
    "\"{segment}\" is a reserved name and not allowed for filenames." : "является зарезервированным именем и не допускается для имен файлов.",
    "\"{extension}\" is not an allowed filetype." : "не является разрешенным типом файла.",
    "Folder names must not end with \"{extension}\"." : "Имена папок не должны заканчиваться на \"{extension}\".",
    "Filenames must not end with \"{extension}\"." : "Имена файлов не должны заканчиваться на",
    "Invalid folder name." : "Недопустимое имя папки.",
    "List of favorite files and folders." : "Список избранных файлов и папок.",
    "No favorites yet" : "В избранное ещё ничего не добавлено ",
    "Files and folders you mark as favorite will show up here" : "Здесь будут показаны файлы и каталоги, отмеченные как избранные",
    "List of your files and folders." : "Список ваших файлов и каталогов.",
    "Folder tree" : "Дерево папок",
    "List of your files and folders that are not shared." : "Список ваших неопубликованных файлов и папок.",
    "No personal files found" : "Личные файлы не найдены",
    "Files that are not shared will show up here." : "Файлы, которые не опубликованы, показаны здесь.",
    "Recent" : "Недавно изменённые",
    "List of recently modified files and folders." : "Список недавно измененных файлов и директорий.",
    "No recently modified files" : "Нет недавно измененных файлов",
    "Files and folders you recently modified will show up here." : "Здесь будут показаны недавно изменённые файлы и папки",
    "Search" : "Поиск",
    "Search results within your files." : "Результаты поиска в ваших файлах.",
    "This node is unavailable" : "Этот узел недоступен",
    "Renamed \"{oldName}\" to \"{newName}\"" : "Переименовано «{oldName}» в \"{newName}\"",
    "Clear filter" : "Сбросить фильтр",
    "Open file sidebar" : "Открыть боковую панель файлов",
    "Search everywhere …" : "Искать везде…",
    "Search here …" : "Искать здесь…",
    "Preparing …" : "Подготовка…",
    "Submitting fields …" : "Отправка полей…",
    "Invalid path selected" : "Указан некорректный путь",
    "Choose file or folder to transfer" : "Выберите файл или папку для передачи владения",
    "Change" : "Изменить",
    "Shared by link" : "Доступные по ссылке",
    "Shared" : "Опубликованное",
    "You" : "Вы",
    "Shared multiple times with different people" : "Делиться несколько раз с разными людьми",
    "Unable to change the favorite state of the file" : "Невозможно изменить избранное состояние файла",
    "Error while loading the file data" : "Не удалось загрузить данные файла",
    "Tags" : "Метки",
    "Save as …" : "Сохранить как…",
    "Converting files …" : "Преобразование файлов…",
    "Converting file …" : "Преобразование файла…",
    "No entries found in this folder" : "В этом каталоге ничего не найдено",
    "Select all" : "Выбрать всё",
    "Upload too large" : "Файл слишком велик",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Файлы, которые вы пытаетесь передать, превышают лимит максимального размера на этом сервере."
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
