/*!
 * SPDX-FileCopyrightText: 2020 Nextcloud GmbH and Nextcloud contributors
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */
#header {
	background: transparent !important;
	--color-header: rgba(24, 24, 24, 1);

	#body-user.dashboard--dark & {
		--color-header: rgba(255, 255, 255, 1);
	}

	// Show gradient below navigation for visibility of icons when scrolled
	&:before {
		content: ' ';
		display: block;
		position: absolute;
		background-image: linear-gradient(180deg, var(--color-header) 0%, transparent 100%);
		width: 100%;
		height: 70px;
		top: 0;
		margin-top: -70px;
		transition: margin-top var(--animation-slow);

		#body-user.dashboard--scrolled & {
			margin-top: 0;
		}
	}

	// Use flat color instead of gradient for high contrast theme
	#body-user.theme--highcontrast & {
		background-color: var(--color-header) !important;

		&:before {
			display: none;
		}
	}
}

// Move content up so it scrolls below navigation
#content {
	padding-top: 0 !important;
}

// Hide triangle indicators from navigation since they are out of place without the header bar
#appmenu li a.active::before,
#appmenu li:hover a::before,
#appmenu li:hover a.active::before,
#appmenu li a:focus::before {
	display: none !important;
}
