OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Persoonlike aktiwiteitsvoer vir %s",
    "Your feed URL is invalid" : "U voerbronadres is ongeldig",
    "Activity feed" : "Aktiwiteitsvoer",
    "Your settings have been updated." : "U instellings is bygewerk.",
    "Settings have been updated." : "Instellings is bygewerk.",
    "No activities" : "Geen aktiwiteite",
    "Daily activity summary for %s" : "Daaglikse aktiwiteitsopsomming vir %s",
    "All activities" : "Alle aktiwiteite",
    "By others" : "Deur ander",
    "By you" : "Deur u",
    "Hello %s" : "Dag %s",
    "Hello %s," : "Dag %s,",
    "There was some activity at %s" : "Daar was aktiwiteit by %s",
    "_and %n more _::_and %n more _" : ["en nog %n","en nog %n"],
    "Mail" : "Pos",
    "Push" : "Stoot",
    "Activity" : "Aktiwiteit",
    "Notifications" : "Kennisgewings",
    "Today" : "Vandag",
    "From" : "Van",
    "To" : "Aan",
    "Yesterday" : "Gister",
    "You need to set up your email address before you can receive notification emails." : "U moet u e-posadres opstel alvorens u kennisgewings per e-pos kan ontvang.",
    "Send activity emails" : "Stuur aktiwiteit e-posse",
    "As soon as possible" : "So vinnig as moontlik",
    "Hourly" : "Uurliks",
    "Daily" : "Daagliks",
    "Weekly" : "Weekliks",
    "You commented" : "U het kommentaar gelewer",
    "Open {filename}" : "Open {filename}",
    "in {path}" : "in {path}",
    "Home" : "Tuis",
    "This stream will show events like additions, changes & shares" : "Hierdie stroom sal gebeure soos toevoegings, veranderinge & delings vertoon",
    "No activity yet" : "Nog geen aktiwiteit",
    "Enable RSS feed" : "Aktiveer RSS-voer",
    "RSS feed" : "RSS-voer",
    "Unable to load the activity list" : "Kan nie die aktiwiteitslys laai nie",
    "Notification" : "Kennisgewing",
    "Enable notification emails" : "Aktiveer e-poskennisgewings",
    "Send daily activity summary in the morning" : "Stuur soggens daaglikse aktiwiteit",
    "Default settings" : "Verstek instellings",
    "No more events to load" : "Geen meer gebeure om te laai"
},
"nplurals=2; plural=(n != 1);");
