OC.L10N.register(
    "office",
    {
    "Office" : "Oficina",
    "Create new" : "Crea nou",
    "Blank" : "En blanc",
    "Search {category}" : "Cerca {category}",
    "Search" : "Cercar",
    "All" : "Totes",
    "Switch to grid view" : "Canvia a la visualització de quadrícula",
    "Switch to list view" : "Canvia a la visualització de llista",
    "No {category} found" : "No s'ha trobat {category}",
    "Create" : "Crea",
    "Filename" : "Nom del fitxer",
    "Documents" : "Documents",
    "Spreadsheets" : "Fulls de càlcul",
    "Presentations" : "Presentacions",
    "Filename cannot be empty" : "El nom del fitxer no pot estar buit"
},
"nplurals=2; plural=(n != 1);");
