OC.L10N.register(
    "survey_client",
    {
    "Never" : "Никогаш",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Може да помогнете во подобрувањето на Nextcloud со испраќање податоци за вашето тековно поставување и користење."
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
