OC.L10N.register(
    "files_lock",
    {
    "File can only be unlocked by providing a valid owner lock token" : "El archivo solo puede desbloquearse proporcionando un token de bloqueo válido del propietario. ",
    "File can only be unlocked by the owner of the lock" : "El archivo solo puede desbloquearse por el propietario del bloqueo. ",
    "Desktop client" : "Cliente de escritorio",
    "iOS client" : "Cliente iOS",
    "Android client" : "Cliente Android",
    "Temporary files lock" : "Bloqueo temporal de archivos ",
    "Temporary lock your files" : "Bloquea temporalmente tus archivos",
    "Allow your users to temporary lock their files to avoid conflicts while working on shared files." : "Permite a tus usuarios bloquear temporalmente sus archivos para evitar conflictos mientras trabajan en archivos compartidos.",
    "Unlock file" : "Desbloquear archivo",
    "Lock file" : "Bloquear archivo"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
