OC.L10N.register(
    "office",
    {
    "Office" : "Office",
    "Create new" : "Create new",
    "Blank" : "Blank",
    "Search" : "ძებნა",
    "All" : "All",
    "Shared with me" : "Shared with me",
    "Switch to grid view" : "Switch to grid view",
    "Switch to list view" : "Switch to list view",
    "Create" : "Create",
    "Filename" : "Filename",
    "Documents" : "Documents",
    "Filename cannot be empty" : "Filename cannot be empty"
},
"nplurals=2; plural=(n!=1);");
