OC.L10N.register(
    "files_trashbin",
    {
    "restored" : "بازیابی شد",
    "Deleted files" : "فایل‌های حذف شده",
    "Deleted files and folders in the trash bin (may expire during export if you are low on storage space)" : "فایل‌ها و پوشه‌های حذف شده در سطل زباله (ممکن است در حین خروجی‌گیری در صورت کمبود فضای ذخیره‌سازی منقضی شوند)",
    "This application enables people to restore files that were deleted from the system." : "این برنامه به افراد امکان می‌دهد فایل‌هایی را که از سیستم حذف شده‌اند، بازیابی کنند.",
    "This application enables people to restore files that were deleted from the system. It displays a list of deleted files in the web interface, and has options to restore those deleted files back to the people file directories or remove them permanently from the system. Restoring a file also restores related file versions, if the versions application is enabled. When a file is deleted from a share, it can be restored in the same manner, though it is no longer shared. By default, these files remain in the trash bin for 30 days.\nTo prevent an account from running out of disk space, the Deleted files app will not utilize more than 50% of the currently available free quota for deleted files. If the deleted files exceed this limit, the app deletes the oldest files until it gets below this limit. More information is available in the Deleted Files documentation." : "این برنامه به افراد امکان می‌دهد فایل‌هایی را که از سیستم حذف شده‌اند، بازیابی کنند. این برنامه لیستی از فایل‌های حذف شده را در رابط وب نمایش می‌دهد و گزینه‌هایی برای بازگرداندن آن فایل‌های حذف شده به دایرکتوری‌های فایل افراد یا حذف دائمی آن‌ها از سیستم دارد. بازیابی یک فایل، نسخه‌های مرتبط فایل را نیز در صورت فعال بودن برنامه نسخه‌ها، بازیابی می‌کند. هنگامی که یک فایل از یک اشتراک‌گذاری حذف می‌شود، می‌توان آن را به همان روش بازیابی کرد، اگرچه دیگر به اشتراک گذاشته نمی‌شود. به طور پیش‌فرض، این فایل‌ها به مدت ۳۰ روز در سطل زباله باقی می‌مانند.",
    "Restore" : "بازیابی",
    "Not enough free space to restore the file/folder" : "فضای خالی کافی برای بازیابی فایل/پوشه وجود ندارد",
    "Empty deleted files" : "خالی کردن فایل‌های حذف شده",
    "Confirm permanent deletion" : "تأیید حذف دائمی",
    "Are you sure you want to permanently delete all files and folders in the trash? This cannot be undone." : "آیا مطمئن هستید که می‌خواهید تمام فایل‌ها و پوشه‌های موجود در سطل زباله را به طور دائمی حذف کنید؟ این عمل قابل بازگشت نیست.",
    "Cancel" : "لغو",
    "Original location" : "مکان اصلی",
    "Deleted by" : "حذف شده توسط",
    "Deleted" : "حذف شده",
    "few seconds ago" : "چند ثانیه پیش",
    "A long time ago" : "مدت‌ها پیش",
    "Unknown" : "ناشناس",
    "All files" : "همه فایل‌ها",
    "You" : "شما",
    "List of files that have been deleted." : "لیست فایل‌هایی که حذف شده‌اند.",
    "No deleted files" : "فایل حذف شده‌ای وجود ندارد",
    "Files and folders you have deleted will show up here" : "فایل‌ها و پوشه‌هایی که حذف کرده‌اید در اینجا نمایش داده خواهند شد",
    "All files have been permanently deleted" : "همه فایل‌ها به طور دائمی حذف شدند",
    "Failed to empty deleted files" : "خالی کردن فایل‌های حذف شده انجام نشد"
},
"nplurals=2; plural=(n > 1);");
