OC.L10N.register(
    "appstore",
    {
    "Apps" : "Forrit",
    "App name" : "Heiti forrits",
    "Version" : "Útgáfa",
    "Groups" : "Hópar",
    "Actions" : "Aðgerðir",
    "Show details" : "Birta nánari upplýsingar",
    "Grid view" : "Reitasýn",
    "Cancel" : "Cancel",
    "Learn more" : "Læra meira",
    "Daemon" : "Púki",
    "Deploy Daemon" : "Setja bakgrunnsþjónustu (daemon) í gang",
    "Type" : "Tegund",
    "Name" : "Heiti",
    "Display Name" : "Birtingarnafn",
    "GPUs support" : "Stuðningur við GPUs-skjáörgjörva",
    "Compute device" : "Reiknitæki",
    "Environment variables" : "Umhverfisbreytur",
    "No environment variables defined" : "Engar umhverfisbreytur skilgreindar",
    "Mounts" : "Tengipunktar",
    "Host path" : "Slóð á hýsivél",
    "Container path" : "Slóð á gagnagám",
    "Read-only" : "Skrifvarið",
    "Remove mount" : "Fjarlægja tengipunkt",
    "New mount" : "Nýr tengipunktur",
    "Enter path to host folder" : "Settu inn slóð á hýsilvélarmöppu",
    "Enter path to container folder" : "Settu inn slóð á gagnagámsmöppu",
    "Toggle read-only mode" : "Víxla lesham/skrifham af/á",
    "Confirm adding new mount" : "Staðfestu viðbætingu tengipunkts",
    "Confirm" : "Staðfesta",
    "Cancel adding mount" : "Hætta við að bæta inn tengipunkti",
    "Add mount" : "Bæta við tengipunkti",
    "No mounts defined" : "Engir tengipunktar skilgreindir",
    "Description" : "Lýsing",
    "View in store" : "Skoða í hugbúnaðarsafni",
    "Visit website" : "Heimsækja vefsvæðið",
    "Usage documentation" : "Leiðbeiningar um notkun",
    "Admin documentation" : "Hjálparskjöl kerfisstjóra",
    "Developer documentation" : "Skjölun fyrir þróunaraðila",
    "Details" : "Nánar",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Ekki var hægt að setja upp forritið þar sem eftirfarandi kerfiskröfur eru ekki uppfylltar:",
    "Latest updated" : "Síðast uppfært",
    "Author" : "Höfundur",
    "Categories" : "Flokkar",
    "Resources" : "Tilföng",
    "Changelog" : "Breytingaskrá",
    "Supported" : "Stutt",
    "Featured" : "Í deiglunni",
    "This app is supported via your current Nextcloud subscription." : "Þetta forrit er stutt í gegnum fyrirliggjandi Nextcloud-áskrift þína.",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Forrit í deiglunni eru þróuð af og innan samfélagsins. Þau bjóða upp á ýmsa kjarnaeiginleika og eru tilbúin til notkunar í raunvinnslu.",
    "Community rating: {score}/5" : "Einkunnir frá samfélaginu: {score}/5",
    "Default" : "Sjálfgefið",
    "Carousel" : "Hringekja",
    "Previous slide" : "Fyrri skyggna",
    "Next slide" : "Næsta skyggna",
    "Choose slide to display" : "Veldu skyggnu til að birta",
    "{index} of {total}" : "{index} af {total}",
    "Limit to groups" : "Takmarka við hópa",
    "Save" : "Vista",
    "Update all" : "Uppfæra allt",
    "Loading app list" : "Hleð inn forritalista",
    "Search everywhere" : "Leita allsstaðar",
    "Download and enable all" : "Sækja og virkja allt",
    "Nothing to show" : "Ekkert til að sýna",
    "Loading" : "Hleð inn",
    "Fetching the latest news…" : "Sæki nýjustu fréttir…",
    "Loading categories" : "Hleð inn flokkum",
    "Version {version}, {license}-licensed" : "Útgáfa {version}, {license}-notkunarleyfi",
    "Version {version}" : "Útgáfa {version}",
    "Disable" : "Gera óvirkt",
    "Download and enable" : "Sækja og virkja",
    "Rate the app" : "Gefðu forritinu einkunn",
    "Report a bug" : "Tilkynna um villu",
    "Remove" : "Fjarlægja",
    "Update to {version}" : "Uppfæra í {version}",
    "Your apps" : "Forritin þín",
    "Active apps" : "Virk forrit",
    "Disabled apps" : "Óvirk forrit",
    "Updates" : "Uppfærslur",
    "App bundles" : "Forritavöndlar",
    "Featured apps" : "Forrit efst á baugi",
    "Supported apps" : "Studd forrit",
    "An error occurred during the request. Unable to proceed." : "Villa kom upp við beiðnina. Get ekki haldið áfram."
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
