OC.L10N.register(
    "files_sharing",
    {
    "File shares" : "Спільні файли",
    "Downloaded via public link" : "Звантажено за публічним посиланням",
    "Downloaded by {email}" : "Завантажено через {email}",
    "{file} downloaded via public link" : "{file} звантажено через публічне посилання",
    "{email} downloaded {file}" : "{email} звантажено {file}",
    "Shared with group {group}" : "Поділилися з групою {group}",
    "Removed share for group {group}" : "Вилучено спільний доступ для групи {group}",
    "{actor} shared with group {group}" : "{actor} надав(-ла) доступ групі {group}",
    "{actor} removed share for group {group}" : "{actor} вилучив(-ла) спільний доступ для групи {group}",
    "Share for group {group} expired" : "Термін дії спільного доступу для групи {group} сплив",
    "You shared {file} with group {group}" : "Ви поділилися {file} з групою {group}",
    "You removed group {group} from {file}" : "Ви вилучили групу {group} з {file}",
    "{actor} shared {file} with group {group}" : "{actor} надав(-ла) доступ до файлу {file} групі {group}",
    "{actor} removed group {group} from {file}" : "{actor} вилучив(-ла) групи {group} з {file}",
    "Share for file {file} with group {group} expired" : "Термін дії спільного доступу до файла {file} для групи {group} вичерпано",
    "Shared as public link" : "Доступне за публічним посиланням",
    "Removed public link" : "Вилучено публічне посилання",
    "Public link expired" : "Термін дії публічного посилання вичерпано",
    "{actor} shared as public link" : "{actor} поділив(-ла)ся публічним посиланням",
    "{actor} removed public link" : "{actor} вилучив(-ла) публічне посилання",
    "Public link of {actor} expired" : "Термін дії публічного посилання {actor} вичерпано",
    "You shared {file} as public link" : "Ви поділилися {file} за допомогою публічного посилання",
    "You removed public link for {file}" : "Ви вилучили публічне посилання для {file}",
    "Public link expired for {file}" : "Термін дії посилання сплив для файла {file}",
    "{actor} shared {file} as public link" : "{actor} надав(-ла) доступ до файлу {file} через публічне посилання",
    "{actor} removed public link for {file}" : "{actor} вилучив(-ла) публічне посилання для {file}",
    "Public link of {actor} for {file} expired" : "Термін дії публічне посилання {actor} для {file} вичерпано",
    "{user} accepted the remote share" : "{user} прийняв запит на віддалений спільний ресурс",
    "{user} declined the remote share" : "{user} відхилив віддалений спільний ресурс",
    "You received a new remote share {file} from {user}" : "Ви отримали запрошення на доступ до віддаленого спільного ресурсу {file} від {user}",
    "{user} accepted the remote share of {file}" : "{user} прийняв запрошення на доступ до віддаленого спільного ресурсу {file}",
    "{user} declined the remote share of {file}" : "{user} відхилив запрошення на доступ до віддаленого спільного ресурсу {file}",
    "{user} unshared {file} from you" : "{user} закрив доступ для вас до {file}",
    "Shared with {user}" : "Надано доступ для {user}",
    "Removed share for {user}" : "Скасовано спільний доступ для {user}",
    "You removed yourself" : "Ви вилучили себе з доступу",
    "{actor} removed themselves" : "{actor} вийшов(-ла) з доступу",
    "{actor} shared with {user}" : "{actor} надав(-ла) доступ для {user}",
    "{actor} removed share for {user}" : "{actor} скасував спільний доступ для {user}",
    "Shared by {actor}" : "{actor} надав(-ла) доступ",
    "{actor} removed share" : "{actor} скасував спільний доступ",
    "Share for {user} expired" : "Термін дії спільного доступу для {user} вичерпано",
    "Share expired" : "Термін дії спільного доступу до ресурсу вичерпано",
    "You shared {file} with {user}" : "Ви поділилися {file} з {user}",
    "You removed {user} from {file}" : "Ви вилучили {user} з {file}",
    "You removed yourself from {file}" : "Ви вийшли з доступу до {file}",
    "{actor} removed themselves from {file}" : "{actor} вийшов(-ла) з доступу до {file}",
    "{actor} shared {file} with {user}" : "{actor} надав(-ла) доступ для {user} до файлу {file}",
    "{actor} removed {user} from {file}" : "{actor} вилучив(-ла) {user} з {file}",
    "{actor} shared {file} with you" : "{actor} надав(-ла) вам доступ до спільного ресурсу {file}",
    "{actor} removed you from the share named {file}" : "{actor} скасував(-ла) вам доступ до спільного ресурсу {file}",
    "Share for file {file} with {user} expired" : "Термін дії доступу {user} до спільного ресурсу {file} вичерпано",
    "Share for file {file} expired" : "Термін дії спільного доступу до {file} вичерпано",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Файл або каталог, яким поділилився через ел.пошту або публічне посилання було <strong>звантажено</strong>",
    "Files have been <strong>uploaded</strong> to a folder shared by mail or by public link" : "Файли було <strong>завантажено</strong> до каталогу, яким поділилися через ел. пошту або через публічне посилання",
    "A file or folder was shared from <strong>another server</strong>" : "Файлом або каталогом поділилися з <strong>іншого сервера</strong>",
    "Sharing" : "Спільне",
    "A file or folder has been <strong>shared</strong>" : "Файл або каталог було відкрито для <strong>спільного доступу</strong>",
    "Shared link" : "Посилання на спільний доступ",
    "Wrong share ID, share does not exist" : "Неправильний ідентифікатор спільного ресурсу: такий ресурс відсутній",
    "Could not delete share" : "Неможливо вилучити зі спільного доступу",
    "Please specify a file or folder path" : "Будь ласка, зазначте шлях до файла або каталогу",
    "Wrong path, file/folder does not exist" : "Неправильний шлях, такий файл або каталог відсутні",
    "Could not create share" : "Неможливо створити спільний ресурс",
    "Please specify a valid account to share with" : "Зазначте дійсний обліковий запис, з яким ви хочете поділитися",
    "Please specify a valid group" : "Будь ласка, зазначте дійсну групу",
    "Please specify a valid email address" : "Зазначте дійсну адресу ел. пошти",
    "Sharing %s sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "Виникла помилка під час надання доступу до %s, оскільки Nextcloud Talk не активний й відтак неможливо надіслати пароль.",
    "Please specify a valid federated account ID" : "Зазначте дійсний ідентифікатор облікового запис об'єднаної хмари",
    "Please specify a valid federated group ID" : "Будь ласка, зазначте дійсний ідентифікатор групи об'єднаної хмари",
    "You cannot share to a Team if the app is not enabled" : "Неможливо поділитися з командою, якщо застосунок не увімкнено",
    "Please specify a valid team" : "Виберіть дійсну команду",
    "Sharing %s failed because the back end does not support room shares" : "Помилка спільного доступу %s, оскільки серверна частина не підтримує спільний доступ до кімнат",
    "Unknown share type" : "Невідомий тип спільного ресурсу",
    "Not a directory" : "Не каталог",
    "Could not lock node" : "Не вдалося заблокувати вузол",
    "Public upload is only possible for publicly shared folders" : "Публічне завантаження можливе лише для каталогів з публічним доступом",
    "Share must at least have READ or CREATE permissions" : "Спільний доступ має щонайменше мати дозволи READ (читання) або CREATE (створення)",
    "Share must have READ permission if UPDATE or DELETE permission is set" : "Для спільного доступу потрібно щонайменше призначити дозволи READ (читання) або CREATE (створення)",
    "Could not lock path" : "Не вдалося заблокувати шлях",
    "no sharing rights on this item" : "відсутні права на спільний доступ для цього ресурсу",
    "You are not allowed to edit incoming shares" : "У вас відсутні права на редагування спільних ресурсів, якими з вами поділилися",
    "Wrong or no update parameter given" : "Вказано неправильний або відсутній параметр оновлення",
    "\"Sending the password by Nextcloud Talk\" for sharing a file or folder failed because Nextcloud Talk is not enabled." : "Не вдалося надіслати пароль для спільного доступу до файлу чи каталогу з використанням Nextcloud Talk, оскільки цей застосунок вимкнено.",
    "Custom share link tokens have been disabled by the administrator" : "Власні токени спільних ресурсів вимкнено адміністратором",
    "Tokens must be between 1 and %s characters long and may only contain letters, numbers, or a hyphen" : "Токени мають мати довжину від 1 до %s символів та містити лише літери, цифри або дефіс.",
    "Invalid date. Format must be YYYY-MM-DD" : "Недійсна дата. Дата має бути у форматі рік-місяць-число",
    "No sharing rights on this item" : "Відсутні права на спільний доступ для цього ресурсу",
    "Invalid share attributes provided: \"%s\"" : "Отримано недійсні атрибути спільного доступу для \"%s\"",
    "You are not allowed to send mail notifications" : "У вас відсутні права надсилати сповіщення ел. поштою",
    "No mail notification configured for this share type" : "Для цього типу ресурсів спільного доступу не налаштовано сповіщення ел. поштою",
    "Wrong password" : "Недійсний пароль",
    "Error while sending mail notification" : "Помилка під час надсилання сповіщення ел. поштою",
    "Failed to generate a unique token" : "Не вдалося створити унікальний токен",
    "This share does not exist or is no longer available" : "Спільний ресурс не існує або більше не доступний",
    "shared by %s" : "поділилися %s",
    "Download" : "Звантажити",
    "Add to your %s" : "Додайте до свого %s",
    "Direct link" : "Пряме посилання",
    "You are not allowed to share \"%s\"." : "Відсутні права на надання у спільний доступ \"%s\".",
    "You cannot share your home folder." : "Неможливо надати у спільний доступ весь каталог користувача",
    "File cannot be shared with delete permission." : "Неможливо поділитися файлом із дозволом на вилучення",
    "File cannot be shared with create permission." : "Неможливо поділитися файлом із дозволом на створення",
    "File share needs at least read permission." : "Щод поділитися файлом, потрібно мати щонайменше дозвіл на читання",
    "Public upload is not allowed." : "Публічні завантаження не дозволені",
    "You cannot share \"%s\" with more permission than you have yourself." : "Неможливо надати у спільний доступ \"%s\" із більшими дозволами, ніж ви маєте",
    "Share API is disabled" : "API для надання доступу вимкнено",
    "File sharing" : "Обмін файлами",
    "Share will expire tomorrow" : "Термін дії спільного доступу спливає завтра",
    "Your share of {node} will expire tomorrow" : "Термін дії спільного доступу до вашого вузла {node} спливає завтра",
    "You received {share} as a share by {user}" : "(user) надав(-ла) вам доступ до спільного ресурсу {share}",
    "You received {share} to group {group} as a share by {user}" : "(user) надав(-ла) вам доступ до спільного ресурсу {share} в групі {group}",
    "Accept" : "Прийняти",
    "Decline" : "Відхилити",
    "Remember to upload the files to %s" : "Пам'ятати про завантаження файлів до %s",
    "We would like to kindly remind you that you have not yet uploaded any files to the shared folder." : "Нагадування про те, що ви ще не завантажили жодного файлу до спільного каталогу.",
    "Open \"%s\"" : "Відкрити \"%s\"",
    "This application enables people to share files within Nextcloud. If enabled, the admin can choose which groups can share files. The applicable people can then share files and folders with other accounts and groups within Nextcloud. In addition, if the admin enables the share link feature, an external link can be used to share files with other people outside of Nextcloud. Admins can also enforce passwords, expirations dates, and enable server to server sharing via share links, as well as sharing from mobile devices.\nTurning the feature off removes shared files and folders on the server for all share recipients, and also on the sync clients and mobile apps. More information is available in the Nextcloud Documentation." : "Цей застосунок дозволяє користувачам обмінюватися файлами в Nextcloud. Якщо ця функція увімкнена, адміністратор може вибрати, які групи можуть обмінюватися файлами. Відповідні користувачі можуть обмінюватися файлами та каталогами з іншими обліковими записами та групами в Nextcloud. Крім того, якщо адміністратор увімкне функцію спільного доступу за посиланням, зовнішнє посилання можна використовувати для обміну файлами з іншими людьми поза Nextcloud. Адміністратори також можуть встановлювати паролі, терміни дії та вмикати обмін між серверами за допомогою посилань для спільного доступу, а також обмін з мобільних пристроїв.\n\nВимкнення цієї функції видаляє спільні файли та каталоги на сервері для всіх одержувачів спільного доступу, а також на клієнтах синхронізації та в мобільних застосунках. Більше інформації можна знайти в документації Nextcloud.",
    "Filter accounts" : "Вибрати користувачів",
    "you" : "ви",
    "The request will expire on {date} at midnight and will be password protected." : "Термін дії запиту спливе опівночі {date}, запит буде захищено паролем. ",
    "The request will expire on {date} at midnight." : "Термін дії запиту спливе опівночі {date}.",
    "The request will be password protected." : "Запит буде захищено паролем",
    "When should the request expire?" : "Коли спливе час дії запиту?",
    "Set a submission expiration date" : "Встановити останню дату надання в доступ",
    "Expiration date" : "Термін дії",
    "Select a date" : "Виберіть дату",
    "Your administrator has enforced a {count} days expiration policy." : "Адміністратор встановив політику: через {count} днів буде завершено доступ до ресурсу.",
    "What password should be used for the request?" : "Який пароль має використовуватися для цього запиту?",
    "Set a password" : "Встановити пароль",
    "Password" : "Пароль",
    "Enter a valid password" : "Зазначте дійсний пароль",
    "Generate a new password" : "Створити новий пароль",
    "Your administrator has enforced a password protection." : "Адміністратор встановив політику захисту паролем ",
    "Automatically copying failed, please copy the share link manually" : "Помилка під час автоматичного копіювання. Скопіюйте вручну посилання на спільний ресурс.",
    "Link copied" : "Посилання скопійовано",
    "Email already added" : "Ел. адресу вже додано",
    "Invalid email address" : "Недійсна адреса ел. пошти",
    "_The following email address is not valid: {emails}_::_The following email addresses are not valid: {emails}_" : ["{emails} ел. адреса не є дійсною ","{emails} ел. адреси не є дійсними ","{emails} ел. адрес не є дійсними ","{emails} ел. адрес не є дійсними "],
    "_{count} email address already added_::_{count} email addresses already added_" : ["{count} ел. адресу вже додано","{count} ел. адреси вже додано","{count} ел. адрес вже додано","{count} ел. адрес вже додано"],
    "_{count} email address added_::_{count} email addresses added_" : ["{count} ел. адресу додано","{count} ел. адреси додано","{count} ел. адрес додано","{count} ел. адрес додано"],
    "You can now share the link below to allow people to upload files to your directory." : "Тепер ви можете поділитися посиланням, за яким користувачі матимуть змогу завантажити файли до вашого каталогу. ",
    "Share link" : "Надати для публічного доступу",
    "Copy" : "Копіювати",
    "Send link via email" : "Надіслати посилання електронною поштою",
    "Enter an email address or paste a list" : "Зазначте ел. адресу або список адрес",
    "Remove email" : "Вилучити ел. адресу",
    "Select a destination" : "Вибрати призначення",
    "Select" : "Вибрати",
    "What are you requesting?" : "Що ви хочете отримати?",
    "Request subject" : "Тема запиту",
    "Birthday party photos, History assignment…" : "Світлини зі святкування уродин, завдання з історії...",
    "Where should these files go?" : "Для кого ці файли?",
    "Upload destination" : "Завантажити призначення",
    "Revert to default" : "Повернути до типових налаштувань",
    "The uploaded files are visible only to you unless you choose to share them." : "Файли, які було завантажено, будуть доступні тільки вам, допоки ви не поділитеся ними.",
    "Add a note" : "Додати примітку",
    "Note for recipient" : "Примітка для отримувача",
    "Add a note to help people understand what you are requesting." : "Додати примітку, щоб допомогти користувачам зрозуміти, що вони запитують.",
    "You can add links, date or any other information that will help the recipient understand what you are requesting." : "Ви можете додавати посилання, дати або іншу інформацію, яка допоможе зрозуміти отримувачам, що ви від них просите.",
    "Close" : "Закрити",
    "_Send email and close_::_Send {count} emails and close_" : ["Надіслати ел. лист та закрити","Надіслати {count} ел. листи та закрити","Надіслати {count} ел. листів та закрити","Надіслати {count} ел. листів та закрити"],
    "Please select a folder, you cannot share the root directory." : "Виберіть каталог, неможливо поділитися кореневим каталогом.",
    "File request created" : "Запит на файл створено",
    "_File request created and email sent_::_File request created and {count} emails sent_" : ["Створено запит на файл та надіслано ел. лист","Створено запит на файл та надіслано {count} ел. листи","Створено запит на файл та надіслано {count} ел. листів","Створено запит на файл та надіслано {count} ел. листів"],
    "Error creating the share: {errorMessage}" : "Помилка під час створення спільного ресурсу: {errorMessage}",
    "Error creating the share" : "Помилка під час створення спільного ресурсу",
    "Error sending emails: {errorMessage}" : "Помилка під час надсилання ел. пошти: {errorMessage}",
    "Error sending emails" : "Помилка під час надсилання ел. пошти",
    "Create a file request" : "Створити запит на файл",
    "Collect files from others even if they do not have an account." : "Отримати файли від інших користувачів, навіть якщо у них відсутній обліковий запис. ",
    "To ensure you can receive files, verify you have enough storage available." : "Щоби впевнитися, що ви можете отримувати файли, перевірте, що у вас достатньо дискового простору.",
    "File request" : "Запит на файл",
    "Previous step" : "Назад",
    "Cancel" : "Скасувати",
    "Cancel the file request creation" : "Скасувати створення запиту на файл",
    "Close without sending emails" : "Закрити без надсилання ел. пошти",
    "Continue" : "Продовжити",
    "Error while toggling options" : "Помилка під час зміни параметрів",
    "Accept shares from other accounts and groups by default" : "Типово приймати пропозиції спільного доступу від інших користувачів та груп",
    "Choose a default folder for accepted shares" : "Виберіть типовий каталог, куди зберігатимуться прийняті спільні ресурси",
    "Invalid path selected" : "Вибрано неправильний шлях",
    "Unknown error" : "Невідома помилка",
    "Set default folder for accepted shares" : "Типовий каталог для прийнятих спільних ресурсів",
    "Reset" : "Скидання",
    "Reset folder to system default" : "Відновити типові системні налаштування для каталогу",
    "Share expiration: {date}" : "У спільному доступі до: {date}",
    "Share Expiration" : "Термін дії спільного ресурсу:",
    "group" : "група",
    "conversation" : "розмова",
    "remote" : "віддалений",
    "remote group" : "віддалена група",
    "guest" : "гість",
    "by {initiator}" : "{initiator}",
    "Shared with the group {user} by {owner}" : "Надав доступ групі {user} {owner}",
    "Shared with the conversation {user} by {owner}" : "{owner} поділив(-ла-)ся в чаті {user}",
    "Shared with {user} by {owner}" : "{owner} поділив(-ла-)ся з {user}",
    "Open Sharing Details" : "Відкрити деталі спільного доступу",
    "Added by {initiator}" : "Додано {initiator}",
    "Via “{folder}”" : "Через “{folder}”",
    "Unshare" : "Закрити доступ",
    "Cannot copy, please copy the link manually" : "Неможливо скопіювати, скопіюйте посилання вручну",
    "Copy internal link" : "Копіювати посилання",
    "For people who already have access" : "Для тих, хто має доступ",
    "Internal link" : "Внутрішнє посилання",
    "{shareWith} by {initiator}" : "{shareWith} від {initiator}",
    "Shared via link by {initiator}" : "Спільний доступ через посилання від {initiator}",
    "File request ({label})" : "Запит на файл ({label})",
    "Mail share ({label})" : "Спільний доступ через пошту ({label})",
    "Share link ({label})" : "Поділитися посиланням ({label})",
    "Mail share" : "Спільний ресурс через ел. пошту",
    "Share link ({index})" : "Поділитися посиланням ({index})",
    "Create public link" : "Створити публічне посилання",
    "Actions for \"{title}\"" : "Дія для \"{title}\"",
    "Copy public link of \"{title}\"" : "Копіювати публічне посилання на «{title}»",
    "Error, please enter proper password and/or expiration date" : "Помилка. Будь ласка, зазначте правильний пароль та/або термін дії",
    "Link share created" : "Створено посилання на спільний ресурс",
    "Error while creating the share" : "Помилка під час створення спільного ресурсу",
    "Your browser does not support copying, please copy the link manually:" : "Ваш бравзер не підтримує копіювання, скопіюйте посилання вручну:",
    "Successfully copied public link" : "Успішно скопійовано публічне посилання",
    "Please enter the following required information before creating the share" : "Зазначте такі дані перед наданням у публічний доступ",
    "Password protection (enforced)" : "Захист паролем (обов'язково)",
    "Password protection" : "Захист паролем",
    "Enter a password" : "Зазначте пароль",
    "Enable link expiration (enforced)" : "Увімкнути термін дії посилання (примусово)",
    "Enable link expiration" : "Увімкнути термін дії посилання",
    "Enter expiration date (enforced)" : "Зазначте термін дії (примусово)",
    "Enter expiration date" : "Зазначте термін дії",
    "Create share" : "Створити спільний ресурс",
    "Customize link" : "Власне посилання",
    "Generate QR code" : "Створити QR-код",
    "Add another link" : "Додати інше посилання",
    "Create a new share link" : "Створити нове посилання спільного доступу",
    "Quick share options, the current selected is \"{selectedOption}\"" : "Швидкі параметри спільного доступу, зараз вибрано \"{selectedOption}\"",
    "View only" : "Лише перегляд",
    "Can edit" : "Може редагувати",
    "Custom permissions" : "Спеціальні дозволи",
    "Resharing is not allowed" : "Надання спільного доступу іншим не дозволяється",
    "Name or email …" : "Ім'я або ел.пошта …",
    "Name, email, or Federated Cloud ID …" : "Ім'я або ел.пошта або ID об'єднаної хмари …",
    "Searching …" : "Шукаю...",
    "No elements found." : "Елементи не знайдено.",
    "Search everywhere" : "Шукати всюди",
    "Guest" : "Гість",
    "Group" : "Група",
    "Email" : "Ел.пошта",
    "Team" : "Команда",
    "Talk conversation" : "Розмова Talk",
    "Deck board" : "Дошка Deck",
    "ScienceMesh" : "ScienceMesh",
    "on {server}" : "на {server}",
    "Enter external recipients" : "Зазначте зовнішніх отримувачів",
    "Search for internal recipients" : "Шукати внутрішніх отримувачів",
    "Note from" : "Примітка від",
    "Note:" : "Примітка:",
    "File drop" : "Перетягнути файл",
    "Upload files to {foldername}." : "Завантажити файли до {foldername}.",
    "By uploading files, you agree to the terms of service." : "Завантаження файлів означає, що ви погоджуєтеся з умовами користування.",
    "Successfully uploaded files" : "Успішно завантажено файли",
    "View terms of service" : "Переглянути умови користування.",
    "Terms of service" : "Умови використання",
    "Share with {user}" : "Поділитися з {user}",
    "Share with email {email}" : "Поділитися через ел.пошту {email}",
    "Share with group" : "Поділитися з групою",
    "Share in conversation" : "Поширити в розмові ",
    "Share with {user} on remote server {server}" : "Поділитися з {user} на віддаленому сервері {server}",
    "Share with remote group" : "Поділитися з віддаленою групою",
    "Share with guest" : "Поділитися з гостем",
    "Update share" : "Оновити спільний ресурс",
    "Save share" : "Зберегти спільний ресурс",
    "Read" : "Читати",
    "Create" : "Створити",
    "Edit" : "Редагувати",
    "Share" : "Спільне",
    "Delete" : "Вилучити",
    "Password field cannot be empty" : "Поле з паролем має бути заповнено",
    "Replace current password" : "Замінити поточний пароль",
    "Failed to generate a new token" : "Не вдалося створити новий токен",
    "Allow upload and editing" : "Може завантажувати та редагувати",
    "Allow editing" : "Може редагувати",
    "Upload only" : "Тільки завантаження",
    "Advanced settings" : "Розширені",
    "Share label" : "Мітка спільного ресурсу",
    "Share link token" : "Токен спільного ресурсу",
    "Set the public share link token to something easy to remember or generate a new token. It is not recommended to use a guessable token for shares which contain sensitive information." : "Встановіть токен для публічного посилання на спільний ресурс з простою для запам'ятовування назвою або створіть новий токен. Не рекомендується використовувати токени, які можна легко вгадати, для спільних ресурсів, що містять чутливі дані.",
    "Generating…" : "Створення...",
    "Generate new token" : "Створити новий токен",
    "Set password" : "Встановити пароль",
    "Password expires {passwordExpirationTime}" : "Термін дії пароля {passwordExpirationTime}",
    "Password expired" : "Термін дії пароля вичерпано",
    "Video verification" : "Відеоперевірка",
    "Expiration date (enforced)" : "Термін дії (обов'язково)",
    "Set expiration date" : "Встановити термін дії",
    "Hide download" : "Приховати звантаження",
    "Allow download and sync" : "Дозволити звантаження та синхронізацію",
    "Note to recipient" : "Примітка для одержувача",
    "Enter a note for the share recipient" : "Додайте нотатку для одержувача доступу до спільного ресурсу",
    "Show files in grid view" : "Подання файлів сіткою",
    "Delete share" : "Вилучити зі спільного доступу",
    "Others with access" : "Доступ для інших",
    "No other accounts with access found" : "Більше не знайдено користувачів, які мають доступ",
    "Toggle list of others with access to this directory" : "Перемкнути подання списку інших користувачів, які мають доступ до цього каталогу",
    "Toggle list of others with access to this file" : "Перемкнути подання списку інших, які мають доступ до цього файлу",
    "Unable to fetch inherited shares" : "Неможливо отримати успадковані спільні ресурси",
    "Link shares" : "Посилання на спільні ресурси",
    "Shares" : "Спільні",
    "Share files within your organization. Recipients who can already view the file can also use this link for easy access." : "Діліться файлами всередині своєї організації. Одержувачі, які вже мають доступ до файлу, також можуть скористатися цим посиланням для зручного доступу.",
    "Share files with others outside your organization via public links and email addresses. You can also share to {productName} accounts on other instances using their federated cloud ID." : "Надавайте файли у спільний доступ за межами вашої організації шляхом надсилання публічних посилань та зазначення адрес ел.пошти. Також можна поділитися з користувачами {productName} з іншими хмарами через ID об'єднаних хмар.",
    "Shares from apps or other sources which are not included in internal or external shares." : "Спільні ресурси, створені у застосунках або інших джерелах, які не включено до внутрішніх або зовнішніх спільних ресурсів.",
    "Type names, teams, federated cloud IDs" : "Введіть ім'я, команду, ідентифікатор хмари",
    "Type names or teams" : "Введіть ім'я або команду",
    "Type a federated cloud ID" : "Введіть ідентифікатор об'єднаної хмари",
    "Type an email" : "Введіть адресу електронної пошти",
    "Type an email or federated cloud ID" : "Введіть адресу електронної пошти або ідентифікатор об'єднаної хмари",
    "Unable to load the shares list" : "Не вдалося завантажити список спільних ресурсів",
    "Expires {relativetime}" : "Термін дії закінчується {relativetime}",
    "this share just expired." : "термін дії спільного доступу вичерпано.",
    "Shared with you by {owner}" : "{owner} поділив(-ла-)ся з вами",
    "Internal shares" : "Внутрішні спільні ресурси",
    "Internal shares explanation" : "Опис внутрішніх спільних ресурсів",
    "External shares" : "Зовнішні спільні ресурси",
    "External shares explanation" : "Опис зовнішніх спільних ресурсів",
    "Additional shares" : "Додаткові спільні ресурси",
    "Additional shares explanation" : "Опис додаткових спільних ресурсів",
    "Link to a file" : "Посилання на файл",
    "_Accept share_::_Accept shares_" : ["Прийняти запит на спільний ресурс","Прийняти запит на спільні ресурси","Прийняти запит на спільні ресурси","Схвалити запит на спільні ресурси"],
    "Open in Files" : "Відкрити у Файлах",
    "_Reject share_::_Reject shares_" : ["Скасувати запит на спільний ресурс","Скасувати запит на спільні ресурси","Скасувати запит на спільні ресурси","Скасувати запит на спільні ресурси"],
    "_Restore share_::_Restore shares_" : ["Відновити спільний ресурс","Відновити спільні ресурси","Відновити спільні ресурси","Відновити спільні ресурси"],
    "Shared" : "Спільні",
    "Shared by {ownerDisplayName}" : "{ownerDisplayName} надав(-ла) доступ",
    "Shared multiple times with different people" : "Поділилися кілька разів з різними людьми",
    "Sharing options" : "Параметри спільного доступу",
    "Shared with others" : "Ви поділилися",
    "You do not have enough permissions to share this file." : "У вас відсутні повноваження надавати цей файл у спільний доступ.",
    "People" : "Користувачі",
    "Create file request" : "Створити запит на файл",
    "Upload files to {foldername}" : "Завантажити файли до {foldername}",
    "Public file share" : "Публічний спільний ресурс",
    "Publicly shared file." : "Пубічно доступний файл.",
    "No file" : "Немає файлу",
    "The file shared with you will show up here" : "Файл, яким поділилися з вами, буде показано тут",
    "Public share" : "Спільний ресурс",
    "Publicly shared files." : "Публічно доступні файли.",
    "No files" : "Відсутні файли",
    "Files and folders shared with you will show up here" : "Файли та каталоги, яким поділилися з вами, буде показано тут",
    "Overview of shared files." : "Перегляд файлів у спільному доступі.",
    "No shares" : "Відсутні спільні ресурси",
    "Files and folders you shared or have been shared with you will show up here" : "Тут показуватимуться файли та каталоги, якими ви поділилися, або якими поділилися з вами.",
    "Shared with you" : "Відкриті для мене",
    "List of files that are shared with you." : "Список файлів, якими поділилися з вами.",
    "Nothing shared with you yet" : "З вами поки ніхто не поділився файлами",
    "Files and folders others shared with you will show up here" : "Тут показуватимуться файли та каталоги, з якими поділилися інші користувачі.",
    "List of files that you shared with others." : "Список файлів, якими ви поділилися з іншими.",
    "Nothing shared yet" : "Поки немає спільних ресурсів",
    "Files and folders you shared will show up here" : "Тут показуватимуться файи та каталоги якими ви поділилися",
    "Shared by link" : "Доступні за посиланням",
    "List of files that are shared by link." : "Список файлів, якими поділилися за допомогою посилання.",
    "No shared links" : "Відсутні спільні посилання",
    "Files and folders you shared by link will show up here" : "Тут показуватимуться файи та каталоги якими ви поділилися за допомогою посилання",
    "File requests" : "Запити на файл",
    "List of file requests." : "Список запитів на файл.",
    "No file requests" : "Відсутні запити на файл",
    "File requests you have created will show up here" : "Тут буде показано запити на файл, які було створено вами",
    "Deleted shares" : "Більше недоступні",
    "List of shares you left." : "Список спільних ресурсів, від яких ви відписалися.",
    "No deleted shares" : "Відсутні спільні каталоги чи файли, які було вилучено",
    "Shares you have left will show up here" : "Тут показуватимуться спільні ресурси, від яких ви відписалися",
    "Pending shares" : "Запити на доступ",
    "List of unapproved shares." : "Список несхвалених спільних ресурсів.",
    "No pending shares" : "Відсутні запити на доступ",
    "Shares you have received but not approved will show up here" : "Тут показуватимуться спільні ресурси, пропозиції на приєднання до яких ви отримали, але ще не підтвердили.",
    "Error deleting the share" : "Помилка під час вилучення спільного ресурсу",
    "Error updating the share" : "Помилка оновлення спільного ресурсу",
    "File \"{path}\" has been unshared" : "Файл \"{path} вилучено зі спільного доступу",
    "Folder \"{path}\" has been unshared" : "Каталог \"{path}\" було вилучено зі спільного доступу",
    "Could not update share" : "Не вдалося оновити спільний ресурс",
    "Share saved" : "Спільний ресурс збережено",
    "Share expiry date saved" : "Збережено термін дії спільного доступу до ресурсу",
    "Share hide-download state saved" : "Збережено статус прихованого звантаження спільного ресурсу",
    "Share label saved" : "Збережено ярлик спільного ресурсу",
    "Share note for recipient saved" : "Збережено примітку отримувачеві спільного ресурсу",
    "Share password saved" : "Пароль до спільного ресурсу збережено",
    "Share permissions saved" : "Дозволи доступу до спільного ресурсу збережено",
    "To upload files to {folder}, you need to provide your name first." : "Щоб завантажити файли до каталогу {folder}, спочатку потрібно зазначити ваше ім'я.",
    "Upload files to {folder}" : "Завантажити файли до {folder}",
    "Please confirm your name to upload files to {folder}" : "Зазначте ваше ім'я, щоби завантажити файли до каталогу {folder}",
    "{ownerDisplayName} shared a folder with you." : "{ownerDisplayName} поділив(-ла)ся з вами каталогом.",
    "Names must not be empty." : "Ім'я не може бути порожнім.",
    "Names must not start with a dot." : "Імена не можуть починатися з крапки.",
    "\"{char}\" is not allowed inside a name." : "\"{char}\" не дозволено всередині імени.",
    "\"{segment}\" is a reserved name and not allowed." : "\"{segment}\" є зарезервованим ім'ям і не дозволене.",
    "\"{extension}\" is not an allowed name." : "\"{extension}\" не дозволене ім'я.",
    "Names must not end with \"{extension}\"." : "Імена не можуть закінчуватися на \"{extension}\".",
    "Invalid name." : "Недійсне ім'я",
    "Password created successfully" : "Успішно створено пароль",
    "Error generating password from password policy" : "Помилка під час створення пароля згідно з політикою паролів",
    "Shared with you and the group {group} by {owner}" : " {owner} надав доступ вам та групі {group}",
    "Shared with you and {circle} by {owner}" : "{owner} надав доступ вам та колу {circle}",
    "Shared with you and the conversation {conversation} by {owner}" : "{owner} надав доступ вам та у чаті {conversation}",
    "Shared with you in a conversation by {owner}" : "{owner} поділив(-ла-)ся з вами у чаті",
    "Share not found" : "Спільний ресурс не знайдено",
    "Back to %s" : "Назад до %s",
    "Add to your Nextcloud" : "Додати до вашої хмари Nextcloud",
    "Group sharing is disabled by the administrator" : "Груповий спільний доступ вимкнено адміністратором",
    "Public link sharing is disabled by the administrator" : "Адміністратор вимкнув спільний доступ за публічним посиланням",
    "Sharing %1$s failed because the back end does not allow shares from type %2$s" : "Неможливо поділитися %1$s, оскільки бекенд не дозволяє надавати доступ категорії %2$s",
    "Sharing %s failed because the back end does not support ScienceMesh shares" : "Спільне використання %s не вдалося, оскільки бекенд не підтримує спільне використання ScienceMesh",
    "Public upload disabled by the administrator" : "Публічне завантаження вимкнено адміністратором",
    "Tokens must contain at least 1 character and may only contain letters, numbers, or a hyphen" : "Токени мають містити щонайменше 1 символ, можуть складатися тільки з літер, цифр або дефісу",
    "Name or email …" : "Ім'я або електронна адреса …",
    "Name, email, or Federated Cloud ID …" : "Ім’я, адреса електронної пошти або ідентифікатор хмари…",
    "Searching …" : "Пошук..."
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
