<?php

// autoload_static.php @generated by Composer

namespace Composer\Autoload;

class ComposerStaticInitPhotos
{
    public static $files = array (
        '9d2b9fc6db0f153a0a149fefb182415e' => __DIR__ . '/..' . '/symfony/polyfill-php84/bootstrap.php',
    );

    public static $prefixLengthsPsr4 = array (
        'W' => 
        array (
            'WoltLab\\WebpExif\\' => 17,
        ),
        'S' => 
        array (
            'Symfony\\Polyfill\\Php84\\' => 23,
        ),
        'O' => 
        array (
            'OCA\\Photos\\' => 11,
        ),
        'N' => 
        array (
            'Nelexa\\Buffer\\' => 14,
        ),
        'H' => 
        array (
            'Hexogen\\KDTree\\' => 15,
        ),
    );

    public static $prefixDirsPsr4 = array (
        'WoltLab\\WebpExif\\' => 
        array (
            0 => __DIR__ . '/..' . '/woltlab/webp-exif/src',
        ),
        'Symfony\\Polyfill\\Php84\\' => 
        array (
            0 => __DIR__ . '/..' . '/symfony/polyfill-php84',
        ),
        'OCA\\Photos\\' => 
        array (
            0 => __DIR__ . '/../..' . '/lib',
        ),
        'Nelexa\\Buffer\\' => 
        array (
            0 => __DIR__ . '/..' . '/nelexa/buffer/src/Nelexa/Buffer',
        ),
        'Hexogen\\KDTree\\' => 
        array (
            0 => __DIR__ . '/..' . '/hexogen/kdtree/src',
        ),
    );

    public static $classMap = array (
        'Composer\\InstalledVersions' => __DIR__ . '/..' . '/composer/InstalledVersions.php',
        'Deprecated' => __DIR__ . '/..' . '/symfony/polyfill-php84/Resources/stubs/Deprecated.php',
        'Hexogen\\KDTree\\Exception\\ValidationException' => __DIR__ . '/..' . '/hexogen/kdtree/src/Exception/ValidationException.php',
        'Hexogen\\KDTree\\FSKDTree' => __DIR__ . '/..' . '/hexogen/kdtree/src/FSKDTree.php',
        'Hexogen\\KDTree\\FSNode' => __DIR__ . '/..' . '/hexogen/kdtree/src/FSNode.php',
        'Hexogen\\KDTree\\FSTreePersister' => __DIR__ . '/..' . '/hexogen/kdtree/src/FSTreePersister.php',
        'Hexogen\\KDTree\\Interfaces\\ItemFactoryInterface' => __DIR__ . '/..' . '/hexogen/kdtree/src/Interfaces/ItemFactoryInterface.php',
        'Hexogen\\KDTree\\Interfaces\\ItemInterface' => __DIR__ . '/..' . '/hexogen/kdtree/src/Interfaces/ItemInterface.php',
        'Hexogen\\KDTree\\Interfaces\\ItemListInterface' => __DIR__ . '/..' . '/hexogen/kdtree/src/Interfaces/ItemListInterface.php',
        'Hexogen\\KDTree\\Interfaces\\KDTreeInterface' => __DIR__ . '/..' . '/hexogen/kdtree/src/Interfaces/KDTreeInterface.php',
        'Hexogen\\KDTree\\Interfaces\\NodeInterface' => __DIR__ . '/..' . '/hexogen/kdtree/src/Interfaces/NodeInterface.php',
        'Hexogen\\KDTree\\Interfaces\\PointInterface' => __DIR__ . '/..' . '/hexogen/kdtree/src/Interfaces/PointInterface.php',
        'Hexogen\\KDTree\\Interfaces\\SearchAbstract' => __DIR__ . '/..' . '/hexogen/kdtree/src/Interfaces/SearchAbstract.php',
        'Hexogen\\KDTree\\Interfaces\\TreePersisterInterface' => __DIR__ . '/..' . '/hexogen/kdtree/src/Interfaces/TreePersisterInterface.php',
        'Hexogen\\KDTree\\Item' => __DIR__ . '/..' . '/hexogen/kdtree/src/Item.php',
        'Hexogen\\KDTree\\ItemFactory' => __DIR__ . '/..' . '/hexogen/kdtree/src/ItemFactory.php',
        'Hexogen\\KDTree\\ItemList' => __DIR__ . '/..' . '/hexogen/kdtree/src/ItemList.php',
        'Hexogen\\KDTree\\KDTree' => __DIR__ . '/..' . '/hexogen/kdtree/src/KDTree.php',
        'Hexogen\\KDTree\\NearestSearch' => __DIR__ . '/..' . '/hexogen/kdtree/src/NearestSearch.php',
        'Hexogen\\KDTree\\Node' => __DIR__ . '/..' . '/hexogen/kdtree/src/Node.php',
        'Hexogen\\KDTree\\Point' => __DIR__ . '/..' . '/hexogen/kdtree/src/Point.php',
        'Nelexa\\Buffer\\Buffer' => __DIR__ . '/..' . '/nelexa/buffer/src/Nelexa/Buffer/Buffer.php',
        'Nelexa\\Buffer\\BufferException' => __DIR__ . '/..' . '/nelexa/buffer/src/Nelexa/Buffer/BufferException.php',
        'Nelexa\\Buffer\\Cast' => __DIR__ . '/..' . '/nelexa/buffer/src/Nelexa/Buffer/Cast.php',
        'Nelexa\\Buffer\\FileBuffer' => __DIR__ . '/..' . '/nelexa/buffer/src/Nelexa/Buffer/FileBuffer.php',
        'Nelexa\\Buffer\\MemoryResourceBuffer' => __DIR__ . '/..' . '/nelexa/buffer/src/Nelexa/Buffer/MemoryResourceBuffer.php',
        'Nelexa\\Buffer\\ResourceBuffer' => __DIR__ . '/..' . '/nelexa/buffer/src/Nelexa/Buffer/ResourceBuffer.php',
        'Nelexa\\Buffer\\StringBuffer' => __DIR__ . '/..' . '/nelexa/buffer/src/Nelexa/Buffer/StringBuffer.php',
        'Nelexa\\Buffer\\TempBuffer' => __DIR__ . '/..' . '/nelexa/buffer/src/Nelexa/Buffer/TempBuffer.php',
        'OCA\\Photos\\Album\\AlbumFile' => __DIR__ . '/../..' . '/lib/Album/AlbumFile.php',
        'OCA\\Photos\\Album\\AlbumInfo' => __DIR__ . '/../..' . '/lib/Album/AlbumInfo.php',
        'OCA\\Photos\\Album\\AlbumMapper' => __DIR__ . '/../..' . '/lib/Album/AlbumMapper.php',
        'OCA\\Photos\\Album\\AlbumWithFiles' => __DIR__ . '/../..' . '/lib/Album/AlbumWithFiles.php',
        'OCA\\Photos\\AppInfo\\Application' => __DIR__ . '/../..' . '/lib/AppInfo/Application.php',
        'OCA\\Photos\\Command\\AlbumAddCommand' => __DIR__ . '/../..' . '/lib/Command/AlbumAddCommand.php',
        'OCA\\Photos\\Command\\AlbumCreateCommand' => __DIR__ . '/../..' . '/lib/Command/AlbumCreateCommand.php',
        'OCA\\Photos\\Command\\UpdateReverseGeocodingFilesCommand' => __DIR__ . '/../..' . '/lib/Command/UpdateReverseGeocodingFilesCommand.php',
        'OCA\\Photos\\Controller\\AlbumsController' => __DIR__ . '/../..' . '/lib/Controller/AlbumsController.php',
        'OCA\\Photos\\Controller\\ApiController' => __DIR__ . '/../..' . '/lib/Controller/ApiController.php',
        'OCA\\Photos\\Controller\\PageController' => __DIR__ . '/../..' . '/lib/Controller/PageController.php',
        'OCA\\Photos\\Controller\\PreviewController' => __DIR__ . '/../..' . '/lib/Controller/PreviewController.php',
        'OCA\\Photos\\Controller\\PublicAlbumController' => __DIR__ . '/../..' . '/lib/Controller/PublicAlbumController.php',
        'OCA\\Photos\\Controller\\PublicPreviewController' => __DIR__ . '/../..' . '/lib/Controller/PublicPreviewController.php',
        'OCA\\Photos\\DB\\PhotosFile' => __DIR__ . '/../..' . '/lib/DB/PhotosFile.php',
        'OCA\\Photos\\DB\\Place\\PlaceFile' => __DIR__ . '/../..' . '/lib/DB/Place/PlaceFile.php',
        'OCA\\Photos\\DB\\Place\\PlaceInfo' => __DIR__ . '/../..' . '/lib/DB/Place/PlaceInfo.php',
        'OCA\\Photos\\DB\\Place\\PlaceMapper' => __DIR__ . '/../..' . '/lib/DB/Place/PlaceMapper.php',
        'OCA\\Photos\\Dashboard\\OnThisDay' => __DIR__ . '/../..' . '/lib/Dashboard/OnThisDay.php',
        'OCA\\Photos\\Exception\\AlreadyInAlbumException' => __DIR__ . '/../..' . '/lib/Exception/AlreadyInAlbumException.php',
        'OCA\\Photos\\Filters\\DateRangeFilter' => __DIR__ . '/../..' . '/lib/Filters/DateRangeFilter.php',
        'OCA\\Photos\\Filters\\FiltersManager' => __DIR__ . '/../..' . '/lib/Filters/FiltersManager.php',
        'OCA\\Photos\\Filters\\IFilter' => __DIR__ . '/../..' . '/lib/Filters/IFilter.php',
        'OCA\\Photos\\Filters\\PlacesFilter' => __DIR__ . '/../..' . '/lib/Filters/PlacesFilter.php',
        'OCA\\Photos\\Jobs\\AutomaticPlaceMapperJob' => __DIR__ . '/../..' . '/lib/Jobs/AutomaticPlaceMapperJob.php',
        'OCA\\Photos\\Listener\\AlbumsManagementEventListener' => __DIR__ . '/../..' . '/lib/Listener/AlbumsManagementEventListener.php',
        'OCA\\Photos\\Listener\\CSPListener' => __DIR__ . '/../..' . '/lib/Listener/CSPListener.php',
        'OCA\\Photos\\Listener\\ExifMetadataProvider' => __DIR__ . '/../..' . '/lib/Listener/ExifMetadataProvider.php',
        'OCA\\Photos\\Listener\\LoadSidebarScripts' => __DIR__ . '/../..' . '/lib/Listener/LoadSidebarScripts.php',
        'OCA\\Photos\\Listener\\OriginalDateTimeMetadataProvider' => __DIR__ . '/../..' . '/lib/Listener/OriginalDateTimeMetadataProvider.php',
        'OCA\\Photos\\Listener\\PlaceMetadataProvider' => __DIR__ . '/../..' . '/lib/Listener/PlaceMetadataProvider.php',
        'OCA\\Photos\\Listener\\SabrePluginAuthInitListener' => __DIR__ . '/../..' . '/lib/Listener/SabrePluginAuthInitListener.php',
        'OCA\\Photos\\Listener\\SizeMetadataProvider' => __DIR__ . '/../..' . '/lib/Listener/SizeMetadataProvider.php',
        'OCA\\Photos\\Listener\\TagListener' => __DIR__ . '/../..' . '/lib/Listener/TagListener.php',
        'OCA\\Photos\\Migration\\Version20000Date20220727125801' => __DIR__ . '/../..' . '/lib/Migration/Version20000Date20220727125801.php',
        'OCA\\Photos\\Migration\\Version20001Date20220830131446' => __DIR__ . '/../..' . '/lib/Migration/Version20001Date20220830131446.php',
        'OCA\\Photos\\Migration\\Version20003Date20221102170153' => __DIR__ . '/../..' . '/lib/Migration/Version20003Date20221102170153.php',
        'OCA\\Photos\\Migration\\Version20003Date20221103094628' => __DIR__ . '/../..' . '/lib/Migration/Version20003Date20221103094628.php',
        'OCA\\Photos\\Migration\\Version30000Date20240417075405' => __DIR__ . '/../..' . '/lib/Migration/Version30000Date20240417075405.php',
        'OCA\\Photos\\Migration\\Version32000Date20250507132617' => __DIR__ . '/../..' . '/lib/Migration/Version32000Date20250507132617.php',
        'OCA\\Photos\\RepairStep\\InitMetadata' => __DIR__ . '/../..' . '/lib/RepairStep/InitMetadata.php',
        'OCA\\Photos\\Sabre\\Album\\AlbumPhoto' => __DIR__ . '/../..' . '/lib/Sabre/Album/AlbumPhoto.php',
        'OCA\\Photos\\Sabre\\Album\\AlbumRoot' => __DIR__ . '/../..' . '/lib/Sabre/Album/AlbumRoot.php',
        'OCA\\Photos\\Sabre\\Album\\AlbumRootBase' => __DIR__ . '/../..' . '/lib/Sabre/Album/AlbumRootBase.php',
        'OCA\\Photos\\Sabre\\Album\\AlbumsHome' => __DIR__ . '/../..' . '/lib/Sabre/Album/AlbumsHome.php',
        'OCA\\Photos\\Sabre\\Album\\PublicAlbumPhoto' => __DIR__ . '/../..' . '/lib/Sabre/Album/PublicAlbumPhoto.php',
        'OCA\\Photos\\Sabre\\Album\\PublicAlbumRoot' => __DIR__ . '/../..' . '/lib/Sabre/Album/PublicAlbumRoot.php',
        'OCA\\Photos\\Sabre\\Album\\SharedAlbumRoot' => __DIR__ . '/../..' . '/lib/Sabre/Album/SharedAlbumRoot.php',
        'OCA\\Photos\\Sabre\\Album\\SharedAlbumsHome' => __DIR__ . '/../..' . '/lib/Sabre/Album/SharedAlbumsHome.php',
        'OCA\\Photos\\Sabre\\CollectionPhoto' => __DIR__ . '/../..' . '/lib/Sabre/CollectionPhoto.php',
        'OCA\\Photos\\Sabre\\PhotosHome' => __DIR__ . '/../..' . '/lib/Sabre/PhotosHome.php',
        'OCA\\Photos\\Sabre\\Place\\PlacePhoto' => __DIR__ . '/../..' . '/lib/Sabre/Place/PlacePhoto.php',
        'OCA\\Photos\\Sabre\\Place\\PlaceRoot' => __DIR__ . '/../..' . '/lib/Sabre/Place/PlaceRoot.php',
        'OCA\\Photos\\Sabre\\Place\\PlacesHome' => __DIR__ . '/../..' . '/lib/Sabre/Place/PlacesHome.php',
        'OCA\\Photos\\Sabre\\PropFindPlugin' => __DIR__ . '/../..' . '/lib/Sabre/PropFindPlugin.php',
        'OCA\\Photos\\Sabre\\PublicAlbumAuthBackend' => __DIR__ . '/../..' . '/lib/Sabre/PublicAlbumAuthBackend.php',
        'OCA\\Photos\\Sabre\\PublicRootCollection' => __DIR__ . '/../..' . '/lib/Sabre/PublicRootCollection.php',
        'OCA\\Photos\\Sabre\\RootCollection' => __DIR__ . '/../..' . '/lib/Sabre/RootCollection.php',
        'OCA\\Photos\\Service\\MediaPlaceManager' => __DIR__ . '/../..' . '/lib/Service/MediaPlaceManager.php',
        'OCA\\Photos\\Service\\ReverseGeoCoderService' => __DIR__ . '/../..' . '/lib/Service/ReverseGeoCoderService.php',
        'OCA\\Photos\\Service\\UserConfigService' => __DIR__ . '/../..' . '/lib/Service/UserConfigService.php',
        'Pdo\\Dblib' => __DIR__ . '/..' . '/symfony/polyfill-php84/Resources/stubs/Pdo/Dblib.php',
        'Pdo\\Firebird' => __DIR__ . '/..' . '/symfony/polyfill-php84/Resources/stubs/Pdo/Firebird.php',
        'Pdo\\Mysql' => __DIR__ . '/..' . '/symfony/polyfill-php84/Resources/stubs/Pdo/Mysql.php',
        'Pdo\\Odbc' => __DIR__ . '/..' . '/symfony/polyfill-php84/Resources/stubs/Pdo/Odbc.php',
        'Pdo\\Pgsql' => __DIR__ . '/..' . '/symfony/polyfill-php84/Resources/stubs/Pdo/Pgsql.php',
        'Pdo\\Sqlite' => __DIR__ . '/..' . '/symfony/polyfill-php84/Resources/stubs/Pdo/Sqlite.php',
        'ReflectionConstant' => __DIR__ . '/..' . '/symfony/polyfill-php84/Resources/stubs/ReflectionConstant.php',
        'RoundingMode' => __DIR__ . '/..' . '/symfony/polyfill-php84/Resources/stubs/RoundingMode.php',
        'Symfony\\Polyfill\\Php84\\Php84' => __DIR__ . '/..' . '/symfony/polyfill-php84/Php84.php',
        'WoltLab\\WebpExif\\ChunkType' => __DIR__ . '/..' . '/woltlab/webp-exif/src/ChunkType.php',
        'WoltLab\\WebpExif\\Chunk\\Alph' => __DIR__ . '/..' . '/woltlab/webp-exif/src/Chunk/Alph.php',
        'WoltLab\\WebpExif\\Chunk\\Anim' => __DIR__ . '/..' . '/woltlab/webp-exif/src/Chunk/Anim.php',
        'WoltLab\\WebpExif\\Chunk\\Anmf' => __DIR__ . '/..' . '/woltlab/webp-exif/src/Chunk/Anmf.php',
        'WoltLab\\WebpExif\\Chunk\\Chunk' => __DIR__ . '/..' . '/woltlab/webp-exif/src/Chunk/Chunk.php',
        'WoltLab\\WebpExif\\Chunk\\Exception\\AnimationFrameWithoutBitstream' => __DIR__ . '/..' . '/woltlab/webp-exif/src/Chunk/Exception/AnimationFrameWithoutBitstream.php',
        'WoltLab\\WebpExif\\Chunk\\Exception\\DimensionsExceedInt32' => __DIR__ . '/..' . '/woltlab/webp-exif/src/Chunk/Exception/DimensionsExceedInt32.php',
        'WoltLab\\WebpExif\\Chunk\\Exception\\EmptyAnimationFrame' => __DIR__ . '/..' . '/woltlab/webp-exif/src/Chunk/Exception/EmptyAnimationFrame.php',
        'WoltLab\\WebpExif\\Chunk\\Exception\\ExpectedKeyFrame' => __DIR__ . '/..' . '/woltlab/webp-exif/src/Chunk/Exception/ExpectedKeyFrame.php',
        'WoltLab\\WebpExif\\Chunk\\Exception\\MissingExifExtension' => __DIR__ . '/..' . '/woltlab/webp-exif/src/Chunk/Exception/MissingExifExtension.php',
        'WoltLab\\WebpExif\\Chunk\\Exception\\MissingMagicByte' => __DIR__ . '/..' . '/woltlab/webp-exif/src/Chunk/Exception/MissingMagicByte.php',
        'WoltLab\\WebpExif\\Chunk\\Exception\\UnknownChunkWithKnownFourCC' => __DIR__ . '/..' . '/woltlab/webp-exif/src/Chunk/Exception/UnknownChunkWithKnownFourCC.php',
        'WoltLab\\WebpExif\\Chunk\\Exception\\UnsupportedVersion' => __DIR__ . '/..' . '/woltlab/webp-exif/src/Chunk/Exception/UnsupportedVersion.php',
        'WoltLab\\WebpExif\\Chunk\\Exif' => __DIR__ . '/..' . '/woltlab/webp-exif/src/Chunk/Exif.php',
        'WoltLab\\WebpExif\\Chunk\\Iccp' => __DIR__ . '/..' . '/woltlab/webp-exif/src/Chunk/Iccp.php',
        'WoltLab\\WebpExif\\Chunk\\UnknownChunk' => __DIR__ . '/..' . '/woltlab/webp-exif/src/Chunk/UnknownChunk.php',
        'WoltLab\\WebpExif\\Chunk\\Vp8' => __DIR__ . '/..' . '/woltlab/webp-exif/src/Chunk/Vp8.php',
        'WoltLab\\WebpExif\\Chunk\\Vp8l' => __DIR__ . '/..' . '/woltlab/webp-exif/src/Chunk/Vp8l.php',
        'WoltLab\\WebpExif\\Chunk\\Vp8x' => __DIR__ . '/..' . '/woltlab/webp-exif/src/Chunk/Vp8x.php',
        'WoltLab\\WebpExif\\Chunk\\Xmp' => __DIR__ . '/..' . '/woltlab/webp-exif/src/Chunk/Xmp.php',
        'WoltLab\\WebpExif\\Decoder' => __DIR__ . '/..' . '/woltlab/webp-exif/src/Decoder.php',
        'WoltLab\\WebpExif\\Encoder' => __DIR__ . '/..' . '/woltlab/webp-exif/src/Encoder.php',
        'WoltLab\\WebpExif\\Exception\\ExtraChunksInSimpleFormat' => __DIR__ . '/..' . '/woltlab/webp-exif/src/Exception/ExtraChunksInSimpleFormat.php',
        'WoltLab\\WebpExif\\Exception\\ExtraVp8xChunk' => __DIR__ . '/..' . '/woltlab/webp-exif/src/Exception/ExtraVp8xChunk.php',
        'WoltLab\\WebpExif\\Exception\\FileSizeMismatch' => __DIR__ . '/..' . '/woltlab/webp-exif/src/Exception/FileSizeMismatch.php',
        'WoltLab\\WebpExif\\Exception\\LengthOutOfBounds' => __DIR__ . '/..' . '/woltlab/webp-exif/src/Exception/LengthOutOfBounds.php',
        'WoltLab\\WebpExif\\Exception\\MissingChunks' => __DIR__ . '/..' . '/woltlab/webp-exif/src/Exception/MissingChunks.php',
        'WoltLab\\WebpExif\\Exception\\NotEnoughData' => __DIR__ . '/..' . '/woltlab/webp-exif/src/Exception/NotEnoughData.php',
        'WoltLab\\WebpExif\\Exception\\UnexpectedChunk' => __DIR__ . '/..' . '/woltlab/webp-exif/src/Exception/UnexpectedChunk.php',
        'WoltLab\\WebpExif\\Exception\\UnexpectedEndOfFile' => __DIR__ . '/..' . '/woltlab/webp-exif/src/Exception/UnexpectedEndOfFile.php',
        'WoltLab\\WebpExif\\Exception\\UnrecognizedFileFormat' => __DIR__ . '/..' . '/woltlab/webp-exif/src/Exception/UnrecognizedFileFormat.php',
        'WoltLab\\WebpExif\\Exception\\Vp8xAbsentChunk' => __DIR__ . '/..' . '/woltlab/webp-exif/src/Exception/Vp8xAbsentChunk.php',
        'WoltLab\\WebpExif\\Exception\\Vp8xHeaderLengthMismatch' => __DIR__ . '/..' . '/woltlab/webp-exif/src/Exception/Vp8xHeaderLengthMismatch.php',
        'WoltLab\\WebpExif\\Exception\\Vp8xMissingImageData' => __DIR__ . '/..' . '/woltlab/webp-exif/src/Exception/Vp8xMissingImageData.php',
        'WoltLab\\WebpExif\\Exception\\Vp8xWithoutChunks' => __DIR__ . '/..' . '/woltlab/webp-exif/src/Exception/Vp8xWithoutChunks.php',
        'WoltLab\\WebpExif\\Exception\\WebpExifException' => __DIR__ . '/..' . '/woltlab/webp-exif/src/Exception/WebpExifException.php',
        'WoltLab\\WebpExif\\WebP' => __DIR__ . '/..' . '/woltlab/webp-exif/src/WebP.php',
    );

    public static function getInitializer(ClassLoader $loader)
    {
        return \Closure::bind(function () use ($loader) {
            $loader->prefixLengthsPsr4 = ComposerStaticInitPhotos::$prefixLengthsPsr4;
            $loader->prefixDirsPsr4 = ComposerStaticInitPhotos::$prefixDirsPsr4;
            $loader->classMap = ComposerStaticInitPhotos::$classMap;

        }, null, ClassLoader::class);
    }
}
