OC.L10N.register(
    "app_api",
    {
    "Cancel" : "Mégse",
    "Delete" : "Törlés",
    "Password confirmation failed" : "A jelszó megerősítése nem sikerült",
    "Default" : "Alapértelmezett",
    "Edit" : "Szerkesztés",
    "Unlimited" : "Korlátlan",
    "Name" : "Név",
    "Host" : "Kiszolgáló",
    "Nextcloud URL" : "Nextcloud URL",
    "Memory limit" : "Memória korlát",
    "Enabled" : "Engedélyezve",
    "More information" : "További információk",
    "Remove" : "Eltávolítás",
    "From" : "Feladó",
    "To" : "Címzett",
    "Add" : "Hozzáadás",
    "Display name" : "Megjelenítendő név",
    "Confirm" : "Megerősítés",
    "Save" : "Mentés",
    "Register" : "Regisztráció",
    "{license}-licensed" : "{license}-licencelt",
    "Update to {version}" : "Frissítés erre: {version}",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Ennek az alkalmazásnak nincs minimum szükséges Nextcloud verziója megadva. Ez hiba lesz a jövőben.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Ennek az alkalmazásnak nincs maximum szükséges Nextcloud verziója megadva. Ez hiba lesz a jövőben.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Ezt az alkalmazást nem lehet telepíteni, mert a következő függőségek hiányoznak:",
    "View in store" : "Megtekintés a tárban",
    "Visit website" : "Weboldal meglátogatása",
    "Report a bug" : "Hiba bejelentése",
    "User documentation" : "Felhasználói dokumentáció",
    "Admin documentation" : "Rendszergazdai dokumentáció",
    "Developer documentation" : "Fejlesztői dokumentáció",
    "This app is supported via your current Nextcloud subscription." : "Az alkalmazás támogatását a jelenlegi Nextcloud előfizetése biztosítja.",
    "Supported" : "Támogatott",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "A kiemelt alkalmazásokat a közösség tagjai készítik. Ezek biztosítják a fő funkciókat, és készek az éles használatra.",
    "Featured" : "Kiemelt",
    "Update to {update}" : "Frissítés erre: {update}",
    "Icon" : "Ikon",
    "Version" : "Verzió",
    "Daemon" : "Démon",
    "Level" : "Szint",
    "Actions" : "Műveletek",
    "Results from other categories" : "Találatok más kategóriákból",
    "_Update_::_Update all_" : ["Frissítés","Összes frissítése"],
    "Type" : "Típus",
    "Display Name" : "Megjelenített név",
    "Network" : "Hálózat",
    "by {author}\n{license}" : "szerző: {author}\n{license}",
    "Your apps" : "Az Ön alkalmazásai",
    "Documentation" : "Dokumentáció",
    "Details" : "Részletek",
    "Changelog" : "Változásnapló",
    "Active apps" : "Aktív alkalmazások",
    "Disabled apps" : "Letiltott alkalmazások",
    "Updates" : "Frissítések",
    "Featured apps" : "Kiemelt alkalmazások",
    "Supported apps" : "Támogatott alkalmazások",
    "Enable" : "Engedélyezés",
    "Disable" : "Letiltás",
    "Allow untested app" : "Teszteletlen alkalmazás engedélyezése",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Ez az alkalmazás nincs megjelölve, hogy kompatibilis lenne a jelenlegi Nextcloud verzióval. Ha folytatja, telepítheti az alkalmazást. Azonban az alkalmazás lehet, hogy nem fog rendeltetés szerint működni.",
    "An error occurred during the request. Unable to proceed." : "Hiba történt a kérés során. Nem lehet folytatni.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Hiba: az alkalmazás nem nem engedélyezhető, mert instabillá tenné a kiszolgálót"
},
"nplurals=2; plural=(n != 1);");
