OC.L10N.register(
    "circles",
    {
    "Personal" : "﻿ವೈಯಕ್ತಿಕ",
    "Open" : "ತೆರೆಯಿರಿ",
    "Password protected" : "ಗುಪ್ತಪದದಿಂದ ರಕ್ಷಿಸಲಾಗಿದೆ",
    "Local" : "ಸ್ಥಳೀಯ",
    "Federated" : "Federated",
    "Admin" : "﻿ನಿರ್ವಹಕ",
    "Owner" : "Owner",
    "Files" : "﻿ಕಡತಗಳು",
    "Invalid image" : "ಅಸಾಮರ್ಥ್ಯ ಚಿತ್ರ",
    "Unknown filetype" : "﻿ಅಪರಿಚಿತ ಕಡತ ಮಾದರಿ",
    "Save" : "Save",
    "Cancel" : "Cancel",
    "Folder" : "ಕೋಶ",
    "Close" : "ಮುಚ್ಚು",
    "New folder" : "﻿ಹೊಸ ಕೋಶ",
    "Edit" : "ಸಂಪಾದಿಸು",
    "Pending" : "﻿ಬಾಕಿ ಇದೆ",
    "User" : "User",
    "Group" : "﻿ಗುಂಪು",
    "Email" : "﻿ಇ-ಅಂಚೆ",
    "Users" : "﻿ಬಳಕೆದಾರರು",
    "Groups" : "﻿ಗುಂಪುಗಳು",
    "Name" : "﻿ಹೆಸರು",
    "Size" : "﻿ ಗಾತ್ರ",
    "Modified" : "﻿ಬದಲಾಯಿಸಿದ"
},
"nplurals=2; plural=(n > 1);");
