.album[data-v-52a1b252]{display:flex;flex-direction:column}.album__title[data-v-52a1b252]{width:100%}.album__name[data-v-52a1b252]{overflow:hidden;white-space:nowrap;text-overflow:ellipsis}.album__location[data-v-52a1b252]{margin-inline-start:-4px;display:flex;color:var(--color-text-lighter)}
