OC.L10N.register(
    "bruteforcesettings",
    {
    "Brute-force settings" : "防暴力攻擊設定",
    "Whitelist IPs" : "白名單 IP",
    "Brute-force protection is meant to protect Nextcloud servers from attempts to\nguess account passwords in various ways. Besides the obvious \"*let's try a big\nlist of commonly used passwords*\" attack, it also makes it harder to use\nslightly more sophisticated attacks via the reset password form or trying to\nfind app password tokens.\n\nIf triggered, brute-force protection makes requests coming from an IP on a\nbrute-force protected controller with the same API slower for a 24 hour period.\n\nWith this app, the admin can exempt an IP address or range from this\nprotection which can be useful for testing purposes or when there are false\npositives due to a lot of accounts on one IP address." : "防暴力攻擊是用來防止 Nextcloud 伺服器被嘗試\n用各種方式猜測帳號密碼。除了明顯的「*嘗試大量\n常用的密碼清單*」攻擊，它也讓較為複雜的攻擊像是藉由重設填密碼欄位或是試著\n找到應用程式密碼權杖較為困難。\n\n若啟動暴力保護，將會在24小時的時間內從暴力保護控制器的 IP 發出一個同樣的 API 需求變慢。\n\n使用此應用程式，管理員可以用來解除一個 IP 或是範圍的保護，因為這對於用來測試或是當有很多帳號在同一個 IP 位址而誤判的時候可能比較有用。",
    "The comment cannot exceed {max} characters." : "留言不能超過 {max} 個字元。",
    "Leave an internal comment explaining why this IP address is allowed, for example its location, so the entry can be removed when it is no longer needed." : "請留下內部留言說明為何允許此 IP 位址（例如其地理位置），以便在不再需要時能移除此條目。",
    "Your current IP address is detected as \"{remoteAddress}\". This address is currently throttled. Current delay: {delay} ms." : "偵測到您的目前 IP 位址為「{remoteAddress}」。此位址目前受到流量限制。目前延遲：{delay} 毫秒。",
    "Your current IP address is detected as \"{remoteAddress}\". This address bypasses brute-force protection." : "偵測到您的目前 IP 位址為「{remoteAddress}」。此位址可繞過暴力破解防護機制。",
    "Your current IP address is detected as \"{remoteAddress}\". This address is not currently throttled." : "偵測到您的目前 IP 位址為「{remoteAddress}」。此位址目前未受流量限制。",
    "Failed to add the IP address to the allow list." : "無法將該 IP 位址加入允許清單。",
    "Failed to save the rate limit setting." : "儲存速率限制設定失敗。",
    "Failed to update the allow list entry." : "更新允許清單條目失敗。",
    "Brute-force allow list" : "防暴力攻擊允許清單",
    "To exclude IP ranges from the brute-force protection specify them below. Note that any allowed IP can perform authentication attempts without any throttling. For security reasons, it is recommended to list as few remote addresses as possible or ideally even none at all." : "要將 IP 範圍從防暴力攻擊保護排除，請在下方指定。請注意，任何允許的 IP 都可以進行身份驗證嘗試，不會有任何限制。出於安全因素，建議盡量少列入遠端地址，理想情況下應當完全沒有。",
    "Bypass rate limiting for allowed IPs" : "允許 IP 繞過速率限制",
    "Add new IP address" : "新增 IP 地址",
    "IP address" : "IP 位址",
    "Mask" : "遮罩",
    "Comment" : "註解",
    "Add" : "新增",
    "Edit comment for {subnet}" : "編輯 {subnet} 的註解",
    "Save" : "儲存",
    "Delete entry for {subnet}" : "刪除 {subnet} 的條目",
    "Comment cannot exceed {max} characters." : "註解不能超過 {max} 個字元。",
    "Leave an internal comment, why this IP is allowed, e.g. the  location, so it can be revoked, when it is no longer needed." : "留下內部註解，說明為何允許此 IP，例如位置，如此在不需要時可以撤銷。",
    "Your remote address was identified as \"{remoteAddress}\" and is throttled at the moment by {delay}ms." : "您的遠端地址被識別為「{remoteAddress}」，目前受到{delay}毫秒的限制。",
    "Your remote address was identified as \"{remoteAddress}\" and is bypassing brute-force protection." : "您的遠端地址被識別為「{remoteAddress}」，並繞過了暴力攻擊防護。",
    "Your remote address was identified as \"{remoteAddress}\" and is not actively throttled at the moment." : "您的遠端地址被識別為「{remoteAddress}」，目前未受限制。",
    "There was an error adding the IP to the allow list." : "新增 IP 至允許清單時發生錯誤。",
    "There was an error updating the allow list entry." : "更新允許清單條目時發生錯誤。"
},
"nplurals=1; plural=0;");
