OC.L10N.register(
    "files_lock",
    {
    "File is currently locked by %s" : "Файл заблоковано %s",
    "File is not locked" : "Файл не заблоковано",
    "File can only be locked with update permissions." : "Файл можна заблокувати лише за наявности дозволів на внесення змін",
    "File can only be unlocked by providing a valid owner lock token" : "Файл можна розблокувати, якщо надати дійсний токен блокування, що належить власникові",
    "File can only be unlocked by the owner of the lock" : "Файл може розблокувати лише власник замка",
    "Desktop client" : "Клієнт для ПК",
    "iOS client" : "iOS клієнт",
    "Android client" : "Клієнт Android",
    "Temporary files lock" : "Тимчасове блокування файлів",
    "Temporary lock your files" : "Тимчасово заблокувати ваші файли",
    "Allow your users to temporary lock their files to avoid conflicts while working on shared files." : "Дозволити своїм користувачам тимчасово блокувати власні файли, щоб уникнути конфліктів під час роботи зі спільними файлами.",
    "Manually locked by {user}" : "Вручну заблоковано {user}",
    "Locked by editing online in {app}" : "Заблоковано шляхом редагування онлайн в {app}",
    "Automatically locked by {user}" : "Автоматично заблоковано за допомогою {user}",
    "Unlock file" : "Розблокувати файл",
    "Lock file" : "Заблокувати файл",
    "This file has been locked automatically by a client. Removing the lock may lead to a conflict saving the file." : "Цей файл було автоматично заблоковано клієнтом. Зняття блокування може призвести до конфлікту при збереженні файлу.",
    "Keep lock" : "Тримайте замок.",
    "Force unlock" : "Примусове розблокування"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
