import{a9 as o}from"./_plugin-vue_export-helper-BCa8Js7x.chunk.mjs";const i=o("notifications").clearOnLogout().persist().build();export{i as B};
//# sourceMappingURL=BrowserStorage-DqFN4qJZ.chunk.mjs.map
