OC.L10N.register(
    "files_external",
    {
    "You are not logged in" : "Non hai effettuato l'accesso",
    "Permission denied" : "Permesso negato",
    "Storage with ID \"%d\" not found" : "Archiviazione con ID \"%d\" non trovata",
    "Forbidden to manage local mounts" : "Gestione dei mount locali proibita",
    "Invalid backend or authentication mechanism class" : "Motore o classe del meccanismo di autenticazione non valido",
    "Invalid mount point" : "Punto di mount non valido",
    "Objectstore forbidden" : "Objectstore vietato",
    "Invalid storage backend \"%s\"" : "Motore di archiviazione \"%s\" non valido",
    "Not permitted to use backend \"%s\"" : "Utilizzo del motore \"%s\" non permesso",
    "Not permitted to use authentication mechanism \"%s\"" : "Utilizzo del meccanismo di autenticazione \"%s\" non permesso",
    "Unsatisfied backend parameters" : "Parametri del motore non soddisfatti",
    "Unsatisfied authentication mechanism parameters" : "Parametri del meccanismo di autenticazione non soddisfatti",
    "Insufficient data: %s" : "Dati insufficienti: %s",
    "Storage with ID \"%d\" is not editable by non-admins" : "L'archiviazione con ID \"%d\" non è modificabile dai non amministratori",
    "Builtin" : "Integrata",
    "None" : "Nessuno",
    "OpenStack v2" : "OpenStack v2",
    "Login" : "Accedi",
    "Password" : "Password",
    "Tenant name" : "Nome tenant",
    "Identity endpoint URL" : "URL endpoint delle identità",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "Dominio",
    "Rackspace" : "Rackspace",
    "API key" : "Chiave API",
    "Global credentials" : "Credenziali globali",
    "Log-in credentials, save in database" : "Credenziali di accesso, salva nel database",
    "Login and password" : "Login e password",
    "Log-in credentials, save in session" : "Credenziali di accesso, salva nella sessione",
    "Global credentials, manually entered" : "Credenziali globali, inserite manualmente",
    "Manually entered, store in database" : "Inserite manualmente, salva nel database",
    "RSA public key" : "Chiave pubblica RSA",
    "Public key" : "Chiave pubblica",
    "RSA private key" : "Chiave privata RSA",
    "Private key" : "Chiave privata",
    "Kerberos default realm, defaults to \"WORKGROUP\"" : "Regno predefinito di Kerberos, predefinito su \"WORKGROUP\"",
    "Kerberos ticket Apache mode" : "Modalità Apache ticket Kerberos",
    "Kerberos ticket" : "Ticket Kerberos",
    "Bucket" : "Bucket",
    "Hostname" : "Nome host",
    "Port" : "Porta",
    "Proxy" : "Proxy",
    "Region" : "Regione",
    "Storage Class" : "Classe di archiviazione",
    "Enable multipart copy" : "Attiva copia multiparte",
    "SSE-C encryption key" : "Chiave di crittografia SSE-C",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Sottocartella remota",
    "Secure https://" : "Sicuro https://",
    "Host" : "Host",
    "Secure ftps://" : "Sicuro ftps://",
    "Location" : "Posizione",
    "Root" : "Radice",
    "Share" : "Condividi",
    "Show hidden files" : "Mostra i file nascosti",
    "Case sensitive file system" : "File system case sensitive",
    "Disabling it will allow to use a case insensitive file system, but comes with a performance penalty" : "Disattivandolo, sarà possibile usare un file system non sensibile alle maiuscole, ma comporta una riduzione di prestazioni",
    "Verify ACL access when listing files" : "Verifica le ACL di accesso quando elenchi i file",
    "Check the ACL's of each file or folder inside a directory to filter out items where the account has no read permissions, comes with a performance penalty" : "Controlla le ACL di ogni file o cartella all'interno di una cartella per filtrare elementi dove l'account non ha permessi di lettura, implica una riduzione di prestazioni",
    "Timeout" : "Tempo scaduto",
    "Login as share" : "Accedi come condivisione",
    "Service name" : "Nome servizio",
    "Request timeout (seconds)" : "Tempo massimo della richiesta (secondi)",
    "External storage" : "Archiviazione esterna",
    "External storage support" : "Supporto archiviazioni esterne",
    "Adds basic external storage support" : "Aggiunge un supporto di base per archiviazioni esterne",
    "This application enables administrators to configure connections to external storage providers, such as FTP servers, S3 or SWIFT object stores, other Nextcloud servers, WebDAV servers, and more. Administration can choose which types of storage to enable and can mount these storage locations for an account, a group, or the entire system. Users will see a new folder appear in their root Nextcloud directory, which they can access and use like any other Nextcloud folder. External storage also allows people to share files stored in these external locations. In these cases, the credentials for the owner of the file are used when the recipient requests the file from external storage, thereby ensuring that the recipient can access the shared file.\n\nExternal storage can be configured using the GUI or at the command line. This second option provides the administration with more flexibility for configuring bulk external storage mounts and setting mount priorities. More information is available in the external storage GUI documentation and the external storage Configuration File documentation." : "Questa applicazione consente agli amministratori di configurare connessioni a provider di archiviazione esterni, come server FTP, archivi di oggetti S3 o SWIFT, altri server Nextcloud, server WebDAV e altro ancora. L'amministrazione può scegliere quali tipi di archiviazione abilitare e montare queste posizioni di archiviazione per un account, un gruppo o l'intero sistema. Gli utenti vedranno apparire una nuova cartella nella loro directory principale di Nextcloud, a cui potranno accedere e utilizzare come qualsiasi altra cartella Nextcloud. L'archiviazione esterna consente inoltre alle persone di condividere file archiviati in queste posizioni esterne. In questi casi, le credenziali del proprietario del file vengono utilizzate quando il destinatario richiede il file da un archivio esterno, garantendo così che il destinatario possa accedere al file condiviso.\n\nL'archiviazione esterna può essere configurata utilizzando la GUI o dalla riga di comando. Questa seconda opzione offre all'amministrazione maggiore flessibilità per la configurazione dei montaggi di archiviazione esterni in blocco e l'impostazione delle priorità di montaggio. Ulteriori informazioni sono disponibili nella documentazione della GUI dell'archiviazione esterna e nella documentazione del file di configurazione dell'archiviazione esterna.",
    "Add storage" : "Aggiungi archiviazione",
    "Folder name" : "Nome della cartella",
    "Authentication" : "Autenticazione",
    "Cancel" : "Cancel",
    "Edit" : "Modifica",
    "Create" : "Crea",
    "Restrict to" : "Limita a",
    "Never" : "Mai",
    "Once every direct access" : "Una volta per ogni accesso diretto",
    "Always" : "Sempre",
    "Mount options" : "Opzioni di mount",
    "Read only" : "Sola lettura",
    "Enable previews" : "Abilita le anteprime",
    "Enable sharing" : "Abilita condivisione",
    "Enable encryption" : "Abilita cifratura",
    "Compatibility with Mac NFD encoding (slow)" : "Compatibilità con la codifica Mac NFD (lento)",
    "External storages" : "Archiviazioni esterne",
    "Status" : "Stato",
    "Restricted to" : "Limitato a",
    "Actions" : "Azioni",
    "Delete" : "Elimina",
    "Saved" : "Salvato",
    "Error while saving" : "Errore durante il salvataggio",
    "Allow people to mount external storage" : "Consenti alle persone di montare archiviazioni esterne",
    "Error generating key pair" : "Errore durante la generazione della coppia di chiavi",
    "Key size" : "Dimensione chiave",
    "Generate keys" : "Genera la chiavi",
    "Confirm" : "Conferma",
    "Storage credentials" : "Credenziali dello spazio di archiviazione",
    "To access the storage, you need to provide the authentication credentials." : "Per accedere allo spazio di archiviazione è necessario fornire le credenziali di autenticazione.",
    "Enter the storage login" : "Inserisci le credenziali dello spazio di archiviazione",
    "Enter the storage password" : "Inserisci la password dello spazio di archiviazione",
    "{module} is not installed." : "{module} non è installato.",
    "Add external storage" : "Aggiungi archiviazione esterna",
    "Global credentials can be used to authenticate with multiple external storages that have the same credentials." : "Le credenziali globali possono essere utilizzate anche per l'autenticazione con più archiviazioni esterne che hanno le stesse credenziali.",
    "Saving …" : "Salvataggio…",
    "Save" : "Salva",
    "Unable to update this external storage config. {statusMessage}" : "Impossibile aggiornare questa configurazione di archiviazione esterna. {statusMessage}",
    "New configuration successfully saved" : "Nuova configurazione salvata correttamente",
    "Enter missing credentials" : "Digita le credenziali mancanti",
    "Credentials successfully set" : "Credenziali impostate correttamente",
    "Error while setting credentials: {error}" : "Errore durante l'impostazione delle credenziali: {error}",
    "Checking storage …" : "Controllo lo spazio …",
    "There was an error with this external storage." : "Si è verificato un errore con questa archiviazione esterna.",
    "We were unable to check the external storage {basename}" : "Non è stato possibile controllare l'archiviazione esterna {basename}",
    "Examine this faulty external storage configuration" : "Esamina questa configurazione errata di archiviazione esterna",
    "Open in Files" : "Apri in File",
    "External mount error" : "Errore di mount esterno",
    "There was an error with this external storage. Do you want to review this mount point config in the settings page?" : "Si è verificato un errore con questa archiviazione esterna. Vuoi rivedere la configurazione del punto di mount nelle impostazioni?",
    "Open settings" : "Apri impostazioni",
    "Ignore" : "Ignora",
    "List of external storage." : "Lista di archiviazioni esterne.",
    "There is no external storage configured. You can configure them in your Personal settings." : "Nessuna archiviazione esterna configurata. Puoi configurarla nelle impostazioni personali.",
    "There is no external storage configured and you don't have the permission to configure them." : "Nessuna archiviazione esterna configurata e non hai i permessi per configurarla.",
    "No external storage" : "Nessuna archiviazione esterna",
    "Storage type" : "Tipo di archiviazione",
    "Unknown" : "Sconosciuto",
    "Scope" : "Ambito",
    "Personal" : "Personale",
    "System" : "Sistema",
    "Connected" : "Connesso",
    "Error" : "Errore",
    "Incomplete configuration" : "Configurazione incompleta",
    "Unauthorized" : "Non autorizzato",
    "Network error" : "Errore di rete",
    "Grant access" : "Concedi l'accesso",
    "Error configuring OAuth2" : "Errore di configurazione OAuth2",
    "%s" : "%s",
    "Access key" : "Chiave di accesso",
    "Secret key" : "Chiave segreta",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID client",
    "Client secret" : "Segreto del client",
    "S3 Storage" : "Archiviazione S3",
    "Enable SSL" : "Abilita SSL",
    "Enable Path Style" : "Abilita stile percorsi",
    "Legacy (v2) authentication" : "Autenticazione tradizionale (v2)",
    "FTP" : "FTP",
    "Local" : "Locale",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "SFTP with secret key login" : "SFTP con accesso a chiave segreta",
    "SMB/CIFS" : "SMB/CIFS",
    "SMB/CIFS using OC login" : "SMB/CIFS utilizzando le credenziali OC",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Il supporto cURL di PHP non è abilitato o installato. Impossibile montare %s. Chiedi al tuo amministratore di sistema di installarlo.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Il supporto FTP in PHP non è abilitato o installato. Impossibile montare %s. Chiedi al tuo amministratore di sistema di installarlo.",
    "\"%1$s\" is not installed. Mounting of %2$s is not possible. Please ask your system administrator to install it." : "\"%1$s\" non è installato. Impossibile montare %2$s. Chiedi al tuo amministratore di sistema di installarlo.",
    "Checking storage …" : "Controllo spazio di archiviazione…",
    "Type to select account or group." : "Digita per selezionare account o gruppi.",
    "(Group)" : "(Gruppo)",
    "Check for changes" : "Controlla le modifiche",
    "Disconnect" : "Disconnetti",
    "Unknown backend: {backendName}" : "Backend sconosciuto: {backendName}",
    "Admin defined" : "Definito dall'amministratore",
    "Automatic status checking is disabled due to the large number of configured storages, click to check status" : "Il controllo automatico dello stato è disabilitato a causa del numero elevato di archivi configurati, fai clic per controllare lo stato",
    "Are you sure you want to disconnect this external storage?" : "Sei sicuro di voler scollegare questa memoria esterna?",
    "It will make the storage unavailable in {instanceName} and will lead to a deletion of these files and folders on any sync client that is currently connected but will not delete any files and folders on the external storage itself." : "Ciò renderà lo spazio di archiviazione non disponibile su {instanceName} e porterà alla cancellazione di questi file e cartelle su qualsiasi client di sincronizzazione attualmente connesso, ma non cancellerà alcun file o cartella presenti sullo spazio di archiviazione esterno stesso.",
    "Delete storage?" : "Vuoi eliminare l'archiviazione?",
    "Click to recheck the configuration" : "Clic per controllare di nuovo la configurazione",
    "Saving …" : "Salvataggio…",
    "Failed to save global credentials" : "Impossibile salvare le credenziali globali",
    "Failed to save global credentials: {message}" : "Impossibile salvare le credenziali globali: {message}",
    "No external storage configured or you don't have the permission to configure them" : "Nessuna archiviazione esterna configurata o non hai i permessi per configurarle",
    "Open documentation" : "Apri la documentazione",
    "External storage enables you to mount external storage services and devices as secondary Nextcloud storage devices. You may also allow people to mount their own external storage services." : "Archiviazioni esterne ti consente di montare servizi di archiviazione esterna e dispositivi come dispositivi di archiviazione secondari di Nextcloud. Puoi anche permettere alle persone di montare i propri servizi di archiviazione esterna.",
    "Configuration" : "Configurazione",
    "Available for" : "Disponibile per",
    "All people" : "Tutte le persone",
    "Advanced settings" : "Impostazioni avanzate"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
