OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "\"%s\" の個人アクティビティフィード",
    "Your feed URL is invalid" : "フィードURLが無効です",
    "Activity feed for %1$s" : "%1$sのアクティビティフィード",
    "Activity feed" : "アクティビティフィード",
    "Your settings have been updated." : "設定を更新しました。",
    "Settings have been updated." : "設定を更新しました。",
    "remote user" : "リモートユーザー",
    "Recent activity" : "最近のアクティビティ",
    "No activities" : "アクティビティがありません",
    "More activities" : "その他のアクティビティ",
    "Daily activity summary for %s" : "%s のデイリーアクティビティー概要",
    "_and %n more…_::_and %n more…_" : ["%n その他　"],
    "You can disable daily digest emails in the <a href=\"%s\">settings</a>." : "<a href=\"%s\">設定</a>で毎日のダイジェストメールを無効にすることができます。",
    "You can disable daily digest emails in the settings: %s" : "設定で毎日のダイジェストメールを無効にすることができます: %s",
    "All activities" : "すべてのアクティビティ",
    "By others" : "他ユーザー",
    "By you" : "自分",
    "Activity at %s" : "%sの活動",
    "Hello %s" : "%s さん、こんにちは",
    "Hello %s," : "%s さん、こんにちは",
    "There was some activity at %s" : "%s　にアクティビティがありました。",
    "_and %n more _::_and %n more _" : ["と他 %n 件"],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "これらのメールの頻度または完全に無効化することは<a href=\"%s\">設定</a>から行えます。",
    "You can change the frequency of these emails or disable them in the settings: %s" : "これらのメールの頻度または完全に無効化することは設定の次から行えます: %s",
    "Mail" : "メール",
    "Push" : "プッシュ",
    "Activity" : "アクティビティ",
    "Notifications" : "通知",
    "This application enables people to view a log of activities about them, their files or other data." : "このアプリケーションは、アクティビティやファイル等のログの表示を有効にします。",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "このアプリはNextcloudにあるファイルやデータに関連する各種操作状況を確認ができます。\n\t\tユーザー毎に個人設定でそれらアクティビティを通知するかどうかを設定できます。\n\t\tさらに、どのアクティビティを携帯電話へ通知するのか、それともEメールでするのか、\n\t\t他にも日次サマリーを毎朝送信するのかどうかも選択できます。\n\t\tより詳しい情報は、アクティビティに関するドキュメントをご覧ください。",
    "Today" : "今日",
    "Last 7 days" : "7日以内",
    "Last 30 days" : "30日以内",
    "Custom range" : "カスタム範囲",
    "Clear search" : "検索をクリア",
    "Clear filters" : "フィルターをクリア",
    "From" : "開始",
    "To" : "終了",
    "Send email" : "メールを送信",
    "Send push notification" : "プッシュ通知を送信",
    "Activity notification configuration" : "アクティビティ通知の設定",
    "Yesterday" : "昨日",
    "Less" : "以下",
    "More" : "さらに表示",
    "_Downloaded %n time (%s in the last 30 days)_::_Downloaded %n times (%s in the last 30 days)_" : ["ダウンロード回数 %n回（過去30日間で%s回）"],
    "_Downloaded %n time_::_Downloaded %n times_" : ["ダウンロード回数 %n回"],
    "You need to set up your email address before you can receive notification emails." : "通知メールを受け取るにはメールアドレスを設定する必要があります。",
    "Send activity emails" : "アクティビティメールを送信する",
    "As soon as possible" : "できるだけ早く",
    "Hourly" : "1時間ごと",
    "Daily" : "毎日",
    "Weekly" : "毎週",
    "You commented" : "コメント済",
    "Message deleted by author" : "作成者によって削除されたメッセージ",
    "Open {filename}" : "{filename} を開く",
    "in {path}" : "場所： {path}",
    "Home" : "ホーム",
    "Could not load activities" : "アクティビティを読み込めませんでした",
    "Loading activities" : "アクティビティを読み込み中",
    "This stream will show events like additions, changes & shares" : "このタイムラインには、追加、変更、共有が表示されます。",
    "No activity yet" : "まだアクティビティはありません",
    "New activities" : "新しいアクティビティ",
    "Loading more activities" : "アクティビティをさらに読み込み中",
    "No more activities." : "アクティビティはこれ以上ありません。",
    "Could not enable RSS link" : "RSSリンクを有効化できませんでした",
    "RSS link copied to clipboard" : "RSSリンクをクリップボードにコピーしました",
    "Could not copy the RSS link, please copy manually:" : "RSSリンクをコピーできなかったので、手作業でコピーしてください",
    "Activity settings" : "アクティビティの設定",
    "Enable RSS feed" : "RSSフィードを有効にする",
    "RSS feed" : "RSS フィード",
    "Copy RSS feed link" : "RSSフィードのリンクをコピー",
    "Personal notification settings" : "個人通知設定",
    "Clear selection" : "選択をクリア",
    "Unable to load the activity list" : "アクティビティリストを読み込めませんでした",
    "Choose for which activities you want to get an email or push notification." : "メール通知やプッシュ通知を行うアクティビティを選択してください",
    "Choose for which activities you want to get a push notification." : "プッシュ通知を行うアクティビティを選択してください",
    "Notification" : "通知",
    "Enable notification emails" : "メール通知を有効にする",
    "Daily activity summary" : "毎日のアクティビティの概要",
    "Send daily activity summary in the morning" : "日々のアクティビティの概要を朝に送信する",
    "Default settings" : "デフォルト設定",
    "Configure the default notification settings for new accounts." : "新しいアカウントに対してデフォルトの通知設定を構成します。",
    "Unable to save the settings" : "設定を保存できません",
    "No more events to load" : "これ以上読み込むイベントはありません"
},
"nplurals=1; plural=0;");
