OC.L10N.register(
    "sharebymail",
    {
    "Shared with {email}" : "Διαμοιράστηκε με {email}",
    "Shared with {email} by {actor}" : "Διαμοιράστηκε με {email} από {actor}",
    "Unshared from {email}" : "Διακοπή διαμοιρασμού από {email}",
    "Unshared from {email} by {actor}" : "Διακοπή διαμοιρασμού με {email} από {actor}",
    "Password for mail share sent to {email}" : "Το συνθηματικό διαμοιρασμού αλληλογραφίας αποστέλλεται στο {email}",
    "Password for mail share sent to you" : "Το συνθηματικό για διαμοιρασμό αλληλογραφίας σας έχει σταλεί",
    "You shared {file} with {email} by mail" : "Διαμοιραστήκατε {file} με {email} μέσω mail",
    "{actor} shared {file} with {email} by mail" : "Ο/Η {actor} διαμοίρασε το {file} με {email} μέσω mail",
    "You unshared {file} from {email} by mail" : "Διακόψατε διαμοιρασμό του {file} από {email} με mail",
    "{actor} unshared {file} from {email} by mail" : "Ο/Η {actor} διέκοψε τον διαμοιρασμό το {file} από {email} με mail",
    "Password to access {file} was sent to {email}" : "Το συνθηματικό για πρόσβαση στο {file} έχει αποσταλεί στο {email}",
    "Password to access {file} was sent to you" : "Σας έχει αποσταλεί το συνθηματικό για πρόσβαση {file}",
    "Share by mail" : "Διαμοιρασμός με ηλεκτρονική αλληλογραφία",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "Ο διαμοιρασμός %1$s απέτυχε, επειδή αυτό το αντικείμενο είναι ήδη διαμοιρασμένο με τον λογαριασμό %2$s",
    "We cannot send you the auto-generated password. Please set a valid email address in your personal settings and try again." : "Δεν μπορούμε να σας στείλουμε το συνθηματικό που δημιουργείται αυτόματα. Ορίστε μια έγκυρη διεύθυνση email στις προσωπικές σας ρυθμίσεις και δοκιμάστε ξανά.",
    "Failed to send share by email. Got an invalid email address" : "Αποτυχία αποστολής της κοινής χρήσης μέσω email. Λάβαμε μια μη έγκυρη διεύθυνση email",
    "Failed to send share by email" : "Αποτυχία αποστολής συνδέσμου διαμοιρασμού μέσω Ηλ.ταχυδρομείου",
    "%1$s shared %2$s with you" : "Ο/Η %1$s μοιράστηκε το %2$s μαζί σας",
    "Note:" : "Σημείωση:",
    "This share is valid until %s at midnight" : "Αυτή η κοινή χρήση ισχύει μέχρι τις %s τα μεσάνυχτα",
    "Expiration:" : "Λήξη:",
    "%1$s via %2$s" : "%1$s μέσω %2$s",
    "%1$s shared %2$s with you. You should have already received a separate mail with a link to access it." : "%1$s κοινοποίησε το %2$s μαζί σας. Θα πρέπει να έχετε ήδη λάβει ξεχωριστό μήνυμα ηλεκτρονικού ταχυδρομείου με έναν σύνδεσμο πρόσβασης.",
    "Password to access %1$s shared to you by %2$s" : "Συνθηματικό για το %1$s που κοινοποιήθηκε μαζί σας από το/την %2$s",
    "Password to access %s" : "Συνθηματικό για το %s",
    "It is protected with the following password:" : "Προστατευμένο με το συνθηματικό:",
    "This password will expire at %s" : "Αυτός ο κωδικός πρόσβασης θα λήξει την %s",
    "%1$s shared %2$s with you and wants to add:" : "Ο/Η %1$s μοιράστηκε το %2$s μαζί σας και θέλει να προσθέσει:",
    "%1$s shared %2$s with you and wants to add" : "Ο/Η %1$s μοιράστηκε το %2$s μαζί σας και θέλει να προσθέσει",
    "%s added a note to a file shared with you" : "Ο/Η %s πρόσθεσε μια σημείωση σε ένα αρχείο που μοιράζεται μαζί σας",
    "You just shared %1$s with %2$s. The share was already sent to the recipient. Due to the security policies defined by the administrator of %3$s each share needs to be protected by password and it is not allowed to send the password directly to the recipient. Therefore you need to forward the password manually to the recipient." : "Μόλις κοινοποιήσατε το %1$s με το/την %2$s. Η κοινή χρήση έχει ήδη σταλεί στον παραλήπτη. Λόγω των πολιτικών ασφαλείας που έχει ορίσει ο διαχειριστής του %3$s, κάθε κοινή χρήση πρέπει να προστατεύεται με κωδικό πρόσβασης και δεν επιτρέπεται η απευθείας αποστολή του κωδικού στον παραλήπτη. Για τον λόγο αυτό, πρέπει να προωθήσετε χειροκίνητα το συνθηματικό στον παραλήπτη.",
    "Password to access %1$s shared by you with %2$s" : "Συνθηματικό για το %1$s που κοινοποιήσατε με το/την %2$s",
    "This is the password:" : "Αυτό είναι το συνθηματικό:",
    "You can choose a different password at any time in the share dialog." : "Μπορείτε να διαλέξετε ένα διαφορετικό συνθηματικό οποιαδήποτε στιγμή στον διάλογο διαμοιρασμού.",
    "Could not find share" : "Αδυναμία εύρεσης κοινόχρηστου",
    "Share provider which allows you to share files by mail" : "Πάροχος κοινής χρήσης που σας επιτρέπει να μοιράζεστε αρχεία μέσω ηλεκτρονικού ταχυδρομείου",
    "Unable to update share by mail config" : "Αδυναμία ενημέρωσης των ρυθμίσεων κοινής χρήσης μέσω ηλεκτρονικού ταχυδρομείου",
    "Allows people to share a personalized link to a file or folder by putting in an email address." : "Επιτρέπει στους χρήστες να μοιράζονται έναν εξατομικευμένο σύνδεσμο για ένα αρχείο ή φάκελο, εισάγοντας μια διεύθυνση ηλεκτρονικού ταχυδρομείου.",
    "Send password by mail" : "Αποστολή συνθηματικου με ηλεκτρονική αλληλογραφία",
    "Reply to initiator" : "Απάντηση στον αποστολέα"
},
"nplurals=2; plural=(n != 1);");
