OC.L10N.register(
    "bruteforcesettings",
    {
    "Brute-force settings" : "Väsytyshyökkäyksen asetukset",
    "Whitelist IPs" : "Sallitut IP:t",
    "Add new IP address" : "Lisää uusi IP-osoite",
    "IP address" : "IP-osoite",
    "Mask" : "Maski",
    "Comment" : "Kommentti",
    "Add" : "Lisää",
    "Save" : "Tallenna"
},
"nplurals=2; plural=(n != 1);");
