OC.L10N.register(
    "circles",
    {
    "You created the team {circle}" : "Креиравте тим {circle}",
    "{author} created the team {circle}" : "{author} креираше тим {circle}",
    "You deleted {circle}" : "Избришавте {circle}",
    "{author} deleted {circle}" : "{author} избриша {circle}",
    "You made {member} join {circle}" : "You made {member} join {circle}",
    "{author} made {member} join {circle}" : "{author} го додаде {member} во {circle}",
    "You added team {member} as member to {circle}" : "Го додаде тимот {member} како член во {circle}",
    "{author} added team {member} as member to {circle}" : "{author} го додаде тимот {member} како член во {circle}",
    "You made {member} leave {circle}" : "Го отстрани {member} од {circle}",
    "{author} made {member} leave {circle}" : "{author} го отстрани {member} од {circle}",
    "You removed {member} from {circle}" : "Го отстранивте {member} од тимот {circle}",
    "{author} removed {member} from {circle}" : "{author} го избриша {member} од {circle}",
    "You joined {circle}" : "Се приклучивте кон тимот {circle}",
    "{member} joined {circle}" : "{member} се приклучи на тимот {circle}",
    "You accepted the invitation to join {circle}" : "Ја прифативте поканата да се приклучите кон тимот {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} ја прифати поканата да се приклучи кон тимот {circle}",
    "You added {member} as member to {circle}" : "Го додадовте {member} како член во тимот {circle}",
    "You have been added as member to {circle} by {author}" : "Ти беше додаден како член во {circle} од {author}",
    "{member} has been added as member to {circle} by {author}" : "{member} беше додаден како член во {circle} од {author}",
    "You added {external} to {circle}" : "Го додадовте {external} во тимот {circle}",
    "{external} has been added to {circle} by {author}" : "{author} го додаде {external} во тимот {circle}",
    "You accepted {member}'s request to join {circle}" : "Го одобривте барањето на {member} за приклучување кон тимот {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Барањето за приклучување кон тимот {circle} е одобрено од {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "Барањето на {member} за приклучување кон тимот {circle} е одобрено од {author}",
    "You left {circle}" : "Го напуштивте тимот {circle}",
    "{member} left {circle}" : "{member} го напушти тимот {circle}",
    "You declined the invitation to join {circle}" : "Ја одбивте поканата да се приклучите кон тимот {circle}",
    "{member} declined an invitation to join {circle}" : "{member} ја одби поканата да се приклучи кон тимот {circle}",
    "You cancelled your request to join {circle}" : "Го откажавте барањето за приклучување кон тимот {circle}",
    "{member} cancelled a request to join {circle}" : "{member} го откажа барањето за приклување кон тимот {circle}",
    "You have been removed from {circle} by {author}" : "Отстранет си од {circle} од {author}",
    "{member} has been removed from {circle} by {author}" : "{member} беше отстранет од {circle} од {author}",
    "You removed {external} from {circle}" : "Го отстранивте {external} од тимот {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} беше отстранет од {circle} од {author}",
    "You cancelled {member}'s invitation to join {circle}" : "Ја откажа поканата на {member} за приклучување во {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "Твојата покана за приклучување во {circle} беше откажана од {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} ја откажа поканата на {member} за приклучување во {circle}",
    "You dismissed {member}'s request to join {circle}" : "Го одбивте барањето на {member} за приклучување кон тимот {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "Барањето за приклучување кон тимот {circle} е одбиено од {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "Барањето на {member} за приклучување кон тимот {circle} е одбиено од {author}",
    "You invited {member} to join {circle}" : "Го поканивте {member} да се приклучи кон тимот {circle}",
    "You have been invited to join {circle} by {author}" : "Поканети сте од {author} да се приклучите кон тимот {circle}",
    "{member} has been invited to join {circle} by {author}" : "{author} го покани {member} да се приклучи кон тимот {circle}",
    "You changed {member}'s level in {circle} to %1$s" : "Го промени нивото на {member} во {circle} на %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} го промени твоето ниво во {circle} на %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} го промени нивото на {member} во {circle} на %1$s",
    "You sent a request to join {circle}" : "Испративте барање за приклучување кон тимот {circle}",
    "{member} sent a request to join {circle}" : "{member} испрати барање за приклучување кон тимот {circle}",
    "You are the new owner of {circle}" : "Вие не сте нов сопственик на тимот {circle}",
    "{member} is the new owner of {circle}" : "{member} е нов сопственик на тимот {circle}",
    "Teams" : "Тимови",
    "On events happening in a <strong>team</strong> of which you are a member" : "За настани што се случуваат во <strong>тим</strong> на кој си член",
    "Any important event in a <strong>team</strong> you are moderating" : "За важни настани во <strong>тим</strong> кој го модерираш",
    "On global events happening in any <strong>team</strong>" : "За глобални настани што се случуваат во било кој <strong>тим</strong>",
    "Single" : "Единечен",
    "Personal" : "Сопствен",
    "System" : "Систем",
    "Visible" : "Видлив",
    "Open" : "Отвори",
    "Invite" : "Покани",
    "Join request" : "Барање за приклучување",
    "Friends" : "Пријатели",
    "Password protected" : "Заштитено со лозинка",
    "No Owner" : "Нема сопственик",
    "Hidden" : "Сокриен",
    "Backend" : "Заден систем (Backend)",
    "Local" : "Локално",
    "Root" : "Корен",
    "Team invite" : "Покана за тим",
    "Federated" : "Федерален",
    "Mount point" : "Точка за монтирање",
    "App" : "Апликација",
    "Nextcloud Account" : "Nextcloud сметка",
    "Nextcloud Group" : "Nextcloud група",
    "Email address" : "Е-пошта адреса",
    "Contact" : "Контакт",
    "Team" : "Тим",
    "Nextcloud App" : "Nextcloud апликација",
    "Teams App" : "Апликација Тимови",
    "Admin Command Line" : "Администраторска командна линија",
    "Member" : "Член",
    "Moderator" : "Модератор",
    "Admin" : "Администратор",
    "Owner" : "Сопственик",
    "%s shared »%s« with you." : "%s сподели »%s« со вас.",
    "%s shared »%s« with \"%s\"." : "%s сподели »%s« со \"%s\".",
    "%s on %s" : "%s на %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s сподели »%2$s« со тебе. Треба веќе да имаш добиено посебена е-пошта со линк за пристап.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s сподели »%2$s« со тебе. Треба веќе да имаш добиено посебена е-пошта со линк за пристап.",
    "Password to access »%1$s« shared to you by %2$s" : "Лозинката за пристап до »%1$s« е споделена со вас од %2$s",
    "Password to access »%s«" : "Лозинка за пристап »%s«",
    "It is protected with the following password:" : "Заштитено е со следнава лозинка:",
    "%1$s via %2$s" : "%1$s преку %2$s",
    "Click the button below to open it." : "Кликнете на копчето подолу за да ја отворите.",
    "Open »%s«" : "Отвори »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s сподели повеќе датотеки со тебе. Треба веќе да имаш добиено посебен е-пошта со линк за пристап до нив.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s сподели повеќе датотеки со тебе. Треба веќе да имаш добиено посебен е-пошта со линк за пристап до нив.",
    "Password to access files shared to you by %1$s" : "Лозинка за пристап до датотеките што ти ги сподели %1$s",
    "Password to access files" : "Лозинка за пристап до датотеките",
    "%s shared multiple files with \"%s\"." : "%s сподели неколку датотеки со \"%s\".",
    "%s shared multiple files with you." : "%s сподели неколку датотеки со тебе.",
    "Boot up" : "Стартување",
    "Nextcloud Initialization" : "Иницијализација на Nextcloud",
    "Fresh installation status" : "Статус на нова инсталација",
    "Building Local Database" : "Градење на локална база на податоци",
    "Testing Basic Team Creation" : "Тестирање на основно создавање тим",
    "Adding local users and moderators" : "Додавање локални корисници и модератори",
    "Show all teams" : "Прикажи ги сите тимови",
    "Create a new team" : "Креирај нов тим",
    "Files" : "Датотеки",
    "This feature is not available for personal teams" : "Оваа функција не е достапна за лични тимови",
    "The team is not federated" : "Тимот не е федеративен",
    "You cannot join this team" : "Не можеш да се приклучиш на овој тим",
    "This member is not a moderator" : "Овој член не е модератор",
    "Insufficient privileges" : "Недоволни привилегии",
    "This member does not exist" : "Овој член не постои",
    "This member is the owner of the team" : "Овој член е сопственик на тимот",
    "Level cannot be changed for this type of member" : "Нивото не може да се промени за овој тип на член",
    "%s (Team owned by %s)" : "%s (Тим со сопственост на %s)",
    "You are now a member of the Team \"%2$s\"" : "Вие сега сте член на тимот \"%2$s\"",
    "You have been invited by %1$s into the Team \"%2$s\"" : "Поканети сте од %1$s да се приклучите кон тимот \"%2$s\"",
    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$s испрати барање да стане член на тимот \"%2$s\"",
    "Accept" : "Прифати",
    "Refuse" : "Одбиј",
    "Leave the team" : "Напушти го тимот",
    "No image file provided" : "Не е доставена фотографија или датотека",
    "Invalid file provided" : "Доставена е невалидна датотека",
    "File is too big" : "Датотеката е премногу голема",
    "Invalid image" : "Невалидна фотографија",
    "Unknown filetype" : "Непознат тип на датотека",
    "%s" : "%s",
    "Personal team" : "Личен тим",
    "%s owned by %s" : "%s во сопственост на %s",
    "You have no permission to create a new team" : "Немате дозвола да направите нов тим",
    "%s shared a file with \"%s\"." : "%s сподели датотека со \"%s\".",
    "%s shared a file with you." : "%s сподели датотека со тебе.",
    "%1$s shared %2$s with %3$s" : "%1$s сподели %2$s со %3$s",
    "%1$s shared %2$s with \"%3$s\"" : "%1$s сподели %2$s со \"%3$s\"",
    "Open %s" : "Отвори %s",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s сподели содржина со тебе. Треба веќе да имаш добиено посебна е-пошта со линк за пристап.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s сподели содржина со тебе. Треба веќе да имаш добиено посебна е-пошта со линк за пристап.",
    "Password to access content shared with you by %1$s" : "Лозинка за пристап до содржината споделена со тебе од %1$s",
    "Password to access content" : "Лозинка за пристап до содржината",
    "This item is already shared with this team" : "Оваа ставка веќе е споделена со овој тим",
    "Bring cloud-users closer together." : "Приближи ги cloud-корисниците едни до други.",
    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Тимовите им овозможуваат на корисниците да создаваат сопствени групи од луѓе, колеги или пријатели.\nОвие групи потоа можат да се користат во други апликации за споделување содржина.",
    "https://…" : "https://…",
    "Unlimited" : "Неограничено",
    "Default quota" : "Стандардна квота",
    "Select default quota" : "Избери стандардна квота",
    "Save" : "Save",
    "Reconnect" : "Повторно поврзување",
    "Connect" : "Поврзи се",
    "Overview" : "Преглед",
    "No teams found" : "Не се пронајдени тимови",
    "Members" : "Членови",
    "Cancel" : "Cancel",
    "Next" : "Следна",
    "Back" : "Назад",
    "Switch to list view" : "Прикажи поглед во листа",
    "Switch to grid view" : "Прикажи поглед во мрежа",
    "Folder" : "Папка",
    "you" : "ти",
    "Copy link" : "Копирај линк",
    "Enable federation" : "Овозможи федерација",
    "Close" : "Затвори",
    "New folder" : "Нова папка",
    "Folder name" : "Име на папка",
    "Talk conversation" : "Talk раговор",
    "Conversation name" : "Име на разговорот",
    "Calendar" : "Календар",
    "New calendar" : "Нов календар",
    "Please select a valid png or jpg file" : "Изберете png или jpg датотека",
    "Description" : "Опис",
    "Edit" : "Уреди",
    "Create" : "Креирај",
    "Show in Calendar" : "Прикажи во календар",
    "Add" : "Додади",
    "Apply" : "Примени",
    "Remove {type}" : "Избриши {type}",
    "Add guest" : "Додади гостин",
    "Loading …" : "Се вчитува …",
    "No results" : "Нема резултати",
    "Add {type}" : "Додади {type}",
    "Pending" : "Чекање",
    "Role" : "Улога",
    "Add to {team}" : "Додај до {team}",
    "Try again" : "Обиди се повторно",
    "Create your first team" : "Создај го твојот прв тим",
    "Loading" : "Се вчитува",
    "Go back" : "Назад",
    "Join" : "Приклучи се",
    "Failed to load teams" : "Неуспешно вчитување на тимовите",
    "Join or create teams to see them here." : "Приклучи се или создај тимови за да ги видиш овде.",
    "Loading…" : "Се вчитува…",
    "More teams" : "Повеќе тимови",
    "All contacts" : "Сите контакти",
    "User" : "Корисник",
    "Group" : "Група",
    "Email" : "Е-пошта",
    "Federation" : "Федерација",
    "Privacy" : "Приватност",
    "Groups" : "Групи",
    "Contacts" : "Контакти",
    "No files in here" : "Тука нема датотеки",
    "No entries found in this folder" : "Нема ништо во оваа папка",
    "Name" : "Име",
    "Size" : "Големина",
    "Modified" : "Изменето",
    "Circles App Initialization" : "Иницијализација на апликацијата Circles"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
