OC.L10N.register(
    "suspicious_login",
    {
    "New login location detected" : "Saio hasiera kokapen berria antzeman da",
    "Suspicious Login" : "Saio hasiera susmagarria",
    "New login detected" : "Saio hasiera berria antzemana",
    "Detect and warn about suspicious IPs logging into Nextcloud\n\t" : "Antzeman eta ohartarazi IP susmagarrien saio hasierak Nextcloud-en",
    "A new login into your account was detected. The IP address %s was classified as suspicious. If this was you, you can ignore this message. Otherwise you should change your password." : "Saio hasiera berri bat antzeman da zure kontuan. %s IP helbidea susmagarritzat sailkatua izan da. Zu izanez gero, mezu honi ezikusi egin diezaiokezu. Bestela zure pasahitza aldatu beharko zenuke. "
},
"nplurals=2; plural=(n != 1);");
