OC.L10N.register(
    "serverinfo",
    {
    "System" : "System",
    "Unknown" : "Unknown",
    "Monitoring" : "Monitoring",
    "Monitoring app with useful server information" : "Monitoring app with useful server information",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc.",
    "Active users" : "Active users",
    "Webcron" : "Webcron",
    "Background jobs" : "Background jobs",
    "Never" : "Never",
    "Load" : "Load",
    "CPU info not available" : "CPU info not available",
    "Database" : "Database",
    "Type:" : "Type:",
    "Version:" : "Version:",
    "Size:" : "Size:",
    "Available" : "Available",
    "Disk" : "Disk",
    "Files" : "ფაილები",
    "Mount:" : "Mount:",
    "Filesystem:" : "Filesystem:",
    "Available:" : "Available:",
    "Used:" : "Used:",
    "Status" : "Status",
    "Started" : "Started",
    "Duration" : "Duration",
    "When" : "When",
    "Details" : "Details",
    "Failed" : "Failed",
    "Running" : "Running",
    "Memory" : "Memory",
    "RAM info not available" : "RAM info not available",
    "Configuration" : "Configuration",
    "Output in JSON" : "Output in JSON",
    "Skip server update" : "Skip server update",
    "Authentication" : "Authentication",
    "Network" : "Network",
    "Hostname" : "Hostname",
    "Status:" : "Status:",
    "Speed:" : "Speed:",
    "Duplex:" : "Duplex:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "PHP extensions" : "PHP extensions",
    "Unable to list extensions" : "Unable to list extensions",
    "PHP" : "PHP",
    "Memory limit:" : "Memory limit:",
    "Max execution time:" : "Max execution time:",
    "seconds" : "seconds",
    "Upload max size:" : "Upload max size:",
    "OPcache Revalidate Frequency:" : "OPcache Revalidate Frequency:",
    "Show phpinfo" : "Show phpinfo",
    "Shares" : "Shares",
    "Users:" : "Users:",
    "Groups:" : "Groups:",
    "Links:" : "Links:",
    "Emails:" : "Emails:",
    "Federated sent:" : "Federated sent:",
    "Federated received:" : "Federated received:",
    "Talk conversations:" : "Talk conversations:",
    "Warning" : "Warning",
    "Operating System:" : "Operating System:",
    "CPU:" : "CPU:",
    "Server time:" : "Server time:",
    "Uptime:" : "Uptime:",
    "Temperature" : "Temperature",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}",
    "SWAP info not available" : "SWAP info not available",
    "Copied!" : "Copied!",
    "Not supported!" : "Not supported!",
    "Press ⌘-C to copy." : "Press ⌘-C to copy.",
    "Press Ctrl-C to copy." : "Press Ctrl-C to copy.",
    "Memory:" : "Memory:",
    "Files:" : "Files:",
    "Storages:" : "Storages:",
    "Free Space:" : "Free Space:",
    "Hostname:" : "Hostname:",
    "Gateway:" : "Gateway:",
    "Extensions:" : "Extensions:",
    "External monitoring tool" : "External monitoring tool",
    "Use this end point to connect an external monitoring tool:" : "Use this end point to connect an external monitoring tool:",
    "Copy" : "Copy",
    "To use an access token, please generate one then set it using the following command:" : "To use an access token, please generate one then set it using the following command:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Then pass the token with the \"NC-Token\" header when querying the above URL.",
    "DNS:" : "DNS:"
},
"nplurals=2; plural=(n!=1);");
