OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "رمز بازیابی وجود ندارد",
    "Please repeat the recovery key password" : "لطفاً رمز بازیابی را دوباره وارد کنید",
    "Repeated recovery key password does not match the provided recovery key password" : "رمز بازیابی تکراری با رمز بازیابی ارائه‌شده مطابقت ندارد",
    "Recovery key successfully enabled" : "کلید بازیابی با موفقیت فعال شد",
    "Could not enable recovery key. Please check your recovery key password!" : "امکان فعال‌سازی کلید بازیابی وجود ندارد. لطفاً رمز بازیابی خود را بررسی کنید!",
    "Recovery key successfully disabled" : "کلید بازیابی با موفقیت غیرفعال شد",
    "Could not disable recovery key. Please check your recovery key password!" : "امکان غیرفعال‌سازی کلید بازیابی وجود ندارد. لطفاً رمز بازیابی خود را بررسی کنید!",
    "Please provide the old recovery password" : "لطفاً رمز بازیابی قدیمی را وارد کنید",
    "Please provide a new recovery password" : "لطفاً یک رمز بازیابی جدید وارد کنید",
    "Please repeat the new recovery password" : "لطفاً رمز بازیابی جدید را دوباره وارد کنید",
    "Password successfully changed." : "رمز عبور با موفقیت تغییر کرد.",
    "Could not change the password. Maybe the old password was not correct." : "امکان تغییر رمز عبور وجود ندارد. شاید رمز قدیمی اشتباه بوده است.",
    "Recovery Key disabled" : "کلید بازیابی غیرفعال شد",
    "Recovery Key enabled" : "کلید بازیابی فعال شد",
    "Could not enable the recovery key, please try again or contact your administrator" : "امکان فعال‌سازی کلید بازیابی وجود ندارد، لطفاً دوباره تلاش کنید یا با مدیر خود تماس بگیرید",
    "Could not update the private key password." : "امکان به‌روزرسانی رمز کلید خصوصی وجود ندارد.",
    "The old password was not correct, please try again." : "رمز عبور قدیمی اشتباه بود، لطفاً دوباره تلاش کنید.",
    "The current log-in password was not correct, please try again." : "رمز ورود فعلی اشتباه بود، لطفاً دوباره تلاش کنید.",
    "Private key password successfully updated." : "رمز کلید خصوصی با موفقیت به‌روزرسانی شد.",
    "Invalid private key for encryption app. Please update your private key password in your personal settings to recover access to your encrypted files." : "کلید خصوصی برای برنامه رمزگذاری نامعتبر است. لطفاً رمز کلید خصوصی خود را در تنظیمات شخصی به‌روزرسانی کنید تا دسترسی به فایل‌های رمزگذاری‌شده خود را بازیابی کنید.",
    "Encryption App is enabled, but your keys are not initialized. Please log-out and log-in again." : "برنامه رمزگذاری فعال است، اما کلیدهای شما مقداردهی اولیه نشده‌اند. لطفاً خارج شده و دوباره وارد شوید.",
    "Please enable server side encryption in the admin settings in order to use the encryption module." : "لطفاً رمزگذاری سمت سرور را در تنظیمات مدیریت فعال کنید تا از ماژول رمزگذاری استفاده کنید.",
    "Encryption app is enabled and ready" : "برنامه رمزگذاری فعال و آماده است",
    "Bad Signature" : "امضای نامعتبر",
    "Missing Signature" : "امضا وجود ندارد",
    "one-time password for server-side-encryption" : "رمز یک‌بارمصرف برای رمزگذاری سمت سرور",
    "Encryption password" : "رمز رمزگذاری",
    "The administration enabled server-side-encryption. Your files were encrypted using the password <strong>%s</strong>." : "مدیریت رمزگذاری سمت سرور را فعال کرد. فایل‌های شما با استفاده از رمز <strong>%s</strong> رمزگذاری شدند.",
    "The administration enabled server-side-encryption. Your files were encrypted using the password \"%s\"." : "مدیریت رمزگذاری سمت سرور را فعال کرد. فایل‌های شما با استفاده از رمز \"%s\" رمزگذاری شدند.",
    "Please login to the web interface, go to the \"Security\" section of your personal settings and update your encryption password by entering this password into the \"Old login password\" field and your current login password." : "لطفاً به رابط وب وارد شوید، به بخش \"امنیت\" در تنظیمات شخصی خود بروید و رمز رمزگذاری خود را با وارد کردن این رمز در فیلد \"رمز ورود قدیمی\" و رمز ورود فعلی خود به‌روزرسانی کنید.",
    "Cannot decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "نمی‌توان این فایل را رمزگشایی کرد، احتمالاً این یک فایل اشتراکی است. لطفاً از مالک فایل بخواهید فایل را دوباره با شما به اشتراک بگذارد.",
    "Cannot read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "نمی‌توان این فایل را خواند، احتمالاً این یک فایل اشتراکی است. لطفاً از مالک فایل بخواهید فایل را دوباره با شما به اشتراک بگذارد.",
    "Default Encryption Module" : "ماژول رمزگذاری پیش‌فرض",
    "Default encryption module for Nextcloud Server-side Encryption (SSE)" : "ماژول رمزگذاری پیش‌فرض برای رمزگذاری سمت سرور نکست‌کلود",
    "This app provides the (default) cryptography implementation for Nextcloud's Server-side Encryption (SSE) feature.\n\n\t\t\t**Encryption Details**\n\t\t\t*   **Cipher Mode:** AES-256-CTR (default)\n\t\t\t*   **Authentication:** HMAC-SHA256\n\n\t\t\t**Important Warnings**\n\t\t\t*   **DANGER:** Do not disable this application until all files have been decrypted (`occ encryption:decrypt-all`).\n\t\t\t*   **WARNING**: Reverting to non-encrypted file storage after activation requires command-line access. The action is permanent via the Web UI.\"\n\n\t\t\t**Notes for Existing Files**\n\t\t\t*   By default, enabling SSE does not encrypt existing files; only new files will be encrypted.\n\t\t\t*   To encrypt all existing files, use the command `occ encryption:encrypt-all`.\n\n\t\t\t**Before You Begin**\n\t\t\t*   **Read the Documentation:** Before you enable SSE, encrypt existing files, or disable SSE, it is critical to\n\t\t\t\tread the documentation to understand implications and the appropriate procedures to avoid data loss." : "این برنامه پیاده‌سازی رمزنگاری (پیش‌فرض) را برای ویژگی رمزگذاری سمت سرور نکست‌کلود فراهم می‌کند.",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "فعال‌سازی این گزینه همه فایل‌های ذخیره‌شده در حافظه اصلی را رمزگذاری می‌کند، در غیر این صورت فقط فایل‌های موجود در حافظه خارجی رمزگذاری می‌شوند",
    "Encrypt the home storage" : "رمزگذاری حافظه خانگی",
    "Disable recovery key" : "غیرفعال‌سازی کلید بازیابی",
    "Enable recovery key" : "فعال‌سازی کلید بازیابی",
    "The recovery key is an additional encryption key used to encrypt files. It is used to recover files from an account if the password is forgotten." : "کلید بازیابی یک کلید رمزگذاری اضافی است که برای رمزگذاری فایل‌ها استفاده می‌شود. از آن برای بازیابی فایل‌ها از یک حساب کاربری در صورت فراموشی رمز عبور استفاده می‌شود.",
    "Recovery key password" : "رمز کلید بازیابی",
    "Passwords fields do not match" : "فیلدهای رمز عبور مطابقت ندارند",
    "Repeat recovery key password" : "تکرار رمز کلید بازیابی",
    "An error occurred while updating the recovery key settings. Please try again." : "هنگام به‌روزرسانی تنظیمات کلید بازیابی خطایی رخ داد. لطفاً دوباره تلاش کنید.",
    "Change recovery key password" : "تغییر رمز کلید بازیابی",
    "Old recovery key password" : "رمز کلید بازیابی قدیمی",
    "New recovery key password" : "رمز کلید بازیابی جدید",
    "Repeat new recovery key password" : "تکرار رمز کلید بازیابی جدید",
    "An error occurred while changing the recovery key password. Please try again." : "هنگام تغییر رمز کلید بازیابی خطایی رخ داد. لطفاً دوباره تلاش کنید.",
    "Update private key password" : "به‌روزرسانی رمز کلید خصوصی",
    "Your private key password no longer matches your log-in password. Set your old private key password to your current log-in password." : "رمز عبور کلید خصوصی شما دیگر با رمز ورود شما مطابقت ندارد. لطفاً رمز عبور قدیمی کلید خصوصی خود را با رمز ورود فعلی‌تان تنظیم کنید.",
    "If you do not remember your old password you can ask your administrator to recover your files." : "اگر رمز عبور قدیمی خود را به خاطر نمی‌آورید، می‌توانید از مدیر سیستم بخواهید فایل‌های شما را بازیابی کند.",
    "Old log-in password" : "رمز ورود قدیمی",
    "Current log-in password" : "رمز ورود فعلی",
    "Update" : "به‌روزرسانی",
    "Updating recovery keys. This can take some time…" : "در حال به‌روزرسانی کلیدهای بازیابی. این فرآیند ممکن است مدتی طول بکشد…",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "فعال‌سازی این گزینه به شما امکان می‌دهد در صورت فراموشی رمز عبور، دوباره به فایل‌های رمزگذاری‌شده خود دسترسی پیدا کنید.",
    "Enable password recovery" : "فعال‌سازی بازیابی رمز عبور",
    "Default encryption module" : "ماژول رمزگذاری پیش‌فرض",
    "Encryption app is enabled but your keys are not initialized, please log-out and log-in again" : "برنامه رمزگذاری فعال است اما کلیدهای شما مقداردهی اولیه نشده‌اند، لطفاً خارج شده و دوباره وارد شوید.",
    "Basic encryption module" : "ماژول رمزگذاری پایه",
    "Missing parameters" : "پارامترهای ازدست‌رفته",
    "Default encryption module for server-side encryption" : "ماژول رمزگذاری پیش‌فرض برای رمزگذاری سمت سرور",
    "In order to use this encryption module you need to enable server-side encryption in the admin settings. Once enabled this module will encrypt all your files transparently. The encryption is based on AES 256 keys.\nThe module will not touch existing files, only new files will be encrypted after server-side encryption was enabled. It is also not possible to disable the encryption again and switch back to an unencrypted system.\nPlease read the documentation to know all implications before you decide to enable server-side encryption." : "برای استفاده از این ماژول رمزگذاری، باید رمزگذاری سمت سرور را در تنظیمات مدیریت فعال کنید. پس از فعال‌سازی، این ماژول تمام فایل‌های شما را به صورت شفاف رمزگذاری می‌کند. رمزگذاری بر اساس کلیدهای AES 256 انجام می‌شود.",
    "Change recovery key password:" : "تغییر رمز عبور کلید بازیابی:",
    "Change Password" : "تغییر رمز عبور",
    "Your private key password no longer matches your log-in password." : "رمز عبور کلید خصوصی شما دیگر با رمز ورود شما مطابقت ندارد.",
    "Set your old private key password to your current log-in password:" : "رمز عبور قدیمی کلید خصوصی خود را با رمز ورود فعلی‌تان تنظیم کنید:",
    "Update Private Key Password" : "به‌روزرسانی رمز عبور کلید خصوصی",
    "Enable password recovery:" : "فعال‌سازی بازیابی رمز عبور:",
    "Enabled" : "فعال",
    "Disabled" : "غیرفعال",
    "This app provides the (default) cryptography implementation for Nextcloud's Server-side Encryption (SSE) feature.\n\n\t\t\t**Encryption Details**\n\t\t\t*   **Cipher Mode:** AES-256-CTR (default)\n\t\t\t*   **Authentication:** HMAC-SHA256\n\n\t\t\t**Important Warnings**\n\t\t\t*   **DANGER:** Do not disable this application until all files have been decrypted (`occ encryption:decrypt-all`).\n\t\t\t*   **WARNING**: Reverting to non-encrypted file storage after activation requires command-line access. The action is permanent via the Web UI.\"\n\n\t\t\t**Notes for Existing Files**\n\t\t\t*   By default, enabling SSE does not encrypt existing files; only new files will be encrypted.\n\t\t\t*   To encrypt all existing files, use the command `occ encryption:encrypt-all`.\n\n\t\t\t**Before You Begin**\n\t\t\t*   **Read the Documentation:** Before you enable SSE, encrypt existing files, or disable SSE, it is critical to \n\t\t\t\tread the documentation to understand implications and the appropriate procedures to avoid data loss." : "این برنامه پیاده‌سازی رمزنگاری (پیش‌فرض) را برای ویژگی رمزگذاری سمت سرور (SSE) نکست‌کلود فراهم می‌کند."
},
"nplurals=2; plural=(n > 1);");
