<?php
// This file is auto-generated. Do not edit!
return array('minimumGroupingDigits'=>1,'symbols'=>array('decimal'=>',','group'=>'.','list'=>';','percentSign'=>'%','plusSign'=>'+','minusSign'=>'-','approximatelySign'=>'~','exponential'=>'E','superscriptingExponent'=>'×','perMille'=>'‰','infinity'=>'∞','nan'=>'NaN','timeSeparator'=>':'),'percentFormats'=>array('standard'=>array('positive'=>'%1$s%2$s','negative'=>'-%1$s%2$s')),'currencyFormats'=>array('currencySpacing'=>array('beforeCurrency'=>array('currency'=>'/^[^\\pS\\pZ]/u','surrounding'=>'/\\pN$/u','insertBetween'=>' '),'afterCurrency'=>array('currency'=>'/[^\\pS\\pZ]$/u','surrounding'=>'/\\pN$/u','insertBetween'=>' ')),'standard'=>array('positive'=>'%1$s %2$s','negative'=>'-%1$s %2$s'),'accounting'=>array('positive'=>'%1$s %2$s','negative'=>'(%1$s %2$s)'),'unitPattern'=>array('count-one'=>'%1$s %2$s','count-few'=>'%1$s %2$s','count-other'=>'%1$s %2$s')));
