OC.L10N.register(
    "notifications",
    {
    "We want to keep offering our push notification service for free, but large number of users overload our infrastructure. For this reason we have to rate-limit the use of push notifications. If you need this feature, consider using Nextcloud Enterprise." : "Queremos continuar oferecendo nosso serviço de notificação por push gratuitamente, mas um grande número de usuários sobrecarrega nossa infraestrutura. Por esse motivo, temos que limitar o uso das notificações por push. Se você precisar desse recurso, considere usar o Nextcloud Empresarial.",
    "User not found" : "Utilizador não encontrado",
    "An unexpected error occurred, ask your administration to check the logs." : "Ocorreu um erro inesperado, peça ao administrador para verificar os logs.",
    "Hello %s" : "Olá %s",
    "Hello %s," : "Olá %s,",
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "Pode alterar a frequência desses e-mails ou desativá-los nas  <a href=\"%s\">definições</a>.",
    "You can change the frequency of these emails or disable them in the settings: %s" : "Pode alterar a frequência desses e-mails ou desativá-los nas definições: %s",
    "Admin notifications" : "Notificações de administrador",
    "Notifications" : "Notificações",
    "Nextcloud GmbH sponsors a free push notification gateway for private users. To ensure good service, the gateway limits the number of push notifications per server and the limit was reached for this server. For enterprise users, a more scalable gateway is available." : "Nextcloud GmbH patrocina um gateway de notificação push gratuito para usuários privados. Para garantir um bom serviço, o gateway limita o número de notificações push por servidor e o limite foi atingido para este servidor. Para usuários corporativos, está disponível um gateway mais escalável.",
    "This app provides a backend and frontend for the notification API available in Nextcloud." : "Este aplicativo fornece uma estrutura e interface para a API de notificação do Nextcloud.",
    "This app provides a backend and frontend for the notification API available in Nextcloud.\n\t\tThe API is used by other apps to notify users in the web UI and sync clients about various things. Some examples are:\n\n📬 Federated file sharing: You received a new remote share\n\n📑 Comments: Another user mentioned you in a comment on a file\n\n🚢 Update notification: Available update for an app or nextcloud itself\n\n📣 Announcement center: An announcement was posted by an admin" : "Este aplicativo fornece uma estrutura e interface para a API de notificação do Nextcloud.\n\t\tA API é usada por outros aplicativos para notificar os usuários na interface web e para sincronizar os clientes em várias coisas. Alguns exemplos são:\n\n📬 Compartilhamento de arquivos federados: você recebeu um novo compartilhamento remoto\n\n📑 Comentários: Um usuário mencionou você num comentário em um arquivo\n\n🚢 Notificação de atualização: Atualização disponível para um aplicativo ou para o nextcloud\n\n📣 Central de anúncios: Um anúncio foi postado por um administrador",
    "Failed to perform action" : "Falhou a executar ação",
    "Failed to dismiss notification" : "Falhou a dispensar notificação",
    "Dismiss" : "Dispensar",
    "in {path}" : "em {path}",
    "Push notifications might be unreliable" : "As notificações push podem não ser confiáveis",
    "Nextcloud GmbH sponsors a free push notification gateway for private users. To ensure good service, the gateway limits the number of push notifications per server. For enterprise users, a more scalable gateway is available. Contact Nextcloud GmbH for more information." : "A Nextcloud GmbH patrocina um gateway de notificação por push gratuito para usuários privados. Para garantir um bom serviço, o gateway limita o número de notificações por push por servidor. Para usuários corporativos, um gateway mais escalável está disponível. Entre em contato com a Nextcloud GmbH para obter mais informações.",
    "Requesting browser permissions to show notifications" : "Solicitando permissões do navegador para mostrar notificações",
    "No notifications" : "Sem notificações",
    "Failed to dismiss all notifications" : "Falhou a dispensar todas as notificações",
    "Dismiss all notifications" : "Dispensar todas as notificações",
    "Never" : "Nunca",
    "1 hour" : "1 hora",
    "3 hours" : "3 horas",
    "1 day" : "1 dia",
    "1 week" : "1 semana",
    "Your settings have been updated." : "As suas definições foram atualizadas.",
    "An error occurred while updating your settings." : "Ocorreu um erro ao atualizar as suas definições.",
    "Configure the default notification settings" : "Configure as configurações padrão de notificação",
    "Send email reminders about unhandled notifications after:" : "Enviar lembretes por e-mail sobre notificações não tratadas após:",
    "Web push settings" : "Configurações do Web Push",
    "Web push is a push notification system that lets web applications send notifications to users´ mobile apps or browser, even when the app is not open in a tab." : "O Web Push é um sistema de notificações push que permite que aplicativos web enviem notificações para os aplicativos móveis ou navegadores dos usuários, mesmo quando o aplicativo não estiver aberto em uma aba.",
    "Web push notifications are encrypted but routed through services provided by Mozilla, Microsoft, Apple, Google or user-choosen ones in case of mobile apps. While the content is protected, metadata such as timing and frequency of notifications may be exposed to these providers." : "As notificações Web Push são criptografadas, mas encaminhadas por meio de serviços fornecidos pela Mozilla, Microsoft, Apple, Google ou por outros serviços escolhidos pelo usuário, no caso de aplicativos móveis. Embora o conteúdo esteja protegido, metadados como o horário e a frequência das notificações podem ser expostos a esses provedores.",
    "Allow web push for browsers" : "Permitir o Web Push para navegadores",
    "None" : "Nenhum",
    "You need to set up your email address before you can receive notification emails." : "Precisa de configurar o seu endereço de e-mail antes de poder receber mensagens de notificação.",
    "Also repeat sound on a secondary speaker" : "Repitir também o som em um alto-falante secundário",
    "Select a device" : "Selecionar um dispositivo"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
