OC.L10N.register(
    "files_pdfviewer",
    {
    "Failed to load settings" : "Error al cargar la configuración",
    "Failed to save settings" : "Error al guardar ajustes"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
