OC.L10N.register(
    "files_lock",
    {
    "File is currently locked by %s" : "Faili kwa sasa imefungwa na %s",
    "File is not locked" : " Faili haijafungwa",
    "File can only be locked with update permissions." : "Faili inaweza tu kufungwa kwa vibali vya kusasisha. ",
    "File can only be unlocked by providing a valid owner lock token" : "Faili inaweza tu kufunguliwa kwa kutoa tokeni halali ya kufuli ya mmiliki",
    "File can only be unlocked by the owner of the lock" : "Faili inaweza kufunguliwa na mmiliki wa kufuli tu",
    "Desktop client" : " Mteja wa Desktop ",
    "iOS client" : "Mteja wa iOS",
    "Android client" : "Mteja wa Android",
    "Temporary files lock" : "Faili za muda zimefungwa",
    "Temporary lock your files" : "Funga faili zako kwa muda",
    "Allow your users to temporary lock their files to avoid conflicts while working on shared files." : "Ruhusu watumiaji wako kufunga faili zao kwa muda ili kuepusha migongano wakati wa kushughulikia faili zilizoshirikiwa.",
    "Manually locked by {user}" : "Imefungwa kikawaida na {user}",
    "Locked by editing online in {app}" : "Imefungwa kwa kuhariri mtandaoni ndani {app}",
    "Automatically locked by {user}" : "Imefungwa kiotomatiki na {user}",
    "Unlock file" : "Fungua faili",
    "Lock file" : "Funga faili",
    "files_lock" : "faili_kufuli",
    "This file has been locked automatically by a client. Removing the lock may lead to a conflict saving the file." : "Faili hii imefungwa kiotomatiki na mteja. Kuondoa kufuli kunaweza kusababisha mzozo kuhifadhi faili.",
    "Keep lock" : "Weka kufuli",
    "Force unlock" : "Lazimisha kufungua"
},
"nplurals=2; plural=(n != 1);");
