OC.L10N.register(
    "related_resources",
    {
    "Calendar" : "Calendar",
    "Deck board \"%s\"" : "Panou Deck \"%s\"",
    "Files" : "Fișiere",
    "File \"%s\"" : "Fișier \"%s\"",
    "Group Folder" : "Folder de grup",
    "Group Folder \"%s\"" : "Folder de grup \"%s\"",
    "Talk conversation" : "Conversație Talk",
    "Conversation with %s" : "Conversație cu %s",
    "Talk" : "Discuție",
    "Talk conversation \"%s\"" : "Conversație Talk \"%s\"",
    "Related Resources" : "Resurse conexe",
    "Displays resources related to current item in right panel" : "Afișează resursele conexe ale elementului curent în panoul drept",
    "Displays resources related to current item in right panel." : "Afișează resursele conexe ale elementului curent în panoul din dreapta."
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
