OC.L10N.register(
    "support",
    {
    "Link:" : "Линк:",
    "Password:" : "Лозинка:",
    "Support" : "Поддршка",
    "Basic subscription" : "Основна претплата",
    "Standard subscription" : "Стандардна претплата",
    "Premium subscription" : "Премиум претплата",
    "Subscription" : "Претплата",
    "Subscription key:" : "Претплатнички клуч:",
    "_%n year_::_%n years_" : ["1 година","%n години"],
    "_%n month_::_%n months_" : ["1 месец","%n месеци"],
    "_%n day_::_%n days_" : ["1 ден","%n дена"],
    "For an unlimited amount of users" : "За неограничен број на корисници",
    "_For %n active users_::_For %n active users_" : ["За 1 активен корисник","За %n активни корисници"],
    "_For %n users_::_For %n users_" : ["За 1 корисник","За %n корисници"],
    "System information" : "Информации за системот",
    "Unsupported" : "Неподржано",
    "More information" : "Повеќе информации",
    "Forum" : "Форум",
    "Nextcloud is free software which is supported by a very active community. Please register at the forum to ask questions and discuss with others." : "Nextcloud е бесплатен софтвер кој е поддржан од многу активна заедница. Ве молиме, регистрирајте се на форумот за да поставите прашања и да разговарате со другите.",
    "Nextcloud forum" : "Nextcloud форум",
    "GitHub" : "GitHub",
    "Nextcloud uses GitHub as platform to collaboratively work. You can file bug reports directly there." : "Nextcloud го користи GitHub како платформа за заедничка работа. Можете да поднесете извештаи за грешки директно таму.",
    "Nextcloud at GitHub" : "Nextcloud на GitHub",
    "Subscription key" : "Претплатнички клуч",
    "If you have an active Nextcloud Subscription please enter your subscription key here." : "Доколку имате активна Nextcloud претплата ве молиме внесете го вашиот претплатнички клуч овде.",
    "Learn more about an enterprise subscription." : "Причитајте повеќе за професионалната претплата.",
    "Set subscription key" : "Поставете претплатнички клуч",
    "The subscription key was invalid." : "Невалиден претплатнички клуч.",
    "The subscription key had an invalid format." : "Претплатничкиот клуч е внесен во невалидна форма.",
    "The button below generates a text file in the folder \"System information\" and shares it as password protected public link. The link is valid for 2 weeks." : "Копчето подулу генерира текстуална датотека во папка \"System information\" и се споделува со линк заштетен со лозинка. Линкот е важечки 2 недели од генерирањето.",
    "News" : "Новости",
    "To get up to date information what is going on at Nextcloud sign up for the newsletter and follow us on our social media accounts." : "За да добивате ажурирани информации што се случува на Nextcloud, претплатете се на нашиот билтен и следете нè на социјалните мрежи.",
    "Like our Facebook page" : "Лајкни ја нашата Facebook страна",
    "Follow us on Twitter" : "Следете не на Twitter",
    "Check out our blog" : "Проверете го нашиот блог",
    "Subscribe to our newsletter" : "Претплатете се на нашиот билтен"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
