OC.L10N.register(
    "suspicious_login",
    {
    "New login location detected" : "Log på fra ny placering opdaget",
    "More info about the suspicious IP address available on %s" : "Mere info om den mistænkelige IP adresse er tilgængelig på %s",
    "Open %s ↗" : "Åbn %s ↗",
    "Suspicious Login" : "Mistænkeligt log på",
    "New login detected" : "Nyt log på opdaget",
    "Detect and warn about suspicious IPs logging into Nextcloud\n\t" : "Opdag og advar om mistænkelige IP-adresser, som kan logge på Nextcloud",
    "A new login into your account was detected. The IP address %s was classified as suspicious. If this was you, you can ignore this message. Otherwise you should change your password." : "Et nyt log på, på din konto er opdaget. IP-adressen %s er klassificeret som mistænkelig. Hvis det var dig kan du blot ignorere denne besked. Hvis ikke, anbefales det at skifte adgangskode."
},
"nplurals=2; plural=(n != 1);");
