OC.L10N.register(
    "settings",
    {
    "{actor} added you to group {group}" : "{actor} adicionou você ao grupo {group}",
    "You added {user} to group {group}" : "Você adicionou {user} ao grupo {group}",
    "An administrator added you to group {group}" : "Um administrador adicionou-o ao grupo {group}",
    "An administrator added {user} to group {group}" : "Um administrador adicionou {user} ao grupo {group}",
    "{actor} removed you from group {group}" : "{actor} removeu-o do grupo {group}",
    "You removed {user} from group {group}" : "Removeu {user} do grupo {group}",
    "{actor} removed {user} from group {group}" : "{actor} removeu {user} do grupo {group}",
    "An administrator removed you from group {group}" : "Um administrador removeu você do grupo {group}",
    "Your <strong>group memberships</strong> were modified" : "Seus <strong>membros do grupo</strong> foram alterados",
    "{actor} changed your password" : "{actor} alterou a sua senha",
    "You changed your password" : "Você alterou a sua senha",
    "Your password was reset by an administrator" : "A sua senha foi alterada por um administrador",
    "Your password was reset" : "A sua password foi redefinida",
    "{actor} changed your email address" : "{actor} alterou o seu endereço de e-mail",
    "You changed your email address" : "Você alterou o seu endereço de e-mail",
    "Your email address was changed by an administrator" : "O seu endereço de e-mail foi alterado por um administrador",
    "You created an app password for a session named \"{token}\"" : "Você criou uma senha de aplicativo para uma sessão chamada \"{token}\"",
    "An administrator created an app password for a session named \"{token}\"" : "Um administrador criou uma senha de aplicativo para uma sessão chamada \"{token}\"",
    "You deleted app password \"{token}\" and cancelled its pending remote wipe" : "Você excluiu a senha do aplicativo \"{token}\" e cancelou seu apagamento remoto pendente",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Você renomeou a senha do aplicativo \"{token}\" para \"{newToken}\"",
    "You granted filesystem access to app password \"{token}\"" : "Você concedeu acesso ao sistema de arquivos para a senha do aplicativo \"{token}\"",
    "You revoked filesystem access from app password \"{token}\"" : "Você revogou o acesso ao sistema de arquivos da senha do aplicativo \"{token}\"",
    "Security" : "Segurança",
    "You successfully logged in using two-factor authentication (%1$s)" : "Autenticado com sucesso utilizando autenticação de dois fatores (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Tentativa falhada de autenticação utilizando dois fatores (%1$s)",
    "Remote wipe was started on %1$s" : "Eliminação remota iniciada em %1$s ",
    "Remote wipe has finished on %1$s" : "Eliminação remota terminou em %1$s",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "A <strong>password</strong> ou <strong>email</strong> foram modificados",
    "QR Code login" : "Iniciar sessão com código QR",
    "Wrong password" : "Palavra-passe errada",
    "Unable to change personal password" : "Não foi possível mudar a palavra-passe pessoal",
    "Saved" : "Guardado",
    "Unable to change password" : "Não é possível alterar a sua palavra-passe ",
    "Unable to change password. Password too long." : "Não foi possível mudar a palavra-passe. Palavra-passe demasiado longa.",
    "Authentication error" : "Erro na autenticação",
    "Please provide an admin recovery password; otherwise, all account data will be lost." : "Por favor, forneça uma senha de recuperação de administrador; caso contrário, todos os dados da conta serão perdidos.",
    "Wrong admin recovery password. Please check the password and try again." : "Palavra-passe de recuperação do administrador errada. Por favor, verifique a palavra-passe e tente novamente.",
    "Backend does not support password change, but the encryption of the account key was updated." : "O back-end não suporta alteração de senha, mas a criptografia da chave da conta foi atualizada.",
    "Administrator documentation" : "Documentação de Administrador.",
    "User documentation" : "Documentação de Utilizador",
    "Nextcloud help overview" : "Visão geral da ajuda do Nextcloud",
    "Invalid SMTP password." : "Senha de SMTP inválida.",
    "Email setting test" : "Teste definições de email",
    "Well done, %s!" : "Muito bem, %s!",
    "If you received this email, the email configuration seems to be correct." : "Se recebeu este email, a configuração do serviço de email deverá estar correta.",
    "Email could not be sent. Check your mail server log" : "O email não pode ser enviado. Por favor verifique os logs do seu servidor de e-mail.",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Ocorreu um problema ao enviar o e-mail. Por favor verifique as suas definições. (Erro: %s)",
    "You need to set your account email before being able to send test emails. Go to %s for that." : "Você precisa definir o e-mail da sua conta antes de poder enviar e-mails de teste. Acesse %s para fazer isso.",
    "Recently active" : "Ativo recentemente",
    "Disabled accounts" : "Contas desativadas",
    "Settings" : "Configurações",
    "Invalid account" : "Conta inválida",
    "Invalid mail address" : "Endereço de correio eletrónico inválido",
    "Settings saved" : "Definições guardadas",
    "Unable to change full name" : "Não foi possível alterar o seu nome completo",
    "Unable to change email address" : "Não foi possível alterar o seu endereço de e-mail",
    "Unable to set invalid phone number" : "Número de telefone inválido",
    "Unable to set invalid website" : "Website inválido",
    "Some account data was invalid" : "Alguns dados são inválidos",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Por forma a validar a sua conta de Twitter, por favor publique o seguinte Twitter ( garanta que a publicação não contém quebras de linha):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Por forma de validar o Website, por favor publique o conteúdo seguinte na sua raiz em 'well-known/CloudIdVerificationCode.txt' (garanta que o texto completo se encontra numa única linha):",
    "%1$s changed your password on %2$s." : "%1$s modificou a sua senha em %2$s.",
    "Your password on %s was changed." : "A sua senha para %s foi modificada.",
    "Your password on %s was reset by an administrator." : "A sua senha para  %s foi redefinida pelo administrador.",
    "Password for %1$s changed on %2$s" : "A senha para %1$s foi modificada em %2$s",
    "Password changed for %s" : "Senha modificada para %s",
    "If you did not request this, please contact an administrator." : "Se não requereu isto por favor contacte um administrador.",
    "Your email address on %s was changed." : "O endereço de e-mail me %s foi modificado.",
    "Your email address on %s was changed by an administrator." : "O seu endereço de email em %s foi modificado por um administrador.",
    "Email address for %1$s changed on %2$s" : "Endereço de e-mail para %1$s modificado em %2$s",
    "Email address changed for %s" : "Endereço de e-mail modificado para %s",
    "The new email address is %s" : "O novo endereço de e-mail é %s",
    "Appearance and accessibility" : "Aspeto e acessibilidade",
    "Personal settings" : "Configurações pessoais",
    "Administration settings" : "Configurações de administração",
    "Accounts" : "Contas",
    "Help & privacy" : "Ajuda & privacidade",
    "Your %s account was created" : "A tua conta %s foi criada",
    "Welcome aboard" : "Bem-vindo a bordo",
    "Welcome aboard %s" : "Bem-vindo a bordo %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Bem-vindo à conta %s, aqui pode adicionar, proteger e partilhar os seus dados.",
    "Your Login is: %s" : "O seu Login é: %s",
    "Set your password" : "Escolher senha",
    "Go to %s" : "Ir para %s",
    "Install Client" : "Instalar Cliente",
    "Logged in account must be a sub admin" : "A conta conectada deve ser um subadministrador",
    "Personal" : "Pessoal",
    "Administration" : "Administração",
    "Users" : "Utilizadores",
    "Additional settings" : "Definições adicionais",
    "Assistant" : "Assistente",
    "Administration privileges" : "Privilégios de administração",
    "Groupware" : "Groupware",
    "Office" : "OFFICE",
    "Overview" : "Visão Geral",
    "Basic settings" : "Definições básicas",
    "Sharing" : "Partilha",
    "Availability" : "Disponibilidade",
    "Calendar" : "Calendário",
    "Personal info" : "Informação pessoal",
    "Mobile & desktop" : "Móvel e área de trabalho",
    "Artificial Intelligence" : "Inteligência Artificial",
    "None / STARTTLS" : "Sem / STARTTLS",
    "Email server" : "Servidor de Correio Eletrónico",
    "Mail provider enables sending emails directly through the user's personal email account. At present, this functionality is limited to calendar invitations. It requires Nextcloud Mail 4.1 and an email account in Nextcloud Mail that matches the user's email address in Nextcloud." : "O provedor de e-mail permite o envio de e-mails diretamente pela conta de e-mail pessoal do usuário. No momento, essa funcionalidade está limitada a convites de calendário. Ele requer o Nextcloud Mail 4.1 e uma conta de e-mail no Nextcloud Mail que corresponda ao endereço de e-mail do usuário no Nextcloud.",
    "Send emails using" : "Enviar e-mails via",
    "User's email account" : "Conta de e-mail do usuário",
    "System email account" : "Conta de e-mail do sistema",
    "Settings presets" : "Predefinições de configurações",
    "Background jobs" : "Tarefas de segundo plano",
    "Unlimited" : "Ilimitado",
    "Verifying" : "A verificar",
    "Verifying …" : "A verificar...",
    "Verify" : "Verificar",
    "Allowed admin IP ranges" : "Intervalos de IP de administrador permitidos",
    "Admin IP filtering isn't applied." : "A filtragem de IPs de administrador não é aplicada.",
    "Configuration key \"%1$s\" expects an array (%2$s found). Admin IP range validation will not be applied." : "A chave de configuração \"%1$s\" espera um array (%2$s encontrado). A validação do intervalo de IP do administrador não será aplicada.",
    "Configuration key \"%1$s\" contains invalid IP range(s): \"%2$s\"" : "A chave de configuração \"%1$s\" contém um ou mais intervalos de IP inválidos: \"%2$s\"",
    "Admin IP filtering is correctly configured." : "A filtragem de IP do administrador está configurada corretamente.",
    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:\n%s" : "Alguns diretórios de aplicativos pertencem a um usuário diferente do usuário do servidor web. Este pode ser o caso se os aplicativos tiverem sido instalados manualmente. Verifique as permissões dos seguintes diretórios de aplicativos: \n%s",
    "App directories have the correct owner \"%s\"" : "Os diretórios de aplicativos têm o proprietário correto \"%s\"",
    "Brute-force Throttle" : "Limitação de força bruta",
    "Your remote address could not be determined." : "Seu endereço remoto não pode ser determinado.",
    "Your remote address was identified as \"%s\" and is brute-force throttled at the moment slowing down the performance of various requests. If the remote address is not your address this can be an indication that a proxy is not configured correctly." : "Seu endereço remoto foi identificado como \"%s\" e está sendo limitado por força bruta no momento, diminuindo o desempenho de diversas solicitações. Se o endereço remoto não for o seu, isso pode ser uma indicação de que um proxy não está configurado corretamente.",
    "Your remote address \"%s\" is not brute-force throttled." : "Seu endereço remoto \"%s\" não é limitado por força bruta.",
    "Old administration imported certificates" : "Certificados importados da administração antigos",
    "There are some administration imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Existem alguns certificados SSL importados da administração presentes, que não são mais usados com o Nextcloud 21. Eles podem ser importados na linha de comando via comando \"occ security:certificates:import\". Seus caminhos dentro do diretório de dados são mostrados abaixo.",
    "Code integrity" : "Integridade de código",
    "Integrity checker has been disabled. Integrity cannot be verified." : "O verificador de integridade foi desativado. Não é possível verificar a integridade.",
    "No altered files" : "Nenhum arquivo alterado",
    "Some files have not passed the integrity check. {link1} {link2}" : "Alguns arquivos não passaram na verificação de integridade. {link1} {link2}",
    "Rescan…" : "Verificar novamente…",
    "Cron errors" : "Erros do cron",
    "The last cron job ran without errors." : "A última execução do cron terminou sem erros.",
    "Cron last run" : "Última execução do cron",
    "Last background job execution ran %s. Something seems wrong. {link}." : "A última execução de trabalho em segundo plano foi %s. Algo parece errado. {link}.",
    "Last background job execution ran %s." : "A última execução de trabalho em segundo plano foi %s.",
    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Seu diretório de dados e arquivos provavelmente estão acessíveis pela Internet. O arquivo .htaccess não está funcionando. É altamente recomendável que você configure seu servidor web para que o diretório de dados não seja mais acessível ou mova o diretório de dados para fora da raiz do documento do servidor web.",
    "Could not check that the data directory is protected. Please check manually that your server does not allow access to the data directory." : "Não foi possível verificar se o diretório de dados está protegido. Verifique manualmente se o servidor não permite o acesso ao diretório de dados.",
    "Database missing columns" : "Colunas faltando no banco de dados",
    "Missing optional column \"%s\" in table \"%s\"." : "Coluna opcional \"%s\" ausente na tabela \"%s\".",
    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "Estão faltando algumas colunas opcionais no banco de dados. Devido ao fato de que adicionar colunas em grandes tabelas pode levar algum tempo, elas não foram adicionadas automaticamente por serem opcionais. Ao executar \"occ db: add-missing-columns\", elas podem ser adicionadas manualmente enquanto a instância continua em execução. Depois que as colunas são adicionadas, alguns recursos podem melhorar a capacidade de resposta ou a usabilidade.",
    "Database missing indices" : "Índices faltando no banco de dados",
    "Missing indices:" : "Índices ausentes:",
    "\"%s\" in table \"%s\"" : "\"%s\" na tabela \"%s\"",
    "Detected some missing optional indices. Occasionally new indices are added (by Nextcloud or installed applications) to improve database performance. Adding indices can sometimes take awhile and temporarily hurt performance so this is not done automatically during upgrades. Once the indices are added, queries to those tables should be faster. Use the command `occ db:add-missing-indices` to add them." : "Detectou alguns índices opcionais ausentes. Ocasionalmente, novos índices são adicionados (pelo Nextcloud ou por aplicativos instalados) para melhorar o desempenho do banco de dados. A adição de índices às vezes pode demorar um pouco e prejudicar temporariamente o desempenho, portanto, isso não é feito automaticamente durante as atualizações. Depois que os índices forem adicionados, as consultas a essas tabelas deverão ficar mais rápidas. Use o comando `occ db:add-missing-indices` para adicioná-los.",
    "Database missing primary keys" : "Chaves primárias faltando no banco de dados",
    "Missing primary key on table \"%s\"." : "Chave primária faltando na tabela \"%s\".",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "O banco de dados está sem algumas chaves primárias. Devido ao fato de que adicionar chaves primárias em tabelas grandes pode levar algum tempo, elas não foram adicionadas automaticamente. Ao executar \"occ db:add-missing-primary-keys\" essas chaves primárias ausentes podem ser adicionadas manualmente enquanto a instância continua em execução.",
    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline." : "Algumas colunas do banco de dados não têm conversão para big int. Devido ao fato de que a alteração dos tipos de colunas em tabelas grandes pode levar algum tempo, elas não foram alteradas automaticamente. Ao executar \"occ db:convert-filecache-bigint\" essas alterações pendentes podem ser aplicadas manualmente. Esta operação precisa ser feita enquanto a instância estiver off-line.",
    "Debug mode" : "Modo de depuração",
    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "Esta instância está sendo executada no modo de depuração. Habilite isso apenas para desenvolvimento local e não em ambientes de produção.",
    "Debug mode is disabled." : "O modo de depuração está desativado.",
    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective ISO 3166-1 code of the region to your config file." : "Sua instalação não tem uma região padrão de telefone definida. Isto é necessário para validar números de telefone nas configurações do perfil sem código de país. Para permitir números sem código de país, adicione \"default_phone_region\" com o respectivo código ISO 3166-1 da região ao seu arquivo de configuração.",
    "Email test" : "Teste de e-mail",
    "Mail delivery is disabled by instance config \"%s\"." : "A entrega de e-mails está desativada pela configuração da instância \"%s\".",
    "Email test was successfully sent" : "Teste de e-mail enviado com sucesso",
    "You have not set or verified your email server configuration, yet. Please head over to the \"Basic settings\" in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "Você ainda não definiu ou verificou a configuração do seu servidor de e-mail. Por favor, vá para as \"Configurações básicas\" para defini-las. Depois, use o botão \"Enviar e-mail\" abaixo do formulário para verificar suas configurações.",
    "Transactional File Locking" : "Trancamento de Arquivo Transacional",
    "Transactional File Locking is disabled. This is not a a supported configuraton. It may lead to difficult to isolate problems including file corruption. Please remove the `'filelocking.enabled' => false` configuration entry from your `config.php` to avoid these problems." : "O Trancamento de Arquivo Transacional está desativado. Esta não é uma configuração suportada. Isso pode dificultar o isolamento de problemas, incluindo corrupção de arquivos. Por favor remova a entrada de configuração `'filelocking.enabled' => false` do seu `config.php` para evitar esses problemas.",
    "The database is used for transactional file locking. To enhance performance, please configure memcache, if available." : "O banco de dados é usado para trancamento de arquivo transacional. Para melhorar o desempenho, configure o memcache, se disponível.",
    "Forwarded for headers" : "Cabeçalhos Forwarded for",
    "Your \"trusted_proxies\" setting is not correctly set, it should be an array." : "Sua configuração \"trusted_proxies\" não está definida corretamente; deveria ser um arranjo.",
    "Your \"trusted_proxies\" setting is not correctly set, it should be an array of IP addresses - optionally with range in CIDR notation." : "Sua configuração \"trusted_proxies\" não está definida corretamente; deve ser um arranjo de endereços IP - opcionalmente com intervalo na notação CIDR.",
    "The reverse proxy header configuration is incorrect. This is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud." : "A configuração de cabeçalhos do proxy reverso está incorreta. Isto é um problema de segurança e pode permitir que um invasor falsifique seu endereço IP como visível para o Nextcloud.",
    "Your IP address was resolved as %s" : "Seu endereço IP foi resolvido como %s",
    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud." : "A configuração de cabeçalhos do proxy reverso está incorreta ou você está acessando Nextcloud de um proxy confiável. Caso contrário, isto é um problema de segurança e pode permitir que um invasor falsifique seu endereço IP como visível para o Nextcloud.",
    "HTTPS access and URLs" : "Acesso HTTPS e URLs",
    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead. Without it some important web functionality like \"copy to clipboard\" or \"service workers\" will not work!" : "Acessando o site de forma insegura via HTTP. É altamente recomendável configurar seu servidor para exigir HTTPS. Sem ele, algumas funcionalidades importantes da web, como \"copiar para a área de transferência\" ou \"service workers\" não funcionarão!",
    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This likely means that your instance is behind a reverse proxy and the Nextcloud `overwrite*` config values are not set correctly." : "Você está acessando sua instância por meio de uma conexão segura, mas sua instância está gerando URLs inseguros. Isso provavelmente significa que sua instância está atrás de um proxy reverso e os valores de configuração `overwrite*` do Nextcloud não estão definidos corretamente.",
    "Your instance is generating insecure URLs. If you access your instance over HTTPS, this likely means that your instance is behind a reverse proxy and the Nextcloud `overwrite*` config values are not set correctly." : "Sua instância está gerando URLs inseguros. Se você acessar sua instância por HTTPS, isso provavelmente significa que sua instância está atrás de um proxy reverso e os valores de configuração `overwrite*` do Nextcloud não estão definidos corretamente.",
    "You are accessing your instance over a secure connection, and your instance is generating secure URLs." : "Você está acessando sua instância por meio de uma conexão segura e sua instância está gerando URLs seguros.",
    "Internet connectivity" : "Conetividade da Internet",
    "Internet connectivity is disabled in configuration file." : "A conetividade da Internet está desativada no ficheiro de configuração.",
    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Este servidor não tem conexão com a Internet: Não foi possível acessar vários pontos de extremidade. Isso significa que alguns dos recursos, como montagem de armazenamento externo, notificações sobre atualizações ou instalação de aplicativos de terceiros, não funcionarão. Acessar arquivos remotamente e enviar e-mails de notificação também pode não funcionar. Estabeleça uma conexão deste servidor com a Internet para desfrutar de todos os recursos. ",
    "JavaScript modules support" : "Suporte a módulos JavaScript",
    "Unable to run check for JavaScript support. Please remedy or confirm manually if your webserver serves `.mjs` files using the JavaScript MIME type." : "Não foi possível executar a verificação de suporte a JavaScript. Corrija ou confirme manualmente se o seu servidor web serve arquivos `.mjs` usando o tipo MIME JavaScript.",
    "Your webserver does not serve `.mjs` files using the JavaScript MIME type. This will break some apps by preventing browsers from executing the JavaScript files. You should configure your webserver to serve `.mjs` files with either the `text/javascript` or `application/javascript` MIME type." : "Seu servidor web não serve arquivos `.mjs` usando o tipo MIME JavaScript. Isso interromperá alguns aplicativos, impedindo que os navegadores executem os arquivos JavaScript. Você deve configurar seu servidor web para servir arquivos `.mjs` com o tipo MIME `text/javascript` ou `application/javascript`.",
    "JavaScript source map support" : "Suporte a source maps de JavaScript",
    "Your webserver is not set up to serve `.js.map` files. Without these files, JavaScript Source Maps won't function properly, making it more challenging to troubleshoot and debug any issues that may arise." : "Seu servidor web não está configurado para servir arquivos `.js.map`. Sem esses arquivos, os source maps de JavaScript não funcionarão corretamente, tornando mais difícil solucionar e depurar quaisquer problemas que possam surgir.",
    "Old server-side-encryption" : "Criptografia antiga do lado do servidor",
    "Disabled" : "Desativado",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "O antigo formato de criptografia do lado do servidor está ativado. Recomendamos desativar isso.",
    "Logging level" : "Nível de registro",
    "The %1$s configuration option must be a valid integer value." : "A opção de configuração %1$s deve ser um número inteiro válido.",
    "The logging level is set to debug level. Use debug level only when you have a problem to diagnose, and then reset your log level to a less-verbose level as it outputs a lot of information, and can affect your server performance." : "O nível de registro está definido como nível de depuração. Use o nível de depuração somente quando tiver um problema a ser diagnosticado e, em seguida, redefina o nível de registro para um nível menos detalhado, pois ele gera muitas informações e pode afetar o desempenho do servidor.",
    "Logging level configured correctly." : "Nível de registro configurado corretamente.",
    "Maintenance window start" : "Início da janela de manutenção",
    "Server has no maintenance window start time configured. This means resource intensive daily background jobs will also be executed during your main usage time. We recommend to set it to a time of low usage, so users are less impacted by the load caused from these heavy tasks." : "O servidor não tem horário de início da janela de manutenção configurado. Isso significa que trabalhos diários em segundo plano com uso intensivo de recursos também serão executados durante o tempo de uso principal. Recomendamos configurá-lo para um horário de baixo uso, para que os usuários sejam menos impactados pela carga causada por essas tarefas pesadas.",
    "Memcache" : "Memcache",
    "Memcached is configured as distributed cache, but the wrong PHP module (\"memcache\") is installed. Please install the PHP module \"memcached\"." : "O Memcached está configurado como cache distribuído, mas o módulo PHP errado (\"memcache\") está instalado. Por favor, instale o módulo PHP \"memcached\".",
    "Memcached is configured as distributed cache, but the PHP module \"memcached\" is not installed. Please install the PHP module \"memcached\"." : "O Memcached está configurado como cache distribuído, mas o módulo PHP \"memcached\" não está instalado. Por favor, instale o módulo PHP \"memcached\".",
    "No memory cache has been configured. To enhance performance, please configure a memcache, if available." : "Nenhum cache de memória foi configurado. Para melhorar o desempenho, configure um memcache, se disponível.",
    "Failed to write and read a value from distributed cache." : "Falha ao gravar e ler um valor do cache distribuído.",
    "Configured" : "Configurado",
    "Mimetype migrations available" : "Migrações de mimetype disponíveis",
    "One or more mimetype migrations are available. Occasionally new mimetypes are added to better handle certain file types. Migrating the mimetypes take a long time on larger instances so this is not done automatically during upgrades. Use the command `occ maintenance:repair --include-expensive` to perform the migrations." : "Uma ou mais migrações de mimetype estão disponíveis. Ocasionalmente, novos mimetypes são adicionados para lidar melhor com certos tipos de arquivo. A migração dos mimetypes leva muito tempo em instâncias maiores, portanto, isso não é feito automaticamente durante as atualizações. Use o comando 'occ maintenance:repair --include-expensive' para executar as migrações.",
    "MySQL row format" : "Formato de linhas do MySQL",
    "Incorrect row format found in your database. ROW_FORMAT=Dynamic offers the best database performances for Nextcloud. Please update row format on the following list: %s." : "Formato de linhas incorreto encontrado em seu banco de dados. ROW_FORMAT=Dynamic oferece o melhor desempenho de banco de dados para o Nextcloud. Atualize o formato de linhas na lista a seguir: %s.",
    "MySQL Unicode support" : "Suporte a Unicode do MySQL",
    "MySQL is used as database and does support 4-byte characters" : "MySQL é usado como banco de dados e é compatível com caracteres de 4 bytes",
    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL." : "MySQL é usado como banco de dados, mas não suporta caracteres de 4 bytes. Para poder lidar com caracteres de 4 bytes (como emojis) sem problemas em nomes de arquivos ou comentários, por exemplo, é recomendado habilitar o suporte de 4 bytes no MySQL.",
    "OCS provider resolving" : "Resolução do provedor OCS",
    "Could not check if your web server properly resolves the OCM and OCS provider URLs." : "Não foi possível verificar se o seu servidor web resolve corretamente os URLs do provedor OCM e OCS.",
    "Your web server is not properly set up to resolve %1$s.\nThis is most likely related to a web server configuration that was not updated to deliver this folder directly.\nPlease compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx.\nOn Nginx those are typically the lines starting with \"location ~\" that need an update." : "Seu servidor web não está configurado corretamente para resolver %1$s.\nProvavelmente, isso está relacionado a uma configuração do servidor web que não foi atualizada para entregar esta pasta diretamente.\nPor favor, compare sua configuração com as regras rewrite enviadas em \".htaccess\" para Apache ou com as fornecidas na documentação para Nginx.\nNo Nginx, essas são normalmente as linhas que começam com \"location ~\" e que precisam de atualização.",
    "Overwrite CLI URL" : "Substituir URL da CLI",
    "The \"overwrite.cli.url\" option in your config.php is correctly set to \"%s\"." : "A opção \"overwrite.cli.url\" em seu config.php está definida corretamente como \"%s\".",
    "The \"overwrite.cli.url\" option in your config.php is set to \"%s\" which is a correct URL. Suggested URL is \"%s\"." : "A opção \"overwrite.cli.url\" em seu config.php está definida como \"%s\", que é uma URL correta. O URL sugerido é \"%s\".",
    "Please make sure to set the \"overwrite.cli.url\" option in your config.php file to the URL that your users mainly use to access this Nextcloud. Suggestion: \"%s\". Otherwise there might be problems with the URL generation via cron. (It is possible though that the suggested URL is not the URL that your users mainly use to access this Nextcloud. Best is to double check this in any case.)" : "Certifique-se de definir a opção \"overwrite.cli.url\" em seu arquivo config.php para o URL que seus usuários usam principalmente para acessar este Nextcloud. Sugestão: \"%s\". Caso contrário, poderá haver problemas com a geração de URLs via cron. (No entanto, é possível que o URL sugerido não seja o URL que seus usuários usam principalmente para acessar este Nextcloud. De qualquer forma, é melhor verificar isso duas vezes.)",
    "PHP APCu configuration" : "Configuração PHP APCu",
    "Your APCu cache is almost full at %s%%, consider increasing the apc.shm_size php setting." : "Seu cache APCu está quase cheio em %s%%. Considere aumentar a configuração do PHP apc.shm_size.",
    "PHP configuration option \"default_charset\" should be UTF-8" : "A opção de configuração do PHP \"default_charset\" deve ser UTF-8",
    "PHP set_time_limit" : "PHP set_time_limit",
    "The function is available." : "A função está disponível.",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "A função PHP \"set_time_limit\" não está disponível. Isto pode resultar na paragem de scripts a meio da execução, corrompendo a instalação. A ativação desta função é altamente recomendada.",
    "Freetype" : "Freetype",
    "Supported" : "Suportado",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "O seu PHP não suporta FreeType, podendo resultar em fotos de perfil e interface de definições corrompidos. ",
    "PHP getenv" : "PHP getenv",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "O PHP não parece estar bem configurado para consultar variáveis do ambiente do sistema. O teste com getenv(\"PATH\") apenas devolveu uma resposta em branco.",
    "The PHP upload_max_filesize is too low. A size of at least %1$s is recommended. Current value: %2$s." : "O PHP upload_max_filesize é muito baixo. Um tamanho de pelo menos %1$s é recomendado. Valor atual: %2$s.",
    "The PHP post_max_size is too low. A size of at least %1$s is recommended. Current value: %2$s." : "O PHP post_max_size é muito baixo. Um tamanho de pelo menos %1$s é recomendado. Valor atual: %2$s.",
    "The PHP max_input_time is too low. A time of at least %1$s is recommended. Current value: %2$s." : "O PHP max_input_time é muito baixo. Um tempo de pelo menos %1$s é recomendado. Valor atual: %2$s.",
    "The PHP max_execution_time is too low. A time of at least %1$s is recommended. Current value: %2$s." : "O PHP max_execution_time é muito baixo. Um tempo de pelo menos %1$s é recomendado. Valor atual: %2$s.",
    "PHP memory limit" : "Limite de memória do PHP",
    "The PHP memory limit is below the recommended value of %s. Some features or apps - including the Updater - may not function properly." : "O limite de memória do PHP está abaixo do valor recomendado de %s. Alguns recursos ou aplicativos - incluindo o Atualizador - podem não funcionar adequadamente.",
    "increases language translation performance and fixes sorting of non-ASCII characters" : "aumenta o desempenho da tradução de idiomas e corrige a classificação de caracteres não-ASCII",
    "for Argon2 for password hashing and Ed25519 signature verification for RFC 9421 http message signatures" : "para o Argon2 para o hash de senhas e a verificação de assinaturas Ed25519 para assinaturas de mensagens HTTP conforme a RFC 9421",
    "required for SFTP storage and recommended for WebAuthn performance" : "necessário para o armazenamento SFTP e recomendado para o desempenho do WebAuthn",
    "This instance is missing some required PHP modules. It is required to install them: %s." : "Esta instância está faltando alguns módulos PHP obrigatórios. É necessário instalá-los: %s.",
    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them:\n%s" : "Esta instância está faltando alguns módulos PHP recomendados. Para melhor desempenho e melhor compatibilidade é altamente recomendável instalá-los:\n%s",
    "PHP opcache" : "PHP opcache",
    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "O módulo PHP OPcache não está carregado. Para um melhor desempenho, é recomendável carregá-lo em sua instalação do PHP.",
    "OPcache is disabled. For better performance, it is recommended to apply \"opcache.enable=1\" to your PHP configuration." : "OPcache está desativado. Para melhor desempenho, é recomendado aplicar \"opcache.enable=1\" à sua configuração PHP.",
    "The shared memory based OPcache is disabled. For better performance, it is recommended to apply \"opcache.file_cache_only=0\" to your PHP configuration and use the file cache as second level cache only." : "O OPcache baseado em memória compartilhada está desabilitado. Para melhor desempenho, é recomendado aplicar \"opcache.file_cache_only=0\" à sua configuração PHP e usar o cache de arquivos apenas como cache de segundo nível.",
    "OPcache is not working as it should, opcache_get_status() returns false, please check configuration." : "OPcache não está funcionando como deveria, opcache_get_status() retorna falso, verifique a configuração.",
    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be kept in the cache, it is recommended to apply \"opcache.max_accelerated_files\" to your PHP configuration with a value higher than \"%s\"." : "O número máximo de chaves OPcache está quase excedido. Para garantir que todos os scripts possam ser mantidos no cache, é recomendado aplicar \"opcache.max_accelerated_files\" à sua configuração PHP com um valor maior que \"%s\".",
    "The OPcache buffer is nearly full. To assure that all scripts can be hold in cache, it is recommended to apply \"opcache.memory_consumption\" to your PHP configuration with a value higher than \"%s\"." : "O retentor do OPcache está quase cheio. Para garantir que todos os scripts possam ser mantidos em cache, é recomendado aplicar \"opcache.memory_consumption\" à sua configuração PHP com um valor maior que \"%s\".",
    "The OPcache interned strings buffer is nearly full. To assure that repeating strings can be effectively cached, it is recommended to apply \"opcache.interned_strings_buffer\" to your PHP configuration with a value higher than \"%s\"." : "O retentor de strings internadas do OPcache está quase cheio. Para garantir que strings repetidas possam ser efetivamente armazenadas em cache, é recomendado aplicar \"opcache.interned_strings_buffer\" à sua configuração PHP com um valor maior que \"%s\".",
    "OPcache is configured to remove code comments. With OPcache enabled, \"opcache.save_comments=1\" must be set for Nextcloud to function." : "OPcache está configurado para remover comentários de código. Com o OPcache habilitado, \"opcache.save_comments=1\" deve ser definido para que o Nextcloud funcione.",
    "Nextcloud is not allowed to use the OPcache API. With OPcache enabled, it is highly recommended to include all Nextcloud directories with \"opcache.restrict_api\" or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud não tem permissão para usar a API OPcache. Com o OPcache habilitado, é altamente recomendável incluir todos os diretórios Nextcloud com \"opcache.restrict_api\" ou redefinir esta configuração para desabilitar as restrições da API OPcache, para evitar erros durante atualizações do núcleo do Nextcloud ou dos aplicativos.",
    "Correctly configured" : "Configurado corretamente",
    "PHP version" : "Versão PHP",
    "You are currently running PHP %1$s. PHP %2$s is deprecated since Nextcloud %3$s. Nextcloud %4$s may require at least PHP %5$s. Please upgrade to one of the officially supported PHP versions provided by the PHP Group as soon as possible." : "No momento, você está executando o PHP %1$s. O PHP %2$s está obsoleto desde o Nextcloud %3$s. O Nextcloud %4$s pode exigir pelo menos o PHP %5$s. Atualize para uma das versões do PHP oficialmente suportadas fornecidas pelo PHP Group assim que possível.",
    "You are currently running PHP %s." : "No momento, você está executando o PHP %s.",
    "PHP configuration option \"output_buffering\" must be disabled" : "A opção de configuração do PHP \"output_buffering\" deve estar desabilitada",
    "Push service" : "Serviço push",
    "Valid enterprise license" : "Licença empresarial válida",
    "Free push service" : "Serviço push gratuito",
    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications are limited to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at {link}." : "Esta é a construção da comunidade não suportada do Nextcloud. Dado o tamanho desta instância, o desempenho, a confiabilidade e a escalabilidade não podem ser garantidos. As notificações push são limitadas para evitar sobrecarregar nosso serviço gratuito. Saiba mais sobre os benefícios do Nextcloud Empresarial em {link}.",
    "No suitable source for randomness found by PHP which is highly discouraged for security reasons." : "Nenhuma fonte adequada para aleatoriedade encontrada pelo PHP, o que é altamente desencorajado por razões de segurança.",
    "Secure" : "Seguro",
    "Configuration file access rights" : "Direitos de acesso ao arquivo de configuração",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "A configuração Só-de-Leitura foi ativada. Isto evita definir algumas configurações através da interface da Web. Além disso, o ficheiro precisa de ser definido gravável manualmente para cada atualização.",
    "Scheduling objects table size" : "Tamanho da tabela de objetos de agendamento",
    "You have more than %s rows in the scheduling objects table. Please run the expensive repair jobs via occ maintenance:repair --include-expensive." : "Você tem mais de %s linhas na tabela de objetos de agendamento. Por favor, execute os trabalhos de reparo caros via occ maintenance:repair --include-expensive.",
    "HTTP headers" : "Cabeçalhos HTTP",
    "- The `%1$s` HTTP header is not set to `%2$s`. Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "- O cabeçalho HTTP `%1$s` não está definido como `%2$s`. Alguns recursos podem não funcionar corretamente, portanto, é recomendado ajustar esta configuração de acordo.",
    "- The `%1$s` HTTP header is not set to `%2$s`. This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "- O cabeçalho HTTP `%1$s` não está definido como `%2$s`. Este é um possível risco à segurança ou à privacidade, portanto, é recomendável ajustar esta configuração de acordo.",
    "- The `%1$s` HTTP header is not set to `%2$s`, `%3$s`, `%4$s`, `%5$s` or `%6$s`. This can leak referer information. See the {w3c-recommendation}." : "- O cabeçalho HTTP `%1$s` não está definido como `%2$s`, `%3$s`, `%4$s`, `%5$s` ou `%6$s`. Isso pode vazar informações do referenciador. Consulte a {w3c-recommendation}.",
    "- The `Strict-Transport-Security` HTTP header is not set to at least `%d` seconds (current value: `%d`). For enhanced security, it is recommended to use a long HSTS policy." : "- O cabeçalho HTTP `Strict-Transport-Security` não está definido para pelo menos `%d` segundos (valor atual: `%d`). Para aumentar a segurança, é recomendável usar uma política HSTS longa.",
    "- The `Strict-Transport-Security` HTTP header is malformed: `%s`. For enhanced security, it is recommended to enable HSTS." : "- O cabeçalho HTTP `Strict-Transport-Security` está malformado: `%s`. Para aumentar a segurança, é recomendável ativar o HSTS.",
    "- The `Strict-Transport-Security` HTTP header is not set (should be at least `%d` seconds). For enhanced security, it is recommended to enable HSTS." : "- O cabeçalho HTTP `Strict-Transport-Security` não está definido (deve ter pelo menos `%d` segundos). Para aumentar a segurança, é recomendável ativar o HSTS.",
    "Some headers are not set correctly on your instance" : "Alguns cabeçalhos não estão configurados corretamente na sua instância",
    "Could not check that your web server serves security headers correctly. Please check manually." : "Não foi possível verificar se o seu servidor web fornece cabeçalhos de segurança corretamente. Verifique manualmente.",
    "Could not check that your web server serves security headers correctly, unable to query `%s`" : "Não foi possível verificar se o seu servidor web fornece cabeçalhos de segurança corretamente, não foi possível consultar `%s`",
    "Server identifier isn’t configured. It is recommended if your Nextcloud instance is running on several PHP servers. Add a server ID in your configuration." : "O identificador do servidor não está configurado. É recomendado se a sua instância do Nextcloud estiver sendo executada em vários servidores PHP. Adicione um ID de servidor na sua configuração.",
    "Server identifier is configured and valid." : "O identificador do servidor está configurado e válido.",
    "Database version" : "Versão do banco de dados",
    "MariaDB version 10.6 detected, this version is end-of-life and only supported as part of Ubuntu 22.04. MariaDB >=%1$s and <=%2$s is suggested for best performance, stability and functionality with this version of Nextcloud." : "Versão do MariaDB 10.3 detectada, esta versão é fim de vida e só suportada como parte do Ubuntu 20.04. MariaDB >=%1$s e <=%2$s é sugerido para melhor desempenho, estabilidade e funcionalidade com esta versão do Nextcloud.",
    "MariaDB version \"%1$s\" detected. MariaDB >=%2$s and <=%3$s is suggested for best performance, stability and functionality with this version of Nextcloud." : "Versão do MariaDB \"%1$s\" detectada. MariaDB >=%2$s e <=%3$s é sugerido para melhor desempenho, estabilidade e funcionalidade com esta versão do Nextcloud.",
    "MySQL version \"%1$s\" detected. MySQL >=%2$s and <=%3$s is suggested for best performance, stability and functionality with this version of Nextcloud." : "Versão do MySQL \"%1$s\" detectada. MySQL >=%2$s e <=%3$s é sugerido para melhor desempenho, estabilidade e funcionalidade com esta versão do Nextcloud.",
    "PostgreSQL version \"%1$s\" detected. PostgreSQL >=%2$s and <=%3$s is suggested for best performance, stability and functionality with this version of Nextcloud." : "Versão do PostgreSQL \"%1$s\" detectada. O PostgreSQL >= %2$s e <= %3$s é sugerido para melhor desempenho, estabilidade e funcionalidade com esta versão do Nextcloud.",
    "Nextcloud %d does not support your current version, so be sure to update the database before updating your Nextcloud Server." : "O Nextcloud %d não suporta a sua versão atual, portanto, certifique-se de atualizar o banco de dados antes de atualizar o seu servidor Nextcloud.",
    "Oracle version \"%1$s\" detected. Oracle >=%2$s and <=%3$s is suggested for best performance, stability and functionality with this version of Nextcloud." : "Versão Oracle \"%1$s\" detectada. Oracle >=%2$s e <=%3$s é recomendado para obter o melhor desempenho, estabilidade e funcionalidade com esta versão do Nextcloud.",
    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend. This is particularly recommended when using the desktop client for file synchronisation. To migrate to another database use the command line tool: \"occ db:convert-type\"." : "No momento, o SQLite está sendo usado como banco de dados de back-end. Para instalações maiores, recomendamos que você mude para um back-end de banco de dados diferente. Isso é especialmente recomendado quando se usa o cliente de desktop para sincronização de arquivos. Para migrar para outro banco de dados, use a ferramenta de linha de comando: \"occ db:convert-type\".",
    "Unknown database platform" : "Plataforma de banco de dados desconhecida",
    "Architecture" : "Arquitetura",
    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit!" : "Parece que você está executando uma versão PHP de 32 bits. Nextcloud precisa de 64 bits para funcionar bem. Atualize seu sistema operacional e PHP para 64 bits!",
    "Task Processing pickup speed" : "Velocidade de inicio do Processamento de Tarefas",
    "_No scheduled tasks in the last day._::_No scheduled tasks in the last %n days._" : ["Nenhuma tarefa agendada no último dia.","Nenhuma tarefa agendada nos últimos %n de dias.","Nenhuma tarefa agendada nos últimos %n dias."],
    "_The task pickup speed has been ok in the last day._::_The task pickup speed has been ok in the last %n days._" : ["A velocidade de início do processamento de tarefas tem sido boa no último dia.","A velocidade de início do processamento de tarefas tem sido boa nos últimos %n de dias.","A velocidade de início do processamento de tarefas tem sido boa nos últimos %n dias."],
    "_The task pickup speed has been slow in the last day. Many tasks took longer than 4 minutes to be picked up. Consider setting up a worker to process tasks in the background._::_The task pickup speed has been slow in the last %n days. Many tasks took longer than 4 minutes to be picked up. Consider setting up a worker to process tasks in the background._" : ["A velocidade de início do processamento de tarefas tem sido lenta no último dia. Muitas tarefas levaram mais de 4 minutos para serem processadas. Considere configurar um trabalhador para processar tarefas em segundo plano.","A velocidade de início do processamento de tarefas tem sido lenta nos últimos %n de dias. Muitas tarefas levaram mais de 4 minutos para serem processadas. Considere configurar um trabalhador para processar tarefas em segundo plano.","A velocidade de início do processamento de tarefas tem sido lenta nos últimos %n dias. Muitas tarefas levaram mais de 4 minutos para serem processadas. Considere configurar um trabalhador para processar tarefas em segundo plano."],
    "_No scheduled tasks in the last %n day._::_No scheduled tasks in the last %n days._" : ["Não há tarefas agendadas no último %n dia.","Não há tarefas agendadas nos últimos %n de dias.","Não há tarefas agendadas nos últimos %n dias."],
    "_Most tasks were successful in the last %n day._::_Most tasks were successful in the last %n days._" : ["A maioria das tarefas foi concluída com sucesso no último %n dia.","A maioria das tarefas foi concluída com sucesso nos últimos %n de dias.","A maioria das tarefas foi concluída com sucesso nos últimos %n dias."],
    "_A lot of tasks failed in the last day. Consider checking the nextcloud log for errors and investigating whether the AI provider apps have been set up correctly._::_A lot of tasks failed in the last %n days. Consider checking the nextcloud log for errors and investigating whether the AI provider apps have been set up correctly._" : ["Muitas tarefas falharam no último dia. Considere verificar o log do Nextcloud em busca de erros e investigar se os aplicativos do provedor de IA foram configurados corretamente.","Muitas tarefas falharam nos últimos %n de dias. Considere verificar o log do Nextcloud em busca de erros e investigar se os aplicativos do provedor de IA foram configurados corretamente.","Muitas tarefas falharam nos últimos %n dias. Considere verificar o log do Nextcloud em busca de erros e investigar se os aplicativos do provedor de IA foram configurados corretamente."],
    "Task Processing worker status" : "Status do processador de tarefas",
    "_The Task Processing worker has run in the last %n minute._::_The Task Processing worker has run in the last %n minutes._" : ["O processador de tarefas foi executado no último %n minuto.","O processador de tarefas foi executado nos últimos %n de minutos.","O processador de tarefas foi executado nos últimos %n minutos."],
    "The Task Processing worker does not seem to be running. It seems it has never run so far." : "O processador de tarefas parece não estar em execução. Parece que ele nunca foi executado até agora.",
    "Error while checking the temporary PHP path - it was not properly set to a directory. Returned value: %s" : "Erro ao verificar o caminho temporário do PHP - ele não foi configurado corretamente para um diretório. Valor retornado:%s",
    "The PHP function \"disk_free_space\" is disabled, which prevents the check for enough space in the temporary directories." : "A função PHP \"disk_free_space\" está desativada, o que impede a verificação de espaço suficiente nos diretórios temporários.",
    "Error while checking the available disk space of temporary PHP path or no free disk space returned. Temporary path: %s" : "Erro ao verificar o espaço em disco disponível do caminho PHP temporário ou nenhum espaço livre em disco foi retornado. Caminho temporário: %s",
    "- %.1f GiB available in %s (PHP temporary directory)" : "- %.1f GiB disponível em %s (diretório temporário do PHP)",
    "- %.1f GiB available in %s (Nextcloud temporary directory)" : "- %.1f GiB disponível em %s (diretório temporário do Nextcloud)",
    "Temporary directory is correctly configured:\n%s" : "O diretório temporário está configurado corretamente:\n%s",
    "This instance uses an S3 based object store as primary storage, and has enough space in the temporary directory.\n%s" : "Esta instância usa um armazenamento de objetos baseado em S3 como armazenamento primário e tem espaço suficiente no diretório temporário.\n%s",
    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GiB of free space available in the temp directory of PHP. To improve this please change the temporary directory in the php.ini or make more space available in that path. \nChecking the available space in the temporary path resulted in %.1f GiB instead of the recommended 50 GiB. Path: %s" : "Esta instância usa um armazenamento de objetos baseado em S3 como armazenamento primário. Os arquivos enviados são armazenados temporariamente no servidor e por isso é recomendado ter 50 GiB de espaço livre disponível no diretório temporário do PHP. Para melhorar isso, altere o diretório temporário no php.ini ou disponibilize mais espaço nesse caminho.\nA verificação do espaço disponível no caminho temporário resultou em %.1f GiB em vez dos 50 GiB recomendados. Caminho: %s",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "A sua base de dados não tem o nível de isolamento da transação \"READ COMMITTED\" ativado. Isto pode causar problemas quando várias ações são executadas em paralelo.",
    "Was not able to get transaction isolation level: %s" : "Não foi possível obter o nível de isolamento da transação: %s",
    "Second factor configuration" : "Configuração do segundo fator",
    "Second factor providers are available but two-factor authentication is not enforced." : "Os provedores de segundo fator estão disponíveis, mas a autenticação de dois fatores não é exigida.",
    "Second factor providers are available and enforced: %s." : "Os provedores do segundo fator estão disponíveis e são exigidos: %s.",
    ".well-known URLs" : "URLs .well-known",
    "`check_for_working_wellknown_setup` is set to false in your configuration, so this check was skipped." : "`check_for_working_wellknown_setup` está definido como falso em sua configuração, portanto, esta verificação foi ignorada.",
    "Your web server is not properly set up to resolve `.well-known` URLs, failed on:\n`%s`" : "Seu servidor web não está configurado corretamente para resolver URLs `.well-known`, falhou em:\n`%s`",
    "Your server is correctly configured to serve `.well-known` URLs." : "Seu servidor está configurado corretamente para servir URLs `.well-known`.",
    "Font file loading" : "Carregamento de arquivos de fonte",
    "Could not check for {extension} loading support. Please check manually if your webserver serves `.{extension}` files." : "Não foi possível verificar o suporte de carregamento de {extension}. Verifique manualmente se seu servidor web serve arquivos `.{extension}`.",
    "Your web server is not properly set up to deliver .{extension} files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustment to also deliver .{extension} files. Compare your Nginx configuration to the recommended configuration in our documentation." : "Seu servidor web não está configurado corretamente para entregar arquivos .{extension}. Isto normalmente é um problema com a configuração do Nginx. Para o Nextcloud 15, ele precisa de um ajuste para também entregar arquivos .{extension}. Compare sua configuração do Nginx com a configuração recomendada em nossa documentação.",
    "Profile information" : "Informação de perfil",
    "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Foto do perfil, nome completo, e-mail, número de telefone, endereço, site, Twitter, organização, função, título, biografia e se seu perfil está ativado",
    "Nextcloud settings" : "Definições Nextcloud",
    "Generate text" : "Gerar texto",
    "AI tasks can be implemented by different apps. Here you can set which app should be used for which task." : "As tarefas de IA podem ser implementadas por aplicativos diferentes. Aqui você pode definir qual aplicativo deve ser usado para qual tarefa.",
    "Provider for Task types" : "Provedor para tipos de tarefas",
    "Enable" : "Ativar",
    "Show legacy provider settings" : "Mostrar as configurações de provedores legados",
    "Machine translation can be implemented by different apps. Here you can define the precedence of the machine translation apps you have installed at the moment." : "A tradução automática pode ser implementada por diferentes aplicativos. Aqui você pode definir a precedência dos aplicativos de tradução automática instalados no momento.",
    "This API is deprecated. Install apps that provide Unified task processing to get the best experience." : "Esta API está obsoleta. Instale aplicativos que ofereçam o processamento unificado de tarefas para obter a melhor experiência.",
    "Image generation can be implemented by different apps. Here you can set which app should be used." : "A geração de imagens pode ser implementada por diferentes aplicativos. Aqui você pode definir qual aplicativo deve ser usado.",
    "None of your currently installed apps provide image generation functionality" : "Nenhum dos seus aplicativos instalados atualmente oferece funcionalidade de geração de imagens",
    "Text processing tasks can be implemented by different apps. Here you can set which app should be used for which task." : "Tarefas de processamento de texto podem ser implementadas por diferentes aplicativos. Aqui você pode definir qual aplicativo deve ser usado para qual tarefa.",
    "None of your currently installed apps provide text processing functionality using the Text Processing API." : "Nenhum dos seus aplicativos instalados oferece funcionalidade de processamento de texto usando a API de Processamento de Texto.",
    "Here you can decide which group can access certain sections of the administration settings." : "Aqui você pode decidir qual grupo pode acessar certas seções das configurações de administração.",
    "Unable to modify setting" : "Incapaz de modificar a configuração",
    "None" : "Nenhum",
    "Changed disclaimer text" : "Aviso legal alterado",
    "Deleted disclaimer text" : "Aviso legal excluído",
    "Could not set disclaimer text" : "Não foi possível definir o texto do aviso legal",
    "Allow apps to use the Share API" : "Permitir que os utilizadores usem a API de partilha",
    "Allow resharing" : "Permitir repartilha",
    "Allow sharing with groups" : "Permitir partilha com grupos.",
    "Restrict users to only share with users in their groups" : "Restringe os utilizadores só a partilhar com utilizadores do seu grupo",
    "Users will still be able to screenshot or record the screen. This does not provide any definitive protection." : "Os usuários ainda poderão fazer capturas de tela ou gravar a tela. Isso não oferece nenhuma proteção definitiva.",
    "Allow public uploads" : "Permitir Envios Públicos",
    "This will add share permissions to all newly created link shares." : "Isso adicionará permissões de compartilhamento a todos os compartilhamentos de link novamente criados.",
    "Always ask for a password" : "Pedir sempre a senha",
    "Enforce password protection" : "Forçar proteção por palavra-passe",
    "Shares with custom tokens will continue to be accessible after this setting has been disabled" : "Compartilhamentos com tokens personalizados continuarão acessíveis mesmo após essa configuração ser desativada",
    "Shares with guessable tokens may be accessed easily" : "Compartilhamentos com tokens adivinháveis podem ser acessados facilmente",
    "Exclude some groups" : "Ignorar alguns grupos",
    "Groups excluded from sharing" : "Grupos excluídos do compartilhamento",
    "Set default expiration date for internal shares" : "Defina a data de expiração predefinida para as partilhas internas.",
    "Enforce expiration date" : "Forçar a data de expiração",
    "Set default expiration date for shares to other servers" : "Definir a data de expiração padrão para compartilhamentos com outros servidores",
    "Set default expiration date for shares via link or mail" : "Definir a data de expiração padrão para compartilhamentos via link ou e-mail",
    "Privacy settings for sharing" : "Configurações de privacidade para compartilhamento",
    "If autocompletion restrictions for both \"same group\" and \"phonebook integration\" are enabled, a match in either is enough to show the user." : "Se as restrições de preenchimento automático para \"mesmo grupo\" e \"integração com catálogo de endereços\" estiverem ativadas, uma correspondência em qualquer uma delas é suficiente para exibir o usuário.",
    "Restrict account name autocompletion and system address book access to users within the same groups" : "Restringir o preenchimento automático de nomes das contas e o acesso ao catálogo de endereços do sistema aos usuários dentro dos mesmos grupos",
    "Restrict account name autocompletion to users based on their phonebook" : "Restringir o preenchimento automático do nome da conta aos usuários com base em seu catálogo de endereços",
    "Allow autocompletion to full match when entering the full name (ignoring restrictions like group membership or missing phonebook match)" : "Permitir que o preenchimento automático corresponda totalmente ao inserir o nome completo (ignorando restrições como pertencimento a grupos ou falta de correspondência no catálogo de endereços)",
    "Also allow autocompletion on full match of the display name" : "Permitir também o preenchimento automático em caso de correspondência completa do nome de exibição",
    "Disclaimer text" : "Texto do aviso legal",
    "This text will be shown on the public link upload page when the file list is hidden." : "Este texto será exibido na página de carregamento de ligações públicas quando a lista de ficheiros estiver oculta. ",
    "Two-factor authentication can be enforced for all accounts and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "A autenticação de dois fatores pode ser aplicada a todas as contas e grupos específicos. Se eles não tiverem um provedor de dois fatores configurado, não conseguirão fazer login no sistema.",
    "Enforce two-factor authentication" : "Forçar o uso de autenticação de dois fatores",
    "Limit to groups" : "Limitado a grupos",
    "Enforced groups" : "Grupos obrigatórios",
    "When groups are selected/excluded, they use the following logic to determine if an account has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If an account is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Quando os grupos são selecionados/excluídos, eles usam a seguinte lógica para determinar se uma conta tem a 2FA aplicada: Se nenhum grupo for selecionado, a 2FA será habilitada para todos, exceto os membros dos grupos excluídos. Se grupos forem selecionados, a 2FA será habilitada para todos os membros deles. Se uma conta estiver em um grupo selecionado e excluído, o selecionado terá precedência e a 2FA será aplicada.",
    "Save changes" : "Guardar alterações",
    "Failed to load groups" : "Falha ao carregar grupos",
    "Failed to create group" : "Falha ao criar grupo",
    "List of groups. This list is not fully populated for performance reasons. The groups will be loaded as you navigate or search through the list." : "Lista de grupos. Essa lista não está totalmente preenchida por motivos de desempenho. Os grupos serão carregados quando você navegar ou pesquisar na lista.",
    "Groups" : "Grupos",
    "Create group" : "Criar grupo",
    "Group name" : "Nome do grupo",
    "Google Chrome for Android" : "Google Chrome para Android",
    "{productName} iOS app" : "Aplicativo {productName} para iOS",
    "{productName} Android app" : "{productName} Aplicação Android",
    "{productName} Talk for iOS" : "{productName} Talk para iOS",
    "Sync client" : "Sincronizar cliente",
    "This session" : "Esta sessão",
    "{client} - {version} ({system})" : "{client} - {version} ({system})",
    "{client} - {version}" : "{client} - {version}",
    "Confirm wipe" : "Confirmação de limpeza",
    "Do you really want to wipe your data from this device?" : "Tem a certeza que deseja apagar os dados deste dispositivo?",
    "Wipe device" : "Apagar dispositivo",
    "Cancel" : "Cancelar",
    "Cancel renaming" : "Cancelar renomeação",
    "Device settings" : "Definições de dispositivo",
    "Allow filesystem access" : "Permitir acesso ao sistema de ficheiros",
    "Rename" : "Renomear",
    "Revoke" : "Revogar",
    "Revoke and cancel pending wipe?" : "Revogar e cancelar o apagamento pendente?",
    "Only continue if you no longer need the device to be wiped." : "Só continue se você não precisar mais que o dispositivo seja apagado.",
    "Revoke and cancel wipe" : "Revogar e cancelar apagamento",
    "Revoke app password?" : "Revogar a senha do aplicativo?",
    "The app or device will lose access on its next sync. This cannot be undone." : "O aplicativo ou dispositivo perderá o acesso com a sua próxima sincronização. Isso não pode ser desfeito.",
    "Device" : "Dispositivo",
    "Last activity" : "Última atividade",
    "Actions" : "Ações",
    "Devices & sessions" : "Sessões e dispositivos",
    "Web, desktop and mobile clients currently logged in to your account." : "Os clientes da Web, de PC e móveis estão atualmente autenticados na sua conta.",
    "Error while creating device token" : "Erro durante a criação do token do dispositivo",
    "App name" : "Nome da aplicação",
    "Create new app password" : "Criar nova palavra-passe de aplicação",
    "App password copied!" : "Senha do aplicativo copiada!",
    "Copy app password" : "Copiar senha do aplicativo",
    "Login name copied!" : "Nome de login copiado!",
    "Copy login name" : "Copiar nome de login",
    "Could not copy app password. Please copy it manually." : "Não foi possível copiar a senha do aplicativo. Por favor, copie-a manualmente.",
    "Could not copy login name. Please copy it manually." : "Não foi possível copiar o nome de login. Por favor, copie-o manualmente.",
    "Use the credentials below to configure your app or device. For security reasons this password will only be shown once." : "Use as credenciais abaixo para configurar seu aplicativo ou dispositivo. Por motivos de segurança esta senha só será mostrada uma vez.",
    "Login" : "Iniciar Sessão",
    "Password" : "Palavra-passe",
    "Use system cron service to call the cron.php file every 5 minutes." : "Usar o serviço cron do sistema para chamar o arquivo cron.php a cada 5 minutos.",
    "The cron.php needs to be executed by the system account \"{user}\"." : "O cron.php precisa ser executado pela conta do sistema \"{user}\".",
    "The PHP POSIX extension is required. See {linkstart}PHP documentation{linkend} for more details." : "A extensão POSIX do PHP é obrigatória. Consulte a {linkstart}documentação do PHP{linkend} para obter mais detalhes.",
    "Unable to update background job mode" : "Não foi possível atualizar o modo de trabalho em segundo plano",
    "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information." : "Para que o servidor funcione corretamente, é importante configurar corretamente os trabalhos em segundo plano. Cron é a configuração recomendada. Consulte a documentação para obter maiores informações.",
    "Background job did not run yet!" : "O trabalho em segundo plano ainda não foi executado!",
    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 accounts depending on the usage)." : "cron.php é registrado em um serviço webcron para chamar cron.php a cada 5 minutos por HTTP. Caso de uso: Instância muito pequena (1–5 contas dependendo do uso).",
    "Cron (Recommended)" : "Cron (Recomendado)",
    "Unable to update profile default setting" : "Não foi possível atualizar a configuração padrão do perfil",
    "Profile" : "Perfil",
    "Enable the profile picker" : "Ativar o seletor de perfis",
    "Enable or disable the profile picker in the Smart Picker and the profile link previews." : "Ative ou desative o seletor de perfis no seletor inteligente e as pré-visualizações dos links dos perfis.",
    "Password confirmation is required" : "Confirmação de senha necessária",
    "Failed to save setting" : "Falha ao salvar a configuração",
    "Server-side encryption" : "Atualizar App",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "A cifra do lado do servidor possibilita cifrar os ficheiros que serão enviados para este servidor. Isto implica um impacto no desempenho e só deverá ser ativo quando necessário.",
    "To encrypt all existing files run this OCC command:" : "Para criptografar todos os arquivos existentes, execute este comando OCC:",
    "Enable server-side encryption" : "Ativar encriptação do lado do servidor",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Nenhum módulo de encriptação carregador, por favor ative um módulo de encriptação no menu das aplicações.",
    "Select default encryption module:" : "Selecionar o módulo de encriptação predefinido:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}" : "Você precisa migrar suas chaves de criptografia da criptografia antiga (ownCloud <= 8.0) para a nova. Ative o \"módulo de criptografia padrão\" e execute {command}",
    "Enable encryption" : "Ativar a encriptação",
    "Please read carefully before activating server-side encryption:" : "Leia atentamente antes de ativar a criptografia do lado do servidor:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Uma vez ativada a encriptação, todos os ficheiros carregados para o servidor a partir deste ponto serão encriptados pelo servidor. Só será possível desativar a encriptação numa data mais tarde se o módulo de encriptação ativo suportar essa função, assim como todas as pré-condições (e.g. definir chave de recuperação) sejam cumpridas.",
    "By default a master key for the whole instance will be generated. Please check if that level of access is compliant with your needs." : "Por padrão, será gerada uma chave mestra para toda a instância. Verifique se esse nível de acesso está de acordo com suas necessidades.",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "A cifra por si só não garante a segurança do sistema. Por favor consulte a documentação para mais detalhes sobre a aplicação de cifra e os casos de uso suportados.",
    "Be aware that encryption always increases the file size." : "Tenha em conta que a encriptação aumenta sempre o tamanho do ficheiro.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "É sempre bom criar cópias de segurança regulares dos seus dados, em caso de encriptação tenha a certeza de que faz cópia das chaves de encriptação em conjunto com os seus dados.",
    "This is the final warning: Do you really want to enable encryption?" : "Este é o aviso final: quer mesmo ativar a encriptação?",
    "Please confirm the group removal" : "Por favor confirme a remoção do grupo",
    "Confirm" : "Confirmar",
    "Submit" : "Submeter",
    "Rename group" : "Renomear grupo",
    "Delete group" : "Apagar grupo",
    "Current password" : "Palavra-passe atual",
    "New password" : "Nova palavra-passe",
    "Change password" : "Alterar senha",
    "Choose your profile picture" : "Escolher imagem de perfil",
    "Please select a valid png or jpg file" : "Escolha ficheiro png ou jpg válido",
    "Error setting profile picture" : "Erro a definir imagem de perfil",
    "Error cropping profile picture" : "Erro a cortar imagem de perfil",
    "Error saving profile picture" : "Erro a guardar imagem de perfil",
    "Error removing profile picture" : "Erro a remover imagem de perfil",
    "Your profile picture" : "Imagem de perfil",
    "Upload profile picture" : "Atualização de imagem de perfil",
    "Choose profile picture from Files" : "Escolher a imagem de perfil em Ficheiros",
    "Remove profile picture" : "Remover imagem de perfil",
    "The file must be a PNG or JPG" : "O arquivo deve ser um PNG ou JPG",
    "Picture provided by original account" : "Imagem fornecida pela conta original",
    "Set as profile picture" : "Definir como imagem de perfil",
    "Your biography. Markdown is supported." : "Sua biografia. Markdown é suportado.",
    "Unable to update date of birth" : "Não foi possível atualizar a data de nascimento",
    "Enter your date of birth" : "Digite sua data de nascimento",
    "You are using {s}{usage}{/s} of {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})" : "Você está usando {s}{usage}{/s} de {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})",
    "Details" : "Detalhes",
    "You are a member of the following groups:" : "Membro dos seguintes grupos:",
    "Your full name" : "Nome completo",
    "Unable to update primary email address" : "Não é possível atualizar o endereço de e-mail primário ",
    "No email address set" : "Nenhum endereço de email estabelecido",
    "Email options" : "Opções de correio eletrónico",
    "Options for additional email address {index}" : "Opções para endereço de e-mail adicional {index}",
    "Remove primary email" : "Remoção de correio eletrónico principal",
    "Delete email" : "Apagar correio eletrónico",
    "This address is not confirmed" : "Este endereço não foi confirmado",
    "Unset as primary email" : "Remove atribuição de correio eletrónico como principal",
    "Set as primary email" : "Definir como e-mail principal ",
    "Additional email address {index}" : "Endereço de e-mail adicional {index} ",
    "Unable to add additional email address" : "Não é possível adicionar um endereço de e-mail adicional",
    "Primary email for password reset and notifications" : "E-mail principal para redefinição de senha e notificações",
    "Derived from your locale ({weekDayName})" : "Derivado da sua configuração regional ({weekDayName})",
    "Unable to update first day of week" : "Não é possível atualizar o primeiro dia da semana",
    "Day to use as the first day of week" : "Dia a ser usado como o primeiro dia da semana",
    "No language set" : "Nenhum idioma definido",
    "Unable to update language" : "Não foi possível atualizar o idioma",
    "Help translate" : "Ajude a traduzir",
    "Unable to update locale" : "Não foi possível atualizar a configuração regional",
    "Week starts on {firstDayOfWeek}" : "Semana começa em {firstDayOfWeek}",
    "Your city" : "Sua cidade",
    "Your phone number" : "O seu número de telefone",
    "Edit your Profile visibility" : "Editar a visibilidade do seu Perfil",
    "Enable profile" : "Ativar perfil",
    "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "A configuração mais restritiva de visibilidade ou escopo é respeitada em seu perfil. Por exemplo, se a visibilidade for definida como \"Mostrar para todos\" e o escopo for definido como \"Privado\", \"Privado\" será respeitado.",
    "Unable to update visibility of {displayId}" : "Não é possível atualizar a visibilidade de {displayId}",
    "she/her" : "ela/dela",
    "he/him" : "ele/dele",
    "Your pronouns. E.g. {pronounsExample}" : "Seus pronomes. P. ex., {pronounsExample}",
    "Timezone" : "Fuso horário",
    "Your X (formerly Twitter) handle" : "Seu identificador X (anteriormente Twitter)",
    "Unable to update {property}" : "Não foi possível atualizar {property}",
    "No {property} set" : "Nenhum {property} definido",
    "Change scope level of {property}, current scope is {scope}" : "Alterar o nível de escopo de {property}, escopo atual é {scope}",
    "Unable to update federation scope of the primary {property}" : "Não é possível atualizar o escopo de federação do {property} primário",
    "Add" : "Adicionar",
    "Create" : "Criar",
    "Change" : "Mudar",
    "Delete" : "Eliminar",
    "Reshare" : "Partilhar novamente",
    "Default config values" : "Valores de configuração padrão",
    "Enabled applications" : "Aplicações ativadas",
    "Disabled applications" : "Aplicações desativadas",
    "Large organization" : "Organização muito grande",
    "Hosting company" : "Empresa de hospedagem",
    "University" : "Universidade",
    "School" : "Escola",
    "Club or association" : "Clube ou associação",
    "Family" : "Família",
    "Personal use" : "Uso pessoal",
    "Default" : "Predefinido",
    "Setup errors" : "Erros de instalação",
    "Setup warnings" : "Configurar avisos",
    "Setup recommendations" : "Recomendações de instalação",
    "Default language" : "Idioma padrão",
    "Other languages" : "Outros idiomas",
    "No accounts" : "Sem contas",
    "List of accounts. This list is not fully rendered for performance reasons. The accounts will be rendered as you navigate through the list." : "Lista de contas. Esta lista não foi totalmente renderizada por motivos de desempenho. As contas serão renderizadas quando você navegar pela lista.",
    "Account name" : "Nome da conta",
    "Account updated" : "Conta atualizada",
    "Edit account" : "Editar conta",
    "Saving …" : "A guardar ...",
    "Save" : "Guardar",
    "Account name will be autogenerated" : "O nome da conta será autogerado",
    "Account name (required)" : "Nome da conta (obrigatório)",
    "Email (required)" : "E-mail (obrigatório)",
    "Email" : "Email",
    "Add new account" : "Adicionar nova conta",
    "Display name" : "Nome a exibir",
    "Either password or email is required" : "É necessário ou e-mail ou senha",
    "Failed to search groups" : "Falha ao pesquisar grupos",
    "Set account groups" : "Definir grupos de contas",
    "Language" : "Idioma",
    "Manager" : "Gerente",
    "Search for a manager…" : "Pesquisar gerenciador…",
    "Quota" : "Quota",
    "_{userCount} account …_::_{userCount} accounts …_" : ["{userCount} conta …","{userCount} de contas …","{userCount} contas …"],
    "_{userCount} account_::_{userCount} accounts_" : ["{userCount} conta","{userCount} de contas","{userCount} contas"],
    "Total rows summary" : "Resumo do total de linhas",
    "Avatar" : "Avatar",
    "Group admin for" : "Administrador de grupo para",
    "Storage location" : "Localização do armazenamento",
    "First login" : "Primeiro login",
    "Last login" : "Último início de sessão",
    "Unknown" : "Desconhecido",
    "Never" : "Nunca",
    "{size} used" : "{size} utilizado",
    "Delete account" : "Remover conta",
    "Disable account" : "Desativar conta",
    "Enable account" : "Ativar conta",
    "Resend welcome email" : "Reenviar e-mail de boas-vindas",
    "In case of lost device or exiting the organization, this can remotely wipe the {productName} data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Em caso de perda do dispositivo ou saída da organização, isso pode apagar remotamente os dados do {productName} de todos os dispositivos associados a {userid}. Só funciona se os dispositivos estiverem conectados à Internet.",
    "Remote wipe of devices" : "Apagamento remoto de dispositivos",
    "Wipe {userid}'s devices" : "Apagar os dispositivos de {userid}",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "Excluir totalmente a conta de {userid}, incluindo todos os seus arquivos pessoais, dados de aplicativos, etc.",
    "Account deletion" : "Exclusão de conta",
    "Welcome mail sent!" : "E-mail de boas-vindas enviado!",
    "Loading account …" : "Carregando conta …",
    "Edit" : "Editar",
    "Visibility" : "Visibilidade",
    "Show account backend" : "Mostrar back-end da conta",
    "Show last login" : "Mostrar último início de sessão",
    "Sorting" : "Ordenação",
    "The system config enforces sorting the groups by name. This also disables showing the member count." : "A configuração do sistema impõe a ordenação dos grupos por nome. Isso também desabilita a exibição da contagem de membros.",
    "Sorting only applies to the currently loaded groups for performance reasons. Groups will be loaded as you navigate or search through the list." : "Por motivos de desempenho, a ordenação só se aplica aos grupos carregados no momento. Os grupos serão carregados quando você navegar ou pesquisar na lista.",
    "By name" : "Por nome",
    "Send email" : "Enviar email",
    "Default quota" : "Quota padrão",
    "Select default quota" : "Selecionar a cota padrão",
    "Search" : "Pesquisa sobre",
    "Help" : "Ajuda",
    "Show those shortcuts" : "Mostrar esses atalhos",
    "Server error while trying to complete WebAuthn device registration" : "Erro de servidor ao tentar concluir o registro do dispositivo WebAuthn",
    "Please authorize your WebAuthn device." : "Autorize seu dispositivo Webauthn.",
    "Passwordless Authentication" : "Autenticação sem senha",
    "The following devices are configured for your account:" : "Os seguintes dispositivos estão configurados para sua conta:",
    "Your browser does not support WebAuthn." : "Seu navegador não suporta WebAuthn.",
    "Failed to send email" : "Falha ao enviar o e-mail",
    "Failed to save email settings" : "Falha ao salvar as configurações de e-mail",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "É importante configurar este servidor para ser possível enviar emails, possibilitando enviar notificações bem como possibilitar a recuperação de senhas.",
    "Mail delivery is disabled by instance config \"{config}\"." : "A entrega de e-mails está desativada pela configuração da instância \"{config}\".",
    "Send mode" : "Modo de Envio",
    "Encryption" : "Encriptação",
    "Disable certificate verification (insecure)" : "Desativar a verificação do certificado (inseguro)",
    "From address" : "Do endereço",
    "Domain" : "Domínio",
    "Server address" : "Endereço do Servidor",
    "Host" : "Anfitrião",
    "Port" : "Porta",
    "Authentication" : "Autenticação",
    "Authentication required" : "Autenticação necessária",
    "Send test email" : "Enviar e-mail de teste",
    "Saving…" : "A guardar...",
    "Save settings" : "Salvar configurações",
    "Please double check the {linkStartInstallationGuides}installation guides{linkEnd}, and check for any errors or warnings in the {linkStartLog}log{linkEnd}." : "Por favor verifique novamente os\n{linkStartInstallationGuides}guias de instalação\n{linkEnd} e verifique se há erros ou avisos no \n{linkStartLog}registo{linkEnd}.",
    "Check the security of your {productName} over {linkStart}our security scan{linkEnd}." : "Verifique a segurança do seu {productName} através da {linkStart}nossa verificação de segurança{linkEnd}.",
    "Security & setup warnings" : "Avisos de configuração e segurança",
    "It is important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "É importante para a segurança e o desempenho da sua instância que tudo esteja configurado corretamente. Para ajudar você com isso, estamos realizando algumas verificações automáticas. Consulte a documentação vinculada para obter mais informações.",
    "Failed to run setup checks" : "Falha ao executar as verificações de configuração",
    "Try again" : "Tentar novamente",
    "All checks passed." : "Todas as verificações passaram.",
    "There are some warnings regarding your setup." : "Existem alguns avisos referentes à sua configuração.",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Como administrador pode afinar o comportamento de partilha. Por favor veja a documentação para mais informação.",
    "Failed to save selected preset." : "Falha ao salvar a predefinição selecionada.",
    "Select a configuration preset for easy setup." : "Selecione uma predefinição de configuração para facilitar a instalação.",
    "Apply" : "Aplicar",
    "Admins" : "Administrador",
    "Account management" : "Gerenciamento de contas",
    "Search accounts and groups…" : "Pesquisar contas e grupos…",
    "For performance reasons, when you enable encryption on a {productName} server only new and changed files are encrypted." : "Por motivos de desempenho, quando você habilita a criptografia em um servidor {productName}, apenas os arquivos novos e alterados são criptografados.",
    "Location" : "Localização",
    "Profile picture" : "Foto do perfil",
    "About" : "Sobre",
    "Date of birth" : "Data de nascimento",
    "Full name" : "Nome completo",
    "Additional email" : "E-mail adicional ",
    "Headline" : "Título ",
    "Organisation" : "Organização",
    "Phone number" : "Número de telefone",
    "Pronouns" : "Pronomes",
    "Role" : "Função",
    "Bluesky" : "Bluesky",
    "Website" : "Website",
    "Profile visibility" : "Visibilidade do perfil",
    "First day of week" : "Primeiro dia da semana",
    "timezone" : "fuso horário",
    "Private" : "Privado",
    "Only visible to people matched via phone number integration through Talk on mobile" : "Visível apenas a pessoas cujo acesso é realizado através de número de telefone, na app Talk em dispositivos móveis.",
    "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Não disponível porque esta propriedade é necessária para a funcionalidade principal, incluindo compartilhamento de arquivos e convites de calendário",
    "Local" : "Local",
    "Only visible to people on this instance and guests" : "Visível apenas a pessoas nesta instância e a convidados",
    "Federated" : "Federada",
    "Only synchronize to trusted servers" : "Apenas sincronizar em servidores confiáveis",
    "Not available as federation has been disabled for your account, contact your system administration if you have any questions" : "Não disponível porque a federação foi desativada para sua conta. Entre em contato com a administração do sistema se tiver alguma dúvida",
    "Published" : "Publicado",
    "Synchronize to trusted servers and the global and public address book" : "Sincronizar a servidor confiável e global e lista de endereço público",
    "Not available as publishing account specific data to the lookup server is not allowed, contact your system administration if you have any questions" : "Não disponível porque a publicação de dados específicos da conta no servidor de pesquisa não é permitida. Entre em contato com a administração do sistema se tiver alguma dúvida",
    "Discover" : "Descobrir",
    "Your apps" : "As suas apps",
    "Active apps" : "Aplicativos ativados",
    "Disabled apps" : "Apps desativadas",
    "Updates" : "Atualizações",
    "App bundles" : "Pacotes de apps",
    "Featured apps" : "Aplicações principais",
    "Supported apps" : "Aplicativos compatíveis",
    "Show to everyone" : "Mostrar para todos",
    "Show to logged in accounts only" : "Mostrar apenas para contas logadas",
    "Hide" : "Ocultar",
    "Could not register device: Network error" : "Não foi possível registrar o dispositivo: Erro de rede",
    "Could not delete the app token" : "Não foi possível excluir o token do aplicativo",
    "Error while wiping the device with the token" : "Erro ao apagar o dispositivo com o token",
    "Error while updating device token name" : "Erro ao atualizar o nome do token do dispositivo",
    "Error while updating device token scope" : "Erro ao atualizar o escopo do token do dispositivo",
    "An error occurred during the request. Unable to proceed." : "Ocorreu um erro durante a solicitação. Não é possível prosseguir.",
    "Could not set group sorting" : "Não foi possível definir a classificação de grupo",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Foram efetuados demasiados pedidos a partir da sua rede. Tente mais tarde ou contacte o administrador se for um erro.",
    "Error" : "Erro",
    "Administration documentation" : "Documentação de administração",
    "Documentation" : "Documentação",
    "Forum" : "Fórum",
    "General documentation" : "Documentação geral",
    "Legal notice" : "Informação legal",
    "Privacy policy" : "Política de privacidade",
    "Version" : "Versão",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Desenvolvido pela [communityopen]Comunidade Nextcloud[linkclose]. O [githubcode]código fonte[/linkclose] está licenciado sob [licenseopen]AGPL[linkclose].",
    "Like our Facebook page" : "Deixe um Gosto na nossa página do Facebook",
    "Follow us on Bluesky" : "Siga-nos no Bluesky",
    "Follow us on Mastodon" : "Siga-nos no Mastodon",
    "Check out our blog" : "Veja o nosso blog",
    "Subscribe to our newsletter" : "Subscreva as nossas notícias",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Este lançamento comunitário do Nextcloud não é compatível e as notificações instantâneas não estão disponíveis.",
    "Open documentation" : "Abrir documentação",
    "Use a second factor besides your password to increase security for your account." : "Use um segundo fator além de sua senha para aumentar a segurança da conta.",
    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Se usar aplicativos de terceiros para se conectar ao Nextcloud, certifique-se de criar e configurar uma senha para cada aplicativo antes de habilitar a autenticação em duas etapas.",
    "Very weak password" : "Palavra-passe muito fraca",
    "Weak password" : "Palavra-passe fraca",
    "So-so password" : "Palavra-passe aceitável",
    "Good password" : "Palavra-passe boa",
    "Strong password" : "Palavra-passe forte",
    "Group list is empty" : "Lista de grupo vazia",
    "Unable to retrieve the group list" : "Não foi possível recolher a lista de grupo",
    "Could not remove app." : "Não foi possível remover a aplicação",
    "Could not update app." : "Não foi possível atualizar a aplicação",
    "Apps" : "Apps",
    "for Argon2 for password hashing" : "para Argon2 para hashes de senhas",
    "MariaDB version 10.3 detected, this version is end-of-life and only supported as part of Ubuntu 20.04. MariaDB >=%1$s and <=%2$s is suggested for best performance, stability and functionality with this version of Nextcloud." : "Versão do MariaDB 10.3 detectada, esta versão é fim de vida e só suportada como parte do Ubuntu 20.04. MariaDB >=%1$s e <=%2$s é sugerido para melhor desempenho, estabilidade e funcionalidade com esta versão do Nextcloud.",
    "_Most tasks were successful in the last day._::_Most tasks were successful in the last %n days._" : ["A maioria das tarefas foi bem-sucedida no último dia.","A maioria das tarefas foi bem-sucedida nos últimos %n de dias.","A maioria das tarefas foi bem-sucedida nos últimos %n dias."],
    "_The Task Processing worker has run in the last minute._::_The Task Processing worker has run in the last %n minutes._" : ["O processador de tarefas foi executado no último minuto.","O processador de tarefas foi executado nos últimos %n de minutos.","O processador de tarefas foi executado nos últimos %n minutos."],
    "Machine translation" : "Traduções automáticas",
    "Image generation" : "Geração de imagens",
    "Limit sharing to some groups" : "Limitar o compartilhamento a alguns grupos",
    "Choose Deploy Daemon for {appName}" : "Escolha um Deploy Daemon para {appName}",
    "Registered Deploy daemons list" : "Lista de Deploy daemons registrados",
    "No Deploy daemons configured" : "Nenhum Deploy daemon configurado",
    "Register a custom one or setup from available templates" : "Registre um personalizado ou configure a partir dos modelos disponíveis",
    "Manage Deploy daemons" : "Gerenciar Deploy daemons",
    "Update to {update}" : "Atualizar para {update}",
    "Remove" : "Remover",
    "Featured" : "Destacado",
    "This app is supported via your current Nextcloud subscription." : "Este aplicativo é suportado por sua assinatura atual do Nextcloud.",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Os aplicativos em destaque são desenvolvidos pela comunidade. Eles oferecem funcionalidade central e estão prontos para uso em produção.",
    "Community rating: {score}/5" : "Avaliação da comunidade: {score}/5",
    "Disable all" : "Desativar todos",
    "Download and enable all" : "Transferir e ativar tudo",
    "All apps are up-to-date." : "Todas as aplicações estão atualizadas",
    "Icon" : "Ícone",
    "Name" : "Nome",
    "Level" : "Nível",
    "Results from other categories" : "Resultados de outras categorias",
    "No apps found for your version" : "Nenhuma aplicação encontrada para a sua versão",
    "_%n app has an update available_::_%n apps have an update available_" : ["%n aplicativo tem atualização disponível","%n de aplicativos tem atualização disponível","%n aplicativos tem atualização disponível"],
    "_Update_::_Update all_" : ["Atualizar","Atualizar todos","Atualizar todos"],
    "Could not load app discover section" : "Não foi possível carregar a seção de descoberta de aplicativos",
    "Could not render element" : "Não foi possível renderizar o elemento",
    "Nothing to show" : "Nada a mostrar",
    "Loading" : "A carregar",
    "Fetching the latest news…" : "Buscando as últimas notícias…",
    "Carousel" : "Carrossel",
    "Previous slide" : "Slide anterior",
    "Next slide" : "Próximo slide",
    "Choose slide to display" : "Escolher slide a ser exibido",
    "{index} of {total}" : "{index} de {total}",
    "Daemon" : "Daemon",
    "Deploy Daemon" : "Deploy daemon",
    "Type" : "Tipo",
    "Display Name" : "Nome de exibição",
    "GPUs support" : "Suporte a GPUs",
    "Compute device" : "Dispositivo de computação",
    "Advanced deploy options" : "Opções avançadas de implantação",
    "Edit ExApp deploy options before installation" : "Edite as opções de implantação do ExApp antes da instalação",
    "Configured ExApp deploy options. Can be set only during installation" : "Opções de implantação do ExApp configuradas. Podem ser definidas apenas durante a instalação",
    "Learn more" : "Conheça melhor",
    "Environment variables" : "Variáveis de ambiente",
    "ExApp container environment variables" : "Variáveis de ambiente do contêiner ExApp",
    "No environment variables defined" : "Nenhuma variável de ambiente definida",
    "Mounts" : "Montagens",
    "Define host folder mounts to bind to the ExApp container" : "Definir montagens de pastas no host para vincular ao contêiner do ExApp",
    "Must exist on the Deploy daemon host prior to installing the ExApp" : "Deve existir no host do Deploy daemon antes da instalação do ExApp",
    "Host path" : "Caminho no host",
    "Container path" : "Caminho no contêiner",
    "Read-only" : "Somente leitura",
    "Remove mount" : "Remover montagem",
    "New mount" : "Nova montagem",
    "Enter path to host folder" : "Digite o caminho para a pasta no host",
    "Toggle read-only mode" : "Alternar o modo somente leitura",
    "Confirm adding new mount" : "Confirmar adição da nova montagem",
    "Cancel adding mount" : "Cancelar a adição da montagem",
    "Add mount" : "Adicionar montagem",
    "ExApp container mounts" : "Montagens de contêiner ExApp",
    "No mounts defined" : "Nenhuma montagem definida",
    "Description" : "Descrição",
    "View in store" : "Ver na loja",
    "Visit website" : "Visitar o website",
    "Usage documentation" : "Documentação de utilização",
    "Admin documentation" : "Documentação de administrador",
    "Developer documentation" : "Documentação de programador",
    "All" : "Todos",
    "Limit app usage to groups" : "Limitar o uso do aplicativo a grupos",
    "No results" : "Sem resultados",
    "Update to {version}" : "Atualizar para {version}",
    "Deploy options" : "Opções de implantação",
    "Default Deploy daemon is not accessible" : "O Deploy daemon padrão não está acessível",
    "Delete data on remove" : "Excluir dados ao remover",
    "This app has no maximum {productName} version assigned. This will be an error in the future." : "Este aplicativo não tem uma versão máxima do {productName} atribuída. Isso será um erro no futuro.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Esta aplicação não pode ser instalada porque as seguintes dependências não podem ser realizadas:",
    "Latest updated" : "Última atualização",
    "Author" : "Autor",
    "Categories" : "Categorias",
    "Resources" : "Recursos",
    "Interact" : "Interagir",
    "Report a bug" : "Reportar um erro",
    "Request feature" : "Pedir funcionalidade",
    "Ask questions or discuss" : "Perguntar ou discutir",
    "Rate the app" : "Avalie o aplicativo",
    "Rate" : "Classificar",
    "Changelog" : "Registo de alterações",
    "Loading accounts …" : "A carregar contas ...",
    "_{userCount} account …_::_{userCount} accounts …_" : ["{userCount} conta …","{userCount} de contas …","{userCount} contas …"],
    "Failed to load groups with details" : "Falha ao carregar grupos com detalhes",
    "Failed to load sub admin groups with details" : "Falha ao carregar grupos de subadministradores com detalhes",
    "Display name was successfully changed" : "O nome de exibição foi alterado com sucesso",
    "Email can't be empty" : "O e-mail não pode estar vazio",
    "Email was successfully changed" : "O e-mail foi alterado com sucesso",
    "Loading account …" : "A carregar a conta ...",
    "Change display name" : "Alterar nome de exibição",
    "Set new password" : "Definir nova senha",
    "Set account as admin for" : "Definir conta como administrador para",
    "Done" : "Concluído",
    "Adding your device …" : "A adicionar o seu dispositivo ...",
    "App Store" : "Loja de aplicativos",
    "Loading app list" : "Carregando lista de aplicativos",
    "Loading categories" : "Carregando categorias",
    "Version {version}, {license}-licensed" : "Versão {version}, licenciada por {license}",
    "Version {version}" : "Versão {version}",
    "Sending…" : "A enviar...",
    "Email sent" : "Mensagem de correio eletrónico enviada",
    "Manually installed apps cannot be updated" : "Aplicativos instalados manualmente não podem ser atualizados",
    "{progress}% Deploying …" : "{progress}% Implantando …",
    "{progress}% Initializing …" : "{progress}% Inicializando …",
    "Deploy and Enable" : "Implantar e Ativar",
    "Download and enable" : "Transferir e ativar",
    "Disable" : "Desativar",
    "Allow untested app" : "Permitir aplicativo não testado",
    "The app will be downloaded from the App Store" : "A aplicação será transferida da App Store",
    "This app is not marked as compatible with your {productName} version." : "Este aplicativo não é marcado como compatível com sua versão {productName}.",
    "If you continue you will still be able to install the app. Note that the app might not work as expected." : "Se continuar, ainda poderá instalar o aplicativo. Observe que o aplicativo pode não funcionar como esperado.",
    "The app has been enabled but needs to be updated." : "O aplicativo foi ativado, mas precisa ser atualizado.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Erro: Este aplicativo não pode ser ativado porque torna o servidor instável.",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "A aplicação foi ativada mas necessita ser atualizada. Irá ser redirecionado para a página de atualização em 5 segundos.",
    "SSL" : "SSL",
    "Credentials" : "Credenciais",
    "SMTP Login" : "Login SMTP",
    "SMTP Password" : "Palavra-passe SMTP",
    "Test and verify email settings" : "Testar e verificar as definições de e-mail",
    "Office suite switching is managed through the Nextcloud All-in-One interface." : "A troca de pacotes de escritório é gerenciada através da interface Nextcloud All-in-One.",
    "Please use the AIO interface to switch between office suites." : "Por favor, utilize a interface AIO para alternar entre as suítes de escritório.",
    "Select your preferred office suite. Please note that installing requires manual server setup." : "Selecione a sua suíte de escritório preferida. Observe que a instalação requer configuração manual do servidor.",
    "installed" : "instalado",
    "Disable office suites" : "Desativar pacotes de escritório",
    "Best Nextcloud integration" : "Melhor integração com o Nextcloud",
    "Open source" : "Código aberto",
    "Good performance" : "Bom desempenho",
    "Best security: documents never leave your server" : "Melhor segurança: os documentos nunca saem do seu servidor",
    "Best ODF compatibility" : "Melhor compatibilidade com ODF",
    "Best support for legacy files" : "Melhor suporte para arquivos antigos",
    "Good Nextcloud integration" : "Boa integração com o Nextcloud",
    "Open core" : "Núcleo aberto",
    "Best performance" : "Melhor desempenho",
    "Limited ODF compatibility" : "Compatibilidade limitada com ODF",
    "Best Microsoft compatibility" : "Melhor compatibilidade com a Microsoft",
    "{progress}% Initializing …" : "{progress}% Inicializando …"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
