OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "Неисправан ИД Здруженог облака",
    "Server to server sharing is not enabled on this server" : "Сервер-сервер дељење није подржано на овом серверу",
    "Couldn't establish a federated share." : "Не могу да успоставим здружено дељење.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Не могу да успоставим здружено дељење, можда лозинка не ваља.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Послат захтев за здружено дељење, добићете позивницу. Проверавајте обавештења.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Не могу да успоставим здружено дељење, изгледа да је сервер са којим се треба здружити превише стар (Некстклауд верзија <=9).",
    "It is not allowed to send federated group shares from this server." : "Са овог сервера није дозвољено да шаљете групна дељења ка здруженим серверима.",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "Дељење %1$s није успело зато што се ова ставка већ дели са налогом %2$s",
    "Not allowed to create a federated share to the same account" : "Није дозвољено да се направи федерисано дељење са истим налогом",
    "Federated shares require read permissions" : "Федерисано дељење захтева дозволу за читање",
    "File is already shared with %s" : "Фајл је већ дељен са %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Дељење %1$s није успело, не могу да нађем %2$s, можда сервер тренутно није доступан или користи самопотписани сертификат.",
    "Could not find share" : "Не могу да пронађем дељење",
    "Federated sharing" : "Здружено дељење",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Примили сте {share} као удаљено дељење од {user} (у име {behalf})",
    "You received {share} as a remote share from {user}" : "Примили сте {share} као удаљено дељење од {user}",
    "Accept" : "Прихвати",
    "Decline" : "Одбиј",
    "Federated Cloud Sharing" : "Здружено дељење у облаку",
    "Sharing" : "Дељење",
    "Federated file sharing" : "Здружено дељење фајлова",
    "Provide federated file sharing across servers" : "Пружа здружено дељење фајлова између сервера",
    "Confirm data upload to lookup server" : "Потврди отпремање података на сервер претраге",
    "When enabled, all account properties (e.g. email address) with scope visibility set to \"published\", will be automatically synced and transmitted to an external system and made available in a public, global address book." : "Када је укључено, све особине налога (нпр. и-мејл адреса) са опсегом видљивости постављеним на „објављено” ће се аутоматски синхронизовати, послати на спољни систем и постати доступне у јавном, глобалном адресару.",
    "Enable data upload" : "Укључи отпремање података",
    "Disable upload" : "Искључи отпремање",
    "Confirm querying lookup server" : "Потврди упитивање сервера претраге",
    "When enabled, the search input when creating shares will be sent to an external system that provides a public and global address book." : "Када је укључено, унос претраге приликом креирања дељења ће се послати на спољни систем који обезбеђује јавни и глобални адресар.",
    "This is used to retrieve the federated cloud ID to make federated sharing easier." : "Ово се користи за добављање ID здруженог облака и олакшавање здружених дељења.",
    "Moreover, email addresses of users might be sent to that system in order to verify them." : "Уз то, и-мејл адресе корисника би могле да се шаљу на тај систем да би се потврдиле.",
    "Enable querying" : "Укључи упитивање",
    "Disable querying" : "Искључи упитивање",
    "Unable to update federated files sharing config" : "Конфигурација федерисаног дељења фајлова није могла да се ажурира",
    "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "Подесите како људи могу да деле између сервера. То укључује и дељење између људи на овом серверу ако користе федерисано дељење.",
    "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Дозволи да људи са овог сервера шаљу дељења на друге сервере (ова опција такође дозвољава WebDAV приступ јавним дељењима)",
    "Allow people on this server to receive shares from other servers" : "Дозволи да људи на овом серверу примају дељења са других сервера",
    "Allow people on this server to send shares to groups on other servers" : "Дозволи људима на овом серверу да деле са групама на другим серверима",
    "Allow people on this server to receive group shares from other servers" : "Дозволи да људи на овом серверу примају групна дељења са других сервера",
    "The lookup server is only available for global scale." : "Сервер претраге је доступан само за глобални ниво.",
    "Search global and public address book for people" : "Људе тражи и у глобалним и у јавним адресарима",
    "Allow people to publish their data to a global and public address book" : "Дозволи да људи објаве своје податке у јавне и глобалне адресаре",
    "Trusted federation" : "Здуживање од поверења",
    "Automatically accept shares from trusted federated accounts and groups by default" : "Аутоматско подразумевано прихватање дељења са здружених налога којима се верује и група",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Делите самном помоћу мог #Nextcloud Federated Cloud ID, погледајте {url}",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Дели са мном преко мог #Некстклауд Здруженог облака",
    "Share with me via Nextcloud" : "Дели са мном преко Некстклауда",
    "Cloud ID copied" : "Копиран је ID облака",
    "Copy" : "Копирај",
    "Clipboard not available. Please copy the cloud ID manually." : "Клипборд није доступан. Молимо вас да ручно копирате ID облака.",
    "Copied!" : "Копирано!",
    "Federated Cloud" : "Здружени облак",
    "You can share with anyone who uses a {productName} server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Можете делите ствари са било ким ко користи {productName} сервер или неки други Open Cloud Mesh (OCM) компатибилни сервер и сервисе! Само унесите ИД из њиховог Здруженог Облака у дијалог за дељење. Тај ИД изгледа нешто попут person@cloud.example.com",
    "Your Federated Cloud ID" : "Ваш ИД Здруженог облака",
    "Share it so your friends can share files with you:" : "Поделите да би Ваши пријатељи могли да деле са Вама:",
    "Bluesky" : "Bluesky",
    "Facebook" : "Фејсбук",
    "Mastodon" : "Mastodon",
    "Add to your website" : "Додај на свој веб сајт",
    "Share with me via {productName}" : "Дели са мном преко {productName}",
    "HTML Code:" : "ХТМЛ кôд:",
    "Cancel" : "Одустани",
    "Add remote share" : "Додај удаљено дељење",
    "Remote share" : "Удаљено дељење",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Да ли желите да додате удаљено дељење {name} од {owner}@{remote}?",
    "Remote share password" : "Лозинка удаљеног дељења",
    "Incoming share could not be processed" : "Долазеће дељење не може да се обради",
    "X (formerly Twitter)" : "X (бивши Twitter)",
    "formerly Twitter" : "бивши Twitter"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
