OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Meðferð persónuupplýsinga",
    "-" : "-",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "Síðan um meðferð persónuupplýsinga sýnir hvar gögnin þín eru geymd og hverjir hafi aðgang að þeim, annað hvort vegna þess að þú deildir þeim eða vegna þess að viðkomandi er kerfisstjórnandi.",
    "Error loading additional administrator." : "Villa við að hlaða inn viðbótarstjórnanda.",
    "Error adding new administrator." : "Villa við að bæta við nýjum stjórnanda.",
    "Error deleting new administrator." : "Villa við að eyða nýjum stjórnanda.",
    "Administrators" : "Stjórnendur",
    "The following accounts are designated administrators and may potentially have access to your data through system storage or backups. However, they do not have easy access to your data via the web interface or client applications." : "Eftirfarandi aðgangar eru sérstakir stjórnunaraðgangar og gætu haft aðgang að gögnunum þínum í gegnum kerfisgeymslur eða öryggisafrit. Aftur á móti eru þeir ekki með auðveldan aðgang að gögnunum þínum í gegnum vefviðmótið eða biðlaraforrit.",
    "Loading administrators …" : "Hleð inn stjórnendum …",
    "Remove external {propertyName} admin" : "Fjarlægja utanaðkomandi {propertyName} stjórnanda",
    "Add external admin" : "Bæta við utanaðkomandi stjórnanda",
    "Cancel" : "Hætta við",
    "Add" : "Bæta við",
    "Name of external admin" : "Nafn utanaðkomandi stjórnanda",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key. It means that administrators can access your files, but not read their content." : "Heimageymslan þín er dulritaðuð með {linkopen}dulritun á þjóni ↗{linkclose} með aðal-dulritunarlykli. Það þýðir að kerfisstjórar hafa mögulegan aðgang að skránum þínum en ekki lesið innihald þeirra.",
    "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key based on their configuration." : "Skrárnar þínar á útværum gagnageymslum geta verið dulritaðar með {linkopen}dulritun á þjónum ↗{linkclose} með aðal-dulritunarlykli sem byggist á uppsetningu þeirra.",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual user key. It means that administrators can access your files, but not read their content." : "Heimageymslan þín er dulritaðuð með {linkopen}dulritun á þjóni ↗{linkclose} með einstaklings-dulritunarlykli. Það þýðir að kerfisstjórar hafa mögulegan aðgang að skránum þínum en ekki lesið innihald þeirra.",
    "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual key based on their configuration." : "Skrárnar þínar á útværum gagnageymslum geta verið dulritaðar með {linkopen}dulritun á þjónum ↗{linkclose} með eintökum dulritunarlykli sem byggist á uppsetningu þeirra.",
    "Additionally, this server is protected with full-disk-encryption." : "Að auki er þessi þjónn varinn með fullri dulritun diska.",
    "This server is protected with full-disk-encryption." : "Þessi þjónn er varinn með fullri dulritun diska.",
    "Your files are not protected by encryption." : "Skrárnar þínar eru ekki varðar með dulritun.",
    "Error saving new state of full-disk-encryption" : "Villa við vistun nýrrar stöðu á fullri dulritun disks",
    "Encryption" : "Dulritun",
    "Edit encryption" : "Breyta dulritun",
    "Edit" : "Breyta",
    "This server is using full-disk-encryption." : "Þessi þjónn er að nota fulla dulritun diska.",
    "Privacy policy" : "Meðferð persónulegra gagna",
    "Read the privacy policy ↗" : "Lestu stefnu varðandi meðferð persónulegra gagna ↗",
    "Error loading information about shares." : "Villa við að hlaða inn upplýsingum um sameignir.",
    "People you've shared with" : "Fólk sem þú hefur deilt með",
    "Loading people you've shared with …" : "Hleð inn fólki sem þú hefur deilt með …",
    "You do not have any shares with individual users." : "Þú ert ekki með neinar sameignir með einstökum notendum.",
    "Your {serverName} account" : "{serverName}-aðgangurinn þinn",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Gögnin þín standa fyrir það sem þú ert og er því miður auðvelt að misnota þau. Við sem stöndum að Nextcloud trúum því að þú hafir rétt til að ákveða hvað verður um gögnin þín. Nextcloud mun verja réttindi þín eins og þau eru skilgreind í yfirlýsingu um notandagögn!",
    "Who has access to your data?" : "Hver hefur aðgang að gögnunum þínum?",
    "Error saving new location of the server" : "Villa við að vista nýja staðsetningu á netþjóninum",
    "Where is your data?" : "Hvar eru gögnin þín?",
    "Your data is located in:" : "Gögnin þín eru geymd í: ",
    "An admin has not selected the location of the server yet." : "Kerfisstjóri er ekki ennþá búinn að velja staðsetningu þjónsins.",
    "Change data location" : "Breyta staðsetningu gagna",
    "Region" : "Svæði",
    "Please select a region" : "Veldu svæði",
    "{bold}Control{/bold} over user data access" : "{bold}Stýrðu{/bold} aðgangi að notendagögnum",
    "{bold}Knowledge{/bold} of how the data is stored" : "{bold}Þekktu{/bold} hvernig gögnin eru geymd",
    "{bold}Freedom{/bold} to choose a platform" : "{bold}Hafðu frelsi{/bold} til að velja kerfi",
    "User Data Manifesto 2.0" : "Yfirlýsing vegna notandagagna 2.0",
    "Defining basic rights for people to control their own data in the internet age." : "Skilgreinir grunnréttindi notenda til að stýra sínum eigin gögnum á internetinu.",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Gögn sem notandinn sendir inn af fúsum og frjálsum vilja eiga að vera undir endanlegri stjórn notandans. Notendur eiga að geta ákveðið sjálfir hverjum þeir veita beinan aðgang að eigin gögnum og með hvaða heimildum eða notkunarleyfum slíkur aðgangur er veittur.",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Þegar gögn eru send inn til tiltekins þjónustuaðila, ættu notendur að vera upplýstir um hvar sá þjónustuaðili geymir gögnin, hve lengi, í hvaða lögsagnarumdæmi þjónustuaðilinn starfar og undir hvaða lög starfsemin fellur.",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Notendur ættu ávallt að geta náð í gögnin sín frá viðkomandi þjónustu, hvenær sem er og án skilyrða af hálfu þjónustuaðilans. Opnir staðlar fyrir skráasnið og samskiptamáta eru grunnurinn til að tryggja það.",
    "Learn more ↗" : "Kanna nánar ↗",
    "Somaliland" : "Sómalíland",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "Sameinuðu arabísku furstadæmin",
    "Afghanistan" : "Afganistan",
    "Antigua and Barbuda" : "Antígva og Barbúda",
    "Anguilla" : "Anguilla",
    "Albania" : "Albanía",
    "Armenia" : "Armenía",
    "Angola" : "Angóla",
    "Antarctica" : "Suðurskautslandið",
    "Argentina" : "Argentína",
    "American Samoa" : "Bandarísku Samóaeyjar",
    "Austria" : "Austurríki",
    "Australia" : "Ástralía",
    "Aruba" : "Arúba",
    "Åland Islands" : "Álandseyjar",
    "Azerbaijan" : "Aserbaídsjan",
    "Bosnia and Herzegovina" : "Bosnía og Herzegónía",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladess",
    "Belgium" : "Belgía",
    "Burkina Faso" : "Búrkína Fasó",
    "Bulgaria" : "Búlgaría",
    "Bahrain" : "Barein",
    "Burundi" : "Búrúndí",
    "Benin" : "Benín",
    "Saint Barthélemy" : "Saint Barthélemy",
    "Bermuda" : "Bermúda",
    "Brunei" : "Brúnei",
    "Bolivia" : "Bólivía",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sankti Eustatius og Saba",
    "Brazil" : "Brasilía",
    "Bahamas" : "Bahamaeyjar",
    "Bhutan" : "Bútan",
    "Bouvet Island" : "Bouvet eyja",
    "Botswana" : "Botsvana",
    "Belarus" : "Hvíta-Rússland",
    "Belize" : "Belís",
    "Canada" : "Kanada",
    "Cocos (Keeling) Islands" : "Kókoseyjar",
    "Democratic Republic of the Congo" : "Alþýðulýðveldið Kongó",
    "Central African Republic" : "Mið-Afríkulýðveldið",
    "Congo" : "Kongó",
    "Switzerland" : "Sviss",
    "Cote d'Ivoire" : "Fílabeinsströndin",
    "Cook Islands" : "Cook-eyjar",
    "Chile" : "Síle",
    "Cameroon" : "Kamerún",
    "China" : "Kína",
    "Colombia" : "Kólumbía",
    "Costa Rica" : "Kosta Ríka",
    "Cuba" : "Kúba",
    "Cabo Verde" : "Grænhöfðaeyjar",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Jólaey",
    "Cyprus" : "Kýpur",
    "Czech" : "Tékkland",
    "Germany" : "Þýskaland",
    "Djibouti" : "Djíbútí",
    "Denmark" : "Danmörk",
    "Dominican Republic" : "Dóminíkanska lýðveldið",
    "Algeria" : "Alsír",
    "Ecuador" : "Ekvador",
    "Estonia" : "Eistland",
    "Egypt" : "Egyptaland",
    "West Sahara" : "Vestur-Sahara",
    "Eritrea" : "Erítrea",
    "Spain" : "Spánn",
    "Ethiopia" : "Eþíópía",
    "Finland" : "Finnland",
    "Fiji" : "Fídjieyjar",
    "Falkland Islands" : "Falklandseyjar",
    "Micronesia" : "Míkrónesía",
    "Faroe Islands" : "Færeyjar",
    "France" : "Frakkland",
    "Gabon" : "Gabon",
    "United Kingdom" : "Bretland",
    "Grenada" : "Grenada",
    "Georgia" : "Georgía",
    "French Guiana" : "Franska Gvæjana",
    "Guernsey" : "Guernsey",
    "Ghana" : "Gana",
    "Gibraltar" : "Gíbraltar",
    "Greenland" : "Grænland",
    "Gambia" : "Gambía",
    "Guinea" : "Gínea",
    "Guadeloupe" : "Gvadelúpeyjar",
    "Equatorial Guinea" : "Miðbaugs-Gínea",
    "Greece" : "Grikkland",
    "South Georgia and the South Sandwich Islands" : "Suður-Georgía og Suður-Sandwich eyjar",
    "Guatemala" : "Gvatemala",
    "Guam" : "Gvam",
    "Guinea-Bissau" : "Gínea-Bissá",
    "Guyana" : "Gvæjana",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Heard-eyja og McDonald-eyjur",
    "Honduras" : "Hondúras",
    "Croatia" : "Króatía",
    "Haiti" : "Haítí",
    "Hungary" : "Ungverjaland",
    "Indonesia" : "Indónesía",
    "Ireland" : "Írland",
    "Israel" : "Ísrael",
    "Isle of Man" : "Mön",
    "India" : "Indland",
    "British Indian Ocean Territory" : "Bresku Indlandshafseyjar",
    "Iraq" : "Írak",
    "Iran" : "Íran",
    "Iceland" : "Ísland",
    "Italy" : "Ítalía",
    "Jamaica" : "Jamaíka",
    "Jordan" : "Jórdanía",
    "Japan" : "Japan",
    "Kenya" : "Kenía",
    "Kyrgyzstan" : "Kirgisistan",
    "Cambodia" : "Kambódía",
    "Kiribati" : "Kíribatí",
    "Comores" : "Kómorró-eyjar",
    "Saint Kitts and Nevis" : "Sankti Kitts og Neviseyjur",
    "North Korea" : "Norður-Kórea",
    "South Korea" : "Suður-Kórea",
    "Kuwait" : "Kúveit",
    "Cayman Islands" : "Cayman-eyjar",
    "Kazakhstan" : "Kasakstan",
    "Laos" : "Laos",
    "Lebanon" : "Líbanon",
    "Saint Lucia" : "Sankti Lúsía",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Srí Lanka",
    "Liberia" : "Líbería",
    "Lesotho" : "Lesótó",
    "Lithuania" : "Litháen",
    "Luxembourg" : "Lúxemborg",
    "Latvia" : "Lettland",
    "Libya" : "Líbía",
    "Morocco" : "Marokkó",
    "Monaco" : "Mónakó",
    "Moldova" : "Moldóvía",
    "Montenegro" : "Svartfjallaland",
    "Saint Martin" : "Sankti Martin",
    "Madagascar" : "Madagaskar",
    "Marshall Islands" : "Marshall eyjar",
    "Macedonia" : "Makedónía",
    "Mali" : "Malí",
    "Myanmar" : "Mjanmar",
    "Mongolia" : "Mongólía",
    "Macao" : "Makaó",
    "Northern Mariana Islands" : "Norður Maríanaeyjar",
    "Mauritania" : "Máritanía",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Máritus",
    "Maldives" : "Maldíveyjar",
    "Malawi" : "Malaví",
    "Mexico" : "Mexíkó",
    "Malaysia" : "Malasía",
    "Mozambique" : "Mósambík",
    "Namibia" : "Namibía",
    "New Caledonia" : "Nýja-Kaledónía",
    "Niger" : "Níger",
    "Norfolk Island" : "Norfolkeyja",
    "Nigeria" : "Nígería",
    "Nicaragua" : "Nígarakúa",
    "Netherlands" : "Holland",
    "Norway" : "Noregur",
    "Nepal" : "Nepal",
    "Nauru" : "Nárú",
    "Niue" : "Niue",
    "New Zealand" : "Nýja-Sjáland",
    "Oman" : "Óman",
    "Panama" : "Panama",
    "Peru" : "Perú",
    "French Polynesia" : "Franska Pólýnesía",
    "Papua New Guinea" : "Papúa Nýja-Gínea",
    "Philippines" : "Filippseyjar",
    "Pakistan" : "Pakistan",
    "Poland" : "Pólland",
    "Saint Pierre and Miquelon" : "Sankti Pierre og Miquelon",
    "Pitcairn" : "Pitcairn",
    "Puerto Rico" : "Puerto Ríko",
    "Palestine" : "Palestína",
    "Portugal" : "Portúgal",
    "Palau" : "Palá",
    "Paraguay" : "Paragvæ",
    "Qatar" : "Katar",
    "Réunion" : "Réunion",
    "Romania" : "Rúmenía",
    "Serbia" : "Serbía",
    "Russia" : "Rússland",
    "Rwanda" : "Rúanda",
    "Saudi Arabia" : "Sádí-Arabía",
    "Solomon Islands" : "Salómonseyjar",
    "Seychelles" : "Seychelles-eyjar",
    "Sudan" : "Súdan",
    "Sweden" : "Svíþjóð",
    "Singapore" : "Singapúr",
    "Saint Helena, Ascension and Tristan da Cunha" : "Sankti Helena, Ascension og Tristan da Cunha",
    "Slovenia" : "Slóvenía",
    "Svalbard and Jan Mayen" : "Svalbarði og Jan Mayen",
    "Slovakia" : "Slóvakía",
    "Sierra Leone" : "Síerra Leóne",
    "San Marino" : "San Marínó",
    "Senegal" : "Senegal",
    "Somalia" : "Sómalía",
    "Suriname" : "Súrínam",
    "South Sudan" : "Suður-Súdan",
    "Sao Tome and Principe" : "Saó Tóme og Prinsípe",
    "El Salvador" : "El Salvador",
    "Sint Maarten" : "Sankti Maarten",
    "Syria" : "Sýrland",
    "Swaziland" : "Svasíland",
    "Turks and Caicos Islands" : "Turks og Kaikós eyjar",
    "Chad" : "Tsjad",
    "Fr. S. Antarctic Lands" : "Frönsku suðurhafs- og suðurskautslandssvæðin",
    "Togo" : "Tógó",
    "Thailand" : "Tæland",
    "Tajikistan" : "Tadsjikistan",
    "Tokelau" : "Tókelá",
    "Timor-Leste" : "Tímor-Leste",
    "Turkmenistan" : "Túrkmenistan",
    "Tunisia" : "Túnis",
    "Tonga" : "Tonga",
    "Turkey" : "Tyrkland",
    "Trinidad and Tobago" : "Trínidad og Tóbagó",
    "Tuvalu" : "Túvalú",
    "Taiwan" : "Tævan",
    "Tanzania" : "Tansanía",
    "Ukraine" : "Úkraína",
    "Uganda" : "Úganda",
    "United States Minor Outlying Islands" : "Ytri-smáeyjar Bandaríkjanna",
    "United States" : "Bandaríkin",
    "Uruguay" : "Úrúgvæ",
    "Uzbekistan" : "Úsbekistan",
    "Holy See" : "Vatíkanska borgríkið (Holy See)",
    "Saint Vincent and the Grenadines" : "Sankti Vincent og Grenadín",
    "Venezuela" : "Venesúela",
    "Virgin Islands (British)" : "Bresku Jómfrúareyjar",
    "Virgin Islands (U.S.)" : "Bandarísku Jómfrúareyjar",
    "Vietnam" : "Víetnam",
    "Vanuatu" : "Vanuatú",
    "Wallis and Futuna" : "Wallis- og Fútúnaeyjar",
    "Samoa" : "Samóa",
    "Yemen" : "Jemen",
    "Mayotte" : "Mayotte",
    "South Africa" : "Suður-Afríka",
    "Zambia" : "Sambía",
    "Zimbabwe" : "Simbabve",
    "Loading administrators …" : "Hleð inn stjórnendum …",
    "Loading people you've shared with …" : "Hleð inn fólki sem þú hefur deilt með",
    "Control" : "Stjórnun",
    "over user data access" : "aðgangs að notendagögnum",
    "Knowledge" : "Þekking",
    "of how the data is stored" : "á því hvernig gögnin eru geymd",
    "Freedom" : "Frelsi",
    "to choose a platform" : "til að velja sér kerfi"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
