OC.L10N.register(
    "photos",
    {
    "Public link" : "קישור ציבורי",
    "Photos" : "תמונות",
    "Your memories under your control" : "הזכרונות שלך בשליטתך",
    "All media" : "כל המדיה",
    "Videos" : "סרטונים",
    "Albums" : "אלבומים",
    "Collaborative albums" : "אלבומים משותפים",
    "Folders" : "תיקייה",
    "Favorites" : "מועדפים",
    "On this day" : "בתאריך זה",
    "Shared with you" : "משותף אתך",
    "Tags" : "תגיות",
    "Places" : "מקומות",
    "Map" : "מפה",
    "Mark selection as favorite" : "סמן בחירה כ'מועדפים'",
    "Add selection to favorites" : "הוסף בחירה למועדפים",
    "Remove selection from favorites" : "הסר בחירה ממועדפים",
    "Name of the album" : "שם האלבום",
    "Location of the album" : "מיקום גיאוגראפי של האלבום",
    "Back" : "חזרה",
    "Add collaborators" : "הוספת שותפים",
    "Save" : "שמירה",
    "Create album" : "יצירת אלבום",
    "Add to Album" : "הוספה לאלבום",
    "Add selection to album {albumName}" : "הוספת בחירה לאלבום {albumName}",
    "Shared by" : "שותף על ידי",
    "Create a new album." : "צור אלבום חדש.",
    "Create new album" : "צור אלבום",
    "New album" : "אלבום חדש",
    "Failed to fetch collaborators list." : "טעינת רשימת השותפים כשלה",
    "Failed to update album." : "עדכון האלבום נכשל",
    "Add people or groups who can edit your album" : "הוספת משתמשים וקבוצות שיכולו לערוך אלבום זה",
    "Search people or groups" : "חפש משתמשים או קבוצות",
    "No recommendations. Start typing." : "אין המלצות. נא להתחיל להקליד.",
    "Copy the public link" : "העתקת קישור ציבורי",
    "Public link copied!" : "קישור ציבורי הועתק!",
    "Copy public link" : "העתקת הקישור הציבורי",
    "Delete the public link" : "מחיקת קישור ציבורי",
    "Create public link share" : "יצירת קישור ציבורי לשיתוף",
    "Share via public link" : "שתף באמצעות קישור ציבורי",
    "This collection does not exist" : "אוסף זה לא קיים",
    "An error occurred" : "אירעה שגיאה",
    "No picture for this day" : "אין תמונות מיום זה",
    "Picture taken on this day will show up here." : "תמונות שצולמו ביום זה יופיעו כאן.",
    "More photos from this day" : "תמונות נוספות מיום זה",
    "Favorite" : "סימון כמועדף",
    "Favorite image, open the full size \"{name}\" image" : "תמונה ממועדפים, פתח את התמונה \"{name}\" בגודל מלא",
    "Open the full size \"{name}\" image" : "לפתוח את התמונה „{name}” בגודל מלא",
    "Select image {imageName}" : "לבחור את התמונה {imageName}",
    "Open the \"{name}\" folder" : "לפתוח את התיקייה \"{name}\"",
    "Go back" : "חזרה",
    "Dates" : "תאריכים",
    "Jump to specific date in list" : "לקפוץ ליום מסויים ברשימה",
    "Jump to {date}" : "לקפוץ ל{date}",
    "Add to {destination}" : "הוספה ל{destination}",
    "There are no photos or videos yet!" : "אין עדיין תמונות וקטעי ווידאו",
    "All folders" : "כל התיקיות",
    "Add folder" : "הוספת תיקייה",
    "Home" : "בית",
    "General" : "כללי",
    "Remove from favorites" : "הסרה מהמועדפים",
    "Loading folders…" : "התיקיות נטענות…",
    "No photos in here" : "אין כאן תמונות",
    "No tags yet" : "אין תגיות עדיין",
    "Photos with tags will show up here" : "תמונות עם תגיות תמיד תופענה כאן",
    "Delete selection" : "מחיקת בחירה",
    "All your media" : "כל המדיה שלך",
    "Shared Albums" : "אלבומים משותפים",
    "Tagged photos" : "תמונות מתויגות",
    "Last week" : "שבוע שעבר",
    "Group" : "קבוצה",
    "Remove {collaboratorLabel} from the collaborators list" : "הסר את {collaboratorLabel} מרשימת השותפים",
    "Enable squared photos view" : "הפעלת תצוגת תמונות מרובעות",
    "View" : "צפייה",
    "Details" : "פרטים",
    "Cancel" : "Cancel",
    "Confirm" : "אישור"
},
"nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
