OC.L10N.register(
    "provisioning_api",
    {
    "Logged in account must be an administrator or have authorization to edit this setting." : "Pålogget konto må være administrator eller ha autorisasjon til å redigere denne innstillingen.",
    "Could not create non-existing user ID" : "Kunne ikke opprette ikke-eksisterende bruker-ID",
    "User already exists" : "Brukeren eksisterer allerede",
    "Group %1$s does not exist" : "Gruppe %1$s finnes ikke",
    "Insufficient privileges for group %1$s" : "Utilstrekkelige privilegier for gruppe %1$s",
    "No group specified (required for sub-admins)" : "Ingen gruppe spesifisert (kreves for underadministratorer)",
    "Sub-admin group does not exist" : "Underadministratorgruppe finnes ikke",
    "Cannot create sub-admins for admin group" : "Kan ikke opprette underadministratorer for admingruppe",
    "No permissions to promote sub-admins" : "Ingen tillatelser til å forfremme underadministratorer",
    "Invalid password value" : "Ugyldig passordverdi",
    "Required email address was not provided" : "Nødvendig e-postadresse ble ikke oppgitt",
    "Invalid email address" : "Ugyldig e-postadresse",
    "Invalid language" : "Ugyldig språk",
    "Invalid quota value: %1$s" : "Ugyldig kvoteverdi: %1$s",
    "Invalid quota value. %1$s is exceeding the maximum quota" : "Ugyldig kvoteverdi. %1$s overskrider den maksimale kvoten",
    "Unlimited quota is forbidden on this instance" : "Ubegrenset kvote er forbudt på denne forekomsten",
    "Setting the password is not supported by the users backend" : "Innstilling av passordet støttes ikke av brukerens backend",
    "Invalid locale" : "Ugyldig nasjonal innstilling",
    "Invalid first day of week" : "Ugyldig første dag i uken",
    "Cannot remove yourself from the admin group" : "Kan ikke fjerne deg selv fra administratorgruppen",
    "Cannot remove yourself from this group as you are a sub-admin" : "Kan ikke fjerne deg selv fra denne gruppen da du er en underadministrator",
    "Not viable to remove user from the last group you are sub-admin of" : "Ikke mulig å fjerne brukeren fra den siste gruppen du er underadministrator for",
    "User does not exist" : "Brukeren finnes ikke",
    "Group does not exist" : "Gruppen finnes ikke",
    "User is not a sub-admin of this group" : "Brukeren er ikke en underadministrator for denne gruppen",
    "Email address not available" : "E-postadresse ikke tilgjengelig",
    "Sending email failed" : "Sending av e-post feilet",
    "Email confirmation" : "E-postbekreftelse",
    "To enable the email address %s please click the button below." : "Klikk på knappen nedenfor for å aktivere e-postadressen %s.",
    "Confirm" : "Bekreft",
    "Email was already removed from account and cannot be confirmed anymore." : "E-posten er allerede fjernet fra kontoen og kan ikke bekreftes lenger.",
    "Could not verify mail because the token is expired." : "Kunne ikke bekrefte e-posten fordi nøkkelen er utløpt.",
    "Could not verify mail because the token is invalid." : "Kunne ikke bekrefte e-post fordi nøkkelen er ugyldig.",
    "An unexpected error occurred. Please contact your admin." : "En uventet feil oppsto. Ta kontakt med administratoren din.",
    "Email confirmation successful" : "E-postbekreftelse vellykket",
    "Provisioning API" : "Provisioning API",
    "This application enables a set of APIs that external systems can use to manage accounts, groups and apps." : "Denne applikasjonen aktiverer et sett med API-er som eksterne systemer kan bruke til å administrere kontoer, grupper og apper.",
    "This application enables a set of APIs that external systems can use to create, edit, delete and query account\n\t\tattributes, query, set and remove groups, set quota and query total storage used in Nextcloud. Group admin accounts\n\t\tcan also query Nextcloud and perform the same functions as an admin for groups they manage. The API also enables\n\t\tan admin to query for active Nextcloud applications, application info, and to enable or disable an app remotely.\n\t\tOnce the app is enabled, HTTP requests can be used via a Basic Auth header to perform any of the functions\n\t\tlisted above. More information is available in the Provisioning API documentation, including example calls\n\t\tand server responses." : "Denne applikasjonen aktiverer et sett med APIer som eksterne systemer kan bruke til å opprette, redigere, slette og spørre konto\n\t\tattributter, spørring, angi og fjern grupper, angi kvote og spørring total lagring brukt i Nextcloud. Kontoer for gruppeadministrator\n\t\tkan også spørre Nextcloud og utføre de samme funksjonene som en administrator for grupper de administrerer. API-en muliggjør også\n\t\ten administrator for å spørre etter aktive Nextcloud-applikasjoner, applikasjonsinformasjon og for å aktivere eller deaktivere en app eksternt.\n\t\tNår appen er aktivert, kan HTTP-forespørsler brukes via en Basic Auth-header for å utføre noen av funksjonene\n\t\tlistet ovenfor. Du finner mer informasjon i dokumentasjonen for Provisioning API, inkludert eksempelkall\n\t\tog serversvar."
},
"nplurals=2; plural=(n != 1);");
