OC.L10N.register(
    "circles",
    {
    "Personal" : "Personal",
    "Visible" : "Visible",
    "Open" : "Dobrir",
    "Password protected" : "Protegit per senhal",
    "Hidden" : "Amagat",
    "Local" : "Local",
    "Federated" : "Federated",
    "Email address" : "Adreça mail",
    "Contact" : "Contacte",
    "Admin" : "Admin",
    "Owner" : "Owner",
    "Open »%s«" : "Dobrir « %s »",
    "Accept" : "Acceptar",
    "No image file provided" : "Cap de fichièr imatge provesit",
    "Invalid file provided" : "Fichièr provesit invalid",
    "File is too big" : "Fichièr tròp pesuc",
    "Invalid image" : "Imatge invalid",
    "Unknown filetype" : "filetype desconegut",
    "Open %s" : "Dobrir %s",
    "Unlimited" : "Illimitat",
    "Default quota" : "Quota per defaut",
    "Save" : "Save",
    "Reconnect" : "Se reconnectar",
    "Connect" : "Connectar",
    "Overview" : "Vista d’ensemble",
    "Members" : "Membres",
    "Cancel" : "Cancel",
    "Next" : "Seguent",
    "Team name" : "Nom de la còla",
    "Folder" : "Dorsièr",
    "you" : "vos",
    "Copy link" : "Copiar lo ligam",
    "Copied" : "Copiat",
    "Create link" : "Crear ligam",
    "Close" : "Plegar",
    "New folder" : "Novèl dorsièr",
    "Folder name" : "Nom del dorsièr",
    "Talk conversation" : "Conversacion Talk",
    "Calendar" : "Calendièr",
    "New calendar" : "Calendièr novèl",
    "Description" : "Descripcion",
    "Edit" : "Modificar",
    "Create" : "Crear",
    "Add" : "Apondre",
    "Apply" : "Aplicar",
    "Remove {type}" : "Suprimir {type}",
    "Loading …" : "Cargament …",
    "No results" : "Cap de resultat",
    "Add {type}" : "Apondre {type}",
    "Pending" : "En espèra",
    "Role" : "Ròtle",
    "Loading" : "Cargament",
    "Go back" : "Revenir en arrière",
    "Join" : "Rejónher",
    "Loading…" : "Telecargament…",
    "Recently contacted" : "Contactat recentament",
    "User" : "Utilizator",
    "Group" : "Grop",
    "Email" : "Adreiça electronica",
    "Privacy" : "Confidencialitat",
    "Users" : "Utilizaires",
    "Contacts" : "Contactes",
    "No files in here" : "Cap de fichièr aicí",
    "Name" : "Nom",
    "Size" : "Talha",
    "Modified" : "Modificat"
},
"nplurals=2; plural=(n > 1);");
