OC.L10N.register(
    "office",
    {
    "Create new" : "Täzesini dörediň",
    "Search" : "Gözlemek",
    "Create" : "Dörediň",
    "Filename" : "Faýlyň ady",
    "Documents" : "Dokumentlar",
    "Filename cannot be empty" : "Faýlyň ady boş bolup bilmez"
},
"nplurals=2; plural=(n != 1);");
