OC.L10N.register(
    "appstore",
    {
    "App store" : "Magasin d'applications",
    "Apps" : "Applications",
    "Nextcloud Appstore" : "App Store Nextcloud",
    "App name" : "Nom de l’application",
    "Version" : "Version",
    "Support level" : "Niveau de support",
    "Groups" : "Groupes",
    "Actions" : "Actions",
    "Show details" : "Afficher les détails",
    "is loading…" : "est en cours de chargement…",
    "Filter view" : "Filtrer la vue",
    "Grid size" : "Taille de la grille",
    "Small grid size" : "Grille de petite taille",
    "Medium grid size" : "Grille de taille moyenne",
    "Large grid size" : "Grille de grande taille",
    "Show incompatible" : "Afficher les incompatibles",
    "Grid view" : "Vue en grille",
    "Force enable {suite}?" : "Forcer l'activation de {suite} ?",
    "Enabling {suite} requires force enabling the app. This may cause issues with your Nextcloud instance. Are you sure you want to proceed?" : "L'activation {suite} nécessite de forcer l'activation de l'application. Cela pourrait entraîner des problèmes avec votre instance Nextcloud. Voulez-vous vraiment continuer ?",
    "Force enable" : "Forcer l'activation",
    "Cancel" : "Annuler",
    "Office suite switching is managed through the Nextcloud All-in-One interface." : "Le changement de suite bureautique est géré via l'interface Nextcloud All-in-One.",
    "Please use the AIO interface to switch between office suites." : "Veuillez utiliser l'interface AIO pour passer d'une suite bureautique à l'autre.",
    "Select your preferred office suite." : "Sélectionnez votre suite bureautique préférée.",
    "Please note that installing requires manual server setup." : "Veuillez noter que l'installation nécessite une configuration manuelle du serveur.",
    "Disable office suites" : "Désactiver les suites bureautiques",
    "installed" : "installé",
    "Features" : "Fonctionnalités",
    "Learn more" : "En savoir plus",
    "Daemon" : "Processus",
    "Deploy Daemon" : "Deamon de déploiement",
    "Type" : "Type",
    "Name" : "Nom",
    "Display Name" : "Nom affiché",
    "GPUs support" : "Prise en charge des GPU",
    "Compute device" : "Appareil de calcul",
    "Advanced deploy options" : "Options avancées de déploiement",
    "Edit ExApp deploy options before installation" : "Éditer les options de déploiement ExApp avant l'installation",
    "Configured ExApp deploy options. Can be set only during installation" : "Options de déploiement ExApp. Ne peuvent être définies que lors de l'installation",
    "Environment variables" : "Variables d'environnement",
    "ExApp container environment variables" : "Variables d'environnement du conteneur ExApp",
    "No environment variables defined" : "Aucune variable d'environnement définie",
    "Mounts" : "Montages",
    "Define host folder mounts to bind to the ExApp container" : "Définir les montages de volumes de l'hôte à attacher au conteneur ExApp",
    "Must exist on the Deploy daemon host prior to installing the ExApp" : "Doivent exister sur l'hôte de déploiement du service avant d'installer ExApp",
    "Host path" : "Chemin de l'hôte",
    "Container path" : "Chemin du conteneur",
    "Read-only" : "Lecture seule",
    "Remove mount" : "Retirer le point de montage",
    "New mount" : "Nouveau point de montage",
    "Enter path to host folder" : "Entrer le chemin du dossier sur l'hôte",
    "Enter path to container folder" : "Entrer le chemin du dossier du conteneur",
    "Toggle read-only mode" : "Activer/Désactiver le mode lecture seule",
    "Confirm adding new mount" : "Confirmer l'ajout de nouveau point de montage",
    "Confirm" : "Confirmer",
    "Cancel adding mount" : "Annuler l'ajout de nouveau point de montage",
    "Add mount" : "Ajouter un point de montage",
    "ExApp container mounts" : "Points de montage ExApp",
    "No mounts defined" : "Aucun point de montage défini",
    "Description" : "Description",
    "View in store" : "Afficher dans le magasin d’applications",
    "Visit website" : "Visiter le site web",
    "Usage documentation" : "Documentation d'utilisation",
    "Admin documentation" : "Documentation administrateur",
    "Developer documentation" : "Documentation développeurs",
    "Details" : "Détails",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Cette application ne peut être installée à cause de ces dépendances non satisfaites :",
    "Missing dependencies" : "Dépendances manquantes",
    "This app cannot be limited to groups because it provides functionality that is executed before group membership is determined." : "Cette application ne peut pas être limitée aux groupes, car elle offre des fonctionnalités qui s'exécutent avant que l'appartenance à un groupe ne soit déterminée.",
    "Limited to groups" : "Limitée aux groupes",
    "Latest updated" : "Dernière mise à jour",
    "Author" : "Auteur",
    "Categories" : "Catégories",
    "Resources" : "Ressources",
    "Documentation resources" : "Ressources documentaires",
    "Changelog" : "Journal des modifs",
    "Supported" : "Prise en charge",
    "Featured" : "En vedette",
    "This app is supported via your current Nextcloud subscription." : "Cette application bénéficie d'un support grâce à votre abonnement Nextcloud.",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Les applications en vedette sont développées par la communauté. Elles proposent des fonctionnalités centrales et sont prêtes pour la production.",
    "Community rating: {score}/5" : "Note de la communauté : {score}/5",
    "Choose Deploy Daemon for {appName}" : "Sélectionner un déploiement de service pour {appName}",
    "No Deploy daemons configured" : "Aucun service de déploiement configuré",
    "Register a custom one or setup from available templates" : "Enregistrez-en un personnalisé ou une configuration à partir des modèles disponibles",
    "Manage Deploy daemons" : "Gérer le service de déploiement",
    "Registered Deploy daemons list" : "Liste des services de déploiement enregistrés",
    "Default" : "Défaut",
    "Carousel" : "Carrousel",
    "Previous slide" : "Diapositive précédente",
    "Next slide" : "Diapositive suivante",
    "Choose slide to display" : "Choisir la diapositive à afficher",
    "{index} of {total}" : "{index} sur {total}",
    "Limit to groups" : "Limiter à des groupes",
    "Restrict the usage of {app} to members of the following groups." : "Restreindre l'utilisation de {app} aux membres des groupes suivants.",
    "Reset limitation" : "Réinitialiser la limite",
    "Save" : "Enregistrer",
    "Failed to update app {appName}" : "Échec de la mise à jour de l'application {appName}",
    "Update all apps" : "Mettre à jour toutes les applications",
    "Are you sure you want to update all apps?" : "Êtes-vous sûr de vouloir mettre à jour toutes les applications ?",
    "Update done" : "Mise à jour terminée",
    "View website" : "Voir le site web",
    "Update all" : "Tout mettre à jour",
    "Loading app list" : "Chargement de la liste des applications",
    "No matching apps found" : "Aucune application correspondante trouvée",
    "Search everywhere" : "Rechercher partout",
    "Download and enable all" : "Tout télécharger et activer",
    "Could not load app discover section" : "Impossible de charger la section des applications à découvrir",
    "Could not render element" : "Impossible de générer l’élément",
    "Nothing to show" : "Rien à montrer",
    "Could not load section content from app store." : "Impossible de charger le contenu de cette section du magasin d'applications.",
    "Loading" : "Chargement",
    "Fetching the latest news…" : "Récupération des dernières nouvelles…",
    "Update all applications" : "Mettre à jour toutes les applications",
    "Appstore categories" : "Catégories de l'App Store",
    "Search apps…" : "Rechercher des applications…",
    "Loading categories" : "Chargement des catégories",
    "Please enter more characters to search." : "Veuillez saisir davantage de caractères pour lancer la recherche.",
    "Search apps" : "Rechercher des applications",
    "Version {version}, {license}-licensed" : "Version {version}, sous licence {license}",
    "Version {version}" : "Version {version}",
    "Disable" : "Désactiver",
    "Enable" : "Activer",
    "Deploy and enable" : "Déployer et activer",
    "Download and enable" : "Télécharger et activer",
    "Install and enable" : "Installer et activer",
    "Deploy and force enable" : "Déployer et forcer l'activation",
    "Download and force enable" : " Télécharger et forcer l'activation",
    "Install and force enable" : "Installer et forcer l'activation",
    "Rate the app" : "Évaluer l’application",
    "Report a bug" : "Signaler un bug",
    "Ask questions or discuss the app" : "Posez des questions ou discutez de l'application",
    "Visit the website" : "Visiter le site web",
    "Remove" : "Supprimer",
    "Update to {version}" : "Mettre à jour vers {version}",
    "Discover" : "Découvrir",
    "Your apps" : "Vos applications",
    "Active apps" : "Applications actives",
    "Disabled apps" : "Applications désactivées",
    "Updates" : "Mises à jour",
    "App bundles" : "Packs d'applications",
    "Featured apps" : "Applications en vedette",
    "Supported apps" : "Applications supportées",
    "Search results" : "Résultats de la recherche",
    "Powered by Euro-Office" : "Propulsé par Euro-Office",
    "Good Nextcloud integration" : "Bonne intégration dans Nextcloud",
    "Open source" : "Open Source",
    "Best performance" : "Meilleures performances",
    "Limited ODF compatibility" : "Compatibilité ODF limitée",
    "Best Microsoft compatibility" : "Meilleure compatibilité Microsoft",
    "Best Nextcloud integration" : "Meilleure intégration dans Nextcloud",
    "Good performance" : "Bonnes performances",
    "Best security: documents never leave your server" : "Meilleure sécurité : les documents ne quittent jamais votre serveur",
    "Best ODF compatibility" : "Meilleure compatibilité ODF",
    "Best support for legacy files" : "Meilleure prise en charge des anciens fichiers",
    "Could not load app categories. Please try again later." : "Impossible de charger les catégories d'applications. Veuillez réessayer plus tard.",
    "Could not load apps list. Please try again later." : "Impossible de charger la liste des applications. Veuillez réessayer plus tard.",
    "Could not update the app. Please try again later." : "Impossible de mettre à jour l'application. Veuillez réessayer plus tard.",
    "An error occurred during the request. Unable to proceed." : "Une erreur est survenue pendant la demande. Impossible de poursuivre."
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
