OC.L10N.register(
    "files_trashbin",
    {
    "restored" : "athchóirithe",
    "Deleted files" : "Comhaid scriosta",
    "Deleted files and folders in the trash bin (may expire during export if you are low on storage space)" : "Comhaid agus fillteáin scriosta sa bhosca bruscair (seans go rachaidh siad in éag le linn easpórtála mura bhfuil mórán spáis stórála agat)",
    "This application enables people to restore files that were deleted from the system." : "Cuireann an feidhmchlár seo ar chumas daoine comhaid a scriosadh as an gcóras a chur ar ais.",
    "This application enables people to restore files that were deleted from the system. It displays a list of deleted files in the web interface, and has options to restore those deleted files back to the people file directories or remove them permanently from the system. Restoring a file also restores related file versions, if the versions application is enabled. When a file is deleted from a share, it can be restored in the same manner, though it is no longer shared. By default, these files remain in the trash bin for 30 days.\nTo prevent an account from running out of disk space, the Deleted files app will not utilize more than 50% of the currently available free quota for deleted files. If the deleted files exceed this limit, the app deletes the oldest files until it gets below this limit. More information is available in the Deleted Files documentation." : "Cuireann an feidhmchlár seo ar chumas daoine comhaid a scriosadh as an gcóras a chur ar ais. Taispeánann sé liosta de chomhaid scriosta sa chomhéadan gréasáin, agus tá roghanna ann chun na comhaid sin a scriosadh a chur ar ais go dtí na heolairí comhaid daoine nó iad a bhaint go buan den chóras. Athchóiríonn comhad a athbhunú leaganacha gaolmhara comhaid, má tá feidhmchlár na leaganacha cumasaithe. Nuair a scriostar comhad ó sciar, is féidir é a chur ar ais ar an mbealach céanna, cé nach bhfuil sé roinnte a thuilleadh. De réir réamhshocraithe, fanann na comhaid seo sa bhosca bruscair ar feadh 30 lá.\nChun cosc ​​a chur ar chuntas imeacht as spás diosca, ní úsáidfidh an aip Comhaid Scriosta níos mó ná 50% den chuóta saor in aisce atá ar fáil faoi láthair le haghaidh comhaid scriosta. Má sháraíonn na comhaid scriosta an teorainn seo, scriosann an aip na comhaid is sine go dtí go n-éireoidh sé faoin teorainn seo. Tá tuilleadh faisnéise ar fáil sa doiciméadú Comhaid Scriosta.",
    "Restore" : "Athchóirigh",
    "Not enough free space to restore the file/folder" : "Níl dóthain spáis saor ann chun an comhad/fillteán a athchóiriú",
    "Empty deleted files" : "Comhaid scriosta folamh",
    "Confirm permanent deletion" : "Deimhnigh scriosadh buan",
    "Are you sure you want to permanently delete all files and folders in the trash? This cannot be undone." : "An bhfuil tú cinnte gur mian leat gach comhad agus fillteán sa bhruscar a scriosadh go buan? Ní féidir é seo a chealú.",
    "Cancel" : "Cealaigh",
    "Original location" : "Suíomh bunaidh",
    "Deleted by" : "Scriosta ag",
    "Deleted" : "Scriosta",
    "few seconds ago" : "cúpla soicind ó shin",
    "A long time ago" : "Fadó fadó",
    "Unknown" : "Anaithnid",
    "All files" : "Gach comhad",
    "You" : "tu",
    "List of files that have been deleted." : "Liosta de na comhaid a scriosadh.",
    "No deleted files" : "Níl aon chomhaid scriosta",
    "Files and folders you have deleted will show up here" : "Taispeánfar na comhaid agus na fillteáin atá scriosta agat anseo",
    "All files have been permanently deleted" : "Scriosadh na comhaid go léir go buan",
    "Failed to empty deleted files" : "Theip ar na comhaid scriosta a fholmhú"
},
"nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");
