OC.L10N.register(
    "bruteforcesettings",
    {
    "Brute-force settings" : "Socruithe brú-fhórsa",
    "Whitelist IPs" : "IPs liosta bán",
    "Brute-force protection is meant to protect Nextcloud servers from attempts to\nguess account passwords in various ways. Besides the obvious \"*let's try a big\nlist of commonly used passwords*\" attack, it also makes it harder to use\nslightly more sophisticated attacks via the reset password form or trying to\nfind app password tokens.\n\nIf triggered, brute-force protection makes requests coming from an IP on a\nbrute-force protected controller with the same API slower for a 24 hour period.\n\nWith this app, the admin can exempt an IP address or range from this\nprotection which can be useful for testing purposes or when there are false\npositives due to a lot of accounts on one IP address." : "Tá cosaint brú-fhórsa i gceist chun freastalaithe Nextcloud a chosaint ó iarrachtaí chun\npasfhocail cuntais a thomhas ar bhealaí éagsúla. Seachas an rud soiléir \"* déanaimis iarracht mór\nliosta de na pasfhocail a úsáidtear go coitianta*\" ionsaí, déanann sé níos deacra é a úsáid freisin\nionsaithe beagán níos sofaisticiúla tríd an bhfoirm athshocrú pasfhocal nó ag iarraidh a\naimsigh pasfhocail feidhmchláir.\n\nMá spreagtar é, déanann cosaint brúidiúil iarratais a thagann ó IP ar a\nrialtóir cosanta brute-force leis an API céanna níos moille ar feadh tréimhse 24 uair an chloig.\n\nLeis an aip seo, is féidir leis an riarthóir seoladh IP a dhíolmhú nó raon uaidh seo\ncosaint a d'fhéadfadh a bheith úsáideach chun críocha tástála nó nuair a bhíonn bréagach ann\ndearfach mar gheall ar go leor cuntas ar aon seoladh IP amháin.",
    "The comment cannot exceed {max} characters." : "Ní féidir níos mó ná {max} carachtar a bheith sa trácht.",
    "Leave an internal comment explaining why this IP address is allowed, for example its location, so the entry can be removed when it is no longer needed." : "Fág trácht inmheánach ag míniú cén fáth a gceadaítear an seoladh IP seo, mar shampla a shuíomh, ionas gur féidir an iontráil a bhaint nuair nach mbeidh gá léi a thuilleadh.",
    "Your current IP address is detected as \"{remoteAddress}\". This address is currently throttled. Current delay: {delay} ms." : "Braitear do sheoladh IP reatha mar \"{remoteAddress}\". Tá an seoladh seo srianta faoi láthair. Moill reatha: {delay} ms.",
    "Your current IP address is detected as \"{remoteAddress}\". This address bypasses brute-force protection." : "Braitear do sheoladh IP reatha mar \"{remoteAddress}\". Seachnaíonn an seoladh seo cosaint brúidiúil.",
    "Your current IP address is detected as \"{remoteAddress}\". This address is not currently throttled." : "Braitear do sheoladh IP reatha mar \"{remoteAddress}\". Níl an seoladh seo srianta faoi láthair.",
    "Failed to add the IP address to the allow list." : "Theip ar an seoladh IP a chur leis an liosta ceadaithe.",
    "Failed to save the rate limit setting." : "Theip ar an socrú teorann ráta a shábháil.",
    "Failed to update the allow list entry." : "Theip ar an iontráil sa liosta ceadanna a nuashonrú.",
    "Brute-force allow list" : "Liosta ceadanna brúidiúil",
    "To exclude IP ranges from the brute-force protection specify them below. Note that any allowed IP can perform authentication attempts without any throttling. For security reasons, it is recommended to list as few remote addresses as possible or ideally even none at all." : "Chun raonta IP a eisiamh ón gcosaint brúidiúil, sonraigh iad thíos. Tabhair faoi deara gur féidir le haon IP ceadaithe iarrachtaí fíordheimhnithe a dhéanamh gan aon srianadh. Ar chúiseanna slándála, moltar chomh beag seoltaí iargúlta agus is féidir a liostáil nó fiú gan aon cheann ar chor ar bith.",
    "Bypass rate limiting for allowed IPs" : "Teorainn ráta seachbhóthair do IPanna ceadaithe",
    "Add new IP address" : "Cuir seoladh IP nua leis",
    "IP address" : "Seoladh IP",
    "Mask" : "Masc",
    "Comment" : "Trácht",
    "Add" : "Cuir",
    "Edit comment for {subnet}" : "Cuir trácht in eagar do {subnet}",
    "Save" : "Sábháil",
    "Delete entry for {subnet}" : "Scrios iontráil le haghaidh {subnet}",
    "Comment cannot exceed {max} characters." : "Ní féidir níos mó ná {max} carachtar a bheith sa trácht.",
    "Leave an internal comment, why this IP is allowed, e.g. the  location, so it can be revoked, when it is no longer needed." : "Fág trácht inmheánach, cén fáth a gceadaítear an seoladh IP seo, m.sh. an suíomh, ionas gur féidir é a chúlghairm nuair nach mbeidh gá leis a thuilleadh.",
    "Your remote address was identified as \"{remoteAddress}\" and is throttled at the moment by {delay}ms." : "Aithníodh do sheoladh cianda mar \"{remoteAddress}\" agus tá {moill}ms mar gheall air faoi láthair.",
    "Your remote address was identified as \"{remoteAddress}\" and is bypassing brute-force protection." : "Aithníodh do sheoladh cianda mar \"{remoteAddress}\" agus tá sé ag seachaint cosaint brúidiúil.",
    "Your remote address was identified as \"{remoteAddress}\" and is not actively throttled at the moment." : "Aithníodh do sheoladh cianda mar \"{remoteAddress}\" agus níl sé faoi sníomh go gníomhach faoi láthair.",
    "There was an error adding the IP to the allow list." : "Tharla earráid agus an seoladh IP á chur leis an liosta ceadaithe.",
    "There was an error updating the allow list entry." : "Tharla earráid agus an iontráil sa liosta ceadanna á nuashonrú."
},
"nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");
