OC.L10N.register(
    "files_sharing",
    {
    "File shares" : "File shares",
    "Downloaded via public link" : "Gedownload via een openbare link",
    "Downloaded by {email}" : "Gedownload via {email}",
    "{file} downloaded via public link" : "{file} gedownload via openbare link",
    "{email} downloaded {file}" : "{email} downloadde {file}",
    "Shared with group {group}" : "Deelde met groep {group}",
    "Removed share for group {group}" : "Share van de groep {group} verwijderd",
    "{actor} shared with group {group}" : "{actor} deelde met groep {group}",
    "{actor} removed share for group {group}" : "{actor} verwijderde de share voor groep {group}",
    "Share for group {group} expired" : "Share voor groep {group} verlopen",
    "You shared {file} with group {group}" : "Je deelde {file} met groep {group}",
    "You removed group {group} from {file}" : "Je verwijderde groep  {group} van {file}",
    "{actor} shared {file} with group {group}" : "{actor} heeft het bestand {file} met groep {group} gedeeld",
    "{actor} removed group {group} from {file}" : "{actor} verwijderde groep {group} van {file}",
    "Share for file {file} with group {group} expired" : "Share voor bestand {file} met groep {group} verlopen",
    "Shared as public link" : "Gedeeld als een openbare link",
    "Removed public link" : "Openbare link verwijderd",
    "Public link expired" : "Openbare link is verlopen",
    "{actor} shared as public link" : "{actor} deelde als een openbare link",
    "{actor} removed public link" : "{actor} verwijderde openbare link",
    "Public link of {actor} expired" : "Openbare link van {actor} is verlopen",
    "You shared {file} as public link" : "Je deelde {file} als openbare link",
    "You removed public link for {file}" : "Je verwijderde de openbare link voor {file}",
    "Public link expired for {file}" : "Openbare link voor {file} is verlopen",
    "{actor} shared {file} as public link" : "{actor} deelde {file} als openbare link",
    "{actor} removed public link for {file}" : "{actor} verwijderde openbare link voor {file}",
    "Public link of {actor} for {file} expired" : "Openbare link van {actor} voor {file} is verlopen",
    "{user} accepted the remote share" : "{user} accepteerde externe share",
    "{user} declined the remote share" : "{user} weigerde externe share",
    "You received a new remote share {file} from {user}" : "Je ontving een nieuwe externe share voor {file} van {user}",
    "{user} accepted the remote share of {file}" : "{user} accepteerde externe gedeelde folder van {file}",
    "{user} declined the remote share of {file}" : "{user} weigerde de externe gedeelde folder van {file}",
    "{user} unshared {file} from you" : "{user} is gestopt het bestand {file} met je te delen",
    "Shared with {user}" : "Gedeeld met {user}",
    "Removed share for {user}" : "Verwijderde gedeelde folder voor {user}",
    "You removed yourself" : "Je verwijderde jezelf",
    "{actor} removed themselves" : "{actor} verwijderde zichzelf",
    "{actor} shared with {user}" : "{actor} deelde met {user}",
    "{actor} removed share for {user}" : "{actor} verwijderde de gedeelde folder voor {user}",
    "Shared by {actor}" : "Gedeeld door {actor}",
    "{actor} removed share" : "{actor} verwijderde de gedeelde folder",
    "Share for {user} expired" : "Share voor {user} verlopen",
    "Share expired" : "Share verlopen",
    "You shared {file} with {user}" : "Je deelde {file} met {user}",
    "You removed {user} from {file}" : "Je verwijderde {user} van {file}",
    "You removed yourself from {file}" : "Je verwijderde jezelf van {file}",
    "{actor} removed themselves from {file}" : "{actor} verwijderde zichzelf van {file}",
    "{actor} shared {file} with {user}" : "{actor} deelde {file} met {user}",
    "{actor} removed {user} from {file}" : "{actor} verwijderde {user} van {file}",
    "{actor} shared {file} with you" : "{actor} heeft {file} met je gedeeld",
    "{actor} removed you from the share named {file}" : "{actor} verwijderde je van share {file}",
    "Share for file {file} with {user} expired" : "Share voor bestande {file} met {user} verlopen",
    "Share for file {file} expired" : "Share voor bestand {file} verlopen",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Een bestand of map gedeeld via mail of publieke link werd <strong>gedownload</strong>",
    "Files have been <strong>uploaded</strong> to a folder shared by mail or by public link" : "Bestanden zijn <strong>geüpload</strong> naar een map die per mail of via een openbare link wordt gedeeld",
    "A file or folder was shared from <strong>another server</strong>" : "Een bestand of map werd gedeeld vanaf <strong>een andere server</strong>",
    "Sharing" : "Delen",
    "A file or folder has been <strong>shared</strong>" : "Een bestand of map is <strong>gedeeld</strong>",
    "Shared link" : "Gedeeld link",
    "Wrong share ID, share does not exist" : "Onjuist deel-ID, de gedeelde folder bestaat niet",
    "Could not delete share" : "Kan gedeelde folder niet verwijderen",
    "Please specify a file or folder path" : "Geef een bestand of pad van een map op",
    "Wrong path, file/folder does not exist" : "slecht path, file/folder bestaat niet",
    "Could not create share" : "Kan gedeelde folder niet aanmaken",
    "Please specify a valid account to share with" : "Geef een geldig account op waarmee je wilt delen",
    "Please specify a valid group" : "Geef een geldige groep op",
    "Please specify a valid email address" : "Geef een geldig e-mailadres op",
    "Sharing %s sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "Delen %s versturen van het wachtwoord via Nextcloud Talk is mislukt omdat Nextcloud Talk niet is ingeschakeld",
    "Please specify a valid federated account ID" : "Geef een geldig federatief account-ID op",
    "Please specify a valid federated group ID" : "Geef een geldig gefedereerd groep-ID op",
    "You cannot share to a Team if the app is not enabled" : "Je kunt niet delen met een Team als de app niet is ingeschakeld",
    "Please specify a valid team" : "Geef een geldig team op",
    "Sharing %s failed because the back end does not support room shares" : "Delen van %s mislukte omdat de backend het delen in ruimtes niet ondersteunt",
    "Unknown share type" : "Onbekend type gedeelde folder",
    "Not a directory" : "Geen directory",
    "Could not lock node" : "Kon de node niet blokkeren",
    "Public upload is only possible for publicly shared folders" : "Publieke upload is alleen mogelijk voor publiek gedeelde mappen",
    "Share must at least have READ or CREATE permissions" : "Share moet ten minste READ - of CREATE-rechten hebben",
    "Share must have READ permission if UPDATE or DELETE permission is set" : "Share moet READ-toestemming hebben als de UPDATE- of DELETE-toestemming is ingesteld",
    "Could not lock path" : "Kan pad niet blokkeren",
    "no sharing rights on this item" : "geen deelrechten op dit item",
    "You are not allowed to edit incoming shares" : "Je mag geen inkomende shares bewerken",
    "Wrong or no update parameter given" : "Verkeerde of geen update parameter opgegeven",
    "\"Sending the password by Nextcloud Talk\" for sharing a file or folder failed because Nextcloud Talk is not enabled." : "\"Het wachtwoord verzenden via Nextcloud Talk\" voor het delen van een bestand of map is mislukt omdat Nextcloud Talk niet is ingeschakeld.",
    "Custom share link tokens have been disabled by the administrator" : "Aangepaste share link tokens zijn uitgeschakeld door de beheerder",
    "Invalid date. Format must be YYYY-MM-DD" : "Ongeldige datum. Formaat moet zijn YYYY-MM-DD",
    "No sharing rights on this item" : "Geen deelrechten op dit item",
    "Invalid share attributes provided: \"%s\"" : "Ongeldige deelattributen verstrekt: \"%s\"",
    "You are not allowed to send mail notifications" : "Je mag geen mailmeldingen versturen",
    "No mail notification configured for this share type" : "Geen mailmelding geconfigureerd voor dit type share",
    "Wrong password" : "Onjuist wachtwoord",
    "Error while sending mail notification" : "Fout tijdens het verzenden van e-mailmelding",
    "Failed to generate a unique token" : "Het genereren van een uniek token is mislukt",
    "This share does not exist or is no longer available" : "Deze share bestaat niet of is niet meer beschikbaar",
    "shared by %s" : "Gedeeld door %s",
    "Download" : "Downloaden",
    "Add to your %s" : "Toevoegen aan je %s",
    "Direct link" : "Directe link",
    "Share API is disabled" : "Delen API is uitgeschakeld",
    "File sharing" : "Bestand delen",
    "Share will expire tomorrow" : "De share vervalt morgen",
    "Your share of {node} will expire tomorrow" : "Je deellink van {node} verloopt morgen",
    "You received {share} as a share by {user}" : "Je ontving {share} als een share van {user}",
    "You received {share} to group {group} as a share by {user}" : "Je ontving {share} aan groep {group} als een share van {user}",
    "Accept" : "Accepteren",
    "Decline" : "Afwijzen",
    "Remember to upload the files to %s" : "Vergeet niet om de bestanden te uploaden naar %s",
    "We would like to kindly remind you that you have not yet uploaded any files to the shared folder." : "We willen je er vriendelijk op wijzen dat je nog geen bestanden hebt geüpload naar de gedeelde map.",
    "Open \"%s\"" : "Open \"%s\"",
    "This application enables people to share files within Nextcloud. If enabled, the admin can choose which groups can share files. The applicable people can then share files and folders with other accounts and groups within Nextcloud. In addition, if the admin enables the share link feature, an external link can be used to share files with other people outside of Nextcloud. Admins can also enforce passwords, expirations dates, and enable server to server sharing via share links, as well as sharing from mobile devices.\nTurning the feature off removes shared files and folders on the server for all share recipients, and also on the sync clients and mobile apps. More information is available in the Nextcloud Documentation." : "Met deze applicatie kunnen mensen bestanden delen binnen Nextcloud. Indien ingeschakeld kan de beheerder kiezen welke groepen bestanden kunnen delen. Deze mensen kunnen vervolgens bestanden en mappen delen met andere accounts en groepen binnen Nextcloud. Als de beheerder de share-linkfunctie inschakelt, kan bovendien een externe link worden gebruikt om bestanden te delen met andere mensen buiten Nextcloud. Beheerders kunnen ook wachtwoorden en vervaldata afdwingen en het delen tussen servers mogelijk maken via share-links, evenals delen vanaf mobiele apparaten.\nAls je de functie uitschakelt, worden gedeelde bestanden en mappen op de server verwijderd voor alle ontvangers van shares, en ook voor de synchronisatieclients en mobiele apps. Meer informatie is beschikbaar in de Nextcloud Documentatie.",
    "Filter accounts" : "Accounts filteren",
    "you" : "jij",
    "The request will expire on {date} at midnight and will be password protected." : "De aanvraag verloopt op {date} om middernacht en zal beveiligd zijn met een wachtwoord.",
    "The request will expire on {date} at midnight." : "De aanvraag verloopt op {date} om middernacht.",
    "The request will be password protected." : "De aanvraag is wachtwoordbeveiligd",
    "When should the request expire?" : "Wanneer moet de aanvraag verlopen?",
    "Set a submission expiration date" : "Stel een opgave vervaldatum in",
    "Expiration date" : "Vervaldatum",
    "Select a date" : "Selecteer een datum",
    "Your administrator has enforced a {count} days expiration policy." : "Je beheerder heeft een vervalbeleid van {count} dagen ingesteld.",
    "What password should be used for the request?" : "Welk wachtwoord moet gebruikt worden voor de aanvraag?",
    "Set a password" : "Instellen wachtwoord",
    "Password" : "Wachtwoord",
    "Enter a valid password" : "Voer een geldig wachtwoord in",
    "Generate a new password" : "Genereer een nieuw wachtwoord",
    "Your administrator has enforced a password protection." : "Je beheerder heeft wachtwoordbeveiliging verplicht gesteld.",
    "Automatically copying failed, please copy the share link manually" : "Automatisch kopiëren mislukt. Kopieer de link handmatig a.u.b.",
    "Link copied" : "Link gekopieerd",
    "Email already added" : "E-mail al toegevoegd",
    "Invalid email address" : "Ongeldig e-mailadres",
    "_The following email address is not valid: {emails}_::_The following email addresses are not valid: {emails}_" : ["Het volgende e-mailadres is niet geldig: {emails}","De volgende e-mailadressen zijn niet geldig: {emails}"],
    "_{count} email address already added_::_{count} email addresses already added_" : ["Al {count} e-mailadres toegevoegd","Al {count} e-mailadressen toegevoegd"],
    "_{count} email address added_::_{count} email addresses added_" : ["{count}  E-mailadres toegevoegd","{count} E-mailadressen toegevoegd"],
    "You can now share the link below to allow people to upload files to your directory." : "Je kan nu onderstaande link delen om anderen toe te staan bestanden naar je map te uploaden.",
    "Share link" : "Delen link",
    "Copy" : "Kopiëren",
    "Send link via email" : "Versturen link via e-mail",
    "Enter an email address or paste a list" : "Voer e-mailadres in of plak een lijst",
    "Remove email" : "Verwijder e-mail",
    "Select a destination" : "Selecteer een bestemming",
    "Select" : "Selecteer",
    "What are you requesting?" : "Wat is je aanvraag?",
    "Request subject" : "Onderwerp aanvraag",
    "Birthday party photos, History assignment…" : "Verjaardagsfoto's, Geschiedenis…",
    "Where should these files go?" : "Waar moeten deze bestanden naartoe?",
    "Upload destination" : "Uploadbestemming",
    "Revert to default" : "Val terug op standaard",
    "The uploaded files are visible only to you unless you choose to share them." : "De geüploade bestanden zijn alleen voor jou zichtbaar, tenzij je ervoor kiest ze te delen.",
    "Add a note" : "Voeg een notitie toe",
    "Note for recipient" : "Notitie voor ontvanger",
    "Add a note to help people understand what you are requesting." : "Voeg een notitie toe zodat anderen begrijpen wat je aanvraag behelst",
    "You can add links, date or any other information that will help the recipient understand what you are requesting." : "Je kan links, datums of andere informatie toevoegen, die de ontvanger helpt te begrijpen wat je aanvraag behelst.",
    "Close" : "Sluit",
    "_Send email and close_::_Send {count} emails and close_" : ["Stuur e-mail en sluit","Verstuur {count} e-mails and sluit"],
    "Please select a folder, you cannot share the root directory." : "Selecteer een map, je kan de basismap niet delen.",
    "File request created" : "Bestandsaanvraag gemaakt",
    "_File request created and email sent_::_File request created and {count} emails sent_" : ["Bestandsaanvraag gemaakt en e-mail verstuurd","Bestandsaanvraag gemaakt en {count} e-mails verstuurd."],
    "Error creating the share: {errorMessage}" : "Fout bij aanmaken share: {errorMessage}",
    "Error creating the share" : "Fout tijdens aanmaken share",
    "Error sending emails: {errorMessage}" : "Fout bij versturen e-mails: {errorMessage}",
    "Error sending emails" : "Fout bij het verzenden van e-mails",
    "Create a file request" : "Maak een bestandsaanvraag",
    "Collect files from others even if they do not have an account." : "Verzamel bestanden van anderen, ook al hebben ze geen account.",
    "To ensure you can receive files, verify you have enough storage available." : "Om zeker te zijn dat je bestanden kan ontvangen, controleer of je genoeg opslagruimte beschikbaar hebt.",
    "File request" : "Bestandsaanvraag",
    "Previous step" : "Vorige stap",
    "Cancel" : "Annuleren",
    "Cancel the file request creation" : "Annuleer het maken van de bestandsaanvraag",
    "Close without sending emails" : "Sluit zonder versturen van e-mails",
    "Continue" : "Doorgaan",
    "Error while toggling options" : "Fout bij het wisselen van opties",
    "Accept shares from other accounts and groups by default" : "Accepteer standaard shares van andere accounts en groepen",
    "Choose a default folder for accepted shares" : "Kies een standaard map voor geaccepteerde shares",
    "Invalid path selected" : "Ongeldig pad geselecteerd",
    "Unknown error" : "Onbekende fout",
    "Set default folder for accepted shares" : "Stel standaard map in voor geaccepteerde shares",
    "Reset" : "Herstellen",
    "Reset folder to system default" : "Reset map naar systeem standaard",
    "Share expiration: {date}" : "Vervaldatum van de share: {date}",
    "Share Expiration" : "Vervaldatum van de share",
    "group" : "groep",
    "conversation" : "gesprek",
    "remote" : "extern",
    "remote group" : "externe groep",
    "guest" : "gast",
    "by {initiator}" : "door {initiator}",
    "Shared with the group {user} by {owner}" : "Gedeeld met groep {user} door {owner}",
    "Shared with the conversation {user} by {owner}" : "Gedeeld met gesprek {user} door {owner}",
    "Shared with {user} by {owner}" : "Gedeeld met {user} door {owner}",
    "Open Sharing Details" : "Open Delen details",
    "Added by {initiator}" : "Toegevoegd door {initiator}",
    "Via “{folder}”" : "Via “{folder}”",
    "Unshare" : "Delen stoppen",
    "Cannot copy, please copy the link manually" : "Kan niet kopiëren, kopieer de link handmatig",
    "Copy internal link" : "Kopieer interne link",
    "For people who already have access" : "Voor personen die al toegang hebben",
    "Internal link" : "Interne link",
    "{shareWith} by {initiator}" : "{shareWith} door {initiator}",
    "Shared via link by {initiator}" : "Gedeeld via link door {initiator}",
    "File request ({label})" : "Bestandsaanvraag ({label})",
    "Mail share ({label})" : "Mail share ({label})",
    "Share link ({label})" : "Link delen ({label})",
    "Mail share" : "Share mailen",
    "Share link ({index})" : "Deellink ({index})",
    "Create public link" : "Creëer openbare link",
    "Actions for \"{title}\"" : "Acties voor \"{title}\"",
    "Copy public link of \"{title}\"" : "Kopieer publieke link van \"{title}\"",
    "Error, please enter proper password and/or expiration date" : "Fout. geef een geldig wachtwoord op en/of een vervaldatum",
    "Link share created" : "Te delen share gemaakt",
    "Error while creating the share" : "Fout bij maken share",
    "Your browser does not support copying, please copy the link manually:" : "Je browser ondersteund geen kopiëren, kopieer de link handmatig",
    "Successfully copied public link" : "De publieke link is succesvol gekopieerd",
    "Please enter the following required information before creating the share" : "Geef de volgend verplichte gegevens op voor het aanmaken van de deellink",
    "Password protection (enforced)" : "Wachtwoordbeveiliging (afgedwongen)",
    "Password protection" : "Wachtwoordbeveiliging",
    "Enter a password" : "Voer een wachtwoord in",
    "Enable link expiration (enforced)" : "Activeer link-verval (afgedwongen)",
    "Enable link expiration" : "Activeer link-verval",
    "Enter expiration date (enforced)" : "Voer vervaldatum in (afgedwongen)",
    "Enter expiration date" : "Voer vervaldatum in",
    "Create share" : "Creëren share",
    "Customize link" : "Bewerk link",
    "Generate QR code" : "Genereer QR code",
    "Add another link" : "Nog een link toevoegen ",
    "Create a new share link" : "Creëer een nieuwe deellink",
    "Quick share options, the current selected is \"{selectedOption}\"" : "Snel delen opties, de huidige geselecteerd is \"{selectedOption}\"",
    "View only" : "Alleen bekijken",
    "Can edit" : "Kan bewerken",
    "Custom permissions" : "Aangepaste machtigingen",
    "Resharing is not allowed" : "Opnieuw delen niet toegestaan",
    "Name or email …" : "Naam of e-mail …",
    "Name, email, or Federated Cloud ID …" : "Naam, e-mail of gefedereerde cloud ID …",
    "Searching …" : "Zoeken ...",
    "No elements found." : "Geen elementen gevonden.",
    "Search everywhere" : "Zoek in alles",
    "Guest" : "Gast",
    "Group" : "Groep",
    "Email" : "E-mail",
    "Team" : "Team",
    "Talk conversation" : "Talk gesprek",
    "Deck board" : "Deck board",
    "ScienceMesh" : "ScienceMesh",
    "on {server}" : "op {server}",
    "Enter external recipients" : "Externe ontvangers invoeren",
    "Search for internal recipients" : "Interne ontvangers zoeken",
    "Note from" : "Notirtie van",
    "Note:" : "Notitie:",
    "File drop" : "Bestandsopslag",
    "Upload files to {foldername}." : "Upload bestanden naar {foldername}",
    "By uploading files, you agree to the terms of service." : "Door het uploaden van bestanden stem je in met de gebruiksvoorwaarden.",
    "Successfully uploaded files" : "Succesvol geüploade bestanden",
    "View terms of service" : "Toon gebruiksvoorwaarden",
    "Terms of service" : "Gebruiksvoorwaarden",
    "Share with {user}" : "Deel met {user}",
    "Share with email {email}" : "Deel met e-mail {email}",
    "Share with group" : "Deel met groep",
    "Share in conversation" : "Deel in gesprek",
    "Share with {user} on remote server {server}" : "Deel met {user} op server {server}",
    "Share with remote group" : "Deel met remote groep",
    "Share with guest" : "Deel met gast",
    "Update share" : "Update share",
    "Save share" : "Bewaar share",
    "Read" : "Lezen",
    "Create" : "Creëer",
    "Edit" : "Bewerk",
    "Share" : "Delen",
    "Delete" : "Verwijderen",
    "Password field cannot be empty" : "Wachtwoordveld kan niet leeg zijn",
    "Replace current password" : "Vervang huidig wachtwoord",
    "Failed to generate a new token" : "Het genereren van een nieuw token is mislukt",
    "Allow upload and editing" : "Uploaden en bewerken toestaan",
    "Allow editing" : "Bewerken toestaan",
    "Upload only" : "Alleen uploaden",
    "Advanced settings" : "Geavanceerde instellingen",
    "Share label" : "Deel het label",
    "Share link token" : "Share link token",
    "Set the public share link token to something easy to remember or generate a new token. It is not recommended to use a guessable token for shares which contain sensitive information." : "Stel het publieke deellink-token in op iets dat gemakkelijk te onthouden is of genereer een nieuw token. Het is niet aanbevolen om een raadbaar token te gebruiken voor shares die gevoelige informatie bevatten.",
    "Generating…" : "Genereren…",
    "Generate new token" : "Nieuw token genereren",
    "Set password" : "Instellen wachtwoord",
    "Password expires {passwordExpirationTime}" : "Wachtwoord vervalt {passwordExpirationTime}",
    "Password expired" : "Wachtwoord is vervallen",
    "Video verification" : "Video verificatie",
    "Expiration date (enforced)" : "Vervaldatum (afgedwongen)",
    "Set expiration date" : "Stel vervaldatum in",
    "Hide download" : "Verberg download",
    "Allow download and sync" : "Download en synchroniseren toestaan",
    "Note to recipient" : "Notitie voor ontvanger",
    "Enter a note for the share recipient" : "Geef een notitie op voor de share-ontvanger",
    "Show files in grid view" : "Bestanden tonen in rasterweergave",
    "Delete share" : "Verwijder share",
    "Others with access" : "Anderen met toegang",
    "No other accounts with access found" : "Geen andere accounts met toegang gevonden",
    "Toggle list of others with access to this directory" : "Omschakelen lijst van anderen met toegang tot deze directory",
    "Toggle list of others with access to this file" : "Omschakelen lijst van anderen met toegang tot dit bestand",
    "Unable to fetch inherited shares" : "Kon overerfde shares niet ophalen",
    "Link shares" : "Deel shares",
    "Shares" : "Shares",
    "Share files within your organization. Recipients who can already view the file can also use this link for easy access." : "Deel bestanden in je organisatie. Ontvangers die het bestand al kunnen zien, kunnen deze link gebruiken voor makkelijke toegang.",
    "Share files with others outside your organization via public links and email addresses. You can also share to {productName} accounts on other instances using their federated cloud ID." : "Deel bestanden met anderen buiten je organisatie via publieke links en e-mailadressen, Je kan ook delen naar{productName} accounts op andere instanties door gebruik te maken van hun gefedereerde cloud ID.",
    "Shares from apps or other sources which are not included in internal or external shares." : "Shares van apps of andere bronnen welke niet zijn inbegrepen in interne of externe shares.",
    "Type names, teams, federated cloud IDs" : "Type namen, teams of gefedereerde cloud ID's",
    "Type names or teams" : "Type namen of teams",
    "Type a federated cloud ID" : "Type een gefedereerde cloud ID",
    "Type an email" : "Type een e-mail",
    "Type an email or federated cloud ID" : "Type een e-mail of gefedereerde cloud ID",
    "Unable to load the shares list" : "Kon de shares-lijst niet laden",
    "Expires {relativetime}" : "Vervalt {relativetime}",
    "this share just expired." : "deze share is net verlopen.",
    "Shared with you by {owner}" : "Met je gedeeld door {owner}",
    "Internal shares" : "Intern delen",
    "Internal shares explanation" : "Uitleg over interne shares",
    "External shares" : "Extern delen",
    "External shares explanation" : "Uitleg over externe shares",
    "Additional shares" : "Aanvullende shares",
    "Additional shares explanation" : "Uitleg over aanvullende shares",
    "Link to a file" : "Link naar een bestand",
    "_Accept share_::_Accept shares_" : ["Accepteer share","Accepteer shares"],
    "Open in Files" : "Open in Bestanden",
    "_Reject share_::_Reject shares_" : ["Wijs share af","Wijs shares af"],
    "_Restore share_::_Restore shares_" : ["Herstel share","Herstel shares"],
    "Shared" : "Gedeeld",
    "Shared by {ownerDisplayName}" : "Gedeeld door {ownerDisplayName}",
    "Shared multiple times with different people" : "Meerdere keren gedeeld met verschillende mensen",
    "Sharing options" : "Deel opties",
    "Shared with others" : "Gedeeld met anderen",
    "You do not have enough permissions to share this file." : "Je hebt niet genoeg machtigingen om dit bestand te delen.",
    "People" : "Mensen",
    "Create file request" : "Maak bestandsaanvraag",
    "Upload files to {foldername}" : "Upload bestanden naar {foldername}",
    "Public file share" : "Openbare bestandsshare",
    "Publicly shared file." : "Openbaar gedeeld bestand.",
    "No file" : "Geen bestand",
    "The file shared with you will show up here" : "Het bestand dat met je gedeeld wordt, wordt hier getoond.",
    "Public share" : "Openbare deellink",
    "Publicly shared files." : "Openbaar gedeelde bestanden.",
    "No files" : "Geen bestanden",
    "Files and folders shared with you will show up here" : "Bestanden en mappen die met je gedeeld worden, worden hier getoond",
    "Overview of shared files." : "Overzicht van gedeelde bestanden.",
    "No shares" : "Geen shares",
    "Files and folders you shared or have been shared with you will show up here" : "Bestanden en mappen die je gedeeld hebt of die met je gedeeld zijn, worden hier getoond",
    "Shared with you" : "Met je gedeeld",
    "List of files that are shared with you." : "Lijst van bestanden die met je gedeeeld zijn.",
    "Nothing shared with you yet" : "Nog niets met je gedeeld",
    "Files and folders others shared with you will show up here" : "Bestanden en mappen die anderen met je delen, worden hier getoond",
    "List of files that you shared with others." : "Lijst van bestanden die je met anderen gedeeld hebt.",
    "Nothing shared yet" : "Nog niets gedeeld",
    "Files and folders you shared will show up here" : "Bestanden en mappen die je deelt, worden hier getoond",
    "Shared by link" : "Gedeeld via een link",
    "List of files that are shared by link." : "Lijst van bestanden die door een link gedeeld zijn.",
    "No shared links" : "Geen gedeelde links",
    "Files and folders you shared by link will show up here" : "Bestanden en mappen die je via links deelt, worden hier getoond",
    "File requests" : "Bestandsaanvragen",
    "List of file requests." : "Lijst met bestandsverzoeken.",
    "No file requests" : "Geen bestandsverzoeken",
    "File requests you have created will show up here" : "Bestandsverzoeken die je hebt aangemaakt, worden hier weergegeven",
    "Deleted shares" : "Verwijderde shares",
    "List of shares you left." : "Lijst met shares die je hebt verlaten.",
    "No deleted shares" : "Geen verwijderde shares",
    "Shares you have left will show up here" : "Shares die je hebt verlaten, verschijnen hier",
    "Pending shares" : "Deellinks in behandeling",
    "List of unapproved shares." : "Lijst van niet-goedgekeurde shares.",
    "No pending shares" : "Geen deellinks in behandeling",
    "Shares you have received but not approved will show up here" : "Shares die je hebt ontvangen maar niet hebt goedgekeurd, verschijnen hier",
    "Error deleting the share" : "Fout bij verwijderen share",
    "Error updating the share" : "Fout tijdens bijwerken share",
    "File \"{path}\" has been unshared" : "Bestand \"{path}\" is niet meer gedeeld",
    "Folder \"{path}\" has been unshared" : "Map \"{path}\" is niet meer gedeeld",
    "Could not update share" : "Kon share niet bijwerken",
    "Share saved" : "Share opgeslagen",
    "Share expiry date saved" : "Share vervaldatum opgeslagen",
    "Share hide-download state saved" : "Share verberg-download status opgeslagen",
    "Share label saved" : "Share label opgeslagen",
    "Share note for recipient saved" : "Share notitie voor ontvanger opgeslagen",
    "Share password saved" : "Share wachtwoord opgeslagen",
    "Share permissions saved" : "Share machtigingen opgeslagen",
    "To upload files to {folder}, you need to provide your name first." : "Om bestanden te uploaden naar {folder}, moet je eerst je naam opgeven.",
    "Upload files to {folder}" : "Upload bestanden naar {folder}",
    "Please confirm your name to upload files to {folder}" : "Bevestig je naam om bestanden naar {folder} te uploaden",
    "{ownerDisplayName} shared a folder with you." : "{ownerDisplayName} deelde een map met je.",
    "Names must not be empty." : "Namen mogen niet leeg zijn.",
    "Names must not start with a dot." : "Namen mogen niet met een punt beginnen.",
    "\"{char}\" is not allowed inside a name." : "\"{char}\" is niet toegestaan in een naam.",
    "\"{segment}\" is a reserved name and not allowed." : "\"{segment}\" is een gereserveerde naam en niet toegestaan.",
    "\"{extension}\" is not an allowed name." : "\"{extension}\" is geen toegestane naam.",
    "Names must not end with \"{extension}\"." : "Namen mogen niet eindigen met \"{extension}\".",
    "Invalid name." : "Ongeldige naam.",
    "Password created successfully" : "Wachtwoord succesvol gemaakt",
    "Error generating password from password policy" : "Fout bij genereren wachtwoord vanuit wachtwoordbeleid",
    "Shared with you and the group {group} by {owner}" : "Met jou en de groep {group} gedeeld door {owner}",
    "Shared with you and {circle} by {owner}" : "Gedeeld met jou en {circle} door {owner}",
    "Shared with you and the conversation {conversation} by {owner}" : "Gedeeld met jou en gesprek {conversation} door {owner}",
    "Shared with you in a conversation by {owner}" : "Met jou in een gesprek gedeeld door {owner}",
    "Share not found" : "Gedeelde map niet gevonden",
    "Back to %s" : "Terug naar %s",
    "Add to your Nextcloud" : "Toevoegen aan je Nextcloud",
    "Group sharing is disabled by the administrator" : "Delen voor groepen is uitgeschakeld door de beheerder",
    "Public link sharing is disabled by the administrator" : "Delen van openbare links is uitgeschakeld door de beheerder",
    "Sharing %1$s failed because the back end does not allow shares from type %2$s" : "Delen van %1$s mislukte omdat de backend het delen van type %2$s niet ondersteunt",
    "Sharing %s failed because the back end does not support ScienceMesh shares" : "Delen %s is mislukt omdat het back-end geen ScienceMesh-shares ondersteunt",
    "Public upload disabled by the administrator" : "Publieke upload uitgeschakeld door de systeembeheerder",
    "Tokens must contain at least 1 character and may only contain letters, numbers, or a hyphen" : "Tokens moeten minimaal 1 teken bevatten en mogen alleen letters, cijfers of een koppelteken bevatten",
    "Name or email …" : "Naam of e-mailadres …",
    "Name, email, or Federated Cloud ID …" : "Naam, e-mailadres of gefedereerde Cloud-ID …",
    "Searching …" : "Zoeken ..."
},
"nplurals=2; plural=(n != 1);");
