.collection[data-v-aecef337]{display:flex;flex-direction:column}.collection__media[data-v-aecef337]{padding:0 64px}@media only screen and (max-width:1200px){.collection__media[data-v-aecef337]{padding:0 4px}}
