<?php

declare (strict_types=1);
namespace OCA\Notifications\Vendor\SpomkyLabs\Pki\ASN1\Exception;

use RuntimeException;
/**
 * Exception thrown on decoding errors.
 */
final class DecodeException extends RuntimeException
{
}