OC.L10N.register(
    "circles",
    {
    "You created the team {circle}" : "Stvorili ste tim {circle}",
    "{author} created the team {circle}" : "{author} je stvorio tim {circle}",
    "You deleted {circle}" : "Izbrisali ste {circle}",
    "{author} deleted {circle}" : "{author} je izbrisao {circle}",
    "You made {member} join {circle}" : "Uključili ste {member} u {circle}",
    "{author} made {member} join {circle}" : "{author} je uključio {member} u {circle}",
    "You added team {member} as member to {circle}" : "Dodali ste tim {member} kao člana u {circle}",
    "{author} added team {member} as member to {circle}" : "{author} je dodao tim {member} kao člana u {circle}",
    "You made {member} leave {circle}" : "Uklonili ste {member} iz {circle}",
    "{author} made {member} leave {circle}" : "{author} je uklonio {member} iz {circle}",
    "You removed {member} from {circle}" : "Uklonili ste {member} iz {circle}",
    "{author} removed {member} from {circle}" : "{author} je uklonio {member} iz {circle}",
    "You joined {circle}" : "Pridružili ste se {circle}",
    "{member} joined {circle}" : "{member} se pridružio {circle}",
    "You accepted the invitation to join {circle}" : "Prihvatili ste pozivnicu za pridruživanje {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} je prihvatio pozivnicu za pridruživanje {circle}",
    "You added {member} as member to {circle}" : "Dodali ste {member} kao člana u {circle}",
    "You have been added as member to {circle} by {author}" : "{author} vas je dodao kao člana u {circle}",
    "{member} has been added as member to {circle} by {author}" : "{author} je dodao {member} kao člana u {circle}",
    "You added {external} to {circle}" : "Dodali ste {external} u {circle}",
    "{external} has been added to {circle} by {author}" : "{author} je dodao {external} u {circle}",
    "You accepted {member}'s request to join {circle}" : "Prihvatili ste poziv {member} na sudjelovanje u {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Vaš zahtjev za pridruživanje {circle} prihvatio je {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "{author} je prihvatio zahtjev {member} za pridruživanje {circle}",
    "You left {circle}" : "Napustili ste {circle}",
    "{member} left {circle}" : "{member} je napustio {circle}",
    "You declined the invitation to join {circle}" : "Odbili ste poziv za pridruživanje {circle}",
    "{member} declined an invitation to join {circle}" : "{član} je odbio poziv za pridruživanje {circle}",
    "You cancelled your request to join {circle}" : "Otkazali ste zahtjev za pridruživanje {circle}",
    "{member} cancelled a request to join {circle}" : "{member} je otkazao zahtjev za pridruživanje {circle}",
    "You have been removed from {circle} by {author}" : "{author} vas je uklonio iz {circle}",
    "{member} has been removed from {circle} by {author}" : "{author} je uklonio {member} iz {circle}",
    "You removed {external} from {circle}" : "Uklonili ste {external} iz {circle}",
    "{external} has been removed from {circle} by {author}" : "{author} je uklonio {external} iz {circle}",
    "You cancelled {member}'s invitation to join {circle}" : "Otkazali ste poziv {member} na sudjelovanje u {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "{author} je otkazao vaš poziv za pridruživanje {circle}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} je otkazao poziv {member} na sudjelovanje u {circle}",
    "You dismissed {member}'s request to join {circle}" : "Zanemarili ste poziv {member} na sudjelovanje u {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "{author} je zanemario vaš zahtjev za pridruživanje {circle}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{author} je zanemario zahtjev {member} za pridruživanje {circle}",
    "You invited {member} to join {circle}" : "Pozvali ste {member} da se pridruži {circle}",
    "You have been invited to join {circle} by {author}" : "{author} vas je pozvao da se pridružite {circle}",
    "{member} has been invited to join {circle} by {author}" : "{author} je pozvao {member} da se pridruži {circle}",
    "You changed {member}'s level in {circle} to %1$s" : "Promijenili ste razinu {member} u {circle} na %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} je promijenio vašu razinu u {circle} na %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} je promijenio razinu {member} u {circle} na %1$s",
    "You sent a request to join {circle}" : "Poslali ste zahtjev za pridruživanje {circle}",
    "{member} sent a request to join {circle}" : "{member} je poslao zahtjev za pridruživanje {circle}",
    "You are the new owner of {circle}" : "Vi ste novi vlasnik {circle}",
    "{member} is the new owner of {circle}" : "{member} je novi vlasnik {circle}",
    "Teams" : "Timovi",
    "On events happening in a <strong>team</strong> of which you are a member" : "O događajima u <strong>timu</strong> čiji ste član",
    "Any important event in a <strong>team</strong> you are moderating" : "Bilo koji važan događaj u <strong>timu</strong> koji moderirate",
    "On global events happening in any <strong>team</strong>" : "O globalnim događajima koji se događaju u bilo kojem<strong>timu</strong>",
    "Single" : "Jedan",
    "Personal" : "Osobno",
    "System" : "Sustav",
    "Visible" : "Vidljivo",
    "Open" : "Otvori",
    "Invite" : "Poziv",
    "Join request" : "Pridruži se",
    "Friends" : "Prijatelji",
    "Password protected" : "Zaštićeno zaporkom",
    "No Owner" : "Nema vlasnika",
    "Hidden" : "Skriveno",
    "Backend" : "Pozadinski sustav",
    "Local" : "Lokalno",
    "Root" : "Korijen",
    "Team invite" : "Timski poziv",
    "Federated" : "Udruženo",
    "Mount point" : "Točka postavljanja",
    "App" : "Aplikacija",
    "Nextcloud Account" : "Nextcloud račun",
    "Nextcloud Group" : "Nextcloud grupa",
    "Email address" : "Adresa e-pošte",
    "Contact" : "Kontakt",
    "Team" : "Tim",
    "Nextcloud App" : "Nextcloud aplikacija",
    "Teams App" : "Aplikacija Timovi",
    "Admin Command Line" : "Administratorska naredbena linija",
    "Member" : "Član",
    "Moderator" : "Moderator",
    "Admin" : "Administrator",
    "Owner" : "Vlasnik",
    "%s shared »%s« with you." : "%s dijeli »%s« s vama.",
    "%s shared »%s« with \"%s\"." : "%s dijeli »%s« s „%s“.",
    "%s on %s" : "%s na %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s dijeli »%2$s« s vama.\nTrebali ste već primiti poruku e-pošte s poveznicom za pristupanje.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s dijeli »%2$s« s vama. Trebali ste već primiti poruku e-pošte s poveznicom za pristupanje.",
    "Password to access »%1$s« shared to you by %2$s" : "Zaporku za pristupanje »%1$s« s vama dijeli %2$s",
    "Password to access »%s«" : "Zaporka za pristupanje »%s«",
    "It is protected with the following password:" : "Zaštićeno je sljedećom zaporkom:",
    "%1$s via %2$s" : "%1$s putem %2$s",
    "Click the button below to open it." : "Kliknite gumb u nastavku za otvaranje.",
    "Open »%s«" : "Otvori »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s dijeli više datoteka s vama.\nTrebali ste primiti poruku e-pošte s poveznicom za pristupanje datotekama.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s dijeli više datoteka s vama. Trebali ste primiti poruku e-pošte s poveznicom za pristupanje datotekama.",
    "Password to access files shared to you by %1$s" : "Zaporka za pristupanje datotekama koju s vama dijeli %1$s",
    "Password to access files" : "Zaporka za pristupanje datotekama",
    "%s shared multiple files with \"%s\"." : "%s dijeli više datoteka s „%s“.",
    "%s shared multiple files with you." : "%s dijeli više datoteka s vama.",
    "Boot up" : "Pokreni",
    "Nextcloud Initialization" : "Nextcloud inicijalizacija",
    "Fresh installation status" : "Status svježe instalacije",
    "Building Local Database" : "Izgradnja lokalne baze podataka",
    "Testing Basic Team Creation" : "Ispitivanje stvaranja osnovnog tima",
    "Adding local users and moderators" : "Dodavanje lokalnih korisnika i moderatora",
    "Show all teams" : "Prikaži sve timove",
    "Create a new team" : "Stvori novi tim",
    "Files" : "Datoteke",
    "This feature is not available for personal teams" : "Ova značajka nije dostupna za osobne timove",
    "The team is not federated" : "Tim nije udruženi",
    "You cannot join this team" : "Ne možete se pridružiti ovom timu",
    "This member is not a moderator" : "Ovaj član nije moderator",
    "Insufficient privileges" : "Nedovoljne ovlasti",
    "This member does not exist" : "Ovaj član ne postoji",
    "This member is the owner of the team" : "Ovaj član je vlasnik tima",
    "Level cannot be changed for this type of member" : "Razina se ne može promijeniti za ovu vrstu člana",
    "You are already a member of this team" : "Već ste član ovog tima",
    "You have been blocked from this team" : "Blokirani ste iz ovog tima",
    "The account is already a member of this team" : "Vaš račun je već član ovog tima",
    "The account has already been invited into this team" : "Ovaj račun je već pozvan u ovaj tim",
    "%s (Team owned by %s)" : "%s (Tim u vlasništvu %s)",
    "You are now a member of the Team \"%2$s\"" : "Niste član tima \"%2$s\"",
    "You have been invited by %1$s into the Team \"%2$s\"" : "%1$s vas je pozvao u tim „%2$s”",
    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$s je poslao zahtjev za učlanjenje u tim „%2$s”",
    "Accept" : "Prihvati",
    "Refuse" : "Odbij",
    "Leave the team" : "Napusti tim",
    "No image file provided" : "Nijedna slika nije dobavljena",
    "Invalid file provided" : "Nevažeća datoteka",
    "File is too big" : "Datoteka je prevelika",
    "Invalid image" : "Slika neispravna",
    "Unknown filetype" : "Vrsta datoteke nepoznata",
    "%s" : "%s",
    "Personal team" : "Osobni tim",
    "%s owned by %s" : "%s u vlasništvu %s",
    "You have no permission to create a new team" : "Nemate dopuštenje za stvaranje novog tima",
    "%s shared a file with \"%s\"." : "%s dijeli datoteku s \"%s\".",
    "%s shared a file with you." : "%s dijeli datoteku s vama.",
    "%1$s shared %2$s with %3$s" : "%1$s dijeli %2$s s %3$s",
    "%1$s shared %2$s with \"%3$s\"" : "%1$s dijeli %2$s s \"%3$s\"",
    "Open %s" : "Otvori %s",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s je podijelio neki sadržaj s vama.\nTrebali ste već primiti zasebnu e-poruku s poveznicom za pristupanje.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s je podijelio neki sadržaj s vama.\nTrebali ste već primiti zasebnu e-poruku s poveznicom za pristupanje.",
    "Password to access content shared with you by %1$s" : "Zaporka za pristupanje sadržaju koju s vama dijeli %1$s",
    "Password to access content" : "Zaporka za pristupanje sadržaju",
    "Federated Teams" : "Udruženi timovi",
    "This item is already shared with this team" : "Ova se stavka već dijeli s ovim timom",
    "Bring cloud-users closer together." : "Približite korisnike oblaka.",
    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Timovi omogućuju korisnicima stvaranje vlastite grupe korisnika/kolega/prijatelja.\nTe grupe korisnika tada možete upotrebljavati za dijeljenje unutar bilo koje druge aplikacije.",
    "Unable to update federated teams config" : "Nije moguće ažurirati konfiguraciju udruženih timova",
    "Invalid URL format. Please provide a valid URL." : "Nevažeći format URL-a. Unesite valjani URL.",
    "Changed frontal cloud URL" : "Promijenjen frontalni URL oblaka",
    "Federation allows you to share teams with other trusted servers and make them discoverable across instances." : "Udruženje vam omogućuje dijeljenje timova s drugim pouzdanim poslužiteljima i njihovo otkrivanje među instancama.",
    "Enable federated teams" : "Omogući udružene timove",
    "Frontal URL" : "Frontalni URL",
    "https://…" : "https://…",
    "The public URL used by other instances to discover and connect to your teams." : "Javni URL koji druge instance koriste za otkrivanje i povezivanje s vašim timovima.",
    "Unlimited" : "Neograničeno",
    "Default quota" : "Zadana kvota",
    "Select default quota" : "Odaberi zadanu kvotu",
    "Save" : "Spremi",
    "Reconnect" : "Ponovno povezivanje",
    "Connect" : "Poveži",
    "Overview" : "Pregled",
    "No teams found" : "Nema pronađenih timova",
    "Members" : "Članovi",
    "Cancel" : "Otkaži",
    "Next" : "Dalje",
    "Back" : "Natrag",
    "Team name" : "Naziv tima",
    "Switch to list view" : "Prebacite na prikaz popisa",
    "Switch to grid view" : "Prebacite se na prikaz rešetke",
    "Folder" : "Mapa",
    "you" : "vi",
    "Copy link" : "Kopiraj poveznicu",
    "Enable federation" : "Omogući udruženja",
    "Copied" : "Kopirano",
    "Create link" : "Stvori poveznicu",
    "Close" : "Zatvori",
    "New folder" : "Nova mapa",
    "Folder name" : "Naziv mape",
    "Talk conversation" : "Razgovori u alatu Talk",
    "Conversation name" : "Ime razgovora",
    "Calendar" : "Kalendar",
    "New calendar" : "Novi kalendar",
    "Calendar name" : "Naziv kalendara",
    "Please select a valid png or jpg file" : "Odaberite valjanu PNG ili JPG datoteku",
    "Description" : "Opis",
    "Edit" : "Uredi",
    "Create" : "Stvori",
    "Show in Calendar" : "Prikaži u kalendaru",
    "Add" : "Dodaj",
    "Apply" : "Primijeni",
    "Remove {type}" : "Ukloni {type}",
    "Search {types}" : "Traži {types}",
    "Loading …" : "Učitavanje …",
    "No results" : "Nema rezultata",
    "Add {type}" : "Dodaj {type}",
    "Pending" : "Na čekanju",
    "Role" : "Uloga",
    "Add to {team}" : "Dodaj u {team}",
    "Try again" : "Pokušajte ponovno",
    "Create your first team" : "Stvori svoj prvi tim",
    "Loading" : "Učitavanje",
    "Go back" : "Natrag",
    "Join" : "Pridruži se",
    "Failed to load teams" : "Učitavanje timova nije uspjelo",
    "Join or create teams to see them here." : "Pridružite se ili stvorite timove da biste ih vidjeli ovdje.",
    "Loading…" : "Učitavanje…",
    "More teams" : "Više timova",
    "All contacts" : "Svi kontakti",
    "Recently contacted" : "Nedavno kontaktiran",
    "User" : "Korisnik",
    "Group" : "Grupa",
    "Email" : "E-pošta",
    "Federation" : "Udruženje",
    "Privacy" : "Privatnost",
    "Users" : "Korisnici",
    "Groups" : "Grupe",
    "Federated users" : "Udruženi korisnici",
    "Contacts" : "Kontakti",
    "No files in here" : "Nema datoteka",
    "No entries found in this folder" : "U ovoj mapi nisu pronađeni nikakvi zapisi",
    "Name" : "Naziv",
    "Size" : "Veličina",
    "Modified" : "Promijenjeno",
    "Circles App Initialization" : "Inicijalizacija aplikacije Krugovi"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
