OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Kata sandi kunci pemulihan tidak ada",
    "Please repeat the recovery key password" : "Silakan ulangi kata sandi kunci pemulihan",
    "Repeated recovery key password does not match the provided recovery key password" : "Kata sandi kunci pemulihan yang diulangi tidak cocok dengan kata sandi kunci pemulihan yang diberikan",
    "Recovery key successfully enabled" : "Kunci pemulihan berhasil diaktifkan",
    "Could not enable recovery key. Please check your recovery key password!" : "Tidak dapat mengaktifkan kunci pemulihan. Silakan periksa kata sandi kunci pemulihan Anda!",
    "Recovery key successfully disabled" : "Kunci pemulihan berhasil dinonaktifkan",
    "Could not disable recovery key. Please check your recovery key password!" : "Tidak dapat menonaktifkan kunci pemulihan. Silakan periksa kata sandi kunci pemulihan Anda!",
    "Please provide the old recovery password" : "Mohon berikan kata sandi pemulihan lama",
    "Please provide a new recovery password" : "Mohon berikan kata sandi pemulihan baru",
    "Please repeat the new recovery password" : "Silakan ulangi sandi pemulihan baru",
    "Password successfully changed." : "Kata sandi berhasil diubah.",
    "Could not change the password. Maybe the old password was not correct." : "Tidak dapat mengubah kata sandi. Kemungkinan kata sandi lama yang dimasukkan salah.",
    "Recovery Key disabled" : "Kunci Pemulihan dinonaktifkan",
    "Recovery Key enabled" : "Kunci Pemulihan diaktifkan",
    "Could not enable the recovery key, please try again or contact your administrator" : "Tidak dapat mengaktifkan kunci pemulihan, silakan coba lagi atau hubungi administrator Anda",
    "Could not update the private key password." : "Tidak dapat memperbarui kata sandi kunci private.",
    "The old password was not correct, please try again." : "Kata sandi lama salah, mohon coba lagi.",
    "The current log-in password was not correct, please try again." : "Kata sandi masuk saat ini salah, mohon coba lagi.",
    "Private key password successfully updated." : "Sandi kunci privat berhasil diperbarui.",
    "Invalid private key for encryption app. Please update your private key password in your personal settings to recover access to your encrypted files." : "Kunci privat tidak sah untuk aplikasi enkripsi. Silakan perbarui kata sandi kunci privat Anda pada pengaturan pribadi untuk memulihkan akses ke berkas Anda yang dienkripsi.",
    "Encryption App is enabled, but your keys are not initialized. Please log-out and log-in again." : "Apl Enkripsi telah aktif, tapi kunci Anda tidak diinisialisasikan. Harap keluar-log dan masuk-log kembali.",
    "Please enable server side encryption in the admin settings in order to use the encryption module." : "Silakan aktifkan enkripsi sisi-peladen pada setelan admin untuk menggunakan modul enkripsi.",
    "Encryption app is enabled and ready" : "Apl enkripsi aktif dan siap",
    "Bad Signature" : "Tanda salah",
    "Missing Signature" : "Tanda hilang",
    "one-time password for server-side-encryption" : "kata sandi sekali pakai untuk server-side-encryption",
    "Encryption password" : "Sandi enkripsi",
    "The administration enabled server-side-encryption. Your files were encrypted using the password <strong>%s</strong>." : "Administrasi mengaktifkan enkripsi sisi server. File Anda dienkripsi menggunakan kata sandi <strong>%s</strong>.",
    "The administration enabled server-side-encryption. Your files were encrypted using the password \"%s\"." : "Administrasi mengaktifkan enkripsi sisi server. File Anda dienkripsi menggunakan kata sandi \"%s\".",
    "Please login to the web interface, go to the \"Security\" section of your personal settings and update your encryption password by entering this password into the \"Old login password\" field and your current login password." : "Silakan masuk ke antarmuka web, buka bagian \"Keamanan\" pada pengaturan pribadi Anda, lalu perbarui kata sandi enkripsi Anda dengan memasukkan kata sandi ini ke kolom \"Kata sandi login lama\" serta kata sandi login Anda saat ini.",
    "Cannot decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Tidak dapat mendekripsi file ini, mungkin ini adalah file bersama. Harap minta pemilik file untuk membagikan ulang file dengan Anda.",
    "Cannot read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Tidak dapat membaca file ini, mungkin ini adalah file bersama. Harap minta pemilik file untuk membagikan ulang file dengan Anda.",
    "Default Encryption Module" : "Modul Enkripsi Default",
    "Default encryption module for Nextcloud Server-side Encryption (SSE)" : "Modul enkripsi default untuk Enkripsi Sisi Server Nextcloud (SSE)",
    "This app provides the (default) cryptography implementation for Nextcloud's Server-side Encryption (SSE) feature.\n\n\t\t\t**Encryption Details**\n\t\t\t*   **Cipher Mode:** AES-256-CTR (default)\n\t\t\t*   **Authentication:** HMAC-SHA256\n\n\t\t\t**Important Warnings**\n\t\t\t*   **DANGER:** Do not disable this application until all files have been decrypted (`occ encryption:decrypt-all`).\n\t\t\t*   **WARNING**: Reverting to non-encrypted file storage after activation requires command-line access. The action is permanent via the Web UI.\"\n\n\t\t\t**Notes for Existing Files**\n\t\t\t*   By default, enabling SSE does not encrypt existing files; only new files will be encrypted.\n\t\t\t*   To encrypt all existing files, use the command `occ encryption:encrypt-all`.\n\n\t\t\t**Before You Begin**\n\t\t\t*   **Read the Documentation:** Before you enable SSE, encrypt existing files, or disable SSE, it is critical to\n\t\t\t\tread the documentation to understand implications and the appropriate procedures to avoid data loss." : "Aplikasi ini menyediakan implementasi kriptografi (default) untuk fitur Enkripsi Sisi Server (SSE) Nextcloud.\n\n\t\t\t**Rincian Enkripsi**\n\t\t\t*   **Mode Sandi:** AES-256-CTR (default)\n\t\t\t*   **Autentikasi:** HMAC-SHA256\n\n\t\t\t**Peringatan Penting**\n\t\t\t*  **BAHAYA:** Jangan menonaktifkan aplikasi ini sampai semua file telah didekripsi (`occ encryption:decrypt-all`).\n\t\t\t*   **PERINGATAN**: Mengembalikan penyimpanan file tanpa enkripsi setelah aktivasi memerlukan akses baris perintah. Tindakan ini bersifat permanen melalui UI Web.\"\n\n\t\t\t**Catatan untuk File yang Sudah Ada**\n\t\t\t*   Secara default, mengaktifkan SSE tidak mengenkripsi file yang sudah ada; hanya file baru yang akan dienkripsi.\n\t\t\t*   Untuk mengenkripsi semua file yang sudah ada, gunakan perintah `occ encryption:encrypt-all`.\n\n\t\t\t**Sebelum Anda Memulai**\n\t\t\t*   **Baca Dokumentasi:** Sebelum Anda mengaktifkan SSE, mengenkripsi file yang sudah ada, atau menonaktifkan SSE, sangat penting untuk\n\t\t\t\tmembaca dokumentasi untuk memahami implikasi dan prosedur yang tepat guna menghindari kehilangan data.",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "Mengaktifkan opsi ini akan mengenkripsi semua berkas yang disimpan pada penyimpanan utama, jika tidak diaktifkan maka hanya berkas pada penyimpanan eksternal saja yang akan dienkripsi",
    "Encrypt the home storage" : "Enkripsi penyimpanan rumah",
    "Disable recovery key" : "Nonaktifkan kunci pemulihan",
    "Enable recovery key" : "Aktifkan kunci pemulihan",
    "The recovery key is an additional encryption key used to encrypt files. It is used to recover files from an account if the password is forgotten." : "Kunci pemulihan adalah kunci enkripsi tambahan yang digunakan untuk mengenkripsi file. Kunci ini digunakan untuk memulihkan file dari suatu akun jika kata sandi terlupa.",
    "Recovery key password" : "Kata sandi kunci pemulihan",
    "Passwords fields do not match" : "Kolom kata sandi tidak cocok",
    "Repeat recovery key password" : "Ulangi kata sandi kunci pemulihan",
    "An error occurred while updating the recovery key settings. Please try again." : "Terjadi kesalahan saat memperbarui pengaturan kunci pemulihan. Silakan coba lagi.",
    "Change recovery key password" : "Ubah kata sandi kunci pemulihan",
    "Old recovery key password" : "Kata sandi kunci pemulihan lama",
    "New recovery key password" : "Kata sandi kunci pemulihan baru",
    "Repeat new recovery key password" : "Ulangi sandi kunci pemulihan baru",
    "An error occurred while changing the recovery key password. Please try again." : "Terjadi kesalahan saat mengubah kata sandi kunci pemulihan. Silakan coba lagi.",
    "Update private key password" : "Perbarui kata sandi kunci privat",
    "Your private key password no longer matches your log-in password. Set your old private key password to your current log-in password." : "Kata sandi kunci privat Anda tidak lagi cocok dengan kata sandi login Anda. Atur kata sandi kunci privat lama Anda menjadi kata sandi login Anda saat ini.",
    "If you do not remember your old password you can ask your administrator to recover your files." : "Jika Anda tidak ingat kata sandi lama Anda, Anda dapat meminta administrator Anda untuk memulihkan file Anda.",
    "Old log-in password" : "Kata sandi masuk yang lama",
    "Current log-in password" : "Kata sandi masuk saat ini",
    "Update" : "Perbarui",
    "Updating recovery keys. This can take some time…" : "Memperbarui kunci pemulihan. Ini dapat memerlukan beberapa waktu…",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Mengaktifkan opsi ini memungkinkan Anda untuk mendapatkan kembali akses ke berkas terenkripsi Anda dalam kasus kehilangan kata sandi",
    "Enable password recovery" : "Aktifkan pemulihan kata sandi",
    "Default encryption module" : "Modul bawaan enkripsi",
    "Encryption app is enabled but your keys are not initialized, please log-out and log-in again" : "Aplikasi enkripsi telah diaktifkan tetapi kunci tidak terinisialisasi, silakan log-out dan log-in lagi",
    "Basic encryption module" : "Modul enkripsi dasar",
    "Missing parameters" : "Parameter salah",
    "Default encryption module for server-side encryption" : "Modul enkripsi bawaan pada enkripsi sisi-peladen",
    "In order to use this encryption module you need to enable server-side encryption in the admin settings. Once enabled this module will encrypt all your files transparently. The encryption is based on AES 256 keys.\nThe module will not touch existing files, only new files will be encrypted after server-side encryption was enabled. It is also not possible to disable the encryption again and switch back to an unencrypted system.\nPlease read the documentation to know all implications before you decide to enable server-side encryption." : "Untuk menggunakan modul enkripsi ini, Anda perlu mengaktifkan enkripsi sisi server di pengaturan admin. Setelah diaktifkan, modul ini akan mengenkripsi semua file Anda secara transparan. Enkripsi ini berbasis kunci AES 256.\nModul ini tidak akan menyentuh file yang sudah ada, hanya file baru yang akan dienkripsi setelah enkripsi sisi server diaktifkan. Selain itu, enkripsi tidak dapat dinonaktifkan lagi dan beralih kembali ke sistem tanpa enkripsi.\nSilakan baca dokumentasi untuk mengetahui semua implikasinya sebelum Anda memutuskan untuk mengaktifkan enkripsi sisi server.",
    "Change recovery key password:" : "Ubah kata sandi kunci pemulihan:",
    "Change Password" : "Ubah Sandi",
    "Your private key password no longer matches your log-in password." : "Kata sandi kunci private Anda tidak lagi cocok dengan kata sandi masuk Anda.",
    "Set your old private key password to your current log-in password:" : "Setel kata sandi kunci private Anda untuk kata sandi masuk Anda saat ini:",
    "Update Private Key Password" : "Perbarui Kata Sandi Kunci Private",
    "Enable password recovery:" : "Aktifkan kata sandi pemulihan:",
    "Enabled" : "Diaktifkan",
    "Disabled" : "Dinonaktifkan",
    "This app provides the (default) cryptography implementation for Nextcloud's Server-side Encryption (SSE) feature.\n\n\t\t\t**Encryption Details**\n\t\t\t*   **Cipher Mode:** AES-256-CTR (default)\n\t\t\t*   **Authentication:** HMAC-SHA256\n\n\t\t\t**Important Warnings**\n\t\t\t*   **DANGER:** Do not disable this application until all files have been decrypted (`occ encryption:decrypt-all`).\n\t\t\t*   **WARNING**: Reverting to non-encrypted file storage after activation requires command-line access. The action is permanent via the Web UI.\"\n\n\t\t\t**Notes for Existing Files**\n\t\t\t*   By default, enabling SSE does not encrypt existing files; only new files will be encrypted.\n\t\t\t*   To encrypt all existing files, use the command `occ encryption:encrypt-all`.\n\n\t\t\t**Before You Begin**\n\t\t\t*   **Read the Documentation:** Before you enable SSE, encrypt existing files, or disable SSE, it is critical to \n\t\t\t\tread the documentation to understand implications and the appropriate procedures to avoid data loss." : "Aplikasi ini menyediakan implementasi kriptografi (default) untuk fitur Enkripsi Sisi Server (SSE) Nextcloud.\n\n\t\t\t**Rincian Enkripsi**\n\t\t\t*   **Mode Sandi:** AES-256-CTR (default)\n\t\t\t*   **Autentikasi:** HMAC-SHA256\n\n\t\t\t**Peringatan Penting**\n\t\t\t*  **BAHAYA:** Jangan menonaktifkan aplikasi ini sampai semua file telah didekripsi (`occ encryption:decrypt-all`).\n\t\t\t*   **PERINGATAN**: Mengembalikan penyimpanan file tanpa enkripsi setelah aktivasi memerlukan akses baris perintah. Tindakan ini bersifat permanen melalui UI Web.\"\n\n\t\t\t**Catatan untuk File yang Sudah Ada**\n\t\t\t*   Secara default, mengaktifkan SSE tidak mengenkripsi file yang sudah ada; hanya file baru yang akan dienkripsi.\n\t\t\t*   Untuk mengenkripsi semua file yang sudah ada, gunakan perintah `occ encryption:encrypt-all`.\n\n\t\t\t**Sebelum Anda Memulai**\n\t\t\t*   **Baca Dokumentasi:** Sebelum Anda mengaktifkan SSE, mengenkripsi file yang sudah ada, atau menonaktifkan SSE, sangat penting untuk \n\t\t\t\tmembaca dokumentasi untuk memahami implikasi dan prosedur yang tepat guna menghindari kehilangan data."
},
"nplurals=1; plural=0;");
