OC.L10N.register(
    "serverinfo",
    {
    "System" : "Σύστημα",
    "Unknown" : "Άγνωστο",
    "Monitoring" : "Παρακολούθηση",
    "Monitoring app with useful server information" : "Εφαρμογή παρακολούθησης πληροφοριών διακομιστή",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Εμφανίζει χρήσιμες πληροφορίες του διακομιστή, όπως χρήση CPU, RAM, σκληρού δίσκου, αριθμός χρηστών, κλτ.",
    "Active users" : "Ενεργοί χρήστες",
    "Last hour" : "Τελευταία ώρα",
    "Last 24 Hours" : "Τελευταίες 24 Ώρες",
    "Last 7 Days" : "Τελευταίες 7 Ημέρες",
    "Last 30 Days" : "Τελευταίες 30 Ημέρες",
    "Webcron" : "Webcron",
    "Background jobs" : "Εργασίες παρασκηνίου",
    "Mode" : "Λειτουργία",
    "Never" : "Ποτέ",
    "Load" : "Χρήση",
    "CPU info not available" : "Οι πληροφορίες επεξεργαστή CPU δεν είναι διαθέσιμες",
    "Current usage" : "Τρέχουσα χρήση",
    "Threads" : "Θέματα",
    "Load average" : "Μέσος όρος φόρτωσης",
    "Database" : "Βάση δεδομένων",
    "Type:" : "Τύπος:",
    "Version:" : "Έκδοση:",
    "Size:" : "Μέγεθος:",
    "Used" : "Σε χρήση",
    "Available" : "Διαθέσιμα",
    "Disk" : "Δίσκος",
    "Files" : "Αρχεία",
    "Mount:" : "Προσάρτηση:",
    "Filesystem:" : "Σύστημα αρχείων:",
    "Available:" : "Διαθέσιμα:",
    "Used:" : "Σε χρήση:",
    "Status" : "Κατάσταση",
    "Started" : "Ξεκίνησε",
    "Duration" : "Διάρκεια",
    "Job" : "Εργασία",
    "When" : "Πότε",
    "Details" : "Λεπτομέρειες",
    "Succeeded" : "Επιτυχία",
    "Failed" : "Αποτυχία",
    "Running" : "Σε εκτέλεση",
    "Memory" : "Μνήμη",
    "RAM info not available" : "Οι πληροφορίες RAM δεν είναι διαθέσιμες",
    "Total" : "Σύνολο",
    "Configuration" : "Διαμόρφωση",
    "Output in JSON" : "Έξοδος σε JSON",
    "Skip server update" : "Παράλειψη ενημέρωσης διακομιστή",
    "Authentication" : "Ταυτοποίηση",
    "Network" : "Δίκτυο",
    "Hostname" : "Όνομα Υπολογιστή",
    "Gateway" : "Πύλη",
    "DNS" : "DNS",
    "Status:" : "Κατάσταση:",
    "Speed:" : "Ταχύτητα:",
    "Duplex:" : "Duplex:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "PHP extensions" : "Επεκτάσεις PHP",
    "Unable to list extensions" : "Αδυναμία λίστας επεκτάσεων",
    "PHP" : "PHP",
    "Memory limit:" : "Όριο μνήμης:",
    "Max execution time:" : "Μέγιστος χρόνος εκτέλεσης:",
    "seconds" : "δευτερόλεπτα",
    "Upload max size:" : "Μέγιστο μέγεθος μεταφόρτωσης:",
    "OPcache Revalidate Frequency:" : "Συχνότητα Επανεπικύρωσης OPcache:",
    "Show phpinfo" : "Εμφάνιση phpinfo",
    "FPM worker pool" : "Συλλογή εργατών FPM",
    "Pool name:" : "Όνομα συλλογής:",
    "Pool type:" : "Τύπος συλλογής:",
    "Start time:" : "Χρόνος έναρξης:",
    "Accepted connections:" : "Αποδεκτές συνδέσεις:",
    "Total processes:" : "Συνολικές διεργασίες:",
    "Active processes:" : "Ενεργές διεργασίες:",
    "Idle processes:" : "Αδρανείς διεργασίες:",
    "Listen queue:" : "Ουρά ακρόασης:",
    "Slow requests:" : "Αργά αιτήματα:",
    "Max listen queue:" : "Μέγιστη ουρά ακρόασης:",
    "Max active processes:" : "Μέγιστες ενεργές διεργασίες:",
    "Max children reached:" : "Φτάστηκε μέγιστος αριθμός παιδιών:",
    "CPU" : "CPU",
    "Resource usage" : "Χρήση πόρων",
    "Shares" : "Κοινόχρηστοι φάκελοι",
    "Users:" : "Χρήστες:",
    "Groups:" : "Ομάδες:",
    "Links:" : "Σύνδεσμοι:",
    "Emails:" : "Email:",
    "Federated sent:" : "Ομοσπονδιακά αποσταλμένα:",
    "Federated received:" : "Ομοσπονδιακά ληφθέντα:",
    "Talk conversations:" : "Συνομιλίες Talk:",
    "Average" : "Μέσος όρος",
    "Warning" : "Προειδοποίηση",
    "Operating System:" : "Λειτουργικό σύστημα",
    "CPU:" : "CPU:",
    "Server time:" : "Ώρα διακομιστή:",
    "Uptime:" : "Διάρκεια λειτουργίας:",
    "Temperature" : "Θερμοκρασία",
    "CPU Usage:" : "Χρήση CPU:",
    "Load average: {percentage} % ({load}) last minute" : "Μέσος φόρτος: {percentage} % ({load}) τελευταίο λεπτό",
    "{lastMinutePercentage} % ({lastMinute}) last Minute\n{last5MinutesPercentage} % ({last5Minutes}) last 5 Minutes\n{last15MinutesPercentage} % ({last15Minutes}) last 15 Minutes" : "{lastMinutePercentage} % ({lastMinute}) τελευταίο Λεπτό\n{last5MinutesPercentage} % ({last5Minutes}) τελευταία 5 Λεπτά\n{last15MinutesPercentage} % ({last15Minutes}) τελευταία 15 Λεπτά",
    "RAM Usage:" : "Χρήση RAM:",
    "SWAP Usage:" : "Χρήση SWAP:",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Σύνολο: {memTotalBytes}/Τρέχουσα χρήση: {memUsageBytes}",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Σύνολο: {swapTotalBytes}/Τρέχουσα χρήση: {swapUsageBytes}",
    "SWAP info not available" : "Οι πληροφορίες SWAP δεν είναι διαθέσιμες",
    "Copied!" : "Αντιγράφηκε!",
    "Not supported!" : "Δεν υποστηρίζεται!",
    "Press ⌘-C to copy." : "Για αντιγραφή πατήστε ⌘-C.",
    "Press Ctrl-C to copy." : "Για αντιγραφή πατήστε Ctrl-C.",
    "threads" : "νήματα",
    "Memory:" : "Μνήμη:",
    "Files:" : "Αρχεία:",
    "Storages:" : "Αποθηκευτικοί χώροι:",
    "Free Space:" : "Ελεύθερος Χώρος:",
    "Hostname:" : "Όνομα υπολογιστή:",
    "Gateway:" : "Πύλη:",
    "%s%% of all users" : "%s%% όλων των χρηστών",
    "Extensions:" : "Επεκτάσεις:",
    "External monitoring tool" : "Εξωτερικό εργαλείο παρακολούθησης",
    "Use this end point to connect an external monitoring tool:" : "Χρησιμοποιήστε αυτό το τελικό σημείο για σύνδεση εξωτερικού εργαλείου παρακολούθησης:",
    "Copy" : "Αντιγραφή",
    "Skip apps section (including apps section will send an external request to the app store)" : "Παράλειψη τμήματος εφαρμογών (η συμπερίληψη του τμήματος εφαρμογών θα στείλει εξωτερικό αίτημα στο app store)",
    "To use an access token, please generate one then set it using the following command:" : "Για να χρησιμοποιήσετε ένα αναγνωριστικό πρόσβασης (token), δημιουργήστε ένα και ορίστε το χρησιμοποιώντας την ακόλουθη εντολή:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Στη συνέχεια, περάστε το αναγνωριστικό με την κεφαλίδα \"NC-Token\" όταν υποβάλετε ερώτημα στην παραπάνω διεύθυνση URL."
},
"nplurals=2; plural=(n != 1);");
