OC.L10N.register(
    "sharebymail",
    {
    "Shared with {email}" : "Compartido con {email}",
    "Shared with {email} by {actor}" : "Compartido con {email} por {actor}",
    "Unshared from {email}" : "Dejó de compartirse con {email}",
    "Unshared from {email} by {actor}" : "Dejó de compartirse con {email} por {actor}",
    "Password for mail share sent to {email}" : "La contraseña para el elemento compartido fue enviada a {email}",
    "Password for mail share sent to you" : "La contraseña para el elemento compartido se le ha sido enviada",
    "You shared {file} with {email} by mail" : "Usted ha compartido {file} con {email} por correo",
    "{actor} shared {file} with {email} by mail" : "{actor} ha compartido {file} con {email} por correo",
    "You unshared {file} from {email} by mail" : "Has dejado de compartir {file} desde {email} por correo",
    "{actor} unshared {file} from {email} by mail" : "{actor} dejó de compartir {file} con {email} por correo",
    "Password to access {file} was sent to {email}" : "La contraseña para acceder {file} ha sido enviada a {email}",
    "Password to access {file} was sent to you" : "La contraseña para acceder {file} se le ha sido enviada",
    "Share by mail" : "Compartir por correo",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "No se pudo compartir %1$s, porque este elemento ya está compartido con la cuenta %2$s",
    "We cannot send you the auto-generated password. Please set a valid email address in your personal settings and try again." : "No podemos enviarle la contraseña generada automáticamente. Por favor, establezca una dirección de correo electrónico válida en sus ajustes personales e inténtelo de nuevo.",
    "Failed to send share by email. Got an invalid email address" : "Error al enviar el compartido por correo electrónico. Se proporcionó una dirección de correo electrónico no válida",
    "Failed to send share by email" : "Se presentó una falla al enviar el elemento compartido por correo electrónico",
    "%1$s shared %2$s with you" : "%1$s ha compartido \"%2$s\" con usted",
    "Note:" : "Nota:",
    "This share is valid until %s at midnight" : "El recurso compartido es válido hasta el %s a la media noche",
    "Expiration:" : "Caducidad:",
    "%1$s via %2$s" : "%1$s vía %2$s",
    "%1$s shared %2$s with you. You should have already received a separate mail with a link to access it." : "%1$s le compartió %2$s. Debería ya haber recibido un correo por separado con el enlace para acceder a éste.",
    "Password to access %1$s shared to you by %2$s" : "Contraseña para acceder a %1$s que le compartió %2$s",
    "Password to access %s" : "Contraseña para acceder a %s",
    "It is protected with the following password:" : "Está protegido con la siguiente contraseña:",
    "This password will expire at %s" : "La compartición expirará el %s.",
    "%1$s shared %2$s with you and wants to add:" : "%1$s le compartió %2$s y quiere añadir:",
    "%1$s shared %2$s with you and wants to add" : "%1$s le compartió %2$s y quiere añadir",
    "%s added a note to a file shared with you" : "%s añadió una nota a un archivo compartido con Ud.",
    "You just shared %1$s with %2$s. The share was already sent to the recipient. Due to the security policies defined by the administrator of %3$s each share needs to be protected by password and it is not allowed to send the password directly to the recipient. Therefore you need to forward the password manually to the recipient." : "Acaba de compartir »%1$s« con %2$s. El recurso compartido ya ha sido enviado al destinatario. Debido a las políticas de seguridad definidas por el administrador de %3$s, cada recurso compartido debe estar protegido con contraseña y no se permite enviar la contraseña directamente al destinatario. Por lo tanto, debe enviarle manualmente la contraseña.",
    "Password to access %1$s shared by you with %2$s" : "Contraseña para acceder a %1$s que compartió con %2$s",
    "This is the password:" : "Esta es la contraseña:",
    "You can choose a different password at any time in the share dialog." : "Puede elegir una contraseña diferente en cualquier momento en la ventana de diálogo de compartir. ",
    "Could not find share" : "No fue posible encontrar el elemento compartido",
    "Share provider which allows you to share files by mail" : "Proveedor de compartidos que te permite compartir archivos por correo electrónico",
    "Unable to update share by mail config" : "No se puede actualizar la configuración de compartir por correo",
    "Allows people to share a personalized link to a file or folder by putting in an email address." : "Permite a los usuarios compartir un enlace personalizado a un archivo o carpeta colocando una dirección de correo electrónico.",
    "Send password by mail" : "La contraseña ha sido enviada por correo",
    "Reply to initiator" : "Responder al remitente"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
