OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "Adicionado à lista de servidores confiáveis.",
    "No server found with ID: %s" : "Nenhum servidor encontrado com o ID: %s",
    "Could not remove server" : "Não foi possível remover o servidor",
    "Server is already in the list of trusted servers." : "O servidor já está na lista de servidores confiáveis.",
    "No server to federate with found" : "Nenhum servidor encontrado para federar",
    "Could not add server" : "Não foi possível adicionar servidor",
    "Trusted servers" : "Servidores confiáveis",
    "Federation" : "Federação",
    "Federation allows you to connect with other trusted servers to exchange the account directory." : "A federação permite que você se conecte a outros servidores confiáveis ​​para trocar o diretório de contas.",
    "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing." : "A federação permite que você se conecte a outros servidores confiáveis ​​para trocar o diretório de contas. Por exemplo, isso será usado para preencher automaticamente contas externas para compartilhamento federado.",
    "Could not add trusted server. Please try again later." : "Não foi possível adicionar o servidor confiável. Tente novamente mais tarde.",
    "Add trusted server" : "Adicionar servidor confiável",
    "Server url" : "URL do servidor",
    "Add" : "Adicionar",
    "Server ok" : "Servidor ok",
    "User list was exchanged at least once successfully with the remote server." : "A lista de usuários foi trocada pelo menos uma vez com sucesso com o servidor remoto.",
    "Server pending" : "Servidor pendente",
    "Waiting for shared secret or initial user list exchange." : "Aguardando o segredo compartilhado ou a troca da lista inicial de usuários.",
    "Server access revoked" : "Acesso ao servidor revogado",
    "Server failure" : "Falha no servidor",
    "Connection to the remote server failed or the remote server is misconfigured." : "Falha na conexão com o servidor remoto ou o servidor remoto está mal configurado.",
    "Failed to delete trusted server. Please try again later." : "Não foi possível excluir o servidor confiável. Tente novamente mais tarde.",
    "Delete" : "Excluir",
    "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "A federação permite que você se conecte a outros servidores confiáveis ​​para trocar o diretório de contas. Por exemplo, isso será usado para preencher automaticamente contas externas para compartilhamento federado. Não é necessário adicionar um servidor como servidor confiável para criar um compartilhamento federado.",
    "Each server must validate the other. This process may require a few cron cycles." : "Cada servidor deve validar o outro. Esse processo pode exigir alguns ciclos de cron.",
    "External documentation for Federated Cloud Sharing" : "Documentação externa para Compartilhamento de Nuvem Federada",
    "+ Add trusted server" : "+Adicionar servidores confiáveis",
    "Trusted server" : "Servidores confiáveis"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
