OC.L10N.register(
    "privacy",
    {
    "Privacy" : "حریم خصوصی",
    "-" : "-",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "مرکز حریم خصوصی به شما نشان می‌دهد که داده‌هایتان کجا ذخیره شده و چه کسانی به آن دسترسی دارند، چه به دلیل اشتراک‌گذاری شما با آن‌ها باشد و چه به دلیل مدیر بودنشان.",
    "Error loading additional administrator." : "خطا در بارگذاری مدیر اضافی.",
    "Error adding new administrator." : "خطا در افزودن مدیر جدید.",
    "Error deleting new administrator." : "خطا در حذف مدیر جدید.",
    "Administrators" : "مدیران",
    "The following accounts are designated administrators and may potentially have access to your data through system storage or backups. However, they do not have easy access to your data via the web interface or client applications." : "حساب‌های زیر به عنوان مدیر تعیین شده‌اند و ممکن است از طریق ذخیره‌سازی سیستم یا پشتیبان‌گیری به داده‌های شما دسترسی داشته باشند. با این حال، آن‌ها از طریق رابط وب یا برنامه‌های کاربردی دسترسی آسانی به داده‌های شما ندارند.",
    "Loading administrators …" : "در حال بارگذاری مدیران…",
    "Remove external {propertyName} admin" : "حذف مدیر {propertyName} خارجی",
    "Add external admin" : "افزودن مدیر خارجی",
    "Cancel" : "لغو",
    "Add" : "افزودن",
    "Name of external admin" : "نام مدیر خارجی",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key. It means that administrators can access your files, but not read their content." : "فضای ذخیره‌سازی خانگی شما با استفاده از {linkopen}رمزگذاری سمت سرور ↗{linkclose} با یک کلید اصلی رمزگذاری شده است. این بدان معناست که مدیران می‌توانند به فایل‌های شما دسترسی داشته باشند، اما محتوای آن‌ها را نمی‌توانند بخوانند.",
    "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key based on their configuration." : "فایل‌های شما در فضای ذخیره‌سازی خارجی ممکن است با استفاده از {linkopen}رمزگذاری سمت سرور ↗{linkclose} با یک کلید اصلی بر اساس پیکربندی آن‌ها رمزگذاری شوند.",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual user key. It means that administrators can access your files, but not read their content." : "فضای ذخیره‌سازی خانگی شما با استفاده از {linkopen}رمزگذاری سمت سرور ↗{linkclose} با یک کلید کاربری فردی رمزگذاری شده است. این بدان معناست که مدیران می‌توانند به فایل‌های شما دسترسی داشته باشند، اما محتوای آن‌ها را نمی‌توانند بخوانند.",
    "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual key based on their configuration." : "فایل‌های شما در فضای ذخیره‌سازی خارجی ممکن است با استفاده از {linkopen}رمزگذاری سمت سرور ↗{linkclose} با یک کلید فردی بر اساس پیکربندی آن‌ها رمزگذاری شوند.",
    "Additionally, this server is protected with full-disk-encryption." : "علاوه بر این، این سرور با رمزگذاری کامل دیسک محافظت می‌شود.",
    "This server is protected with full-disk-encryption." : "این سرور با رمزگذاری کامل دیسک محافظت می‌شود.",
    "Your files are not protected by encryption." : "فایل‌های شما با رمزگذاری محافظت نمی‌شوند.",
    "Error saving new state of full-disk-encryption" : "خطا در ذخیره وضعیت جدید رمزگذاری کامل دیسک",
    "Encryption" : "رمزگذاری",
    "Edit encryption" : "ویرایش رمزگذاری",
    "Edit" : "ویرایش",
    "This server is using full-disk-encryption." : "این سرور از رمزگذاری کامل دیسک استفاده می‌کند.",
    "Privacy policy" : "خط مشی حریم خصوصی",
    "Read the privacy policy ↗" : "مطالعه خط مشی حریم خصوصی ↗",
    "Error loading information about shares." : "خطا در بارگذاری اطلاعات مربوط به اشتراک‌ها.",
    "People you've shared with" : "افرادی که با آن‌ها به اشتراک گذاشته‌اید",
    "Loading people you've shared with …" : "در حال بارگذاری افرادی که با آن‌ها به اشتراک گذاشته‌اید…",
    "You do not have any shares with individual users." : "شما هیچ اشتراکی با کاربران فردی ندارید.",
    "Your {serverName} account" : "حساب {serverName} شما",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "داده‌های شما نشان‌دهنده هویت شما هستند و به راحتی می‌توانند مورد سوءاستفاده قرار گیرند. ما در نکست‌کلود معتقدیم که شما حق دارید تصمیم بگیرید چه اتفاقی برای داده‌هایتان بیفتد. نکست‌کلود از حقوق شما همان‌طور که در مانیفست داده‌های کاربر تعریف شده است، محافظت می‌کند!",
    "Who has access to your data?" : "چه کسی به داده‌های شما دسترسی دارد؟",
    "Error saving new location of the server" : "خطا در ذخیره مکان جدید سرور",
    "Where is your data?" : "داده‌های شما کجاست؟",
    "Your data is located in:" : "داده‌های شما در این مکان قرار دارد:",
    "An admin has not selected the location of the server yet." : "مدیر هنوز مکان سرور را انتخاب نکرده است.",
    "Change data location" : "تغییر مکان داده",
    "Region" : "منطقه",
    "Please select a region" : "لطفاً یک منطقه را انتخاب کنید",
    "{bold}Control{/bold} over user data access" : "{bold}کنترل{/bold} بر دسترسی به داده‌های کاربر",
    "{bold}Knowledge{/bold} of how the data is stored" : "{bold}آگاهی{/bold} از نحوه ذخیره‌سازی داده‌ها",
    "{bold}Freedom{/bold} to choose a platform" : "{bold}آزادی{/bold} در انتخاب پلتفرم",
    "User Data Manifesto 2.0" : "مانیفست داده‌های کاربر 2.0",
    "Defining basic rights for people to control their own data in the internet age." : "تعریف حقوق اساسی برای افراد جهت کنترل داده‌های خود در عصر اینترنت.",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "داده‌هایی که به طور صریح و داوطلبانه توسط کاربر آپلود می‌شوند، باید تحت کنترل نهایی کاربر باشند. کاربران باید بتوانند تصمیم بگیرند که به چه کسی دسترسی مستقیم به داده‌های خود اعطا کنند و این دسترسی با چه مجوزها و مجوزهایی اعطا شود.",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "هنگامی که داده‌ها به یک ارائه‌دهنده خدمات خاص آپلود می‌شوند، کاربران باید در مورد اینکه آن ارائه‌دهنده خدمات خاص داده‌ها را کجا ذخیره می‌کند، چه مدت، در کدام حوزه قضایی فعالیت می‌کند و کدام قوانین اعمال می‌شود، مطلع شوند.",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "کاربران باید همیشه بتوانند در هر زمان داده‌های خود را از سرویس استخراج کنند بدون اینکه با قفل‌شدگی فروشنده مواجه شوند. استانداردهای باز برای فرمت‌ها و پروتکل‌ها برای تضمین این امر ضروری هستند.",
    "Learn more ↗" : "بیشتر بدانید ↗",
    "Somaliland" : "سومالی‌لند",
    "Andorra" : "آندورا",
    "United Arab Emirates" : "امارات متحده عربی",
    "Afghanistan" : "افغانستان",
    "Antigua and Barbuda" : "آنتیگوا و باربودا",
    "Anguilla" : "آنگویلا",
    "Albania" : "آلبانی",
    "Armenia" : "ارمنستان",
    "Angola" : "آنگولا",
    "Antarctica" : "جنوبگان",
    "Argentina" : "آرژانتین",
    "American Samoa" : "ساموآی آمریکا",
    "Austria" : "اتریش",
    "Australia" : "استرالیا",
    "Aruba" : "آروبا",
    "Åland Islands" : "جزایر الند",
    "Azerbaijan" : "جمهوری آذربایجان",
    "Bosnia and Herzegovina" : "بوسنی و هرزگوین",
    "Barbados" : "باربادوس",
    "Bangladesh" : "بنگلادش",
    "Belgium" : "بلژیک",
    "Burkina Faso" : "بورکینافاسو",
    "Bulgaria" : "بلغارستان",
    "Bahrain" : "بحرین",
    "Burundi" : "بوروندی",
    "Benin" : "بنین",
    "Saint Barthélemy" : "سن بارتلمی",
    "Bermuda" : "برمودا",
    "Brunei" : "برونئی",
    "Bolivia" : "بولیوی",
    "Bonaire, Sint Eustatius and Saba" : "بونیر، سینت یوستاتیوس و سابا",
    "Brazil" : "برزیل",
    "Bahamas" : "باهاما",
    "Bhutan" : "بوتان",
    "Bouvet Island" : "جزیره بووه",
    "Botswana" : "بوتسوانا",
    "Belarus" : "بلاروس",
    "Belize" : "بلیز",
    "Canada" : "کانادا",
    "Cocos (Keeling) Islands" : "جزایر کوکوس (کیلینگ)",
    "Democratic Republic of the Congo" : "جمهوری دموکراتیک کنگو",
    "Central African Republic" : "جمهوری آفریقای مرکزی",
    "Congo" : "کنگو",
    "Switzerland" : "سوئیس",
    "Cote d'Ivoire" : "ساحل عاج",
    "Cook Islands" : "جزایر کوک",
    "Chile" : "شیلی",
    "Cameroon" : "کامرون",
    "China" : "چین",
    "Colombia" : "کلمبیا",
    "Costa Rica" : "کاستاریکا",
    "Cuba" : "کوبا",
    "Cabo Verde" : "کیپ‌ورد",
    "Curaçao" : "کوراسائو",
    "Christmas Island" : "جزیره کریسمس",
    "Cyprus" : "قبرس",
    "Czech" : "جمهوری چک",
    "Germany" : "آلمان",
    "Djibouti" : "جیبوتی",
    "Denmark" : "دانمارک",
    "Dominican Republic" : "جمهوری دومینیکن",
    "Algeria" : "الجزایر",
    "Ecuador" : "اکوادور",
    "Estonia" : "استونی",
    "Egypt" : "مصر",
    "West Sahara" : "صحرای غربی",
    "Eritrea" : "اریتره",
    "Spain" : "اسپانیا",
    "Ethiopia" : "اتیوپی",
    "Finland" : "فنلاند",
    "Fiji" : "فیجی",
    "Falkland Islands" : "جزایر فالکلند",
    "Micronesia" : "میکرونزی",
    "Faroe Islands" : "جزایر فارو",
    "France" : "فرانسه",
    "Gabon" : "گابن",
    "United Kingdom" : "بریتانیا",
    "Grenada" : "گرنادا",
    "Georgia" : "گرجستان",
    "French Guiana" : "گویان فرانسه",
    "Guernsey" : "گرنزی",
    "Ghana" : "غنا",
    "Gibraltar" : "جبل‌الطارق",
    "Greenland" : "گرینلند",
    "Gambia" : "گامبیا",
    "Guinea" : "گینه",
    "Guadeloupe" : "گوادلوپ",
    "Equatorial Guinea" : "گینه استوایی",
    "Greece" : "یونان",
    "South Georgia and the South Sandwich Islands" : "جورجیای جنوبی و جزایر ساندویچ جنوبی",
    "Guatemala" : "گواتمالا",
    "Guam" : "گوام",
    "Guinea-Bissau" : "گینه بیسائو",
    "Guyana" : "گویان",
    "Hong Kong" : "هنگ‌کنگ",
    "Heard Island and McDonald Islands" : "جزیره هرد و جزایر مک‌دونالد",
    "Honduras" : "هندوراس",
    "Croatia" : "کرواسی",
    "Haiti" : "هائیتی",
    "Hungary" : "مجارستان",
    "Indonesia" : "اندونزی",
    "Ireland" : "ایرلند",
    "Israel" : "اسرائیل",
    "Isle of Man" : "جزیره من",
    "India" : "هند",
    "British Indian Ocean Territory" : "قلمرو بریتانیا در اقیانوس هند",
    "Iraq" : "عراق",
    "Iran" : "ایران",
    "Iceland" : "ایسلند",
    "Italy" : "ایتالیا",
    "Jamaica" : "جامائیکا",
    "Jordan" : "اردن",
    "Japan" : "ژاپن",
    "Kenya" : "کنیا",
    "Kyrgyzstan" : "قرقیزستان",
    "Cambodia" : "کامبوج",
    "Kiribati" : "کیریباتی",
    "Comores" : "کومور",
    "Saint Kitts and Nevis" : "سنت کیتس و نویس",
    "North Korea" : "کره شمالی",
    "South Korea" : "کره جنوبی",
    "Kuwait" : "کویت",
    "Cayman Islands" : "جزایر کیمن",
    "Kazakhstan" : "قزاقستان",
    "Laos" : "لائوس",
    "Lebanon" : "لبنان",
    "Saint Lucia" : "سنت لوسیا",
    "Liechtenstein" : "لیختن‌اشتاین",
    "Sri Lanka" : "سری‌لانکا",
    "Liberia" : "لیبریا",
    "Lesotho" : "لسوتو",
    "Lithuania" : "لیتوانی",
    "Luxembourg" : "لوکزامبورگ",
    "Latvia" : "لتونی",
    "Libya" : "لیبی",
    "Morocco" : "مراکش",
    "Monaco" : "موناکو",
    "Moldova" : "مولداوی",
    "Montenegro" : "مونته‌نگرو",
    "Saint Martin" : "سنت مارتین",
    "Madagascar" : "ماداگاسکار",
    "Marshall Islands" : "جزایر مارشال",
    "Macedonia" : "مقدونیه",
    "Mali" : "مالی",
    "Myanmar" : "میانمار",
    "Mongolia" : "مغولستان",
    "Macao" : "ماکائو",
    "Northern Mariana Islands" : "جزایر ماریانای شمالی",
    "Mauritania" : "موریتانی",
    "Montserrat" : "مونت‌سرات",
    "Malta" : "مالت",
    "Mauritius" : "موریس",
    "Maldives" : "مالدیو",
    "Malawi" : "مالاوی",
    "Mexico" : "مکزیک",
    "Malaysia" : "مالزی",
    "Mozambique" : "موزامبیک",
    "Namibia" : "نامیبیا",
    "New Caledonia" : "کالدونیای جدید",
    "Niger" : "نیجر",
    "Norfolk Island" : "جزیره نورفولک",
    "Nigeria" : "نیجریه",
    "Nicaragua" : "نیکاراگوئه",
    "Netherlands" : "هلند",
    "Norway" : "نروژ",
    "Nepal" : "نپال",
    "Nauru" : "نائورو",
    "Niue" : "نیوئه",
    "New Zealand" : "نیوزیلند",
    "Oman" : "عمان",
    "Panama" : "پاناما",
    "Peru" : "پرو",
    "French Polynesia" : "پلینزی فرانسه",
    "Papua New Guinea" : "پاپوآ گینه نو",
    "Philippines" : "فیلیپین",
    "Pakistan" : "پاکستان",
    "Poland" : "لهستان",
    "Saint Pierre and Miquelon" : "سن پیر و میکلون",
    "Pitcairn" : "پیتکرن",
    "Puerto Rico" : "پورتوریکو",
    "Palestine" : "فلسطین",
    "Portugal" : "پرتغال",
    "Palau" : "پالائو",
    "Paraguay" : "پاراگوئه",
    "Qatar" : "قطر",
    "Réunion" : "رئونیون",
    "Romania" : "رومانی",
    "Serbia" : "صربستان",
    "Russia" : "روسیه",
    "Rwanda" : "رواندا",
    "Saudi Arabia" : "عربستان سعودی",
    "Solomon Islands" : "جزایر سلیمان",
    "Seychelles" : "سیشل",
    "Sudan" : "سودان",
    "Sweden" : "سوئد",
    "Singapore" : "سنگاپور",
    "Saint Helena, Ascension and Tristan da Cunha" : "سنت هلنا، اسنشن و تریستان دا کونا",
    "Slovenia" : "اسلوونی",
    "Svalbard and Jan Mayen" : "سوالبارد و یان ماین",
    "Slovakia" : "اسلواکی",
    "Sierra Leone" : "سیرالئون",
    "San Marino" : "سن مارینو",
    "Senegal" : "سنگال",
    "Somalia" : "سومالی",
    "Suriname" : "سورینام",
    "South Sudan" : "سودان جنوبی",
    "Sao Tome and Principe" : "سائوتومه و پرینسیپ",
    "El Salvador" : "السالوادور",
    "Sint Maarten" : "سنت مارتین",
    "Syria" : "سوریه",
    "Swaziland" : "سوازیلند",
    "Turks and Caicos Islands" : "جزایر تورکس و کایکوس",
    "Chad" : "چاد",
    "Fr. S. Antarctic Lands" : "سرزمین‌های جنوبی و جنوبگان فرانسه",
    "Togo" : "توگو",
    "Thailand" : "تایلند",
    "Tajikistan" : "تاجیکستان",
    "Tokelau" : "توکلائو",
    "Timor-Leste" : "تیمور شرقی",
    "Turkmenistan" : "ترکمنستان",
    "Tunisia" : "تونس",
    "Tonga" : "تونگا",
    "Turkey" : "ترکیه",
    "Trinidad and Tobago" : "ترینیداد و توباگو",
    "Tuvalu" : "تووالو",
    "Taiwan" : "تایوان",
    "Tanzania" : "تانزانیا",
    "Ukraine" : "اوکراین",
    "Uganda" : "اوگاندا",
    "United States Minor Outlying Islands" : "جزایر کوچک حاشیه‌ای ایالات متحده",
    "United States" : "ایالات متحده",
    "Uruguay" : "اروگوئه",
    "Uzbekistan" : "ازبکستان",
    "Holy See" : "سریر مقدس",
    "Saint Vincent and the Grenadines" : "سنت وینسنت و گرنادین‌ها",
    "Venezuela" : "ونزوئلا",
    "Virgin Islands (British)" : "جزایر ویرجین (بریتانیا)",
    "Virgin Islands (U.S.)" : "جزایر ویرجین (ایالات متحده)",
    "Vietnam" : "ویتنام",
    "Vanuatu" : "وانواتو",
    "Wallis and Futuna" : "والیس و فوتونا",
    "Samoa" : "ساموآ",
    "Yemen" : "یمن",
    "Mayotte" : "مایوت",
    "South Africa" : "آفریقای جنوبی",
    "Zambia" : "زامبیا",
    "Zimbabwe" : "زیمبابوه",
    "Loading administrators …" : "در حال بارگذاری مدیران…",
    "Loading people you've shared with …" : "در حال بارگذاری افرادی که با آن‌ها به اشتراک گذاشته‌اید…",
    "Control" : "کنترل",
    "over user data access" : "بر دسترسی به داده‌های کاربر",
    "Knowledge" : "آگاهی",
    "of how the data is stored" : "از نحوه ذخیره‌سازی داده‌ها",
    "Freedom" : "آزادی",
    "to choose a platform" : "در انتخاب پلتفرم"
},
"nplurals=2; plural=(n > 1);");
