OC.L10N.register(
    "appstore",
    {
    "App store" : "Obchod s aplikacemi",
    "Apps" : "Aplikace",
    "App name" : "Název aplikace",
    "Version" : "Verze",
    "Groups" : "Skupiny",
    "Actions" : "Akce",
    "Show details" : "Zobrazit podrobnosti",
    "Grid view" : "Zobrazení v mřížce",
    "Cancel" : "Zrušit",
    "Office suite switching is managed through the Nextcloud All-in-One interface." : "Přepínání mezi sadami kancelářských aplikací je zpravováno prostřednictvím rozhraní pro správu Nextcloud All-in-One",
    "Please use the AIO interface to switch between office suites." : "Pro přepnutí mezi sadami kancelářských aplikací použijte rozhraní pro správu AIO.",
    "Disable office suites" : "Vypnout sady kancelářských aplikací",
    "installed" : "nainstalované",
    "Features" : "Funkce",
    "Learn more" : "Zjistit více",
    "Daemon" : "Proces služby",
    "Deploy Daemon" : "Nasadit proces služby",
    "Type" : "Typ",
    "Name" : "Název",
    "Display Name" : "Zobrazované jméno",
    "GPUs support" : "Podpora pro výpočty na GPU",
    "Compute device" : "Výpočetní zařízení",
    "Advanced deploy options" : "Pokročilé předvolby pro nasazení",
    "Edit ExApp deploy options before installation" : "Předvolby nasazení ExApp před instalací",
    "Configured ExApp deploy options. Can be set only during installation" : "Nastavené předvolby nasazení ExAPP. Je možné nastavovat pouze při instalaci",
    "Environment variables" : "Proměnné prostředí",
    "ExApp container environment variables" : "Proměnné prostředí pro kontejner s ExApp",
    "No environment variables defined" : "Nedefinovány žádné proměnné prostředí",
    "Mounts" : "Připojení",
    "Define host folder mounts to bind to the ExApp container" : "Definovat připojení hostitelské složky pro napojení na kontejner s ExApp",
    "Must exist on the Deploy daemon host prior to installing the ExApp" : "Je třeba, aby existovalo na hostiteli procesu nasazovací služby ještě před instalací ExApp",
    "Host path" : "Popis umístění hostitele",
    "Container path" : "Popis umístění kontejneru",
    "Read-only" : "Pouze pro čtení",
    "Remove mount" : "Odebrat připojení",
    "New mount" : "Nové připojení",
    "Enter path to host folder" : "Zadejte popis umístění složky hostitele",
    "Enter path to container folder" : "Zadejte popis umístění složky kontejneru",
    "Toggle read-only mode" : "Vyp/zap. režim pouze pro čtení",
    "Confirm adding new mount" : "Potvrďte přidání nového připojení",
    "Confirm" : "Potvrdit",
    "Cancel adding mount" : "Zrušit přidávání připojení",
    "Add mount" : "Přidat připojení",
    "ExApp container mounts" : "Připojení kontejneru s ExApp",
    "No mounts defined" : "Nedefinována žádná připojení",
    "Description" : "Popis",
    "View in store" : "Zobrazit v katalogu aplikací",
    "Visit website" : "Navštívit webovou stránku",
    "Usage documentation" : "Dokumentace k používání",
    "Admin documentation" : "Dokumentace pro správce",
    "Developer documentation" : "Dokumentace pro vývojáře",
    "Details" : "Podrobnosti",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Tuto aplikaci nelze nainstalovat, protože nejsou splněny následující závislosti:",
    "Latest updated" : "Naposledy aktualizováno",
    "Author" : "Autor",
    "Categories" : "Kategorie",
    "Resources" : "Prostředky",
    "Changelog" : "Souhrn změn",
    "Supported" : "Podporováno",
    "Featured" : "Doporučené",
    "This app is supported via your current Nextcloud subscription." : "Tato aplikace je podporována prostřednictvím vašeho stávajícího předplatného podpory Nextcloud.",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Doporučované aplikace jsou vyvíjeny komunitou. Jsou propojeny se zbytkem Nextcloud a připraveny na produkční nasazení.",
    "Community rating: {score}/5" : "Hodnocení komunitou: {score}/5",
    "Choose Deploy Daemon for {appName}" : "Zvolte proces služby nasazování pro {appName}",
    "No Deploy daemons configured" : "Nejsou nastavené žádné procesy služby nasazování",
    "Register a custom one or setup from available templates" : "Zaregistrujte uživatelsky určené nebo nastavte z dostupných šablon",
    "Manage Deploy daemons" : "Spravovat procesy služby nasazování",
    "Registered Deploy daemons list" : "Seznam zaregistrovaných procesů nasazování",
    "Default" : "Výchozí",
    "Carousel" : "Kolotoč",
    "Previous slide" : "Předchozí snímek",
    "Next slide" : "Následující snímek",
    "Choose slide to display" : "Zvolte snímek který zobrazit",
    "{index} of {total}" : "{index} z {total}",
    "Limit to groups" : "Omezit na skupiny",
    "Save" : "Uložit",
    "Update all" : "Aktualizovat vše",
    "Loading app list" : "Načítání seznamu aplikací …",
    "Search everywhere" : "Hledat všude",
    "Download and enable all" : "Stáhnout a zapnout vše",
    "Could not load app discover section" : "Nepodařilo se načíst sekci objevování aplikací",
    "Could not render element" : "Prvek se nepodařilo vykreslit",
    "Nothing to show" : "Není co zobrazit",
    "Could not load section content from app store." : "Nepodařilo se načíst obsah sekce z katalogu aplikací.",
    "Loading" : "Načítání",
    "Fetching the latest news…" : "Získávání nejnovějších zpráv …",
    "Loading categories" : "Načítání kategorií …",
    "Version {version}, {license}-licensed" : "Verze {version}, {license}-licencováno",
    "Version {version}" : "Verze {version}",
    "Disable" : "Vypnout",
    "Enable" : "Povolit",
    "Download and enable" : "Stáhnout a zapnout",
    "Rate the app" : "Ohodnotit aplikaci",
    "Report a bug" : "Nahlásit chybu",
    "Remove" : "Odebrat",
    "Update to {version}" : "Aktualizovat na {version}",
    "Discover" : "Objevit",
    "Your apps" : "Vaše aplikace",
    "Active apps" : "Aktivní aplikace",
    "Disabled apps" : "Vypnuté aplikace",
    "Updates" : "Aktualizace",
    "App bundles" : "Sady aplikací",
    "Featured apps" : "Doporučené aplikace",
    "Supported apps" : "Podporované aplikace",
    "Good Nextcloud integration" : "Dobré začlenění do Nextcloud",
    "Open source" : "Open source",
    "Best performance" : "Nejlepší výkon",
    "Limited ODF compatibility" : "Omezená kompatibilita s formátem ODF",
    "Best Microsoft compatibility" : "Nejlepší kompatibilita s Microsoft formáty",
    "Best Nextcloud integration" : "Nejlepší začlenění do Nextcloud",
    "Good performance" : "Dobrý výkon",
    "Best security: documents never leave your server" : "Nejlepší zabezpečení: dokumenty nikdy neopouštějí váš server",
    "Best ODF compatibility" : "Nejlepší kompatibilita s formátem ODF",
    "Best support for legacy files" : "Nejlepší podpora pro soubory ze starých aplikací",
    "An error occurred during the request. Unable to proceed." : "Během požadavku došlo k chybě. Nelze pokračovat."
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
