OC.L10N.register(
    "logreader",
    {
    "Logging" : "تسجيل الأحداث",
    "Errors in the log" : "أخطاء في تسجيل الأحداث",
    "Failed to get an iterator for log entries: %s" : "تعذّر الحصول على مُكرِّر لإدخاليات سجل الأنشطة : %s",
    "No errors in the logs since %s" : "لم تُسجَّل أيّ أخطاء منذ %s",
    "_%n error in the logs since %s_::_%n errors in the logs since %s_" : ["%nخطأً تمّ تسجيله منذ %s","%n خطأً تمّ تسجيله منذ %s","%n خطأً تمّ تسجيله منذ %s","%n أخطاء تمّ تسجيلها منذ %s","%n خطأً تمّ تسجيله منذ %s","%n خطأً تمّ تسجيله منذ %s"],
    "_%n warning in the logs since %s_::_%n warnings in the logs since %s_" : ["%n تحذيراً تمّ تسجيله منذ %s","%n تحذيراً تمّ تسجيله منذ %s","%n تحذيراً تمّ تسجيله منذ %s","%n تحذيرات تمّ تسجيلها منذ %s","%n تحذيراُ تمّ تسجيله منذ %s","%nتحذيراً تمّ تسجيله منذ %s"],
    "Log Reader" : "قارئ سجل الأحداث",
    "A log reader for Nextcloud" : "تطبيق لقراءة سجل الأحداث في نكست كلاود",
    "Log reader for Nextcloud" : "قارئ سجل الأحداث في نكست كلاود",
    "If you feel this is an error, please verify {setting} in your {config} and check the Nextcloud Administration Manual." : "إذا كنت تشعر أن هذا خطأ، فيُرجى التحقُّق من {setting} في {config} و مراحعة دليل التشغيل لمسؤول النظام في نكست كلاود.",
    "Log reader" : "قارئ سجل الأحداث",
    "Open log reader settings" : "فتح إعدادات قارئ سجل الأحداث",
    "Log reader settings" : "إعدادات قارئ سجل الأحداث",
    "Currently the log file {file} is shown" : "ملف سجل الأحداث {file} يٌعرَض حاليّاً",
    "Show server log" : "عرض سجل أحداث الخادم",
    "Live view is disabled" : "العرض الحي مُعطّل",
    "No log file" : "لا يوجد سجل للأحداث",
    "File-based logging must be enabled to access logs from the Web UI." : "يجب تمكين تسجيل الأحداث في ملفات للوصول إلى السجلات من واجهة مستخدم الويب.",
    "Log entry successfully copied" : "تمّ بنجاح نسخ تسجيلة الحركة",
    "Level" : "الدرجة",
    "App" : "التطبيق",
    "No app in context" : "لا تطبيقات في السياق",
    "Time" : "الوقت",
    "Copy raw entry" : "إنسَخ الإدخال الخامّ",
    "Copy formatted entry" : "إنسَخ الإدخال مع تنسيقه",
    "Hide exception details" : "إخْفِ تفاصيل الاستثناء",
    "View exception details" : "أظهِر تفاصيل الاستثناء",
    "Raw log entry" : "الإدخال الخام للحركة",
    "Search log entries" : "البحث في سجل الأحداث",
    "Caused by {exception}" : "ناتج عن {exception}",
    "Line {line}" : "السطر {line}",
    "Filter log levels" : "تصفية مستويات الأحداث",
    "Set log level" : "تعيين مستوى تسجيل الأحداث",
    "Time format" : "تنسيق الوقت",
    "Live view" : "العرض الحي",
    "Download/Upload logs" : "تنزيل أو رفع سجلات الأحداث",
    "Ctrl" : "تحكم Ctrl",
    "Could not parse local log file" : "تعذّر تحليل ملف سجل الأحداث المحلي",
    "You can also show log entries copied from your clipboard by pasting them on the log view using: {keyboardShortcut}" : "يمكنك أيضًا عرض مداخل سجل الأحداث المنسوخة من حافظتك عن طريق لصقها في مساحة عرض سجل الأحداث باستخدام: {keyboardShortcut}",
    "Download logs" : "تنزيل سجلات الأحداث",
    "Show local log file" : "أعرِض ملف سجل الأحداث المحلي",
    "Upload local log file to be displayed" : "رفع سجل الأحداث المحلي لعرضه",
    "Time format used for displaying the timestamp" : "تنسيق الوقت المستخدم لعرض الطابع الزمني timestamp",
    "(Local log files only support the \"raw\" time format)" : "(تدعم ملفات السجل المحلي تنسيق الوقت \"الخام\" فقط)",
    "Could not change date time format." : "لا يمكن تغيير تنسيق الوقت و التاريخ",
    "Raw data" : "البيانات الخام",
    "Local time" : "الوقت المحلي",
    "UTC time" : "التوقيت العالمي الموحد UTC",
    "Relative" : "مرتبط",
    "Could not change live view setting." : "تعذّر تعديل إعدادات العرض الحي",
    "Polling is disabled because server is not configured to log to file" : "Polling معطل لأنه لم يتم تكوين الخادم لتسجيل الأحداث في ملف",
    "Polling (live view)" : "الاستبيان (العرض الحي)",
    "Could not set logging levels to show" : "تعذّر تعيين مستويات الأحداث للعرض",
    "Filter logging levels" : "تصفية مستويات الأحداث",
    "Could not set logging level" : "تعذّر تعيين مستوى تسجيل الأحداث ",
    "Set backend loglevel" : "تعيين مستوى تسجيل الأحداث الخلفية",
    "Application" : "تطبيق",
    "Message" : "الرسالة",
    "Log entry actions" : "إجراءات على الحركة",
    "Loading older log entries" : "تحميل أحداث أقدم",
    "No older log entries available" : "لا توجد أحداث أقدم",
    "Collapse row" : "طَيَّ الصف",
    "Expand row" : "التوسيع الآن",
    "Show details" : "عرض التفاصيل",
    "Debug" : "تنقيح",
    "Info" : "معلومات",
    "Warning" : "تحذير",
    "Error" : "خطأ",
    "Fatal" : "خطأ فادح",
    "Could not load log entries" : "تعذّر رفع سجلات الحركة",
    "Clipboard" : "الحافظة",
    "Could not parse clipboard content" : "تعذّر تحليل محتويات الحافظة",
    "Could not fetch new log entries (server unavailable)" : "تعذّر جلب أحداث جديدة (الخادم غير متاح)",
    "Could not fetch new entries" : "تعذّر جلب أحداث جديدة",
    "Could not copy to clipboard, please copy manually:" : "تعذّر النسخ إلى الحافظة. إنسَخ يدويّاً رجاءً:",
    "\tfrom {address} by {user} at {time}\n" : "\tمن {address} من قِبَل {user} في {time}\n"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
