OC.L10N.register(
    "recommendations",
    {
    "Recommended files" : "فایل‌های پیشنهادی",
    "Recommendations" : "پیشنهادها",
    "Shows recommended files" : "نمایش فایل‌های پیشنهادی",
    "Shows recommended files for quick access of files and folders with recent activity" : "نمایش فایل‌های پیشنهادی برای دسترسی سریع به فایل‌ها و پوشه‌های دارای فعالیت اخیر",
    "No recommendations yet" : "هنوز پیشنهادی وجود ندارد",
    "Last updated {timeAgo}" : "آخرین به‌روزرسانی {timeAgo}",
    "Shared with you {timeAgo}" : "اشتراک‌گذاری شده با شما {timeAgo}",
    "Last commented on {timeAgo}" : "آخرین نظر {timeAgo}",
    "Path name {path}" : "مسیر {path}",
    "Show recommendations" : "نمایش پیشنهادها"
},
"nplurals=2; plural=(n > 1);");
