OC.L10N.register(
    "office",
    {
    "Search {category}" : "Buscar {category}",
    "Search" : "Buscar",
    "All" : "Todos",
    "Filename" : "Nombre de archivo",
    "Filename cannot be empty" : "El nombre del archivo no puede estar en blanco. "
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
