OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "ฟีดกิจกรรมส่วนตัวสำหรับ %s",
    "Your feed URL is invalid" : "ฟีด URL ของคุณไม่ถูกต้อง",
    "Activity feed for %1$s" : "กิจกรรมในฟีดสำหรับ %1$s",
    "Activity feed" : "ฟีดกิจกรรม",
    "Your settings have been updated." : "อัปเดตการตั้งค่าของคุณแล้ว",
    "Settings have been updated." : "อัปเดตการตั้งค่าแล้ว",
    "remote user" : "ควบคุมผู้ใช้ระยะไกล",
    "Recent activity" : "กิจกรรมล่าสุด",
    "No activities" : "ไม่มีกิจกรรม",
    "More activities" : "กิจกรรมเพิ่มเติม",
    "Daily activity summary for %s" : "สรุปกิจกรรมประจำวันสำหรับ %s",
    "_and %n more…_::_and %n more…_" : ["และ %n อีกมากมาย…"],
    "You can disable daily digest emails in the <a href=\"%s\">settings</a>." : "คุณสามารถปิดการรับอีเมลสรุปรายวันได้ใน<a href=\"%s\">ตั้งค่า</a>",
    "You can disable daily digest emails in the settings: %s" : "คุณสามารถปิดการรับอีเมลสรุปรายวันได้ในการตั้งค่า: %s",
    "All activities" : "กิจกรรมทั้งหมด",
    "By others" : "โดยผู้อื่น",
    "By you" : "โดยคุณ",
    "Activity at %s" : "กิจกรรมที่ %s",
    "Hello %s" : "สวัสดี %s",
    "Hello %s," : "สวัสดี %s",
    "There was some activity at %s" : "มีกิจกรรมบางอย่างที่ %s",
    "_and %n more _::_and %n more _" : ["และอีก %n"],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "คุณสามารถเปลี่ยนความถี่ในการส่งอีเมลเหล่านี้ หรือปิดการใช้งานได้ใน<a href=\"%s\">ตั้งค่า</a>",
    "You can change the frequency of these emails or disable them in the settings: %s" : "คุณสามารถเปลี่ยนความถี่ในการส่งอีเมลเหล่านี้ หรือปิดการใช้งานได้ในการตั้งค่า: %s",
    "Mail" : "จดหมาย",
    "Push" : "พุช",
    "Activity" : "กิจกรรม",
    "Notifications" : "การแจ้งเตือน",
    "This application enables people to view a log of activities about them, their files or other data." : "แอปพลิเคชันนี้ช่วยให้ผู้ใช้สามารถดูบันทึกกิจกรรมเกี่ยวกับตนเอง ไฟล์ หรือข้อมูลอื่นๆ ได้",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "แอปนี้ช่วยให้ผู้คนเห็นการกระทำที่เกี่ยวข้องกับไฟล์และข้อมูลของพวกเขาใน Nextcloud\nแต่ละคนสามารถกำหนดค่าการกระทำแต่ละรายการได้ในการตั้งค่าส่วนบุคคล\nเพื่อเลือกว่าควรส่งการกระทำไปยังโทรศัพท์มือถือ ส่งทางอีเมล\nหรือส่งสรุปรายวันในทุกเช้า\nข้อมูลเพิ่มเติมสามารถหาได้ในเอกสารกิจกรรม",
    "Today" : "วันนี้",
    "Last 7 days" : "ภายใน 7 วัน",
    "Last 30 days" : "ภายใน 30 วัน",
    "Clear search" : "ล้างการค้นหา",
    "Send email" : "ส่งอีเมล",
    "Send push notification" : "ส่งแจ้งเตือนแบบเด้ง",
    "Activity notification configuration" : "กำหนดค่าการแจ้งเตือนกิจกรรม",
    "Yesterday" : "เมื่อวานนี้",
    "Less" : "ย่อ",
    "More" : "เพิ่มเติม",
    "_Downloaded %n time (%s in the last 30 days)_::_Downloaded %n times (%s in the last 30 days)_" : ["ดาวน์โหลด %n ครั้ง (%s ครั้งใน 30 วันที่ผ่านมา)"],
    "_Downloaded %n time_::_Downloaded %n times_" : ["ดาวน์โหลด %n ครั้ง"],
    "You need to set up your email address before you can receive notification emails." : "คุณจะได้รับอีเมลแจ้งเตือนหลังจากที่คุณตั้งค่าที่อยู่อีเมลของคุณ",
    "Send activity emails" : "ส่งอีเมลกิจกรรม",
    "As soon as possible" : "เร็วที่สุดที่เป็นไปได้",
    "Hourly" : "รายชั่วโมง",
    "Daily" : "รายวัน",
    "Weekly" : "รายสัปดาห์",
    "You commented" : "คุณได้แสดงความคิดเห็น",
    "Message deleted by author" : "ข้อความถูกลบโดยผู้เขียน",
    "Open {filename}" : "เปิด {filename}",
    "in {path}" : "ใน {path}",
    "Home" : "หน้าหลัก",
    "Could not load activities" : "ไม่สามารถโหลดกิจกรรมได้",
    "Loading activities" : "กำลังโหลดกิจกรรม",
    "This stream will show events like additions, changes & shares" : "สตรีมนี้จะแสดงเหตุการณ์ต่าง ๆ เช่น การเพิ่ม การเปลี่ยนแปลง และการแชร์",
    "No activity yet" : "ยังไม่มีกิจกรรม",
    "New activities" : "กิจกรรมใหม่",
    "Loading more activities" : "โหลดกิจกรรมเพิ่มเติม",
    "No more activities." : "ไม่มีกิจกรรมเพิ่มเติม",
    "Could not enable RSS link" : "ไม่สามารถเปิดใช้งานลิงก์ RSS ได้",
    "RSS link copied to clipboard" : "ลิงก์ RSS ถูกคัดลอกไปยังคลิปบอร์ดแล้ว",
    "Could not copy the RSS link, please copy manually:" : "ไม่สามารถคัดลอกลิงก์ RSS ได้ โปรดคัดลอกด้วยตนเอง",
    "Activity settings" : "ตั้งค่ากิจกรรม",
    "Enable RSS feed" : "เปิดใช้งานฟีด RSS",
    "RSS feed" : "ฟีด RSS",
    "Copy RSS feed link" : "คัดลอก RSS ฟีตลิงค์",
    "Personal notification settings" : "ตั้งค่าการแจ้งเตือนส่วนบุคคล",
    "Unable to load the activity list" : "ไม่สามารถโหลดรายการกิจกรรม",
    "Choose for which activities you want to get an email or push notification." : "เลือกกิจกรรมที่คุณต้องการรับอีเมลหรือการแจ้งเตือนพุช",
    "Choose for which activities you want to get a push notification." : "เลือกกิจกรรมที่คุณต้องการรับการแจ้งเตือนพุช",
    "Notification" : "การแจ้งเตือน",
    "Enable notification emails" : "เปิดอีเมลแจ้งเตือน",
    "Daily activity summary" : "สรุปการใช้งานรายวัน",
    "Send daily activity summary in the morning" : "ส่งสรุปกิจกรรมประจำวันในตอนเช้า",
    "Default settings" : "ค่าเริ่มต้น",
    "Configure the default notification settings for new accounts." : "กำหนดค่าการแจ้งเตือนเริ่มต้นสำหรับบัญชีใหม่",
    "Unable to save the settings" : "ไม่สามารถบันทึกการตั้งค่าได้",
    "No more events to load" : "ไม่มีกิจกรรมเพิ่มเติมที่จะโหลด"
},
"nplurals=1; plural=0;");
