OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "Güvenilen sunucular listesine eklendi",
    "No server found with ID: %s" : "Şu kimlikle bir sunucu bulunamadı: %s",
    "Could not remove server" : "Sunucu kaldırılamadı",
    "Server is already in the list of trusted servers." : "Sunucu zaten güvenilen sunucu listesine eklenmiş.",
    "No server to federate with found" : "Birleştirilecek bir sunucu bulunamadı",
    "Could not add server" : "Sunucu eklenemedi",
    "Trusted servers" : "Güvenilen sunucular",
    "Federation" : "Birleşim",
    "Federation allows you to connect with other trusted servers to exchange the account directory." : "Birleşim, diğer güvenilen sunucularla bağlantı kurarak hesap dizininin paylaşılmasını sağlar.",
    "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing." : "Birleşik çalışma, diğer güvenilen sunucularla hesap dizininin paylaşılmasını sağlar. Örneğin, bu işlem birleşik paylaşım için dış hesapların otomatik olarak tamamlanmasını sağlar.",
    "Could not add trusted server. Please try again later." : "Güvenilen sunucu eklenemedi. Lütfen bir süre sonra yeniden deneyin.",
    "Add trusted server" : "Güvenilen sunucu ekle",
    "Server url" : "Sunucu adresi",
    "Add" : "Ekle",
    "Server ok" : "Sunucu tamam",
    "User list was exchanged at least once successfully with the remote server." : "Kullanıcı listesi uzak sunucudan en az bir kez başarılı olarak değiştirildi.",
    "Server pending" : "Sunucu bekliyor",
    "Waiting for shared secret or initial user list exchange." : "Paylaşılan parola veya ilk kullanıcı listesi değişimi bekleniyor.",
    "Server access revoked" : "Sunucu erişimi geçersiz kılındı",
    "Server failure" : "Sunucu sorunu",
    "Connection to the remote server failed or the remote server is misconfigured." : "Uzak sunucu ile bağlantı kurulamadı veya uzak sunucu yanlış yapılandırılmış.",
    "Failed to delete trusted server. Please try again later." : "Güvenilen sunucu silinemedi. Lütfen bir süre sonra yeniden deneyin.",
    "Delete" : "Sil",
    "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "Birleşik çalışma, diğer güvenilen sunucularla hesap dizininin paylaşılmasını sağlar. Örneğin, bu işlem birleşik paylaşım için dış hesapların otomatik olarak tamamlanmasını sağlar. Bir birleşik çalışma oluşturmak için bir güvenilen sunucu eklenmesi gerekmez.",
    "Each server must validate the other. This process may require a few cron cycles." : "Her sunucunun diğerini doğrulaması gerekir. Bu işlemin tamamlanması için birkaç zamanlanmış görev döngüsünün geçilmesi gerekebilir.",
    "External documentation for Federated Cloud Sharing" : "Birleşik bulut paylaşımı belgeleri",
    "+ Add trusted server" : "+ Güvenilen sunucu ekle",
    "Trusted server" : "Güvenilen sunucu"
},
"nplurals=2; plural=(n > 1);");
