OC.L10N.register(
    "files_lock",
    {
    "File is currently locked by %s" : "檔案目前已被 %s 鎖定",
    "File is not locked" : "檔案未被鎖定",
    "File can only be locked with update permissions." : "檔案僅能以更新權限鎖定。",
    "File can only be unlocked by providing a valid owner lock token" : "檔案只能透過提供有效的擁有者鎖定權杖來解鎖",
    "File can only be unlocked by the owner of the lock" : "檔案僅能由鎖的擁有者解鎖",
    "Desktop client" : "桌面用戶端",
    "iOS client" : "iOS 客戶端",
    "Android client" : "Android 客戶端",
    "Temporary files lock" : "暫時上鎖檔案",
    "Temporary lock your files" : "暫時將您的檔案上鎖",
    "Allow your users to temporary lock their files to avoid conflicts while working on shared files." : "允許您的使用者將他們的檔案暫時上鎖，以免在處理分享檔案時出現衝突。",
    "Manually locked by {user}" : "由 {user} 手動鎖定",
    "Locked by editing online in {app}" : "因在 {app} 中線上編輯而鎖定",
    "Automatically locked by {user}" : "由 {user} 自動鎖定",
    "Unlock file" : "解鎖檔案",
    "Lock file" : "上鎖檔案",
    "files_lock" : "files_lock",
    "This file has been locked automatically by a client. Removing the lock may lead to a conflict saving the file." : "此檔案已被客戶端自動鎖定。移除鎖定可能會導致儲存檔案時發生衝突。",
    "Keep lock" : "維持鎖定",
    "Force unlock" : "強制解鎖",
    "Allow your users to temporary lock their files to avoid conflicts while working on shared files.\n\nℹ️ As of Nextcloud 34 this app is bundled with Nextcloud Hub and hence not released through the appstore anymore." : "允許使用者暫時鎖定其檔案，以避免在處理共用檔案時發生衝突。\n\nℹ️ 自 Nextcloud 34 起，此應用程式已整合至 Nextcloud Hub，因此不再透過應用程式商店釋出。"
},
"nplurals=1; plural=0;");
