OC.L10N.register(
    "logreader",
    {
    "Logging" : "Rexistru",
    "Errors in the log" : "Errores nel rexistru",
    "Failed to get an iterator for log entries: %s" : "Nun se pue consiguir un iterador pa les entraes del rexistru: %s",
    "No errors in the logs since %s" : "Nun hai nengún error nel rexistru dende'l %s",
    "_%n error in the logs since %s_::_%n errors in the logs since %s_" : ["%n error nel rexistru dende'l %s","%n errores nel rexistru dende'l %s"],
    "_%n warning in the logs since %s_::_%n warnings in the logs since %s_" : ["%n alvertencies nel rexistru dende'l %s","%n alvertencies nel rexistru dende'l %s"],
    "Log Reader" : "Llector del rexistru",
    "A log reader for Nextcloud" : "Un llector de rexistros pa Nextcloud",
    "Log reader for Nextcloud" : "Llector de rexistros pa Nextcloud",
    "If you feel this is an error, please verify {setting} in your {config} and check the Nextcloud Administration Manual." : "Si pienses qu'esto ye un error, verifica «{setting}» en «{config}» y comprueba'l manual d'alministración de Nextcloud.",
    "Log reader" : "Llector de rexistros",
    "Open log reader settings" : "Abrir la configuración del llector de rexistros",
    "Log reader settings" : "Configuración del llector de rexistros",
    "Currently the log file {file} is shown" : "Ta amosándose'l ficheru de rexistru «{file}»",
    "Show server log" : "Amosar el rexistru del sirvidor",
    "Live view is disabled" : "La visualización en direuto ta desactivada",
    "No log file" : "Nun hai nengún ficheru de rexistru",
    "File-based logging must be enabled to access logs from the Web UI." : "El rexistru basáu en ficheru ha tar activáu p'acceder a los rexistros dende la IU web.",
    "Log entry successfully copied" : "La entrada del rexistru copióse correutamente",
    "Level" : "Nivel",
    "App" : "Aplicación",
    "No app in context" : "Nun hai nenguna aplicación nel contestu",
    "Time" : "Data",
    "Copy raw entry" : "Copiar la entrada en bruto",
    "Copy formatted entry" : "Copiar la entrada con formatu",
    "Hide exception details" : "Anubrir los detalles de la esceición",
    "View exception details" : "Ver los detalles de la esceición",
    "Raw log entry" : "Entrada del rexistru en bruto",
    "Search log entries" : "Buscar entraes del rexistru",
    "Caused by {exception}" : "Problema causáu por «{exception}»",
    "Line {line}" : "Llinia {line}",
    "Filter log levels" : "Peñerar los niveles del rexistru",
    "Set log level" : "Aficar el nivel de rexistru",
    "Time format" : "Formatu de la hora",
    "Live view" : "Visualización en direuto",
    "Download/Upload logs" : "Rexistros de descarga/xuba",
    "Ctrl" : "Ctrl",
    "Could not parse local log file" : "Nun se pudo analizar el ficheru de ficheru llocal",
    "You can also show log entries copied from your clipboard by pasting them on the log view using: {keyboardShortcut}" : "Tamién pues amosar les entraes del rexistru del cartafueyu apegándoles nel visor de rexistros con: {keyboardShortcut}",
    "Download logs" : "Baxar los rexistros",
    "Show local log file" : "Amosar el ficheru de rexistru llocal",
    "Upload local log file to be displayed" : "Xubi un ficheru de rexistru llocal que quieras amosar",
    "Time format used for displaying the timestamp" : "El formatu de la hora usáu p'amosar la marca de tiempu",
    "(Local log files only support the \"raw\" time format)" : "(Los ficheros de rexistru llocales namás son compatibles col formatu d'hora «en bruto»)",
    "Could not change date time format." : "Nun se pudo camudar el formatu de la data",
    "Raw data" : "Datos en bruto",
    "Local time" : "Hora llocal",
    "UTC time" : "Hora UTC",
    "Relative" : "Relativu",
    "Could not change live view setting." : "Nun se pudo camudar la opción de la visualización en direuto.",
    "Could not set logging levels to show" : "Nun se pudieron afitar los niveles de rexistru p'amosar",
    "Filter logging levels" : "Peñerar los niveles de rexistru",
    "Could not set logging level" : "Nun se pudo afitar el nivel de rexistru",
    "Set backend loglevel" : "Afitar el nivel de rexistru del backend",
    "Application" : "Aplicación",
    "Message" : "Mensaxe",
    "Log entry actions" : "Aiciones de la entrada del rexistru",
    "Loading older log entries" : "Cargando les entraes del rexistru antigües",
    "No older log entries available" : "Nun hai nenguna entrada del rexistru antigua",
    "Collapse row" : "Contrayer la filera",
    "Expand row" : "Espander la filera",
    "Show details" : "Amosar los detalles",
    "Debug" : "Depuración",
    "Info" : "Información",
    "Warning" : "Alvertencia",
    "Error" : "Error",
    "Fatal" : "Fatal",
    "Could not load log entries" : "Nun se pudieron cargar les entraes del rexistru",
    "Clipboard" : "Cartafueyu",
    "Could not parse clipboard content" : "Nun se pudo analizar el conteníu del cartafueyu",
    "Could not fetch new log entries (server unavailable)" : "Nun se pudo dir en cata de les entraes nueves (el sirvidor nun ta disponible)",
    "Could not fetch new entries" : "Nun se pudo dir en cata de les entraes nueves",
    "Could not copy to clipboard, please copy manually:" : "Nun se pudo copiar nel cartafueyu, copia manualmente:",
    "\tfrom {address} by {user} at {time}\n" : "\tde {address} por {user} a la hora: {time}\n"
},
"nplurals=2; plural=(n != 1);");
