OC.L10N.register(
    "files_lock",
    {
    "File is currently locked by %s" : "Файл одоогоор %s-р түгжигдсэн",
    "File is not locked" : "Файл түгжигдээгүй",
    "File can only be locked with update permissions." : "Файлыг зөвхөн шинэчлэх эрхээр түгжиж болно.",
    "File can only be unlocked by providing a valid owner lock token" : "Файлыг зөвхөн хүчинтэй эзэмшигчийн түгжээний токен өгснөөр тайлж болно",
    "File can only be unlocked by the owner of the lock" : "Файлыг зөвхөн түгжээний эзэмшигч тайлж болно",
    "Desktop client" : "захиалагчийн дэлгэц",
    "iOS client" : "iOS үйлчлүүлэгч",
    "Android client" : "Android хэрэглэгч",
    "Temporary files lock" : "Түр зуурын файл түгжээ",
    "Temporary lock your files" : "Файлуудаа түр зуур түгжих",
    "Allow your users to temporary lock their files to avoid conflicts while working on shared files." : "Хэрэглэгчиддээ хуваалцсан файлуудтай ажиллах явцад зөрчилдөөнөөс зайлсхийхийн тулд файлуудаа түр түгжих боломжийг олго.",
    "Manually locked by {user}" : "{user}-р гараар түгжигдсэн",
    "Locked by editing online in {app}" : "{app}-д онлайн засварлахад түгжигдсэн",
    "Automatically locked by {user}" : "{user}-р автоматаар түгжигдсэн",
    "Unlock file" : "Файл тайлах",
    "Lock file" : "Файл түгжих",
    "files_lock" : "files_lock",
    "This file has been locked automatically by a client. Removing the lock may lead to a conflict saving the file." : "Энэ файлыг клиент автоматаар түгжсэн байна. Түгжээг арилгасан нь файлыг хадгалахад зөрчилдөөн үүсгэж болзошгүй.",
    "Keep lock" : "Түгжээ хадгалах",
    "Force unlock" : "Хүчээр тайлах"
},
"nplurals=2; plural=(n != 1);");
