OC.L10N.register(
    "app_api",
    {
    "Cancel" : "Anulare",
    "Delete" : "Șterge",
    "Default" : "Implicită",
    "Edit" : "Editează",
    "Unlimited" : "Nelimitată",
    "Name" : "Nume",
    "Host" : "Gazdă",
    "Enabled" : "Activat",
    "More information" : "Mai multe informații",
    "Remove" : "Elimină",
    "From" : "De la",
    "To" : "Către",
    "Add" : "Adaugă",
    "Display name" : "Nume afișat",
    "Confirm" : "Confirmă",
    "Save" : "Salvează",
    "Register" : "Înregistrează-te",
    "Update to {version}" : "Actualizare la {version}",
    "View in store" : "Vezi în magazin",
    "Visit website" : "Viziteaza pagina web",
    "Report a bug" : "Raportează un defect",
    "User documentation" : "Documentație utilizator",
    "Admin documentation" : "Documentație pentru administrare",
    "Developer documentation" : "Documentație pentru dezvoltatori",
    "Featured" : "Recomandată",
    "Icon" : "Pictogramă",
    "Version" : "Versiune",
    "Level" : "Nivel",
    "Actions" : "Acțiuni",
    "Type" : "Tip",
    "Your apps" : "Aplicațiile tale",
    "Documentation" : "Documentație",
    "Details" : "Detalii",
    "Changelog" : "Listă modificări",
    "Disabled apps" : "Aplicații inactive",
    "Updates" : "Actualizări",
    "Featured apps" : "Aplicații recomandate",
    "Enable" : "Activare",
    "Disable" : "Dezactivează"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
