OC.L10N.register(
    "files_pdfviewer",
    {
    "PDF viewer" : "PDF ikustailea",
    "Directly view PDF documents in your Nextcloud. \nAs an added bonus, this app can also display Adobe Illustrator (.ai) files. \nPowered by [pdf.js](https://mozilla.github.io/pdf.js/)" : "Ikusi zuzenean PDF dokumentuak zure Nextcloud-en. \nHobari gehigarri gisa, aplikazio honek Adobe Illustrator (.ai) fitxategiak ere bistara ditzake. \n[pdf.js](https://mozilla.github.io/pdf.js/)",
    "Failed to load settings" : "Ezarpenak kargatzeak huts egin du",
    "Failed to save settings" : "Ezarpenak gordetzeak huts egin du",
    "File upload failed." : "Ezin izan da kargatu fitxategiak.",
    "To view a shared PDF file, the download needs to be allowed for this file share" : "Partekatutako PDF fitxategi bat ikusteko, deskarga baimendu behar da fitxategi honetarako"
},
"nplurals=2; plural=(n != 1);");
