OC.L10N.register(
    "circles",
    {
    "Teams" : "Jamoalar",
    "Personal" : "Personal",
    "System" : "Tizim",
    "Open" : "Ochish",
    "Invite" : "Taklif qiling",
    "Password protected" : "Parol bilan himoyalangan",
    "Hidden" : "Yashirin",
    "Local" : "Lokal",
    "App" : "Ilova",
    "Email address" : "E-pochta manzili",
    "Contact" : "Aloqa",
    "Team" : "Jamoa",
    "Member" : "A'zo",
    "Admin" : "Administrator",
    "Owner" : "Egasi",
    "Open »%s«" : "ochish »%s«",
    "Files" : "Fayllar",
    "Accept" : "Qabul qiling",
    "Invalid file provided" : "Noto'g'ri fayl taqdim etildi",
    "File is too big" : "Fayl juda katta",
    "Invalid image" : "Noto'g'ri rasm",
    "Unknown filetype" : "Noma'lum fayl turi",
    "%s" : "%s",
    "Open %s" : "Ochiq %s",
    "Federation allows you to share teams with other trusted servers and make them discoverable across instances." : "Jamg'arma sizga jamoalarni boshqa ishonchli serverlar bilan baham ko'rish va ularni turli holatlarda ko'rinadigan qilish imkonini beradi.",
    "https://…" : "https://…",
    "Unlimited" : "Unlimited",
    "Save" : "Saqlash",
    "Connect" : "Connect",
    "Overview" : "Umumiy koʻrinish",
    "Cancel" : "Bekor qilish",
    "Next" : "Keyingisi",
    "Back" : "Orqaga",
    "Folder" : "Jild",
    "you" : "siz",
    "Copy link" : "Havolani nusxalash",
    "Close" : "Yopish",
    "New folder" : "Yangi jild",
    "Folder name" : "Papka nomi",
    "Calendar" : "Taqvim",
    "New calendar" : "Yangi taqvim",
    "Calendar name" : "Taqvim nomi",
    "Description" : "Tavsif",
    "Edit" : "Tahrirlash",
    "Create" : "Yaratish",
    "Add" : "Qo'shish",
    "Remove {type}" : " {type} ni o'chirish",
    "Loading …" : "Yuklanmoqda...",
    "No results" : "Natija yo'q",
    "Add {type}" : " {type} ni qo'shish",
    "Pending" : "Kutilmoqda",
    "Add to {team}" : " {team}ni qo`shish",
    "Loading" : "Yuklanmoqda",
    "Loading…" : "Yuklanmoqda...",
    "All contacts" : "Barcha kontaktlar",
    "Recently contacted" : "Yaqinda bog'langan",
    "User" : "Foydalanuvchi",
    "Group" : "Guruh",
    "Email" : "E-pochta",
    "Federation" : "Jamg'arma",
    "Privacy" : "Maxfiylik",
    "Users" : "Foydalanuvchilar",
    "Groups" : "Groups",
    "Contacts" : "Aloqalar",
    "No files in here" : "No files in hereBu erda fayl mavjud emas",
    "No entries found in this folder" : "Ushbu papkada hech qanday yozuv topilmadi",
    "Name" : "Nomi",
    "Size" : "O'lchami",
    "Modified" : "O'zgartirilgan"
},
"nplurals=1; plural=0;");
