OC.L10N.register(
    "files_lock",
    {
    "File is currently locked by %s" : "Датотеката е моментално заклучена од %s",
    "File is not locked" : "Датотеката не е заклучена",
    "File can only be unlocked by providing a valid owner lock token" : "Датотеката може да се отклучи само со важечки токен за сопственик.",
    "File can only be unlocked by the owner of the lock" : "Датотеката може да ја отклучи само сопственикот на заклучувањето.",
    "Desktop client" : "Клиент за компјутер",
    "iOS client" : "iOS клиент",
    "Android client" : "Android клиент",
    "Temporary files lock" : "Привремено заклучени датотеки",
    "Temporary lock your files" : "Повремено заклучување на ваши датотеки",
    "Allow your users to temporary lock their files to avoid conflicts while working on shared files." : "Дозволи им на корисниците да ги заклучуваат своите датотеките за да избегнат конфликт додека работат на споделени датотеки.",
    "Manually locked by {user}" : "Рачно заклучено од {user}",
    "Locked by editing online in {app}" : "Заклучено поради уредување онлајн во апликација {app}",
    "Automatically locked by {user}" : "Автоматски заклучена од {user}",
    "Unlock file" : "Отклучи датотека",
    "Lock file" : "Заклучи датотека",
    "files_lock" : "files_lock",
    "This file has been locked automatically by a client. Removing the lock may lead to a conflict saving the file." : "Оваа датотека е автоматски заклучена од клиент. Отстранувањето на заклучувањето може да предизвика конфликт при зачувување.",
    "Keep lock" : "Задржи заклучување",
    "Force unlock" : "Принудно отклучи"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
