OC.L10N.register(
    "related_resources",
    {
    "Calendar" : "Dagatal",
    "Calendar \"%s\"" : "Dagatal \"%s\"",
    "Deck" : "Deck-spjaldaforrit",
    "Deck board \"%s\"" : "Deck-borð \"%s\"",
    "Files" : "Skrár",
    "File \"%s\"" : "Skrá \"%s\"",
    "Group Folder" : "Mappa hóps",
    "Group Folder \"%s\"" : "Mappa hóps \"%s\"",
    "Talk conversation" : "Samtal í Talk-spjalli",
    "Conversation with %s" : "Samtal við %s",
    "Talk" : "Spjalla",
    "Talk conversation \"%s\"" : "Samtal í Talk-spjalli \"%s\"",
    "Related Resources" : "Tengd tilföng",
    "Displays resources related to current item in right panel" : "Birtir tilföng sem tengjast fyrirliggjandi atriði á spjaldinu til hægri",
    "Displays resources related to current item in right panel." : "Birtir tilföng sem tengjast fyrirliggjandi atriði á spjaldinu til hægri."
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
