OC.L10N.register(
    "serverinfo",
    {
    "System" : "Sistema",
    "Unknown" : "Ezezaguna",
    "Monitoring" : "Jarraipena",
    "Monitoring app with useful server information" : "Monitorizazio aplikazioa zerbitzariaren informazio baliagarriarekin",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Zerbitzariaren informazio baliagarria ematen du, CPU karga, RAM erabilera, diskoaren erabilera, erabiltzaile kopurua, etab. bezala.",
    "Active users" : "Erabiltzaile aktiboak",
    "Last hour" : "Azken ordua",
    "Webcron" : "Webcron",
    "Background jobs" : "Atzeko planoko lanak",
    "Mode" : "Modua",
    "Never" : "Inoiz ez",
    "Load" : "Karga",
    "CPU info not available" : "CPU informazioa ez dago eskuragarri",
    "Current usage" : "Gaur egungo erabilera",
    "Load average" : "Batez besteko karga",
    "Database" : "Datu-basea",
    "Type:" : "Mota:",
    "Version:" : "Bertsioa:",
    "Size:" : "Tamaina:",
    "Used" : "Erabilia",
    "Available" : "Erabilgarri",
    "Disk" : "Diskoa",
    "Files" : "Fitxategiak",
    "Storages" : "Biltegiak",
    "Mount:" : "Muntatzea:",
    "Filesystem:" : "Fitxategi-sistema:",
    "Available:" : "Erabilgarri:",
    "Used:" : "Erabilia:",
    "Status" : "Egoera",
    "Started" : "Hasi da",
    "Duration" : "Iraupena",
    "Job" : "Lana",
    "When" : "Noiz",
    "Details" : "Xehetasunak",
    "Succeeded" : "Arrakastatsua",
    "Failed" : "Huts egin du",
    "Running" : "Exekutatzen",
    "Memory" : "Memoria",
    "RAM info not available" : "RAM informazioa ez dago eskuragarri",
    "Total" : "Denetara",
    "Configuration" : "Ezarpenak",
    "Authentication" : "Autentifikazioa",
    "Network" : "Sarea",
    "Hostname" : "Ostalari-izena",
    "Gateway" : "Atebidea",
    "DNS" : "DNS",
    "Status:" : "Egoera:",
    "Speed:" : "Abiadura:",
    "Duplex:" : "Duplex:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "PHP extensions" : "PHP luzapenak",
    "Unable to list extensions" : "Ezin dira zerrendatu luzapenak",
    "PHP" : "PHP",
    "Memory limit:" : "Memoria muga:",
    "Max execution time:" : "Gehienezko exekuzio denbora:",
    "seconds" : "duela segundu batzuk",
    "Upload max size:" : "Igotzeko gehienezko tamaina:",
    "Show phpinfo" : "Erakutsi phpinfo",
    "CPU" : "PUZa",
    "Resource usage" : "Baliabideen erabilpena",
    "Shares" : "Partekatutakoak",
    "Users:" : "Erabiltzaileak:",
    "Groups:" : "Taldeak:",
    "Links:" : "Estekak:",
    "Emails:" : "E-postak:",
    "Federated sent:" : "Bidalketa federatua:",
    "Federated received:" : "Jasoketa federatua:",
    "Talk conversations:" : "Talk elkarrizketak:",
    "Average" : "Batezbestekoa",
    "Warning" : "Abisua",
    "Operating System:" : "Sistema eragilea:",
    "CPU:" : "PUZ:",
    "Server time:" : "Zerbitzariaren ordua:",
    "Uptime:" : "Denbora aktibo:",
    "Temperature" : "Tenperatura",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Totala: {memTotalBytes}/Erabiltzen: {memUsageBytes}",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Totala: {swapTotalBytes}/Erabiltzen: {swapUsageBytes}",
    "SWAP info not available" : "SWAP informazioa ez dago eskuragarri",
    "Copied!" : "Kopiatuta!",
    "Not supported!" : "Ez da onartzen!",
    "Press ⌘-C to copy." : "Sakatu ⌘-C kopiatzeko.",
    "Press Ctrl-C to copy." : "Sakatu Ctrl-C kopiatzeko.",
    "Memory:" : "Memoria:",
    "Files:" : "Fitxategiak:",
    "Storages:" : "Biltegiak:",
    "Free Space:" : "Leku librea:",
    "Hostname:" : "Ostalari-izena:",
    "Gateway:" : "Sarbidea:",
    "Extensions:" : "Hedapenak:",
    "External monitoring tool" : "Kanpo jarraipen tresna",
    "Copy" : "Kopiatu",
    "To use an access token, please generate one then set it using the following command:" : "Sarbide-token bat erabiltzeko, sortu bat eta ezarri komando hau erabiliz:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Ondoren, pasatu token-a \"NC-Token\" goiburuarekin goiko URLa kontsultatzerakoan.",
    "DNS:" : "DNS:"
},
"nplurals=2; plural=(n != 1);");
