OC.L10N.register(
    "contactsinteraction",
    {
    "Recently contacted" : "Berriki kontaktatuak",
    "Contacts Interaction" : "Kontaktuen hartu-emana",
    "Manages interaction between accounts and contacts" : "Kontu eta kontaktuen arteko interakzioa kudeatzen du",
    "Collect data about accounts and contacts interactions and provide an address book for the data" : "Bildu kontu eta kontaktuen arteko interakzioen datuak eta eskaini datuentzat helbide-agenda bat"
},
"nplurals=2; plural=(n != 1);");
