/**
 * SPDX-FileCopyrightText: 2023 Nextcloud GmbH and Nextcloud contributors
 * SPDX-License-Identifier: AGPL-3.0-or-later
 *
 * This is a dummy file for testing webserver support of JavaScript modules.
 */

export default 'Hello'
