OC.L10N.register(
    "files_versions",
    {
    "Block file versioning" : "Bloquear o controle de versões de arquivos",
    "Automatic tag based blocking of file version creation." : "Bloqueio automático da criação de versões de arquivos com base em etiquetas.",
    "No rule given" : "Nenhuma regra definida",
    "A new version is created" : "É criada uma nova versão",
    "Versions" : "Versões",
    "This application automatically maintains older versions of files that are changed." : "Este aplicativo mantém automaticamente versões mais antigas de arquivos que são alterados.",
    "This application automatically maintains older versions of files that are changed. When enabled, a hidden versions folder is provisioned in every user's directory and is used to store old file versions. A user can revert to an older version through the web interface at any time, with the replaced file becoming a version. The app automatically manages the versions folder to ensure the account does not run out of Quota because of versions.\n\t\tIn addition to the expiry of versions, the versions app makes certain never to use more than 50% of the account's currently available free space. If stored versions exceed this limit, the app will delete the oldest versions first until it meets this limit. More information is available in the Versions documentation." : "Este aplicativo mantém automaticamente versões mais antigas de arquivos que foram alterados. Quando ativada, uma pasta de versões oculta é provisionada no diretório de cada usuário e usada para armazenar versões antigas de arquivos. Um usuário pode reverter para uma versão mais antiga através da interface web a qualquer momento, com o arquivo substituído se tornando uma versão. O aplicativo gerencia automaticamente a pasta de versões para garantir que a conta não fique sem cota por causa das versões. \n\t\tAlém da expiração das versões, o aplicativo de versões garante nunca usar mais de 50% do espaço livre disponível atualmente na conta. Se as versões armazenadas excederem esse limite, o aplicativo excluirá primeiro as versões mais antigas até atingir esse limite. Mais informações estão disponíveis na documentação de Versões.",
    "Current version" : "Versão atual",
    "Initial version" : "Versão inicial",
    "You" : "Você",
    "Name this version" : "Nomear esta versão",
    "Edit version name" : "Editar nome da versão",
    "Compare to current version" : "Comparar com a versão atual",
    "Restore version" : "Restaurar versão",
    "Download version" : "Transferir versão",
    "Delete version" : "Excluir versão",
    "Cancel" : "Cancelar",
    "Remove version name" : "Remover nome da versão",
    "Save version name" : "Salvar nome da versão",
    "Version name" : "Nome da versão",
    "Named versions are persisted, and excluded from automatic cleanups when your storage quota is full." : "As versões nomeadas são mantidas e excluídas das limpezas automáticas quando sua cota de armazenamento está cheia.",
    "Initial version restored" : "Versão inicial restaurada",
    "Version restored" : "Versão restaurada",
    "Could not restore version" : "Não foi possível restaurar esta versão",
    "File versions" : "Versões do arquivo"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
