OC.L10N.register(
    "profile",
    {
    "View profile" : "Profil megtekintése",
    "Profile" : "Profil",
    "Searching …" : "Keresés…",
    "Not found" : "Nem található",
    "Insert" : "Beillesztés",
    "You have not added any info yet" : "Még nem adott meg semmilyen információt",
    "{user} has not added any info yet" : "{user} még nem adott meg semmilyen információt",
    "Error opening the user status modal, try hard refreshing the page" : "Hiba a felhasználói állapot párbeszédablak megnyitásakor, próbálja meg az oldal kényszerített újratöltését",
    "The headline and about sections will show up here" : "A címsor és a névjegy szakaszok itt fognak megjelenni",
    "Profile not found" : "Nem található profil",
    "Back to %s" : "Vissza ide: %s",
    "Edit Profile" : "Profil szerkesztése",
    "The profile does not exist." : "A profil nem létezik."
},
"nplurals=2; plural=(n != 1);");
