OC.L10N.register(
    "circles",
    {
    "You created the team {circle}" : "Criou o grupo {circle}",
    "{author} created the team {circle}" : "{author} criou o grupo {circle}",
    "You deleted {circle}" : "Eliminou {circle}",
    "{author} deleted {circle}" : "{author} eliminou {circle}",
    "You made {member} join {circle}" : "O {member}foi adicionado a {circle}",
    "{author} made {member} join {circle}" : "{author}adicionou {member} a {circle}",
    "You added team {member} as member to {circle}" : "O grupo {member} pertence a {circle} ",
    "{author} added team {member} as member to {circle}" : "{author}adicionou o grupo {member} a {circle}",
    "You made {member} leave {circle}" : "{member} foi removido de {circle}",
    "{author} made {member} leave {circle}" : "{author}fez {member} sair de {circle}",
    "You removed {member} from {circle}" : "Removeu {member} de {circle}",
    "{author} removed {member} from {circle}" : "{author}removeu {member} de {circle}",
    "You joined {circle}" : "Juntou-se a {circle}",
    "{member} joined {circle}" : "{member} juntou-se a {circle}",
    "You accepted the invitation to join {circle}" : "Aceitou o convite para juntar-se a {circle}",
    "{member} accepted the invitation to join {circle}" : "{member}aceitou o convite para juntar-se a {circle}",
    "You added {member} as member to {circle}" : "Adicionou {member} como participante de {circle}",
    "You have been added as member to {circle} by {author}" : "Foi adicionado como membro de {circle} por {author}",
    "{member} has been added as member to {circle} by {author}" : "{member} foi adicionado como membro de {circle} por {author} ",
    "You added {external} to {circle}" : "Adicionou {external}a {circle}",
    "{external} has been added to {circle} by {author}" : "{external} foi adicionado a {circle} por {author}",
    "You accepted {member}'s request to join {circle}" : "Aceitou o pedido de {member} para pertencer a {circle}",
    "Your request to join {circle} has been accepted by {author}" : "O seu pedido para pertencer a {circle} foi aceite por {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "O pedido de{member} para pertencer a {circle} foi aceite por {author}",
    "You left {circle}" : "Saiu de {circle}",
    "{member} left {circle}" : "{member} saiu de {circle}",
    "You declined the invitation to join {circle}" : "Declinou o convite para se juntar a {circle}",
    "{member} declined an invitation to join {circle}" : "{member} declinou o convite para se juntar a {circle}",
    "You cancelled your request to join {circle}" : "Cancelou o pedido para se juntar a {circle}",
    "{member} cancelled a request to join {circle}" : "{member} cancelou o pedido para se juntar a {circle}",
    "You have been removed from {circle} by {author}" : "Foi removido do grupo {circle} por {author}",
    "{member} has been removed from {circle} by {author}" : "{member} foi removido do grupo {circle} por {author}",
    "You removed {external} from {circle}" : "Removeu {external}de {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} foi removido de {circle} por {author}",
    "You cancelled {member}'s invitation to join {circle}" : "Cancelou o convite de {member}para se juntar a {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "O seu convite para se juntar a {circle} foi cancelado por {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author}cancelou o convite de {member} para se juntar a {circle}",
    "You dismissed {member}'s request to join {circle}" : "Removeu o pedido de {member}para se juntar a {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "O seu pedido para se juntar a {circle} não foi considerado por {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "O pedido de {member} para se juntar a {circle} foi desconsiderado por {author}",
    "You invited {member} to join {circle}" : "Convidou {member} para se juntar a {circle}",
    "You have been invited to join {circle} by {author}" : "Foi convidado por {author} para se juntar a {circle}",
    "{member} has been invited to join {circle} by {author}" : "{member}foi convidado por {author} para se juntar a {circle} ",
    "You changed {member}'s level in {circle} to %1$s" : "Modificou o estatuto de {member} em {circle} para %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} modificou o seu estatuto em {circle} para %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} modificou o estatuto de {member} em {circle} para %1$s",
    "You sent a request to join {circle}" : "Fez um pedido para se juntar a {circle}",
    "{member} sent a request to join {circle}" : "{member} fez um pedido para pertencer a {circle}",
    "You are the new owner of {circle}" : "É o novo responsável por {circle}",
    "{member} is the new owner of {circle}" : "{member} é o novo responsável por {circle}",
    "Teams" : "Grupos",
    "On events happening in a <strong>team</strong> of which you are a member" : "Em eventos ativos no <strong>grupo</strong> ao qual pertence",
    "Any important event in a <strong>team</strong> you are moderating" : "Qualquer evento importante no <strong>grupo </strong> em que é moderador",
    "On global events happening in any <strong>team</strong>" : "Eventos globais que estejam a acontecer em qualquer <strong>grupo</strong>",
    "Single" : "Único",
    "Personal" : "Pessoal",
    "System" : "Sistema",
    "Visible" : "Visível",
    "Open" : "Abrir",
    "Invite" : "Convite",
    "Join request" : "Pedido de adesão",
    "Friends" : "Amigos",
    "Password protected" : "Protegido com Palavra-passe",
    "No Owner" : "Sem responsável",
    "Hidden" : "Escondido",
    "Backend" : "backend",
    "Local" : "Local",
    "Root" : "Root",
    "Team invite" : "Convite do grupo",
    "Federated" : "Federada",
    "Mount point" : "Local para assignar o volume",
    "App" : "Aplicação",
    "Nextcloud Account" : "Conta Nextcloud",
    "Nextcloud Group" : "Grupo Nextcloud",
    "Email address" : "Endereço de email",
    "Contact" : "Contacto",
    "Team" : "Grupo",
    "Nextcloud App" : "Aplicação Nextcloud",
    "Teams App" : "Aplicativo Equipes",
    "Admin Command Line" : "Linha de Comando do Administrador",
    "Member" : "membro",
    "Moderator" : "Moderador",
    "Admin" : "Administrador",
    "Owner" : "Proprietário",
    "%s shared »%s« with you." : "%s partilhou »%s« consigo.",
    "%s shared »%s« with \"%s\"." : "%s partilhou  »%s« com \"%s\".",
    "%s on %s" : "%s às %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s partilhou »%2$s« consigo.\nJá deverá ter recebido um email com uma hiperligação para lhe aceder.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s partilhou »%2$s« consigo. Já deve ter recebido um email com um link para aceder aos mesmos.",
    "Password to access »%1$s« shared to you by %2$s" : "Palavra passe para aceder »%1$s« partilhado por si %2$s",
    "Password to access »%s«" : "Palavra-chave de acesso »%s«",
    "It is protected with the following password:" : "Está protegido com a seguinte palavra-chave:",
    "%1$s via %2$s" : "%1$s via %2$s",
    "Click the button below to open it." : "Clicar no botão abaixo para o abrir.",
    "Open »%s«" : "Abrir »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s partilhou vários ficheiros consigo.\nJá deve ter recebido um email com um link para aceder aos mesmos.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s partilhou vários ficheiros consigo. Deve ter recebido um email com um link para aceder aos mesmos.",
    "Password to access files shared to you by %1$s" : "Palavra passe para aceder a ficheiros partilhados por %1$s",
    "Password to access files" : "Palavra passe para aceder aos ficheiros",
    "%s shared multiple files with \"%s\"." : "%s partilhou vários ficheiros com \"%s\".",
    "%s shared multiple files with you." : "%s partilhou vários ficheiros consigo.",
    "Boot up" : "Arrancar a aplicação",
    "Nextcloud Initialization" : "Inicialização do Nextcloud",
    "Fresh installation status" : "Estado da instalação",
    "Building Local Database" : "Construção da Base de Dados Local",
    "Testing Basic Team Creation" : "Teste de Criação de uma Equipe Básica",
    "Adding local users and moderators" : "Adicionando utilizadores e moderadores locais",
    "Show all teams" : "Mostrar todos os grupos",
    "Create a new team" : "Criar um novo grupo",
    "Files" : "Ficheiros",
    "This feature is not available for personal teams" : "Este recurso não está disponível para equipes pessoais",
    "The team is not federated" : "Este grupo não está federado",
    "You cannot join this team" : "Não tem forma de aderir a este grupo",
    "This member is not a moderator" : "Este membro não é um moderador",
    "Insufficient privileges" : "Privilégios insuficientes",
    "This member does not exist" : "Este membro não existe",
    "This member is the owner of the team" : "Este membro é responsável pelo grupo",
    "Level cannot be changed for this type of member" : "O estatuto não pode ser mudado para este tipo de membro",
    "You are already a member of this team" : "Você já é membro desta equipe",
    "The account is already a member of this team" : "A conta já é membro desta equipe",
    "The account has already been invited into this team" : "A conta já foi convidada para esta equipe",
    "%s (Team owned by %s)" : "%s (Grupo gerido por %s)",
    "You are now a member of the Team \"%2$s\"" : "Agora você é um membro da Equipe \"%2$s\"",
    "You have been invited by %1$s into the Team \"%2$s\"" : "Você foi convidado por %1$s para fazer parte da equipe \"%2$s\"",
    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$s enviou uma solicitação para ser um membro da Equipe \"%2$s\"",
    "Accept" : "Aceitar",
    "Refuse" : "Recusar",
    "Leave the team" : "Deixar a equipe",
    "No image file provided" : "Nenhum arquivo de imagem fornecido",
    "Invalid file provided" : "Fornecido ficheiro inválido",
    "File is too big" : "O ficheiro é demasiado grande",
    "Invalid image" : "Imagem inválida",
    "Unknown filetype" : "Tipo de ficheiro desconhecido",
    "%s" : "%s",
    "Personal team" : "Grupo pessoal",
    "%s owned by %s" : "%s gerido por %s",
    "You have no permission to create a new team" : "Não tem permissão para criar um novo grupo",
    "Insufficient permissions to perform this action" : "Permissões insuficientes para realizar esta ação",
    "%s shared a file with \"%s\"." : "%s partilhou um ficheiro com \"%s\".",
    "%s shared a file with you." : "%s partilhou um ficheiro consigo.",
    "%1$s shared %2$s with %3$s" : "%1$s compartilhou %2$s com %3$s",
    "%1$s shared %2$s with \"%3$s\"" : "%1$s compartilhou %2$s com \"%3$s\"",
    "Open %s" : "Abrir %s",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s partilhou algum conteúdo consigo.\n Já deve ter recebido um email com uma hiperligação para lhe aceder.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s partilhou algum conteúdo consigo. Já deve ter recebido um email com uma hiperligação para lhe aceder.",
    "Password to access content shared with you by %1$s" : "Palavra passe para aceder ao conteúdo partilhado por %1$s",
    "Password to access content" : "Palavra passe para aceder ao conteúdo",
    "This item is already shared with this team" : "Este item já foi partilhado com este grupo",
    "Bring cloud-users closer together." : "Aproximar os utilizadores Nextcloud",
    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Equipas permite que os utilizadores possam criar os seus próprios grupos de pessoas/colegas/amigos.\nEsses grupos de pessoas podem ser usados por qualquer outra APP para que possa partilhar conteúdo.",
    "Unable to update federated teams config" : "Não foi possível atualizar a configuração das equipes federadas",
    "Invalid URL format. Please provide a valid URL." : "Formato de URL inválido. Por favor, fornece um URL válido.",
    "Changed frontal cloud URL" : "URL de nuvem frontal alterado",
    "Federation allows you to share teams with other trusted servers and make them discoverable across instances." : "A federação permite que você compartilhe equipes com outros servidores confiáveis e as torne detectáveis em todas as instâncias.",
    "Enable federated teams" : "Ativar equipes federadas",
    "https://…" : "https://…",
    "The public URL used by other instances to discover and connect to your teams." : "O URL público usado por outras instâncias para descobrir e se conectar às suas equipes.",
    "Unlimited" : "Ilimitado",
    "Default quota" : "Quota padrão",
    "Select default quota" : "Selecionar a cota padrão",
    "Save" : "Save",
    "Reconnect" : "Reconectar",
    "Connect" : "Ligar",
    "Overview" : "Visão Geral",
    "No teams found" : "Nenhum grupo encontrado",
    "Members" : "Membros",
    "Cancel" : "Cancel",
    "Next" : "Seguinte",
    "Back" : "Voltar",
    "Create team" : "Criar equipe",
    "Step {current} of {total}" : "Etapa {current} de {total}",
    "Team name" : "Nome do team",
    "Switch to list view" : "Mudar visualização para o modo lista",
    "Switch to grid view" : "Mudar visualização para o modo grelha",
    "Folder" : "Pasta",
    "you" : "Você",
    "Copy link" : "Copiar hiperligação",
    "Delete team" : "Excluir equipe",
    "Copied" : "Copiado",
    "Create link" : "Criar hiperligação",
    "Close" : "Fechar",
    "New folder" : "Nova pasta",
    "Folder name" : "Nome da pasta",
    "Talk conversation" : "Conversa Talk",
    "Conversation name" : "Nome da conversação",
    "Calendar" : "Calendário",
    "New calendar" : "Novo calendário",
    "Calendar name" : "Nome do calendário",
    "Please select a valid png or jpg file" : "Escolha ficheiro png ou jpg válido",
    "Description" : "Descrição",
    "Edit" : "Editar",
    "Create" : "Criar",
    "Show in Calendar" : "Mostrar no Calendário",
    "Add" : "Adicionar",
    "Apply" : "Aplicar",
    "Remove {type}" : "Remover {type} ",
    "Search {types}" : "Pesquisar {types}",
    "Add guest" : "Adicionar convidado",
    "Loading …" : "Carregando …",
    "No results" : "Sem resultados",
    "Add {type}" : "Adicionar {type}",
    "Remove member" : "Remover membro",
    "Pending" : "Pendente",
    "Role" : "Função",
    "Add to {team}" : "Adicionar a {team}",
    "Try again" : "Tentar novamente",
    "Create your first team" : "Crie sua primeira equipe",
    "Loading" : "A carregar",
    "Go back" : "Voltar",
    "Join" : "Aderir",
    "Join or create teams to see them here." : "Junte-se ou crie equipes para vê-las aqui.",
    "Loading…" : "A carregar…",
    "More teams" : "Mais equipes",
    "All contacts" : "Todos os contatos",
    "User" : "Utilizador",
    "Group" : "Grupo",
    "Email" : "E-mail",
    "Federation" : "Federação",
    "Privacy" : "Privacidade",
    "Users" : "Utilizadores",
    "groups" : "grupos",
    "Groups" : "Grupos",
    "Federated users" : "Usuários federados",
    "Contacts" : "Contactos",
    "No files in here" : "Sem ficheiros aqui",
    "No entries found in this folder" : "Não foram encontradas entradas nesta pasta",
    "Name" : "Nome",
    "Size" : "Tamanho",
    "Modified" : "Modificado",
    "Circles App Initialization" : "Inicialização da App Circles"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
