OC.L10N.register(
    "office",
    {
    "Office" : "Ofis",
    "Office overview" : "Ofis özeti",
    "Office overview app for Nextcloud" : "Nextcloud için ofis özeti uygulaması",
    "Create new" : "Yeni oluştur",
    "Scroll left" : "Sola kaydır",
    "Scroll right" : "Sağa kaydır",
    "Blank" : "Boş",
    "Search {category}" : "{category} ara",
    "Search" : "Ara",
    "Failed to create file" : "Dosya oluşturulamadı",
    "Failed to load files" : "Dosyalar yüklenemedi",
    "No office suite installed" : "Herhangi bir ofis paketi kurulmamış",
    "{count} found in {category}" : "{category} kategoride {count} bulundu",
    "Recent {category}" : "Son {category}",
    "Filter files" : "Dosyaları süz",
    "All" : "Tümü",
    "Mine" : "Benim",
    "Shared with me" : "Benimle paylaşılanlar",
    "Switch to grid view" : "Izgara görünümüne geç",
    "Switch to list view" : "Liste görünümüne geç",
    "No {category} found" : "Herhangi bir {category} bulunamadı",
    "Switch to \"All\" to see every file you have access to" : "Erişiminiz olan tüm dosyaları görmek için \"Tümü\" olarak seçin",
    "Search all in Files" : "Tüm dosyalarda ara",
    "Show all in Files" : "Tümünü Dosyalar uygulamasında görüntüle",
    "Create" : "Oluştur",
    "Filename" : "Dosya adı",
    "Documents" : "Belgeler",
    "Spreadsheets" : "Elektronik tablolar",
    "Presentations" : "Sunumlar",
    "Diagrams" : "Şemalar",
    "Filename cannot be empty" : "Dosya adı boş olamaz",
    "Filename contains invalid characters" : "Dosya adı içinde geçersiz karakterler var",
    "{count} {category} found" : "{count} {category} bulundu"
},
"nplurals=2; plural=(n > 1);");
