OC.L10N.register(
    "survey_client",
    {
    "Last report sent on: {on}" : "Siste rapport sendt: {on}",
    "An error occurred while sending your report." : "Feil under forsendelse av din rapport.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "Liste over apper <em>(for hver app: navn, versjon, påslått status)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Database-miljø <em>(type, versjon, databasestørrelse)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Krypteringsinformasjon <em>(er den påskrudd?, hva er forvalgt modul)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Antall ressurser <em>(per type og tilgangsinnstilling)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "PHP-miljø <em>(versjon, minnegrense, maksimal eksekveringstid, maksimal filstørrelse)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Serverinstallasjonsdetaljer <em>(versjon, bruk av hurtigminne, status for låsing/forhåndsvisninger/avatarer)</em>",
    "Statistic <em>(number of files, users, storages per type, comments and tags)</em>" : "Statistikk <em>(antall filer, brukere, lagring per type, kommentarer og merkelapper)</em>",
    "Usage survey" : "Statistikk for bruksmønster",
    "Help improve Nextcloud" : "Hjelp til med å forbedre Nextcloud",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Du kan hjelpe til med å forbedre Nextcloud ved å sende oss noe anonymisert data om ditt nåværende oppsett og bruk. Du kan skru det av igjen når som helst fra administrasjonsinnstillingene.",
    "Send usage" : "Send bruk",
    "Not now" : "Ikke nå",
    "Never" : "Aldri",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud." : "Sender anonymiserte data til Nextcloud som brukes for å forbedre Nextcloud.",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud. You\n\t\talways have full control over the content sent to Nextcloud and can disable\n\t\tit again at any time." : "Sender anonymisert data til Nextcloud for å hjelpe til med forbedring av Nextcloud. Du har alltid full kontroll over innholdet som sendes til Nextcloud og du kan deaktivere det igjen når som helst.",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Du kan hjelpe til med å forbedre Nextcloud ved å sende oss noe data om ditt nåværende oppsett og bruk.",
    "Send new report now" : "Send ny rapport nå",
    "Send usage survey monthly" : "Send statistikk for bruk månedlig ",
    "Data to send" : "Data å sende",
    "Last report" : "Siste rapport",
    "Last report sent on: %s" : "Siste rapport sendt: %s"
},
"nplurals=2; plural=(n != 1);");
