OC.L10N.register(
    "files_external",
    {
    "You are not logged in" : "Nesate prisijungęs",
    "Permission denied" : "Leidimas atmestas",
    "Storage with ID \"%d\" not found" : "Nerasta saugykla su identifikacijos numeriu \"%d\"",
    "Forbidden to manage local mounts" : "Draudžiama valdyti vietinius prijungimus",
    "Invalid backend or authentication mechanism class" : "Netinkama programinio kodo klasė realizuoja prisijungimo mechanizmą",
    "Invalid mount point" : "Neteisingas prijungimo taškas",
    "Objectstore forbidden" : "Objektų saugykla yra neprieinama",
    "Invalid storage backend \"%s\"" : "Neteisinga saugyklos „%s“ posistemė",
    "Not permitted to use backend \"%s\"" : "Neleidžiama naudoti posistemės „%s“",
    "Not permitted to use authentication mechanism \"%s\"" : "Neleidžiama naudoti tapatybės nustatymo mechanizmo „%s“",
    "Unsatisfied backend parameters" : " Netinkami posistemės parametrai",
    "Unsatisfied authentication mechanism parameters" : "Netinkami parametrai perduoti į prisijungimo mechanizmą",
    "Insufficient data: %s" : "Trūksta duomenų: %s",
    "Storage with ID \"%d\" is not editable by non-admins" : "Ne administratoriai negali redaguoti saugyklos su ID „%d“  ",
    "Static credentials" : "Statiniai prisijungimo duomenys",
    "Access key ID" : "Prieigos raktų ID",
    "Secret access key" : "Slaptas prieigos raktas",
    "Builtin" : "Įtaisytasis",
    "None" : "Nėra",
    "OpenStack v2" : "OpenStack v2",
    "Login" : "Prisijungti",
    "Password" : "Slaptažodis",
    "Tenant name" : "Laikino valdytojo vardas",
    "Identity endpoint URL" : "Tapatybės galutinio taško URL",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "Domenas",
    "Rackspace" : "Rackspace",
    "API key" : "API raktas",
    "Global credentials" : "Visuotiniai prisijungimo duomenys",
    "Log-in credentials, save in database" : "Prisijungimo duomenys, saugoti duomenų bazėje",
    "Login and password" : "Prisijungimas ir slaptažodis",
    "Log-in credentials, save in session" : "Prisijungimo duomenys, saugoti sesijoje",
    "Global credentials, manually entered" : "Prisijungimas ir slaptažodis",
    "Manually entered, store in database" : "Įvesta rankiniu būdu, saugoma duomenų bazėje",
    "RSA public key" : "RSA viešasis raktas",
    "Public key" : "Viešasis raktas",
    "RSA private key" : "RSA privatusis raktas",
    "Private key" : "Privatusis raktas",
    "Kerberos default realm, defaults to \"WORKGROUP\"" : "Numatytoji „Kerberos“ sritis, numatytoji reikšmė yra „WORKGROUP“",
    "Kerberos ticket Apache mode" : "Kerberos bilieto Apache režimas",
    "Kerberos ticket" : "Kerberos bilietas",
    "S3-Compatible Object Storage" : "Su S3 suderinama objektų saugykla",
    "Bucket" : "Amazon S3 saugykla",
    "Hostname" : "Domeno vardas",
    "Port" : "Prievadas",
    "Proxy" : "Tarpinis serveris",
    "Region" : "Regionas",
    "Storage Class" : "Saugyklos klasė",
    "Use HTTPS" : "Naudoti HTTPS",
    "Use Path Style (https://example.com/bucket)" : "Naudokite kelio stilių (https://example.com/bucket)",
    "Use Legacy S3 signing (v2)" : "Naudoti senąjį S3 pasirašymo būdą (v2)",
    "Enable multipart copy" : "Įgalinti kelių dalių kopijavimą",
    "Enable Direct Downloads (presigned URLs)" : "Įjungti tiesioginius atsisiuntimus (iš anksto pasirašytus URL)",
    "SSE-C encryption key" : "SSE-C šifravimo raktas",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Nuotolinis poaplankis",
    "Secure https://" : "Saugus https://",
    "FTP/FTPS" : "FTP/FTPS",
    "Host" : "Domenas",
    "Secure ftps://" : "Saugus ftps://",
    "Local (server storage)" : "Vietinė (serverio saugykla)",
    "Location" : "Vieta",
    "Nextcloud (WebDAV)" : "„Nextcloud“ (WebDAV)",
    "SFTP (SSH file transfer)" : "SFTP (failų persiuntimas per SSH)",
    "Root" : "Šakninis",
    "SFTP with public key authentication" : "SFTP su viešojo rakto autentifikavimu",
    "SMB/CIFS (Windows network share)" : "SMB/CIFS (Windows tinklo bendrinimas)",
    "Share" : "Bendrinti",
    "Show hidden files" : "Rodyti paslėptus failus",
    "Case sensitive file system" : "Didžiųjų ir mažųjų raidžių failų sistema",
    "Disabling it will allow to use a case insensitive file system, but comes with a performance penalty" : "Išjungus bus galima naudoti didžiųjų ir mažųjų raidžių neįtakojamą failų sistemą, tačiau tai sumažins našumą.",
    "Verify ACL access when listing files" : "Patikrinkite ACL prieigą, kai rodomi failai",
    "Check the ACL's of each file or folder inside a directory to filter out items where the account has no read permissions, comes with a performance penalty" : "Patikrinkite kiekvieno failo ar aplanko, esančio kataloge, ACL, kad pašalintumėte elementus, kurių paskyra neturi skaitymo teisių, nes tai gali sumažinti našumą.",
    "Timeout" : "Pasibaigė laikas",
    "SMB/CIFS using Nextcloud login" : "SMB/CIFS naudojant „Nextcloud“ prisijungimą",
    "Login as share" : "Prisijungti kaip bendrinti",
    "OpenStack Swift Object Storage" : "OpenStack Swift Object Storage",
    "Service name" : "Paslaugos vardas",
    "Request timeout (seconds)" : "Prisijungimo laikas (sekundėmis)",
    "External storage" : "Išorinė saugykla",
    "External storage support" : "Išorinės saugyklos priežiūra",
    "Adds basic external storage support" : "Pridedama pagrindinė išorinės atminties palaikymo funkcija",
    "This application enables administrators to configure connections to external storage providers, such as FTP servers, S3 or SWIFT object stores, other Nextcloud servers, WebDAV servers, and more. Administration can choose which types of storage to enable and can mount these storage locations for an account, a group, or the entire system. Users will see a new folder appear in their root Nextcloud directory, which they can access and use like any other Nextcloud folder. External storage also allows people to share files stored in these external locations. In these cases, the credentials for the owner of the file are used when the recipient requests the file from external storage, thereby ensuring that the recipient can access the shared file.\n\nExternal storage can be configured using the GUI or at the command line. This second option provides the administration with more flexibility for configuring bulk external storage mounts and setting mount priorities. More information is available in the external storage GUI documentation and the external storage Configuration File documentation." : "Ši programa leidžia administratoriams konfigūruoti ryšius su išorinių saugyklų teikėjais, tokiais kaip FTP serveriai, S3 arba SWIFT objektų saugyklos, kiti „Nextcloud“ serveriai, „WebDAV“ serveriai ir kt. Administratorius gali pasirinkti, kokius saugyklų tipus įjungti, ir gali prijungti šias saugyklų vietas paskyrai, grupei arba visai sistemai. Vartotojai pamatys naują aplanką, atsirastą jų šakniniame „Nextcloud“ kataloge, kurį jie galės pasiekti ir naudoti kaip bet kurį kitą „Nextcloud“ aplanką. Išorinė saugykla taip pat leidžia naudotojams bendrinti failus, saugomus šiose išorinėse vietose. Tokiais atvejais, kai gavėjas prašo failo iš išorinės saugyklos, naudojami failo savininko prisijungimo duomenys, taip užtikrinant, kad gavėjas gali pasiekti bendrinamą failą.\n\nIšorinę saugyklą galima konfigūruoti naudojant grafinę sąsają arba komandinėje eilutėje. Ši antroji parinktis suteikia administratoriui daugiau lankstumo konfigūruojant masinį išorinių saugyklų prijungimą ir nustatant prijungimo prioritetus. Daugiau informacijos rasite išorinės saugyklos grafinės sąsajos dokumentacijoje ir išorinės saugyklos konfigūracijos failo dokumentacijoje.",
    "Edit storage" : "Redaguoti saugyklą",
    "Add storage" : "Pridėti saugyklą",
    "Folder name" : "Aplanko pavadinimas",
    "Authentication" : "Autentifikavimas",
    "Cancel" : "Atsisakyti",
    "Edit" : "Redaguoti",
    "Create" : "Sukurti",
    "Restrict to" : "Apsiriboti",
    "Storage configuration" : "Saugyklos konfigūracija",
    "Never" : "Niekada",
    "Once every direct access" : "Kartą per tiesioginę peržiūrą",
    "Always" : "Visada",
    "Mount options" : "Prijungimo parinktys",
    "Check filesystem changes" : "Patikrinkite failų sistemos pakeitimus",
    "Read only" : "Tik skaitymui",
    "Enable previews" : "Leisti peržiūras",
    "Enable sharing" : "Leisti bendrinti",
    "Enable encryption" : "Įjungti šifravimą",
    "Compatibility with Mac NFD encoding (slow)" : "Suderinamumas su Mac NFD koduote (lėtai)",
    "External storages" : "Išorinės saugyklos",
    "Status" : "Būsena",
    "Restricted to" : "Apribota iki",
    "Actions" : "Veiksmai",
    "Checking …" : "Tikrinama  ...",
    "Recheck status" : "Dar kartą patikrinkite būseną",
    "Delete" : "Ištrinti",
    "System provided storage" : "Sistema suteikė saugyklą",
    "Saved" : "Įrašyta",
    "Error while saving" : "Išsaugant įvyko klaida",
    "Saved allowed backends" : "Išsaugotos leidžiamos posistemės",
    "Failed to save allowed backends" : "Nepavyko išsaugoti leidžiamų posistemių",
    "Advanced options for external storage mounts" : "Išplėstinės išorinių saugyklų prijungimo parinktys",
    "Allow people to mount external storage" : "Leisti naudotojams prijungti išorinę saugyklą",
    "External storage backends people are allowed to mount" : "Išorinių saugyklų posistemės, kurias naudotojams leidžiama prijungti",
    "Error generating key pair" : "Klaida generuojant raktų porą",
    "Key size" : "Rakto dydis",
    "Generate keys" : "Generuoti raktus",
    "Confirm" : "Patvirtinti",
    "Storage credentials" : "Saugyklos prisijungimo duomenys",
    "To access the storage, you need to provide the authentication credentials." : "Norėdami pasiekti saugyklą, turite pateikti autentifikavimo duomenis.",
    "Enter the storage login" : "Įveskite saugyklos prisijungimo vardą",
    "Enter the storage password" : "Įveskite saugyklos slaptažodį",
    "External storage enables you to mount external storage services and devices as secondary Nextcloud storage devices." : "Išorinė atmintis leidžia prijungti išorines saugojimo paslaugas ir įrenginius kaip antrinius „Nextcloud“ saugojimo įrenginius.",
    "You may also allow people to mount their own external storage services." : "Taip pat galite leisti naudotojams prijungti savo išorines saugyklos paslaugas.",
    "The cURL support in PHP is not enabled or installed." : " cURL palaikymas naudojant PHP yra neįgalintas arba neįdiegtas.",
    "The FTP support in PHP is not enabled or installed." : "FTP palaikymas naudojant PHP nėra įjungtas arba įdiegtas.",
    "{module} is not installed." : "{module} modulis nėra įdiegtas",
    "Dependant backends" : "Priklausomos posistemės",
    "No external storage configured or you do not have the permission to configure them" : "Nėra sukonfigūruota išorinė saugykla arba neturite leidimo jos konfigūruoti",
    "Add external storage" : "Pridėti išorinę saugyklą",
    "Global credentials saved" : "Globalūs prisijungimo duomenys išsaugoti",
    "Could not save global credentials" : "Nepavyko išsaugoti globalių prisijungimo duomenų",
    "Global credentials can be used to authenticate with multiple external storages that have the same credentials." : "Globalūs prisijungimo duomenys gali būti naudojami autentifikavimui naudojant kelias išorines saugyklas, turinčias tuos pačius prisijungimo duomenis.",
    "Saving …" : "Įrašoma …",
    "Save" : "Įrašyti",
    "Unable to update this external storage config. {statusMessage}" : "Nepavyko atnaujinti šios išorinės saugyklos konfigūracijos. {statusMessage}",
    "New configuration successfully saved" : "Nauja konfigūracija sėkmingai įrašyta",
    "Enter missing credentials" : "Įveskite trūkstamus prisijungimo duomenis",
    "Credentials successfully set" : "Prisijungimo duomenys sėkmingai nustatyti",
    "Error while setting credentials: {error}" : "Klaida nustatant prisijungimo duomenis: {error}",
    "Checking storage …" : "Tikrinama saugykla  ...",
    "There was an error with this external storage." : "Šioje išorinėje saugykloje įvyko klaida.",
    "We were unable to check the external storage {basename}" : "Nepavyko patikrinti išorinės saugyklos {basename}",
    "Examine this faulty external storage configuration" : "Patikrinkite šią klaidingą išorinės saugyklos konfigūraciją",
    "Open in Files" : "Atidaryti programėlėje „Failai“",
    "External mount error" : "Išorinio prijungimo klaida",
    "There was an error with this external storage. Do you want to review this mount point config in the settings page?" : "Įvyko klaida su šia išorine saugykla. Ar norite peržiūrėti šią prijungimo taško konfigūraciją nustatymų puslapyje?",
    "Open settings" : "Atverti nustatymus",
    "Ignore" : "Nepaisyti",
    "List of external storage." : "Išorinių saugyklų sąrašas.",
    "There is no external storage configured. You can configure them in your Personal settings." : "Nėra sukonfigūruotos išorinės saugyklos. Jas galite sukonfigūruoti asmeniniuose nustatymuose.",
    "There is no external storage configured and you don't have the permission to configure them." : "Nėra sukonfigūruotos išorinės saugyklos ir jūs neturite leidimo jų konfigūruoti.",
    "No external storage" : "Nėra išorinės atminties",
    "Storage type" : "Saugyklos tipas",
    "Unknown" : "Nežinoma",
    "Scope" : "Apimtis",
    "Personal" : "Asmeniniai",
    "System" : "Sistema",
    "Connected" : "Prisijungta",
    "Error" : "Klaida",
    "Indeterminate" : "Neapibrėžta",
    "Incomplete configuration" : "Nebaigta konfigūracija",
    "Unauthorized" : "Neautorizuota",
    "Network error" : "Tinklo klaida",
    "Grant access" : "Suteikti prieigą",
    "Error configuring OAuth2" : "Klaida, konfigūruojant OAuth2",
    "%s" : "%s",
    "Access key" : "Prieigos raktas",
    "Secret key" : "Slaptasis raktas",
    "OAuth2" : "OAuth2",
    "Client ID" : "Kliento ID",
    "Client secret" : "Kliento paslaptis",
    "S3 Storage" : "S3 saugykla",
    "Enable SSL" : "Įjungti SSL",
    "Enable Path Style" : "Įgalinti kelio stilių",
    "Legacy (v2) authentication" : "\"Legacy\" (v2) autentifikacija",
    "FTP" : "FTP",
    "Local" : "Vietinis",
    "Nextcloud" : "„Nextcloud“",
    "SFTP" : "SFTP",
    "SFTP with secret key login" : "SFTP protokolas su prisijungimu",
    "SMB/CIFS" : "SMB/CIFS",
    "SMB/CIFS using OC login" : "SMB/CIFS naudojant OC prisijungimą",
    "OpenStack Object Storage" : "„OpenStack“ objektų saugykla",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "cURL palaikymas yra neįjungtas arba neįdiegtas į PHP. %s prijungimas neįmanomas. Paprašykite sistemos administratoriaus pagalbos.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "FTP palaikymas yra neįjungtas arba neįdiegtas į PHP. %s prijungimas neįmanomas. Paprašykite sistemos administratoriaus pagalbos.",
    "\"%1$s\" is not installed. Mounting of %2$s is not possible. Please ask your system administrator to install it." : "\"%1$s\" nėra įdiegtas. %2$s prijungimas yra neįmanomas. Paprašykite savo sistemos administratoriaus, kad jį įdiegtų.",
    "Checking storage …" : "Tikrinama saugykla...",
    "Type to select account or group." : "Įveskite tekstą, kad pasirinktumėte paskyrą arba grupę.",
    "(Group)" : "(Grupė)",
    "Check for changes" : "Patikrinti ar nėra pakeitimų",
    "Disconnect" : "Atsijungti",
    "Unknown backend: {backendName}" : "Nežinoma posistemė: {backendName}",
    "Admin defined" : "Administratorius apibrėžtas",
    "Automatic status checking is disabled due to the large number of configured storages, click to check status" : "Automatinis būsenos tikrinimas išjungtas dėl didelio sukonfigūruotų saugyklų skaičiaus, spustelėkite, kad patikrintumėte būseną",
    "Are you sure you want to disconnect this external storage?" : "Ar tikrai norite atjungti šią išorinę saugyklą?",
    "It will make the storage unavailable in {instanceName} and will lead to a deletion of these files and folders on any sync client that is currently connected but will not delete any files and folders on the external storage itself." : "Tai padarys saugyklą nepasiekiama {instanceName} ir šie failai bei aplankai bus ištrinti bet kuriame šiuo metu prijungtame sinchronizavimo kliente, tačiau nebus ištrinti jokie failai ir aplankai pačioje išorinėje saugykloje.",
    "Delete storage?" : "Ištrinti saugyklą?",
    "Click to recheck the configuration" : "Spustelėkite norėdami iš naujo patikrinti konfigūraciją",
    "Saving …" : "Įrašoma …",
    "Failed to save global credentials" : "Nepavyko išsaugoti globalių prisijungimo duomenų",
    "Failed to save global credentials: {message}" : "Nepavyko išsaugoti globalių prisijungimo duomenų: {message}",
    "No external storage configured or you don't have the permission to configure them" : "Nėra sukonfigūruota jokia išorinė saugykla arba jūs neturite leidimo jų konfigūruoti",
    "Open documentation" : "Atverti dokumentaciją",
    "External storage enables you to mount external storage services and devices as secondary Nextcloud storage devices. You may also allow people to mount their own external storage services." : "Išorinė saugykla leidžia prijungti išorinių saugyklų paslaugas ir įrenginius kaip antrinius „Nextcloud“ saugojimo įrenginius. Taip pat galite leisti naudotojams prijungti savo išorines saugojimo paslaugas.",
    "Configuration" : "Konfigūracija",
    "Available for" : "Prieinamas",
    "All people" : "Visi naudotojai",
    "Advanced settings" : "Išplėstiniai nustatymai",
    "Use presigned S3 url" : "Naudoti iš anksto pasirašytą S3 URL"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
