OC.L10N.register(
    "files",
    {
    "Added to favorites" : "Gogokoetara gehitu da",
    "Removed from favorites" : "Gogokoetatik kendu da",
    "You added {file} to your favorites" : "{file} gehitu duzu gogokoetara",
    "You removed {file} from your favorites" : "{file} kendu duzu gogokoetatik",
    "Favorites" : "Gogokoak",
    "File changes" : "Fitxategi aldaketak",
    "Created by {user}" : "{user} erabiltzaileak sortua",
    "Changed by {user}" : "{user} erabiltzaileak aldatua",
    "Deleted by {user}" : "{user} erabiltzaileak ezabatua",
    "Restored by {user}" : "{user} erabiltzaileak leheneratua",
    "Renamed by {user}" : "{user} erabiltzaileak berrizendatua",
    "Moved by {user}" : "{user} erabiltzaileak lekuz aldatua",
    "\"remote account\"" : "\"urrutiko kontua\"",
    "You created {file}" : "{file} sortu duzu",
    "You created an encrypted file in {file}" : "{file} karpetan enkriptatutako fitxategi bat sortu duzu",
    "{user} created {file}" : "{user} erabiltzaileak {file} sortu du",
    "{user} created an encrypted file in {file}" : "{user} erabiltzaileak enkriptatutako fitxategi bat sortu du {file} karpetan",
    "{file} was created in a public folder" : "{file} sortu da karpeta publiko batean",
    "You changed {file}" : "{file} aldatu duzu",
    "You changed an encrypted file in {file}" : "{file} karpetan enkriptatutako fitxategi bat aldatu duzu",
    "{user} changed {file}" : "{user} erabiltzaileak {file} aldatu du",
    "{user} changed an encrypted file in {file}" : "{user} erabiltzaileak enkriptatutako fitxategi bat aldatu du {file} karpetan",
    "You deleted {file}" : "{file} ezabatu duzu",
    "You deleted an encrypted file in {file}" : "Enkriptatutako fitxategi bat ezabatu duzu {file} karpetan",
    "{user} deleted {file}" : "{user} erabiltzaileak {file} ezabatu du",
    "{user} deleted an encrypted file in {file}" : "{user} erabiltzaileak enkriptatutako fitxategi bat ezabatu du {file} karpetan",
    "You restored {file}" : "{file} leheneratu duzu",
    "{user} restored {file}" : "{user} erabiltzaileak {file} leheneratu du",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "{oldfile} (ezkutukoa) {newfile} (ezkutukoa) bezala berrizendatu duzu",
    "You renamed {oldfile} (hidden) to {newfile}" : "{oldfile} (ezkutukoa) {newfile} bezala berrizendatu duzu",
    "You renamed {oldfile} to {newfile} (hidden)" : "{oldfile} {newfile} (ezkutukoa) bezala berrizendatu duzu",
    "You renamed {oldfile} to {newfile}" : "{oldfile} {newfile} bezala berrizendatu duzu",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} erabiltzaileak {oldfile} (ezkutukoa) {newfile} (ezkutukoa) bezala berrizendatu du",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} erabiltzaileak {oldfile} (ezkutukoa) {newfile} bezala berrizendatu du",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} erabiltzaileak {oldfile} {newfile} (ezkutukoa) bezala berrizendatu du",
    "{user} renamed {oldfile} to {newfile}" : "{user} erabiltzaileak {oldfile} {newfile} bezala berrizendatu du",
    "You moved {oldfile} to {newfile}" : "{oldfile} lekuz aldatu duzu {newfile}(e)ra",
    "{user} moved {oldfile} to {newfile}" : "{user} erabiltzaileak {oldfile} lekuz aldatu du {newfile}(e)ra",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Fitxategi bat gehitu edo kendu da zure <strong>gogokoetatik</strong>",
    "Files" : "Fitxategiak",
    "A file or folder has been <strong>changed</strong>" : "Fitxategi edo karpeta bat <strong>aldatu da</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "Gogoko fitxategi edo karpeta bat <strong>aldatu</strong> egin da.",
    "Failed to authorize" : "Ezin izan da baimendu",
    "Invalid folder path" : "Karpeta bide baliogabea",
    "Folder not found" : "Ez da karpeta aurkitu",
    "The file cannot be found" : "Ezin da fitxategia aurkitu",
    "The destination path does not exist: %1$s" : "Helburuko bidea ez dago: %1$s",
    "You do not have permission to create a file at the specified location" : "Ez duzu baimenik fitxategia sortzeko zehaztutako tokian",
    "The file could not be converted." : "Fitxategia ezin izan da bihurtu.",
    "Could not get relative path to converted file" : "Ezin da lortu bide erlatiboa bihurtutako fitxategiarentzat",
    "Limit must be a positive integer." : "Mugak zenbaki osoa eta positiboa izan behar du.",
    "The replacement character may only be a single character." : "Ordezko karaktereak bakarra izan behar du.",
    "Filename sanitization already started." : "Fitxategi-izenen garbiketa hasi da jada.",
    "No filename sanitization in progress." : "Fitxategi-izenen garbiketa ez dago martxan.",
    "Favorite files" : "Gogoko fitxategiak",
    "No favorites" : "Gogokorik ez",
    "More favorites" : "Gogoko gehiago",
    "Accept" : "Onartu",
    "Reject" : "Ukatu",
    "Incoming ownership transfer from {user}" : "{user}(r)en jabetza-transferentzia",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "{path} onartu nahi duzu?\n\nOharra: onarpenaren ondoren transferentzia prozesuak ordu 1 iraun dezake.",
    "Ownership transfer denied" : "Jabetza transferentzia ukatu egin da",
    "Your ownership transfer of {path} was denied by {user}." : "{path}-ren zure jabetza-transferentzia {user} erabiltzaileak ukatu du",
    "Ownership transfer failed" : "Jabetzaren transferentziak huts egin du",
    "Your ownership transfer of {path} to {user} failed." : "{path}(r)en jabetza {user} erabiltzaileari transferitzeak huts egin du.",
    "The ownership transfer of {path} from {user} failed." : "{path}(r)ren jabetza {user} erabiltzailetik transferitzeak huts egin du.",
    "Ownership transfer done" : "Jabetzaren transferentzia egina",
    "Your ownership transfer of {path} to {user} has completed." : "{path}(r)en jabetza {user} erabiltzaileari transferitzea osatu da.",
    "The ownership transfer of {path} from {user} has completed." : "{path}(r)en jabetza {user} erabiltzailetik transferitzea osatu da.",
    "in %s" : "%s(e)n",
    "Transferred from %1$s on %2$s" : "%1$s(e)tik %2$s(e)n transferitua",
    "Delete files" : "Ezabatu fitxategiak",
    "Show files in grid view" : "Erakutsi fitxategiak sareta ikuspegian",
    "File" : "Fitxategia",
    "File Management" : "Fitxategi-kudeaketa",
    "Home" : "Etxea",
    "Target folder does not exist any more" : "Helburuko karpeta ez da existitzen jadanik",
    "Reload current directory" : "Birkargatu uneko direktorioa",
    "Go to the \"{dir}\" directory" : "Joan \"{dir}\" direktoriora",
    "Current directory path" : "Uneko direktorio-bidea",
    "Share" : "Partekatu",
    "Reload content" : "Birkargatu edukia",
    "Your have used your space quota and cannot upload files anymore" : "Zure espazio-kuota erabili duzu eta ezin duzu fitxategi gehiago kargatu",
    "You do not have permission to upload or create files here." : "Ez daukazu baimenik bertan fitxategiak sortzeko edo kargatzeko.",
    "Drag and drop files here to upload" : "Jaregin fitxategiak hemen igotzeko",
    "Favorite" : "Gogokoa",
    "Back" : "Itzuli",
    "Toggle selection for file \"{displayName}\"" : "Ordeztu hautatutakoa  \"{displayName}\" fitxategiarekin",
    "Toggle selection for folder \"{displayName}\"" : "Ordeztu hautatutakoa  \"{displayName}\" karpetarekin",
    "File is loading" : "Fitxategia kargatzen ari da",
    "Folder is loading" : "Karpeta kargatzen ari da",
    "Filename" : "Fitxategi-izena",
    "Folder name" : "Karpetaren izena",
    "Another entry with the same name already exists." : "Izen bereko beste sarrera bat badago jada.",
    "Invalid filename." : "Fitxategi-izen baliogabea.",
    "Rename file" : "Berrizendatu fitxategia",
    "Recently created" : "Duela gutxi sortuak",
    "Folder" : "Karpeta",
    "Unknown file type" : "Fitxategi mota ezezaguna",
    "{ext} image" : "{ext} irudia",
    "{ext} video" : "{ext} bideoa",
    "{ext} audio" : "{ext} audioa",
    "{ext} text" : "{ext} testua",
    "Pending" : "Zain",
    "Unknown date" : "Data ezezaguna",
    "Active filters" : "Iragazki aktiboak",
    "Remove filter" : "Kendu iragazkia",
    "Today" : "Gaur",
    "Last 7 days" : "Azken 7 egunetan",
    "Last 30 days" : "Azken 30 egunetan",
    "This year ({year})" : "Aurten ({year})",
    "Last year ({year})" : "Iaz ({year})",
    "Custom range" : "Pertsonalizatu tartea",
    "Custom date range" : "Data-tarte pertsonalizatua",
    "Search everywhere" : "Bilatu nonahi",
    "Documents" : "Dokumentuak",
    "Spreadsheets" : "kalkulu-orriak",
    "Presentations" : "Aurkezpenak",
    "PDFs" : "PDFak",
    "Folders" : "Karpetak",
    "Audio" : "Audio",
    "Images" : "Irudiak",
    "Videos" : "Bideoak",
    "Filters" : "Iragazkiak",
    "Back to filters" : "Itzuli iragazietara",
    "Appearance" : "Itxura",
    "Show hidden files" : "Erakutsi ezkutuko fitxategiak",
    "Show file type column" : "Erakutsi fitxategi luzapenen zutabea",
    "Show file extensions" : "Erakutsi fitxategien luzapena",
    "Crop image previews" : "Moztu irudien aurrebistak",
    "General" : "Orokorra",
    "Sort favorites first" : "Ordenatu gogokoak lehenengo",
    "Sort folders before files" : "Ordenatu karpetak fitxategien aurretik",
    "Enable folder tree view" : "Gaitu karpeten zuhaitz ikuspegia",
    "Default view" : "Ikuspegi lehenetsia",
    "All files" : "Fitxategi guztiak",
    "Personal files" : "Fitxategi pertsonalak",
    "Additional settings" : "Ezarpen gehiago",
    "Actions" : "Ekintzak",
    "File actions" : "Fitxategi ekintzak",
    "Selection" : "Hautapena",
    "Select all files" : "Fitxategi guztiak aukeratu",
    "Deselect all" : "Deshautatu dena",
    "Select or deselect" : "Hautatu edo desautatu",
    "Select a range" : "Hautatu tarte bat",
    "Navigation" : "Nabigazioa",
    "Go to parent folder" : "Joan karpeta gurasora",
    "Go to file above" : "Joan goiko fitxategira",
    "Go to file below" : "Joan beheko fitxategira",
    "Go left in grid" : "Joan ezkerrera saretan",
    "Go right in grid" : "Joan eskuinera saretan",
    "View" : "Ikusi",
    "Toggle grid view" : "Txandakatu sareta ikuspegia",
    "Show those shortcuts" : "Erakutsi lasterbide horiek",
    "Warnings" : "Oharrak",
    "Warn before changing a file extension" : "Abisatu fitxategiaren luzapena aldatu aurretik",
    "Warn before deleting a file" : "Abisatu fitxategi bat ezabatu aurretik",
    "WebDAV URL" : "WebDAV URLa",
    "Create an app password" : "Sortu aplikazioaren pasahitza",
    "Required for WebDAV authentication because Two-Factor Authentication is enabled for this account." : "WebDAV autentifikaziorako beharrezkoa da, kontu honetan bi faktoreko autentifikazioa gaituta dagoelako.",
    "How to access files using WebDAV" : "Nola sartu fitxategietara WebDAV erabiliz",
    "Total rows summary" : "Errenkaden guztirako laburpena",
    "Toggle selection for all files and folders" : "Ordeztu hautatutako fitxategi eta karpeta guztiak",
    "Name" : "Izena",
    "File type" : "Fitxategi mota",
    "Size" : "Tamaina",
    "Modified" : "Aldatuta",
    "{displayName}: failed on some elements" : "{displayName}: huts egin du elementu batzuetan",
    "{displayName}: done" : "{displayName}: egina",
    "{displayName}: failed" : "{displayName}: huts egin du",
    "(selected)" : "(hautatuta)",
    "List of files and folders." : "Fitxategi eta karpeten zerrenda.",
    "You have used your space quota and cannot upload files anymore." : "Zure espazio-kuota erabili duzu eta ezin duzu fitxategi gehiago kargatu.",
    "Column headers with buttons are sortable." : "Botoiak dituzten zutabeen goiburuak ordena daitezke.",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Zerrenda hau ez da guztiz ikusten errendimendu arrazoiengatik. Fitxategiak zerrendan zehar nabigatzen duten heinean bistaratuko dira.",
    "File not found" : "Ez da fitxategia aurkitu",
    "_{count} selected_::_{count} selected_" : ["{count} hautatuta","{count} hautatuta"],
    "Views" : "Ikuspegiak",
    "Search everywhere …" : "Bilatu nonahi …",
    "Search here …" : "Bilatu hemen …",
    "Search scope options" : "Bilaketa-eremuaren aukerak",
    "Search here" : "Bilatu hemen",
    "Owner" : "Jabea",
    "{usedQuotaByte} used" : "{usedQuotaByte} erabilita",
    "{used} of {quota} used" : "{used} / {quota} erabilita",
    "{relative}% used" : "%{relative} erabilita",
    "Could not refresh storage stats" : "Ezin izan da biltegiratze maila freskatu",
    "Your storage is full, files can not be updated or synced anymore!" : "Zure biltegia beteta dago, ezin duzu fitxategirik igo edo sinkronizatu jada!",
    "Storage information" : "Biltegiaren informazioa",
    "Storage quota" : "Biltegiratze-kuota",
    "New folder" : "Karpeta berria",
    "Create new folder" : "Sortu karpeta berria",
    "This name is already in use." : "Izen hau dagoeneko erabiltzen ari da.",
    "Create" : "Sortu",
    "Files starting with a dot are hidden by default" : "Puntu batez hasten diren fitxategiak ezkutatuta daude",
    "Failed to start filename sanitization." : "Ezin izan da fitxategi-izenen garbiketa abiatu.",
    "Failed to refresh filename sanitization status." : "Ezin izan da fitxategi-izenen garbiketa egoera freskatu.",
    "Filename sanitization in progress." : "Fitxategi-izenen garbiketa martxan da.",
    "Currently {processedUsers} of {totalUsers} accounts are already processed." : "Une honetan {totalUsers}kontuetatik {processedUsers}prozesatu dira.",
    "Preparing …" : "Prestatzen …",
    "Refresh" : "Freskatu",
    "All files have been santized for Windows filename support." : "Fitxategi guztiak garbitu dira Windows-en fitxategi-izenaren onarpenerako.",
    "Some files could not be sanitized, please check your logs." : "Fitxategi batzuk ezin izan dira garbitu, begiratu erregistroak.",
    "Sanitization errors" : "Garbiketa erroreak",
    "Not sanitized filenames" : "Garbitu gabeko fitxategi-izenak",
    "Windows filename support has been enabled." : "Windows-en fitxategi-izenen onarpena aktibatu da.",
    "While this blocks users from creating new files with unsupported filenames, existing files are not yet renamed and thus still may break sync on Windows." : "Honek erabiltzaileei onartzen ez diren fitxategi-izenekin fitxategi berriak sortzea eragozten dien bitartean, existitzen diren fitxategiak ez dira oraindik izenez aldatuko eta, beraz, Windows-en sinkronizazioa eten daiteke.",
    "You can trigger a rename of files with invalid filenames, this will be done in the background and may take some time." : "Fitxategi-izen baliogabea duten fitxategien izenak alda ditzakezu. Hori bigarren planoan egingo da, eta baliteke denbora pixka bat behar izatea.",
    "Please note that this may cause high workload on the sync clients." : "Kontuan izan horrek lan-karga handia eragin diezaiekeela sinkronizazio-bezeroei.",
    "Limit" : "Muga",
    "This allows to configure how many users should be processed in one background job run." : "Honek atzeko planoko exekuzio batean zenbat erabiltzaile prozesatu behar diren konfiguratzeko aukera ematen du.",
    "Sanitize filenames" : "Garbitu fitxategi-izenak",
    "(starting)" : "(abiatzen)",
    "Fill template fields" : "Bete txantiloien eremuak",
    "Submitting fields …" : "Eremuak bidaltzen …",
    "Submit" : "Bidali",
    "Choose a file or folder to transfer" : "Aukeratu fitxategi edo karpeta bat transferitzeko",
    "Transfer \"{path}\"" : "Igorri \"{path}\"",
    "Select file or folder" : "Hautatu fitxategia edo karpeta",
    "Transfer" : "Transferitu",
    "Transfer {path} to {userid}" : "Transfereritu {path}  {userid} erabiltzaileari",
    "Error while opening file picker for transfer ownership" : "Errore bat gertatu da jabetza transferitzeko fitxategi-hautatzailea irekitzean",
    "Error while searching for users" : "Errorea erabiltzaileak bilatzean",
    "Ownership transfer request sent" : "Jabetza transferentzia eskaera bidalita",
    "Cannot transfer ownership of a file or folder you do not own" : "Ezin da zurea ez den fitxategi edo karpeta baten jabetza transferitu",
    "Error while sending ownership transfer request" : "Errore bat gertatu da jabetza transferitzeko eskaera bidaltzean",
    "Transfer ownership of a file or folder" : "Transferitu fitxategiaren edo karpetaren jabetza",
    "File or folder to transfer" : "Transferitzeko fitxategia edo karpeta",
    "No file or folder selected" : "Ez da fitxategirik edo karpetarik hautatu",
    "New owner" : "Jabe berria",
    "You need to select a file or folder to transfer ownership." : "Fitxategi edo karpeta bat hautatu behar duzu jabetza transferitzeko.",
    "You need to select a new owner for the file or folder." : "Fitxategi edo karpetarako jabe berri bat hautatu behar duzu.",
    "Keep {old}" : " {old} mantendu",
    "Keep without extension" : "Mantendu luzapenik gabe",
    "Use {new}" : "Erabili {new}",
    "Remove extension" : "Kendu luzapena",
    "Change file extension" : "Aldatu fitxategiaren luzapena",
    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "Fitxategiaren luzapena «{old}»(e)tik «{new}»(e)ra aldatzeak irakurezin bihur dezake.",
    "Removing the file extension \"{old}\" may render the file unreadable." : "«{old}» fitxategiaren luzapena kentzeak fitxategia irakurezin bihur dezake.",
    "Adding the file extension \"{new}\" may render the file unreadable." : "«{new}» fitxategiaren luzapena gehitzeak fitxategia irakurezin bihur dezake.",
    "Do not show this dialog again." : "Ez erakutsi elkarrizketa hau berriro",
    "Rename file to hidden" : "Berrizendatu fitxategia ezkutukora",
    "Prefixing a filename with a dot may render the file hidden." : "Fitxategi-izenaren aurretik puntu bat jartzeak fitxategia ezkutatu dezake.",
    "Are you sure you want to rename the file to \"{filename}\"?" : "Ziur al zaude fitxategia \"{filename}\" ra berrizendatu nahi duzula?",
    "Cancel" : "Utzi",
    "Rename" : "Berrizendatu",
    "Select file or folder to link to" : "Hautatu estekatzeko fitxategia edo karpeta",
    "Choose {file}" : "Aukeratu {file}",
    "Files settings" : "FItxategien ezarpenak",
    "Switch to list view" : "Aldatu zerrenda ikuspegira",
    "Switch to grid view" : "Aldatu sareta ikuspegira",
    "The file could not be found" : "Fitxategiaren hodeia ez da aurkitu",
    "Upload was cancelled by user" : "Igoera bertan behera utzi du erabiltzaileak",
    "Not enough free space" : "Ez dago leku libre nahikorik",
    "Operation is blocked by access control" : "Sarbide kontrolak eragiketa blokeatu du",
    "Error during upload: {message}" : "Errorea igotzean: {message}",
    "Error during upload, status code {status}" : "Errore bat gertatu da igotzean, {status} egoera kodea",
    "Unknown error during upload" : "Errore ezezaguna igotzean",
    "File list is reloading" : "Fitxategi zerrenda birkargatzen",
    "Loading current folder" : "Uneko karpeta kargatzen",
    "Retry" : "saiatu berriro",
    "No files in here" : "Ez dago fitxategirik hemen",
    "Upload some content or sync with your devices!" : "Igo edukiren bat edo sinkronizatu zure gailuekin!",
    "Go back" : "Atzera",
    "Loading …" : "Kargatzen …",
    "Your files" : "Zure fitxategiak",
    "Open in files" : "Ireki Fitxategiak aplikazioan",
    "File cannot be accessed" : "Ezin da fitxategia atzitu",
    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Ezin izan da fitxategia aurkitu edo ez duzu ikusteko baimenik. Eskatu bidaltzaileari partekatzeko.",
    "No search results for “{query}”" : "Ez da aurkitu emaitzarik “{query}” kontsultarentzat",
    "Search for files" : "Bilatu fitxategiak",
    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Baimendu fitxategi-izenak mugatzea, fitxategiak bezero guztiekin sinkroniza daitezkeela ziurtatzeko. Lehenespenez POSIX-en balio duten fitxategi-izen guztiak (adibidez, Linux edo macOS) onartzen dira.",
    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Windows-ekin bateragarriak diren fitxategi-izenak gaitu ondoren, lehendik dauden fitxategiak ezin dira gehiago aldatu, baina jabeak baliozko izen berria eman diezaioke.",
    "Failed to toggle Windows filename support" : "Huts egin du Windows-en fitxategi-izenen onarpena aldatzeak",
    "Files compatibility" : "Fitxategien bateragarritasuna",
    "Enforce Windows compatibility" : "Ezarri Windows bateragarritasuna",
    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Honek Windows sistemetan balio ez duten fitxategi-izenak blokeatuko ditu, adibidez, izen erreserbatuak edo karaktere bereziak erabiltzea. Baina honek ez du maiuskulak eta minuskulak bereizteko bateragarritasuna beteko.",
    "Blank" : "Hutsik",
    "Unable to create new file from template" : "Ezin da fitxategi berria sortu txantiloitik",
    "Pick a template for {name}" : "Hautatu {name}(r)entzako txantiloia",
    "Create a new file with the selected template" : "Sortu fitxategi berria hautatutako txantiloiarekin",
    "Creating file" : "Fitxategia sortzen",
    "Save as {displayName}" : "Gorde honela: {displayName}",
    "Save as …" : "Gorde honela …",
    "Converting files …" : "Fitxategiak bihurtzen …",
    "Failed to convert files: {message}" : "Huts egin du fitxategiak bihurtzeak: {message}",
    "All files failed to be converted" : "Huts egin du fitxategi guztiak bihurtzean",
    "One file could not be converted: {message}" : "Fitxategi bat ezin izan da bihurtu: {message}",
    "_%n file could not be converted_::_%n files could not be converted_" : ["Fitxategi %n ezin izan da bihurtu","%n fitxategi ezin izan dira bihurtu"],
    "_%n file converted_::_%n files converted_" : ["Fitxategi %n bihurtu da","%n fitxategi bihurtu dira"],
    "Files converted" : "Fitxategiak bihurtu dira",
    "Failed to convert files" : "Huts egin du fitxategien bihurtzeak",
    "Converting file …" : "Fitxategia bihurtzen …",
    "File successfully converted" : "Fitxategia behar bezala bihurtu da",
    "Failed to convert file: {message}" : "Fitxategi honen bihurtzeak huts egin du: {message}",
    "Failed to convert file" : "Huts egin du fitxategiaren bihurtzeak",
    "Delete" : "Ezabatu",
    "Leave this share" : "Utzi partekatze hau",
    "Leave these shares" : "Utzi partekatze hauek",
    "Disconnect storage" : "Deskonektatu biltegia",
    "Disconnect storages" : "Deskonektatu biltegiak",
    "Delete permanently" : "Ezabatu betirako",
    "Delete and unshare" : "Ezabatu eta kendu partekatzea",
    "Delete file" : "Fitxategia ezabatu",
    "Delete folder" : "Ezabatu karpeta",
    "Delete folders" : "Ezabatu karpetak",
    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Elementu {count} betiko ezabatzera zoaz","{count} elementu betiko ezabatzera zoaz"],
    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Elementu {count} ezabatzera zoaz"," {count}  elementu ezabatzera zoaz"],
    "Confirm deletion" : "Berretsi ezabaketa",
    "Download" : "Deskargatu",
    "The requested file is not available." : "Eskatutako fitxategia ez dago eskuragarri.",
    "The requested files are not available." : "Eskatutako fitxategiak ez daude eskuragarri.",
    "Add to favorites" : "Gehitu gogokoetara",
    "Remove from favorites" : "Kendu gogokoetatik",
    "Add or remove favorite" : "Gehitu edo kendu gogokoetatik",
    "Move" : "Mugitu",
    "Copy" : "Kopiatu",
    "Move or copy" : "Mugitu edo kopiatu",
    "Destination is not a folder" : "Helburua ez da karpeta bat",
    "This file/folder is already in that directory" : "Fitxategi/karpeta hau dagoeneko karpeta horretan dago",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "Ezin duzu fitxategi/karpeta bat berera edo bere azpikarpeta batera mugitu",
    "A file or folder with that name already exists in this folder" : "Izen hori duen fitxategi edo karpeta bat dago karpena honetan",
    "The files are locked" : "Fitxategiak blokeatuta daude",
    "The file does not exist anymore" : "Fitxategia ez da existizen dagoeneko",
    "Moving \"{source}\" to \"{destination}\" …" : "\"{source}\"  \"{destination}\"-ra eramaten …",
    "_Moving %n file to \"{destination}\" …_::_Moving %n files to \"{destination}\" …_" : ["Fitxategi %n\"{destination}\"-ra eramaten…","%n fitxategi \"{destination}\"-ra eramaten…"],
    "Copying \"{source}\" to \"{destination}\" …" : " \"{source}\" \"{destination}\"-ra kopiatzen …",
    "_Copying %n file to \"{destination}\" …_::_Copying %n files to \"{destination}\" …_" : ["Fitxategi %n \"{destination}\"-ra kopiatzen...","%n fitxategi \"{destination}\"-ra kopiatzen..."],
    "Choose destination" : "Aukeratu helburua",
    "Copy to {target}" : "Kopiatu hona: {target}",
    "Move to {target}" : "Mugitu hona: {target}",
    "Move or copy operation failed" : "Mugitzeko edo kopiatzeko eragiketak huts egin du",
    "Open folder" : "Ireki karpeta",
    "Open folder {displayName}" : "Ireki {displayName} karpeta",
    "Open in Files" : "Ireki Fitxategiak aplikazioan",
    "Open locally" : "Ireki lokalean",
    "Failed to redirect to client" : "Bezerora birbideratzeak huts egin du",
    "Open file locally" : "Ireki fitxategia lokalean",
    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Fitxategia orain zure gailuan ireki beharko litzateke. Hala ez bada, egiaztatu mahaigaineko aplikazioa instalatuta duzula.",
    "Retry and close" : "Saiatu berriro eta itxi",
    "Open online" : "Ireki linean",
    "Details" : "Xehetasunak",
    "Open the details sidebar" : "Ireki zehetasunen alboko barra",
    "Unfavorite" : "Kendu gogokoetatik",
    "View in folder" : "Ikusi karpetan",
    "Type" : "Mota",
    "Created new folder \"{name}\"" : "\"{name}\" karpeta berria sortu da",
    "Unable to initialize the templates directory" : "Ezin da txantiloien direktorioa hasieratu",
    "Create templates folder" : "Sortu txantiloien karpeta",
    "Templates" : "Txantiloiak",
    "New template folder" : "Txantiloien karpeta berria",
    "In folder" : "Karpetan",
    "Pick folder to search in" : "Aukeratu bilatu nahi duzun karpeta",
    "Search in all files" : "Bilatu fitxategi guztietan",
    "Search in folder: {folder}" : "Bilatu {folder} karpetan",
    "One of the dropped files could not be processed" : "Jaregindako fitxategietako bat ezin izan da prozesatu",
    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Zure nabigatzaileak ez du Filesystem APIa onartzen. Direktorioak ez dira igoko",
    "No files to upload" : "Ez dago igotzeko fitxategirik",
    "Unable to create the directory {directory}" : "Ezin da {directory} direktorioa sortu",
    "Some files could not be uploaded" : "Fitxategi batzuk ezin izan dira igo",
    "Files uploaded successfully" : "Fitxategiak behar bezala igo dira",
    "No files to process" : "Ez dago prozesatzeko fitxategirik",
    "Files copied successfully" : "Fitxategiak behar bezala kopiatu dira",
    "Files moved successfully" : "Fitxategiak behar bezala mugitu dira",
    "Some files could not be copied" : "Fitxategi batzuk ezin izan dira kopiatu",
    "Some files could not be moved" : "Fitxategi batzuk ezin izan dira mugitu",
    "Conflicts resolution skipped" : "Gatazkak konpontzea saihestu da",
    "Upload cancelled" : "Igotzea bertan behera utzi da",
    "Could not rename \"{oldName}\", it does not exist any more" : "Ezin izan da \"{oldName}\" berrizendatu, ez da existitzen dagoeneko",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "\"{newName}\" izena \"{dir}\" karpetan dagoeneko erabiltzen da. Mesedez aukeratu beste izen bat.",
    "Could not rename \"{oldName}\"" : "Ezin izan da \"{oldName}\" berrizendatu ",
    "This operation is forbidden" : "Eragiketa hau debekatuta dago",
    "This folder is unavailable, please try again later or contact the administration" : "Karpeta hau ez dago erabilgarri. Saiatu geroago edo jarri harremanetan administrazioarekin",
    "Storage is temporarily not available" : "Biltegia ez dago erabilgarri aldi baterako",
    "Unexpected error: {error}" : "Ustekabeko errorea: {error}",
    "Unknown error" : "Errore ezezaguna",
    "_%n file_::_%n files_" : ["Fitxategi %n","%n fitxategi"],
    "_%n folder_::_%n folders_" : ["Karpeta %n","%n karpeta"],
    "_%n hidden_::_%n hidden_" : ["%n ezkutuan","%n ezkutuan"],
    "Filename must not be empty." : "Fitxategi-izenak ez du hutsik egon behar.",
    "\"{char}\" is not allowed inside a filename." : "\"{char}\" ez da onartzen fitxategi-izen baten barruan.",
    "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" izen erreserbatua da eta ez da onartzen fitxategi-izenetan.",
    "\"{extension}\" is not an allowed filetype." : "\"{extension}\" fitxategi mota ez dago baimenduta.",
    "Filenames must not end with \"{extension}\"." : "Fitxategi-izenak ez dira \"{extension}\"rekin amaitu behar..",
    "List of favorite files and folders." : "Gogoko fitxategi eta karpeten zerrenda.",
    "No favorites yet" : "Gogokorik ez oraindik",
    "Files and folders you mark as favorite will show up here" : "Gogokotzat markatutako fitxategi eta karpetak hemen agertuko dira",
    "List of your files and folders." : "Zure fitxategi eta karpeten zerrenda.",
    "Folder tree" : "Fitxategien zuhaitza",
    "List of your files and folders that are not shared." : "Partekatu ez diren zure fitxategi eta karpeten zerrenda.",
    "No personal files found" : "Ez dago fitxategi pertsonalik",
    "Files that are not shared will show up here." : "Partekatu ez dituzun fitxategiak hemen agertuko dira",
    "Recent" : "Azkenak",
    "List of recently modified files and folders." : "Azkenaldian aldatutako fitxategi eta karpeten zerrenda.",
    "No recently modified files" : "Ez dago azkenaldian aldatutako fitxategirik",
    "Files and folders you recently modified will show up here." : "Azkenaldian aldatu dituzun fitxategi eta karpetak hemen agertuko dira.",
    "Search" : "Bilatu",
    "Search results within your files." : "Bilatu emaitzak zure fitxategien barruan.",
    "This node is unavailable" : "Nodo hori ez dago erabilgarri",
    "Renamed \"{oldName}\" to \"{newName}\"" : "\"{oldName}\" \"{newName}\"(e)ra berrizendatu da.",
    "Clear filter" : "Garbitu iragazkia",
    "Open file sidebar" : "Ireki alboko barra",
    "Search everywhere …" : "Bilatu nonahi...",
    "Search here …" : "Bilatu hemen...",
    "Preparing …" : "Prestatzen...",
    "Submitting fields …" : "Bidaltzeko eremuak",
    "Invalid path selected" : "Bide baliogabea hautatuta",
    "Choose file or folder to transfer" : "Aukeratu fitxategia edo karpeta transferitzeko",
    "Change" : "Aldatu",
    "Shared by link" : "Esteka bidez partekatuta",
    "Shared" : "Partekatuta",
    "You" : "Zu ",
    "Shared multiple times with different people" : "Hainbat aldiz partekatua pertsona ezberdinekin",
    "Unable to change the favorite state of the file" : "Ezin da fitxategiaren gogoko egoera aldatu",
    "Error while loading the file data" : "Errorea fitxategiaren datuak kargatzerakoan",
    "Tags" : "Etiketak",
    "Save as …" : "Gorde honela...",
    "Converting files …" : "Fitxategiak bihurtzen...",
    "Converting file …" : "Fitxategia bihurtzen...",
    "No entries found in this folder" : "Ez da sarrerarik aurkitu karpeta honetan",
    "Select all" : "Hautatu dena",
    "Upload too large" : "Igotzekoa handiegia da",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Igotzen saiatzen ari zaren fitxategiek zerbitzari honek onartzen duen gehienezko tamaina gainditzen dute."
},
"nplurals=2; plural=(n != 1);");
