import{a,c as s,u as i}from"./preload-helper-B5suVMXI.chunk.mjs";import{n as l,q as g}from"./index-jVniDJU4.chunk.mjs";const p=`<svg
	xmlns="http://www.w3.org/2000/svg"
	viewBox="0 0 24 12">
	<path d="M17,1H7A5,5 0 0,0 2,6 5,5 0 0,0 7,11H17A5,5 0 0,0 22,6 5,5 0 0,0 17,1Z" />
	<circle
		cy="6"
		r="3"
		fill="var(--color-main-background)" />
</svg>`,v=a({__name:"NcIconToggleSwitch",props:{checked:{type:Boolean},size:{default:34},inline:{type:Boolean,default:!1}},setup(o){const c=o;i((w,r)=>({"2d1b8583":r.color,"78386a55":r.cx}));const e=s(()=>c.checked?"var(--color-primary-element)":"var(--color-text-maxcontrast)"),n=s(()=>c.checked?"calc(17 / 24 * 100%)":"calc(7 / 24 * 100%)");return{__sfc:!0,svg:p,props:c,color:e,cx:n,NcIconSvgWrapper:g}}}),h="_iconToggleSwitch_rwBqv",m={"material-design-icon":"_material-design-icon_584lD",iconToggleSwitch:h};var _=function(){var o=this,c=o._self._c,e=o._self._setupProxy;return c(e.NcIconSvgWrapper,{class:o.$style.iconToggleSwitch,attrs:{svg:e.svg,size:o.size,inline:o.inline}})},f=[];const t={$style:m};function u(o){for(var c in t)this[c]=t[c]}var d=l(v,_,f,!1,u,null);const S=d.exports;export{S as N};
//# sourceMappingURL=NcIconToggleSwitch-DCTeQGv5-BYHJ3b-0.chunk.mjs.map
