OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Está faltando a senha da chave de recuperação",
    "Please repeat the recovery key password" : "Por favor, repita a senha da chave de recuperação",
    "Repeated recovery key password does not match the provided recovery key password" : "A senha repetida não corresponde com a senha da chave de recuperação fornecida",
    "Recovery key successfully enabled" : "Chave de recuperação habilitada com sucesso",
    "Could not enable recovery key. Please check your recovery key password!" : "Impossível ativar a chave de recuperação. Por favor, verifique a senha da chave de recuperação!",
    "Recovery key successfully disabled" : "Chave de recuperação desabilitada com sucesso",
    "Could not disable recovery key. Please check your recovery key password!" : "Impossível desativar a chave de recuperação. Por favor, verifique a senha da chave de recuperação!",
    "Please provide the old recovery password" : "Por favor, forneça a antiga senha de recuperação",
    "Please provide a new recovery password" : "Por favor, forneça a nova senha de recuperação",
    "Please repeat the new recovery password" : "Por favor, repita a nova senha de recuperação",
    "Password successfully changed." : "Senha alterada.",
    "Could not change the password. Maybe the old password was not correct." : "Não foi possível alterar a senha. Talvez a senha antiga não estava correta.",
    "Recovery Key disabled" : "Chave de recuperação desativada",
    "Recovery Key enabled" : "Chave de recuperação ativada",
    "Could not enable the recovery key, please try again or contact your administrator" : "Não foi possível ativar a chave de recuperação. Tente novamente ou entre em contato com o administrador",
    "Could not update the private key password." : "Não foi possível atualizar a senha da chave privada.",
    "The old password was not correct, please try again." : "A senha antiga não estava correta, tente novamente.",
    "The current log-in password was not correct, please try again." : "A senha atual de acesso não estava correta, tente novamente.",
    "Private key password successfully updated." : "Senha de chave privada atualizada com sucesso.",
    "Invalid private key for encryption app. Please update your private key password in your personal settings to recover access to your encrypted files." : "Chave privada inválida para o aplicativo de criptografia. Atualize a senha da sua chave privada nas configurações pessoais para recuperar o acesso aos seus arquivos criptografados.",
    "Encryption App is enabled, but your keys are not initialized. Please log-out and log-in again." : "O aplicativo de criptografia está habilitado mas suas chaves não foram inicializadas. Por favor, saia e entre novamente.",
    "Please enable server side encryption in the admin settings in order to use the encryption module." : "Habilite a criptografia do lado do servidor em configurações administrativas a fim de usar o módulo de criptografia.",
    "Encryption app is enabled and ready" : "O aplicativo de criptografia está habilitado e pronto",
    "Bad Signature" : "Assinatura ruim",
    "Missing Signature" : "Assinatura faltante",
    "one-time password for server-side-encryption" : "senha de uso único para criptografia do lado do servidor",
    "Encryption password" : "Senha de criptografia",
    "The administration enabled server-side-encryption. Your files were encrypted using the password <strong>%s</strong>." : "A administração ativou a criptografia do lado do servidor. Seus arquivos foram criptografados usando a senha <strong>%s</strong>.",
    "The administration enabled server-side-encryption. Your files were encrypted using the password \"%s\"." : "A administração ativou a criptografia do lado do servidor. Seus arquivos foram criptografados usando a senha \"%s\".",
    "Please login to the web interface, go to the \"Security\" section of your personal settings and update your encryption password by entering this password into the \"Old login password\" field and your current login password." : "Por favor, faça login na interface web, vá para a seção \"Segurança\" de suas configurações pessoais e atualize sua senha de criptografia inserindo esta senha no campo \"Senha de login antiga\" e sua senha de login atual.",
    "Cannot decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Não foi possível descriptografar este arquivo, provavelmente é um arquivo compartilhado. Por favor, solicite ao proprietário do arquivo para recompartilhá-lo com você.",
    "Cannot read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Não foi possível ler este arquivo, provavelmente é um arquivo compartilhado. Por favor, solicite ao proprietário do arquivo para recompartilhá-lo com você.",
    "Default Encryption Module" : "Módulo de Criptografia Padrão",
    "Default encryption module for Nextcloud Server-side Encryption (SSE)" : "Módulo de criptografia padrão para criptografia do lado do servidor (SSE) do Nextcloud",
    "This app provides the (default) cryptography implementation for Nextcloud's Server-side Encryption (SSE) feature.\n\n\t\t\t**Encryption Details**\n\t\t\t*   **Cipher Mode:** AES-256-CTR (default)\n\t\t\t*   **Authentication:** HMAC-SHA256\n\n\t\t\t**Important Warnings**\n\t\t\t*   **DANGER:** Do not disable this application until all files have been decrypted (`occ encryption:decrypt-all`).\n\t\t\t*   **WARNING**: Reverting to non-encrypted file storage after activation requires command-line access. The action is permanent via the Web UI.\"\n\n\t\t\t**Notes for Existing Files**\n\t\t\t*   By default, enabling SSE does not encrypt existing files; only new files will be encrypted.\n\t\t\t*   To encrypt all existing files, use the command `occ encryption:encrypt-all`.\n\n\t\t\t**Before You Begin**\n\t\t\t*   **Read the Documentation:** Before you enable SSE, encrypt existing files, or disable SSE, it is critical to\n\t\t\t\tread the documentation to understand implications and the appropriate procedures to avoid data loss." : "Este aplicativo fornece a implementação (padrão) de criptografia para o recurso de criptografia do lado do servidor (SSE) do Nextcloud.\n\n\t\t\t**Detalhes da criptografia**\n\t\t\t* **Modo de criptografia:** AES-256-CTR (padrão)\n\t\t\t* **Autenticação:** HMAC-SHA256\n\n\t\t\t**Avisos importantes**\n\t\t\t* **PERIGO:** Não desative este aplicativo até que todos os arquivos tenham sido descriptografados (`occ encryption:decrypt-all`).\n\t\t\t* **AVISO**: Reverter para o armazenamento de arquivos não criptografado após a ativação requer acesso à linha de comando. A ação é permanente através da interface do usuário web.\n\n\t\t\t**Observações sobre arquivos existentes**\n\t\t\t* Por padrão, habilitar o SSE não criptografa os arquivos existentes; apenas os novos arquivos serão criptografados.\n\t\t\t* Para criptografar todos os arquivos existentes, use o comando `occ encryption:encrypt-all`.\n\n\t\t\t**Antes de começar**\n\t\t\t* **Leia a documentação:** Antes de habilitar o SSE, criptografar os arquivos existentes ou desativar o SSE, é fundamental\n\t\t\tler a documentação para entender as implicações e os procedimentos adequados para evitar a perda de dados.",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "Ativar essa opção irá criptografar todos os arquivos do armazenamento principal, caso contrário, apenas arquivos no armazenamento externo serão criptografados",
    "Encrypt the home storage" : "Criptografar a pasta de armazenamento home",
    "Disable recovery key" : "Dasabilitar chave de recuperação",
    "Enable recovery key" : "Ativar chave de recuperação",
    "The recovery key is an additional encryption key used to encrypt files. It is used to recover files from an account if the password is forgotten." : "A chave de recuperação é uma chave de criptografia adicional usada para criptografar arquivos. É usado para recuperar arquivos de uma conta se a senha for esquecida.",
    "Recovery key password" : "Senha da chave de recuperação",
    "Passwords fields do not match" : "Os campos de senha não correspondem",
    "Repeat recovery key password" : "Repita a senha da chave de recuperação",
    "An error occurred while updating the recovery key settings. Please try again." : "Ocorreu um erro ao atualizar as configurações da chave de recuperação. Tente novamente.",
    "Change recovery key password" : "Alterar a senha da chave de recuperação",
    "Old recovery key password" : "Senha da chave de recuperação antiga",
    "New recovery key password" : "Senha nova da chave de recuperação",
    "Repeat new recovery key password" : "Repita a senha nova da chave de recuperação",
    "An error occurred while changing the recovery key password. Please try again." : "Ocorreu um erro ao alterar a senha da chave de recuperação. Tente novamente.",
    "Update private key password" : "Atualizar senha da chave privada",
    "Your private key password no longer matches your log-in password. Set your old private key password to your current log-in password." : "A senha da sua chave privada não corresponde mais à sua senha de login. Defina a senha antiga da sua chave privada como a sua senha de login atual.",
    "If you do not remember your old password you can ask your administrator to recover your files." : "Se não se lembrar da senha antiga, peça ao administrador para recuperar seus arquivos.",
    "Old log-in password" : "Senha antiga de login",
    "Current log-in password" : "Senha atual de login",
    "Update" : "Atualizar",
    "Updating recovery keys. This can take some time…" : "Atualizando as chaves de recuperação. Isso pode demorar algum tempo…",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Ativar essa opção vai permitir que você obtenha novamente acesso aos seus arquivos criptografados em caso de perda de senha",
    "Enable password recovery" : "Ativar recuperação de senha",
    "Default encryption module" : "Módulo de criptografia padrão",
    "Encryption app is enabled but your keys are not initialized, please log-out and log-in again" : "O aplicativo de criptografia está habilitado, mas suas chaves não foram inicializadas. Por favor, saia e entre novamente.",
    "Basic encryption module" : "Módulo de criptografia básico",
    "Missing parameters" : "Parâmetros faltantes",
    "Default encryption module for server-side encryption" : "Módulo de criptografia padrão para criptografia do lado do servidor",
    "In order to use this encryption module you need to enable server-side encryption in the admin settings. Once enabled this module will encrypt all your files transparently. The encryption is based on AES 256 keys.\nThe module will not touch existing files, only new files will be encrypted after server-side encryption was enabled. It is also not possible to disable the encryption again and switch back to an unencrypted system.\nPlease read the documentation to know all implications before you decide to enable server-side encryption." : "Para usar este módulo de criptografia, você precisa ativar a criptografia do lado do servidor nas configurações de administração. Quando ativado, este módulo criptografará todos os seus arquivos de forma transparente. A criptografia é baseada em chaves AES 256.\nO módulo não tocará nos arquivos existentes, apenas novos arquivos serão criptografados após a criptografia do lado do servidor for ativada. Também não é possível desabilitar a criptografia novamente e voltar para um sistema não criptografado.\nLeia a documentação para conhecer todas as implicações antes de decidir ativar a criptografia do lado do servidor.",
    "Change recovery key password:" : "Mudar a senha da chave de recuperação:",
    "Change Password" : "Trocar senha",
    "Your private key password no longer matches your log-in password." : "A sua senha de chave privada não corresponde a sua senha de login.",
    "Set your old private key password to your current log-in password:" : "Defina a sua senha antiga da chave privada para sua senha de login atual:",
    "Update Private Key Password" : "Atualizar senha da chave privada",
    "Enable password recovery:" : "Ativar recuperação de senha:",
    "Enabled" : "Habilitado",
    "Disabled" : "Desabilitado",
    "This app provides the (default) cryptography implementation for Nextcloud's Server-side Encryption (SSE) feature.\n\n\t\t\t**Encryption Details**\n\t\t\t*   **Cipher Mode:** AES-256-CTR (default)\n\t\t\t*   **Authentication:** HMAC-SHA256\n\n\t\t\t**Important Warnings**\n\t\t\t*   **DANGER:** Do not disable this application until all files have been decrypted (`occ encryption:decrypt-all`).\n\t\t\t*   **WARNING**: Reverting to non-encrypted file storage after activation requires command-line access. The action is permanent via the Web UI.\"\n\n\t\t\t**Notes for Existing Files**\n\t\t\t*   By default, enabling SSE does not encrypt existing files; only new files will be encrypted.\n\t\t\t*   To encrypt all existing files, use the command `occ encryption:encrypt-all`.\n\n\t\t\t**Before You Begin**\n\t\t\t*   **Read the Documentation:** Before you enable SSE, encrypt existing files, or disable SSE, it is critical to \n\t\t\t\tread the documentation to understand implications and the appropriate procedures to avoid data loss." : "Este aplicativo fornece a implementação de criptografia (padrão) para o recurso de criptografia do lado do servidor (SSE) do Nextcloud.\n\n\t\t\t**Detalhes da Criptografia**\n\t\t\t* **Modo de Criptografia:** AES-256-CTR (padrão)\n\t\t\t* **Autenticação:** HMAC-SHA256\n\n\t\t\t**Avisos Importantes**\n\t\t\t* **PERIGO:** Não desative este aplicativo até que todos os arquivos tenham sido descriptografados (`occ encryption:decrypt-all`).\n\t\t\t* **AVISO**: Para voltar ao armazenamento de arquivos não criptografado após a ativação, é necessário acessar a linha de comando. A ação é permanente através da interface do usuário da web.\n\n\t\t\t**Observações para Arquivos Existentes**\n\t\t\t* Por padrão, ativar a SSE não criptografa os arquivos existentes; apenas os novos arquivos serão criptografados.\n\t\t\t* Para criptografar todos os arquivos existentes, use o comando `occ encryption:encrypt-all`.\n\n\t\t\t**Antes de Começar**\n\t\t\t* **Leia a documentação:** Antes de ativar a SSE, criptografar arquivos existentes ou desativar a SSE, é fundamental\n\t\t\t\tler a documentação para entender as implicações e os procedimentos adequados para evitar a perda de dados."
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
