OC.L10N.register(
    "office",
    {
    "Search {category}" : "{category} ძებნა",
    "Search" : "ძიება",
    "All" : "ყველა",
    "Filename cannot be empty" : "ფაილის სახელი ვერ იქნება ცარიელი"
},
"nplurals=2; plural=(n!=1);");
