OC.L10N.register(
    "profile",
    {
    "View profile" : "查看个人资料",
    "Profile" : "个人资料",
    "This application provides the profile" : "此应用程序提供个人资料",
    "Searching …" : "正在搜索 …",
    "Not found" : "未找到",
    "Insert" : "插入",
    "You have not added any info yet" : "您尚未添加任何信息",
    "{user} has not added any info yet" : "{user} 尚未添加任何信息",
    "Error opening the user status modal, try hard refreshing the page" : "打开用户状态模块时出错，请努力刷新页面",
    "The headline and about sections will show up here" : "标题和关于部分将显示在此处",
    "Profile not found" : "未找到个人资料",
    "Back to %s" : "返回 %s",
    "Provides a customisable user profile interface." : "提供可定制的用户个人资料界面。",
    "Edit Profile" : "编辑个人资料",
    "The profile does not exist." : "个人资料不存在"
},
"nplurals=1; plural=0;");
