OC.L10N.register(
    "oauth2",
    {
    "Your client is not authorized to connect. Please inform the administrator of your client." : "El veceru nun tien autorización pa conectase. Informa al alministrador de l'aplicación.",
    "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path" : "La URL de redireición tien de ser una URL completa, por exemplu: https://dominiu.com/camin",
    "OAuth 2.0" : "OAuth 2.0",
    "Allows OAuth2 compatible authentication from other web applications." : "Permite l'autenticación compatible con OAuth2 dende otres aplicaciones web.",
    "The OAuth2 app allows administrators to configure the built-in authentication workflow to also allow OAuth2 compatible authentication from other web applications." : "L'aplicación OAuth2 permite a l'alministración configurar el fluxu de trabayu d'autenticación integráu pa que tamién permita l'autenticación compatible con OAuth2 dende otres aplicaciones web.",
    "Secret key" : "Clave del secretu",
    "Delete" : "Desaniciar",
    "OAuth 2.0 clients" : "Veceros d'OAuth 2.0",
    "OAuth 2.0 allows external services to request access to {instanceName}." : "OAuth 2.0 permite que los servicios esternos soliciten l'accesu a «{instanceName}».",
    "Name" : "Nome",
    "Redirection URI" : "URI de redireición",
    "Delete client" : "Desaniciar el veceru",
    "Add client" : "Amestar el veceru",
    "Add" : "Amestar",
    "Client Identifier" : "Identificador del veceru",
    "Show client secret" : "Amosar el secretu del veceru",
    "Hide client secret" : "Anubrir el secretu del veceru"
},
"nplurals=2; plural=(n != 1);");
