OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "Nevažeći ID udruženog oblaka",
    "Server to server sharing is not enabled on this server" : "Dijeljenje između poslužitelja nije omogućeno na ovom poslužitelju",
    "Couldn't establish a federated share." : "Nije moguće uspostaviti udruženo dijeljenje.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Nije moguće uspostaviti udruženo dijeljenje, možda je pogrešna zaporka.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Poslan je zahtjev za udruženo dijeljenje i primit ćete poziv. Provjerite svoje obavijesti.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Nije moguće uspostaviti udruženo dijeljenje, čini se da je poslužitelj s kojim se udružuje prestar (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "Nije dopušteno slanje udruženih grupnih dijeljenja s ovog poslužitelja.",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "Dijeljenje %1$s nije uspjelo jer je ova stavka već podijeljena s računom%2$s",
    "Not allowed to create a federated share to the same account" : "Nije dopušteno stvaranje udruženog dijeljenja s istim računom",
    "Federated shares require read permissions" : "Udružena dijeljenja zahtjevaju dopuštenja za čitanje",
    "File is already shared with %s" : "Datoteka je već dijeljena s %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Dijeljenje %1$s nije uspjelo, nije bilo moguće pronaći %2$s, možda je poslužitelj trenutno nedostupan ili koristi vjerodajnicu koju je sam potpisao.",
    "Could not find share" : "Nije moguće pronaći dijeljenje",
    "Federated sharing" : "Udruženo dijeljenje",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Primili ste {share} kao udaljeno dijeljenje od {user} (u ime {behalf})",
    "You received {share} as a remote share from {user}" : "Primili ste {share} kao udaljeno dijeljenje od {user}",
    "Accept" : "Prihvati",
    "Decline" : "Odbij",
    "Federated Cloud Sharing" : "Dijeljenje putem udruženog oblaka",
    "Sharing" : "Dijeljenje",
    "Federated file sharing" : "Udruženo dijeljenje datoteka",
    "Provide federated file sharing across servers" : "Omogućite udruženo dijeljenje datoteka između poslužitelja",
    "Confirm data upload to lookup server" : "Potvrdi učitavanje podataka na poslužitelj za pretraživanje",
    "When enabled, all account properties (e.g. email address) with scope visibility set to \"published\", will be automatically synced and transmitted to an external system and made available in a public, global address book." : "Kada je omogućeno, sva svojstva računa (npr. adresa e-pošte) čija je vidljivost postavljena na „objavljeno” automatski će se sinkronizirati i prenijeti u vanjski sustav te će biti dostupna u javnom, globalnom imeniku.",
    "Enable data upload" : "Omogući učitavanje podataka",
    "Disable upload" : "Onemogući učitavanje",
    "Confirm querying lookup server" : "Potvrdi upit poslužitelju za pretraživanje",
    "When enabled, the search input when creating shares will be sent to an external system that provides a public and global address book." : "Kada je omogućeno, unos za pretraživanje prilikom stvaranja dijeljenja bit će poslan u vanjski sustav koji pruža javni i globalni imenik.",
    "This is used to retrieve the federated cloud ID to make federated sharing easier." : "Ovo se koristi za dohvaćanje udruženog ID-a oblaka kako bi se olakšalo udruženo dijeljenje.",
    "Moreover, email addresses of users might be sent to that system in order to verify them." : "Osim toga, adrese e-pošte korisnika mogu biti poslane tom sustavu radi njihove provjere.",
    "Enable querying" : "Omogući upite",
    "Disable querying" : "Onemogući upite",
    "Unable to update federated files sharing config" : "Nije moguće ažurirati konfiguraciju dijeljenja datoteka u udruženju",
    "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "Prilagodite način na koji ljudi mogu dijeliti između poslužitelja. To uključuje i dijeljenja između korisnika na ovom poslužitelju ako koriste udruženo dijeljenje.",
    "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Dopustite korisnicima na ovom poslužitelju slanje dijeljenja drugim poslužiteljima (ova opcija također omogućuje WebDAV pristup javnim dijeljenjima)",
    "Allow people on this server to receive shares from other servers" : "Dopustite korisnicima na ovom poslužitelju primanje dijeljenja s drugih poslužitelja",
    "Allow people on this server to send shares to groups on other servers" : "Dopustite korisnicima na ovom poslužitelju slanje dijeljenja grupama na drugim poslužiteljima",
    "Allow people on this server to receive group shares from other servers" : "Dopustite korisnicima na ovom poslužitelju primanje grupnih dijeljenja s drugih poslužitelja",
    "The lookup server is only available for global scale." : "Poslužitelj za pretraživanje dostupan je samo na globalnoj razini.",
    "Search global and public address book for people" : "Pretraži globalni i javni adresar za osobe",
    "Allow people to publish their data to a global and public address book" : "Dopustite osobama objavu svojih podataka u globalnom i javnom adresaru",
    "Trusted federation" : "Pouzdano udruženje",
    "Automatically accept shares from trusted federated accounts and groups by default" : "Automatski prihvaćaj dijeljenja od pouzdanih udruženih računa i grupa prema zadanim postavkama",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Dijeli sa mnom putem mog #ID-ja udruženog oblaka Nextclouda, pogledajte {url}",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Dijeli sa mnom putem mog #ID-ja udruženog oblaka Nextclouda",
    "Share with me via Nextcloud" : "Dijelite sa mnom putem Nextclouda",
    "Cloud ID copied" : "ID oblaka kopiran",
    "Copy" : "Kopirajte",
    "Clipboard not available. Please copy the cloud ID manually." : "Međuspremnik nije dostupan. Molimo ručno kopirajte ID oblaka.",
    "Copied!" : "Kopirano!",
    "Federated Cloud" : "Udruženi oblak",
    "You can share with anyone who uses a {productName} server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Možete dijeliti s bilo kim tko koristi {productName} poslužitelj ili druge poslužitelje i usluge kompatibilne s Open Cloud Mesh (OCM)! Jednostavno unesite njihov ID udruženog oblaka u dijalog dijeljenja. Izgleda ovako: osoba@oblak.primjer.com",
    "Your Federated Cloud ID" : "ID vašeg udruženog oblaka",
    "Share it so your friends can share files with you:" : "Dijelite ga kako bi vaši prijatelji mogli dijeliti datoteke s vama:",
    "Bluesky" : "Bluesky",
    "Facebook" : "Facebook",
    "Mastodon" : "Mastodon",
    "Add to your website" : "Dodajte na svoje web-mjesto",
    "Share with me via {productName}" : "Dijelite sa mnom putem {productName}",
    "HTML Code:" : "HTML kod:",
    "Cancel" : "Odustani",
    "Add remote share" : "Dodaj udaljeno dijeljenje",
    "Remote share" : "Udaljeno dijeljenje",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Želite li dodati udaljeni udjel {name} od {owner} u {remote}?",
    "Remote share password" : "Zaporka za udaljeno dijeljenje",
    "Incoming share could not be processed" : "Dolazno dijeljenje nije moguće obraditi",
    "X (formerly Twitter)" : "X (bivši Twitter)",
    "formerly Twitter" : "bivši Twitter"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
