OC.L10N.register(
    "circles",
    {
    "Personal" : "Personal",
    "System" : "Sistema",
    "Visible" : "Visible",
    "Open" : "Abrir",
    "Password protected" : "Protegido con contraseña",
    "Hidden" : "Oculto",
    "Local" : "Local",
    "Root" : "Raíz",
    "Federated" : "Federado",
    "App" : "Aplicación",
    "Contact" : "Contacto",
    "Member" : "Miembro",
    "Moderator" : "Moderador",
    "Admin" : "Administrador",
    "Owner" : "Dueño",
    "%s shared »%s« with you." : "%s ha compartido »%s« con usted.",
    "Password to access »%1$s« shared to you by %2$s" : "Contraseña para acceder a »%1$s« compartido con usted por %2$s",
    "Password to access »%s«" : "Contraseña para acceder  »%s«",
    "It is protected with the following password:" : "Está protegido con la siguiente contraseña:",
    "%1$s via %2$s" : "%1$s vía %2$s",
    "Click the button below to open it." : "Haga click en el botón de abajo para abrirlo.",
    "Open »%s«" : "Abrir »%s«",
    "Files" : "Archivo",
    "This member is not a moderator" : "Este miembro no es un moderador",
    "This member does not exist" : "Este miembro no existe",
    "Accept" : "Aceptar",
    "Invalid file provided" : "Archivo proporcionado inválido",
    "File is too big" : "El archivo es demasiado grande.",
    "Invalid image" : "Imagen inválida",
    "Unknown filetype" : "Tipo de archivo desconocido",
    "%s" : "%s",
    "Open %s" : "Abrir %s",
    "Unlimited" : "Ilimitado",
    "Default quota" : "Cuota predeterminada",
    "Select default quota" : "Seleccionar la cuota predeterminada",
    "Save" : "Save",
    "Connect" : "Conectar",
    "Overview" : "Visión general",
    "Members" : "Miembros",
    "Cancel" : "Cancel",
    "Back" : "Volver",
    "Folder" : "Carpeta",
    "you" : "usted",
    "Copy link" : "Copiar link",
    "Close" : "Cerrar",
    "New folder" : "Carpeta nueva",
    "Folder name" : "Nombre de la carpeta",
    "Conversation name" : "Nombre de conversación",
    "Calendar" : "Calendario",
    "New calendar" : "Nuevo calendario",
    "Please select a valid png or jpg file" : "Por favor, seleccioná un archivo PNG o JPG válido",
    "Description" : "Descripción",
    "Edit" : "Editar",
    "Add" : "Agregar",
    "Apply" : "Aplicar",
    "Search {types}" : "Buscar {types}",
    "No results" : "No hay resultados",
    "Pending" : "Pendiente",
    "Role" : "Rol",
    "Add to {team}" : "Añadir {team}",
    "Try again" : "Inténtalo de nuevo",
    "Loading" : "Cargando",
    "Go back" : "Regresar",
    "Loading…" : "Cargando…",
    "User" : "Usuario",
    "Group" : "Grupo",
    "Email" : "Correo electrónico",
    "Federation" : "Federación",
    "Users" : "Usuarios",
    "Groups" : "Grupos",
    "No files in here" : "No hay archivos aqui",
    "No entries found in this folder" : "No se encontraron elementos en esta carpeta",
    "Name" : "Nombre",
    "Size" : "Tamaño",
    "Modified" : "Modificado"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
