OC.L10N.register(
    "recommendations",
    {
    "Recommended files" : "File yang direkomendasikan",
    "Recommendations" : "Rekomendasi",
    "Shows recommended files" : "Menampilkan file yang direkomendasikan",
    "Shows recommended files for quick access of files and folders with recent activity" : "Menampilkan file yang direkomendasikan untuk akses cepat ke file dan folder dengan aktivitas terbaru",
    "No recommendations yet" : "Belum ada rekomendasi",
    "Last updated {timeAgo}" : "Terakhir diperbarui {timeAgo}",
    "Shared with you {timeAgo}" : "Dibagikan kepada Anda {timeAgo}",
    "Last commented on {timeAgo}" : "Terakhir dikomentari pada {timeAgo}",
    "Path name {path}" : "Nama path {path}",
    "Show recommendations" : "Tampilkan rekomendasi"
},
"nplurals=1; plural=0;");
