OC.L10N.register(
    "office",
    {
    "Office" : "Oficina",
    "Blank" : "Baleru",
    "Search" : "Buscar",
    "All" : "Too",
    "Shared with me" : "Compartióse conmigo",
    "Switch to grid view" : "Cambiar a la vista de rexáu",
    "Switch to list view" : "Cambiar a la vista de llista",
    "Create" : "Crear",
    "Filename" : "Nome del ficheru",
    "Documents" : "Documentos",
    "Filename cannot be empty" : "El nome del ficheru nun pue tar baleru."
},
"nplurals=2; plural=(n != 1);");
