OC.L10N.register(
    "notifications",
    {
    "We want to keep offering our push notification service for free, but large number of users overload our infrastructure. For this reason we have to rate-limit the use of push notifications. If you need this feature, consider using Nextcloud Enterprise." : "ما می‌خواهیم سرویس اعلان‌های فشاری خود را رایگان نگه داریم، اما تعداد زیاد کاربران زیرساخت ما را تحت فشار قرار می‌دهد. به همین دلیل مجبور به محدود کردن نرخ استفاده از اعلان‌های فشاری هستیم. اگر به این ویژگی نیاز دارید، استفاده از نکست‌کلود سازمانی را در نظر بگیرید.",
    "User not found" : "کاربر یافت نشد",
    "An unexpected error occurred, ask your administration to check the logs." : "خطای غیرمنتظره‌ای رخ داد، از مدیر خود بخواهید لاگ‌ها را بررسی کند.",
    "Hello %s" : "سلام %s",
    "Hello %s," : "سلام %s،",
    "_New notification for %s_::_%n new notifications for %s_" : ["Ø§Ø¹Ù„Ø§Ù† Ø¬Ø¯ÛŒØ¯ Ø¨Ø±Ø§ÛŒ %s","%n Ø§Ø¹Ù„Ø§Ù† Ø¬Ø¯ÛŒØ¯ Ø¨Ø±Ø§ÛŒ %s"],
    "_You have a new notification for %s_::_You have %n new notifications for %s_" : ["Ø´Ù…Ø§ ÛŒÚ© Ø§Ø¹Ù„Ø§Ù† Ø¬Ø¯ÛŒØ¯ Ø¨Ø±Ø§ÛŒ %s Ø¯Ø§Ø±ÛŒØ¯","Ø´Ù…Ø§ %n Ø§Ø¹Ù„Ø§Ù† Ø¬Ø¯ÛŒØ¯ Ø¨Ø±Ø§ÛŒ %s Ø¯Ø§Ø±ÛŒØ¯"],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "می‌توانید تعداد دفعات دریافت این ایمیل‌ها را تغییر دهید یا آن‌ها را در <a href=\"%s\">تنظیمات</a> غیرفعال کنید.",
    "You can change the frequency of these emails or disable them in the settings: %s" : "می‌توانید تعداد دفعات دریافت این ایمیل‌ها را تغییر دهید یا آن‌ها را در تنظیمات غیرفعال کنید: %s",
    "Admin notifications" : "اعلان‌های مدیر",
    "Notifications" : "اعلان‌ها",
    "Push notifications - Fair use policy" : "اعلان‌های فشاری - خط‌مشی استفاده منصفانه",
    "Nextcloud GmbH sponsors a free push notification gateway for private users. To ensure good service, the gateway limits the number of push notifications per server and the limit was reached for this server. For enterprise users, a more scalable gateway is available." : "شرکت Nextcloud GmbH یک دروازه اعلان فشاری رایگان برای کاربران خصوصی ارائه می‌دهد. برای اطمینان از خدمات خوب، این دروازه تعداد اعلان‌های فشاری به ازای هر سرور را محدود می‌کند و این محدودیت برای این سرور به پایان رسیده است. برای کاربران سازمانی، یک دروازه مقیاس‌پذیرتر در دسترس است.",
    "This app provides a backend and frontend for the notification API available in Nextcloud." : "این برنامه یک بک‌اند و فرانت‌اند برای API اعلان موجود در نکست‌کلود فراهم می‌کند.",
    "This app provides a backend and frontend for the notification API available in Nextcloud.\n\t\tThe API is used by other apps to notify users in the web UI and sync clients about various things. Some examples are:\n\n📬 Federated file sharing: You received a new remote share\n\n📑 Comments: Another user mentioned you in a comment on a file\n\n🚢 Update notification: Available update for an app or nextcloud itself\n\n📣 Announcement center: An announcement was posted by an admin" : "این برنامه دارای یک پس زمینه و مقدمه برای API اعلان موجود در نکست کلود است.\n\t\tAPI توسط برنامه های دیگر برای اطلاع رسانی به کاربران در UI وب و همگام سازی مشتری در مورد چیزهای مختلف استفاده می شود. برخی از نمونه ها عبارتند از:\n\n📬 اشتراک فدرال فدرال: شما یک اشتراک از راه دور جدید دریافت کردید\n\n📑 توضیح: کاربر دیگری در اظهارنظر درباره پرونده از شما یاد کرده است\n\n🚢 به روز رسانی اطلاع رسانی: به روز رسانی در دسترس برای یک برنامه یا نکست کلود خود\n\n📣 مرکز اعلامیه: اعلامیه توسط یک مدیر ارسال شده است",
    "Failed to perform action" : "انجام عملیات ناموفق بود",
    "Failed to dismiss notification" : "رد کردن اعلان ناموفق بود",
    "Dismiss" : "رد کردن",
    "Contact Nextcloud GmbH" : "تماس با Nextcloud GmbH",
    "in {path}" : "در {path}",
    "Push notifications might be unreliable" : "اعلان‌های فشاری ممکن است غیرقابل اعتماد باشند",
    "Nextcloud GmbH sponsors a free push notification gateway for private users. To ensure good service, the gateway limits the number of push notifications per server. For enterprise users, a more scalable gateway is available. Contact Nextcloud GmbH for more information." : "شرکت Nextcloud GmbH یک دروازه اعلان فشاری رایگان برای کاربران خصوصی ارائه می‌دهد. برای اطمینان از خدمات خوب، این دروازه تعداد اعلان‌های فشاری به ازای هر سرور را محدود می‌کند. برای کاربران سازمانی، یک دروازه مقیاس‌پذیرتر در دسترس است. برای اطلاعات بیشتر با Nextcloud GmbH تماس بگیرید.",
    "Requesting browser permissions to show notifications" : "درخواست مجوز مرورگر برای نمایش اعلان‌ها",
    "No notifications" : "بدون اعلان",
    "Failed to dismiss all notifications" : "رد کردن همه اعلان‌ها ناموفق بود",
    "Dismiss all notifications" : "رد کردن همه اعلان‌ها",
    "Never" : "هرگز",
    "1 hour" : "1 ساعت",
    "3 hours" : "3 ساعت",
    "1 day" : "1 روز",
    "1 week" : "1 هفته",
    "Your settings have been updated." : "تنظیمات شما به‌روزرسانی شد.",
    "An error occurred while updating your settings." : "هنگام به‌روزرسانی تنظیمات شما خطایی رخ داد.",
    "Notifications defaults" : "پیش‌فرض‌های اعلان",
    "Configure the default notification settings" : "تنظیم پیش‌فرض تنظیمات اعلان",
    "Send email reminders about unhandled notifications after:" : "ارسال یادآوری ایمیلی برای اعلان‌های رسیدگی‌نشده پس از:",
    "Play sound when a new notification arrives" : "پخش صدا هنگام دریافت اعلان جدید",
    "Play sound when a call started (requires Nextcloud Talk)" : "پخش صدا هنگام شروع تماس (نیازمند نکست‌کلود تاک)",
    "Web push settings" : "تنظیمات وب‌پوش",
    "Web push is a push notification system that lets web applications send notifications to users´ mobile apps or browser, even when the app is not open in a tab." : "Web push یک سامانهٔ اعلان فوری است که به برنامه‌های وب امکان می‌دهد حتی زمانی که برنامه در یک زبانه باز نیست، اعلان‌ها را به برنامه‌های موبایل یا مرورگر کاربران ارسال کنند.",
    "Web push notifications are encrypted but routed through services provided by Mozilla, Microsoft, Apple, Google or user-choosen ones in case of mobile apps. While the content is protected, metadata such as timing and frequency of notifications may be exposed to these providers." : "اعلان‌های وب‌پوش رمزگذاری می‌شوند اما از طریق خدمات ارائه‌شده توسط Mozilla، Microsoft، Apple، Google یا موارد انتخابی کاربر در مورد برنامه‌های موبایل مسیریابی می‌شوند. اگرچه محتوا محافظت می‌شود، فراداده‌هایی مانند زمان‌بندی و تعداد دفعات اعلان‌ها ممکن است در معرض این ارائه‌دهندگان قرار گیرد.",
    "Allow web push to be used" : "اجازه استفاده از وب‌پوش",
    "Allow web push for browsers" : "اجازه وب‌پوش برای مرورگرها",
    "None" : "هیچ‌کدام",
    "You need to set up your email address before you can receive notification emails." : "قبل از دریافت ایمیل‌های اعلان، باید آدرس ایمیل خود را تنظیم کنید.",
    "Also repeat sound on a secondary speaker" : "همچنین تکرار صدا در یک بلندگوی ثانویه",
    "Selection of the speaker device is currently not supported by Safari" : "انتخاب دستگاه بلندگو در حال حاضر توسط Safari پشتیبانی نمی‌شود",
    "Select a device" : "انتخاب یک دستگاه"
},
"nplurals=2; plural=(n > 1);");
