OC.L10N.register(
    "profile",
    {
    "View profile" : "Открыть профиль",
    "Profile picker" : "Выбор профиля",
    "Profile" : "Профиль",
    "This application provides the profile" : "Это приложение предоставляет профиль",
    "Searching …" : "Поиск…",
    "Not found" : "Не найдено",
    "Search for a user profile" : "Поиск профиля пользователя",
    "Search for a user profile. Start typing" : "Найти профиль пользователя. Начните печатать",
    "Insert selected user profile link" : "Вставить ссылку на выбранный профиль пользователя",
    "Insert" : "Вставить",
    "You have not added any info yet" : "Вы ещё не добавили никакой информации",
    "{user} has not added any info yet" : "Пользователь {user} ещё не добавил(а) никакой информации",
    "Error opening the user status modal, try hard refreshing the page" : "Произошла ошибка при открытии модального окна пользователя, попробуйте обновить страницу",
    "The headline and about sections will show up here" : "Разделы \"Заголовок\" и \"О вас\" будут отображаться здесь",
    "Profile not found" : "Профиль не найден",
    "The profile does not exist or is unavailable." : "Профиль не существует или недоступен.",
    "Back to %s" : "Вернуться к %s",
    "Provides a customisable user profile interface." : "Предоставляет настраиваемый интерфейс профиля пользователя.",
    "Edit Profile" : "Редактирование профиля",
    "The profile does not exist." : "Профиль не существует"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
