OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "فید فعالیت شخصی برای %s",
    "Your feed URL is invalid" : "آدرس فید شما نامعتبر است",
    "Activity feed for %1$s" : "فید فعالیت برای %1$s",
    "Activity feed" : "فید فعالیت",
    "Your settings have been updated." : "تنظیمات شما به‌روزرسانی شد.",
    "Settings have been updated." : "تنظیمات به‌روزرسانی شد.",
    "remote user" : "کاربر راه‌دور",
    "Recent activity" : "فعالیت‌های اخیر",
    "No activities" : "هیچ فعالیتی وجود ندارد",
    "More activities" : "فعالیت‌های بیشتر",
    "Daily activity summary for %s" : "خلاصه فعالیت روزانه برای %s",
    "_and %n more…_::_and %n more…_" : ["و %n مورد دیگر…","و %n مورد دیگر…"],
    "You can disable daily digest emails in the <a href=\"%s\">settings</a>." : "می‌توانید ایمیل‌های خلاصه روزانه را در <a href=\"%s\">تنظیمات</a> غیرفعال کنید.",
    "You can disable daily digest emails in the settings: %s" : "می‌توانید ایمیل‌های خلاصه روزانه را در تنظیمات غیرفعال کنید: %s",
    "All activities" : "همه فعالیت‌ها",
    "By others" : "توسط دیگران",
    "By you" : "توسط شما",
    "Activity at %s" : "فعالیت در %s",
    "Hello %s" : "سلام %s",
    "Hello %s," : "سلام %s،",
    "There was some activity at %s" : "فعالیتی در %s انجام شده است",
    "_and %n more _::_and %n more _" : ["و %n مورد بیشتر","و %n مورد بیشتر"],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "می‌توانید تعداد دفعات دریافت این ایمیل‌ها را تغییر دهید یا آن‌ها را در <a href=\"%s\">تنظیمات</a> غیرفعال کنید.",
    "You can change the frequency of these emails or disable them in the settings: %s" : "می‌توانید تعداد دفعات دریافت این ایمیل‌ها را تغییر دهید یا آن‌ها را در تنظیمات غیرفعال کنید: %s",
    "Mail" : "ایمیل",
    "Push" : "اعلان فشاری",
    "Activity" : "فعالیت",
    "Notifications" : "اعلان‌ها",
    "This application enables people to view a log of activities about them, their files or other data." : "این برنامه به افراد امکان می‌دهد گزارش فعالیت‌های مربوط به خود، فایل‌ها یا سایر داده‌هایشان را مشاهده کنند.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "این برنامه به افراد امکان می‌دهد اقدامات مربوط به فایل‌ها و داده‌های خود در نکست‌کلود را مشاهده کنند.",
    "Today" : "امروز",
    "Last 7 days" : "۷ روز گذشته",
    "Last 30 days" : "۳۰ روز گذشته",
    "Custom range" : "بازه دلخواه",
    "Clear search" : "پاک کردن جستجو",
    "Clear filters" : "پاک کردن فیلترها",
    "From" : "از",
    "To" : "تا",
    "Send email" : "ارسال ایمیل",
    "Send push notification" : "ارسال اعلان فشاری",
    "Activity notification configuration" : "پیکربندی اعلان فعالیت",
    "Yesterday" : "دیروز",
    "Less" : "کمتر",
    "More" : "بیش‌تر",
    "_Downloaded %n time (%s in the last 30 days)_::_Downloaded %n times (%s in the last 30 days)_" : ["%n بار دانلود شده (%s در ۳۰ روز گذشته)","%n بار دانلود شده (%s در ۳۰ روز گذشته)"],
    "_Downloaded %n time_::_Downloaded %n times_" : ["%n بار دانلود شده","%n بار دانلود شده"],
    "You need to set up your email address before you can receive notification emails." : "قبل از دریافت ایمیل‌های اعلان، باید آدرس ایمیل خود را تنظیم کنید.",
    "Send activity emails" : "ارسال ایمیل‌های فعالیت",
    "As soon as possible" : "در اسرع وقت",
    "Hourly" : "ساعتی",
    "Daily" : "روزانه",
    "Weekly" : "هفتگی",
    "You commented" : "شما نظر دادید",
    "Message deleted by author" : "پیام توسط نویسنده حذف شد",
    "Open {filename}" : "باز کردن {filename}",
    "in {path}" : "در {path}",
    "Home" : "خانه",
    "Could not load activities" : "بارگذاری فعالیت‌ها ممکن نیست",
    "Loading activities" : "در حال بارگذاری فعالیت‌ها",
    "This stream will show events like additions, changes & shares" : "این جریان رویدادهایی مانند افزودن‌ها، تغییرات و اشتراک‌گذاری‌ها را نشان می‌دهد  ",
    "No activity yet" : "هنوز فعالیتی وجود ندارد  ",
    "New activities" : "فعالیت‌های جدید  ",
    "Loading more activities" : "در حال بارگذاری فعالیت‌های بیشتر  ",
    "No more activities." : "فعالیت دیگری وجود ندارد.  ",
    "Could not enable RSS link" : "امکان فعال‌سازی لینک RSS وجود ندارد  ",
    "RSS link copied to clipboard" : "لینک RSS در کلیپ‌بورد کپی شد  ",
    "Could not copy the RSS link, please copy manually:" : "امکان کپی لینک RSS وجود ندارد، لطفاً به صورت دستی کپی کنید:  ",
    "Activity settings" : "تنظیمات فعالیت  ",
    "Enable RSS feed" : "فعال‌سازی خوراک RSS  ",
    "RSS feed" : "خوراک RSS  ",
    "Copy RSS feed link" : "کپی لینک خوراک RSS  ",
    "Personal notification settings" : "تنظیمات اعلان شخصی  ",
    "Clear selection" : "پاک کردن انتخاب",
    "Unable to load the activity list" : "امکان بارگذاری لیست فعالیت‌ها وجود ندارد  ",
    "Choose for which activities you want to get an email or push notification." : "انتخاب کنید برای کدام فعالیت‌ها ایمیل یا اعلان فشاری دریافت کنید.  ",
    "Choose for which activities you want to get a push notification." : "انتخاب کنید برای کدام فعالیت‌ها اعلان فشاری دریافت کنید.  ",
    "Notification" : "اعلان  ",
    "Enable notification emails" : "فعال‌سازی ایمیل‌های اعلان  ",
    "Daily activity summary" : "خلاصه فعالیت روزانه  ",
    "Send daily activity summary in the morning" : "ارسال خلاصه فعالیت روزانه در صبح  ",
    "Default settings" : "تنظیمات پیش‌فرض  ",
    "Configure the default notification settings for new accounts." : "تنظیمات پیش‌فرض اعلان را برای حساب‌های جدید پیکربندی کنید.  ",
    "Unable to save the settings" : "امکان ذخیره تنظیمات وجود ندارد  ",
    "No more events to load" : "رویداد دیگری برای بارگذاری وجود ندارد"
},
"nplurals=2; plural=(n > 1);");
