OC.L10N.register(
    "files_trashbin",
    {
    "restored" : "복원됨",
    "Deleted files" : "삭제된 파일",
    "Deleted files and folders in the trash bin (may expire during export if you are low on storage space)" : "휴지통에 있는 삭제된 파일과 폴더 (저장소 공간이 부족할 경우 내보내기 중 사라질 수 있음)",
    "This application enables people to restore files that were deleted from the system." : "이 앱은 시스템에서 삭제된 파일을 복원할 수 있도록 합니다.",
    "This application enables people to restore files that were deleted from the system. It displays a list of deleted files in the web interface, and has options to restore those deleted files back to the people file directories or remove them permanently from the system. Restoring a file also restores related file versions, if the versions application is enabled. When a file is deleted from a share, it can be restored in the same manner, though it is no longer shared. By default, these files remain in the trash bin for 30 days.\nTo prevent an account from running out of disk space, the Deleted files app will not utilize more than 50% of the currently available free quota for deleted files. If the deleted files exceed this limit, the app deletes the oldest files until it gets below this limit. More information is available in the Deleted Files documentation." : "이 앱은 시스템에서 삭제된 파일을 복원할 수 있도록 합니다. 웹 인터페이스로 삭제된 파일의 목록을 표시하며, 삭제된 파일을 사용자의 파일 디렉터리로 복원하거나 시스템에서 완전히 삭제하는 옵션이 있습니다. 버전 앱을 활성화한 경우 파일을 복원하면 해당 파일의 모든 버전을 같이 복원합니다. 공유에서 삭제한 파일도 같은 방법으로 복원할 수 있으나 더 이상 공유되지는 않습니다. 기본값으로 파일은 휴지통에 30일 동안 저장됩니다.\n사용자 디스크 공간 부족을 예방하기 위해서 삭제된 파일 앱에서는 삭제된 파일 디스크 할당량의 50% 이상을 사용하지 않습니다. 삭제된 파일이 해당 할당량을 초과한다면 할당량 이하로 떨어질 때까지 앱에서 가장 오래된 파일을 삭제합니다. 자세한 정보를 보려면 삭제된 파일 문서를 참조하십시오.",
    "Restore" : "복원",
    "Not enough free space to restore the file/folder" : "파일/폴더를 복원할 여유 공간이 부족합니다",
    "Empty deleted files" : "삭제된 파일 비우기",
    "Confirm permanent deletion" : "영구 삭제 확인",
    "Are you sure you want to permanently delete all files and folders in the trash? This cannot be undone." : "휴지통 안의 모든 파일과 폴더를 영구적으로 삭제하시겠습니까? 되돌릴 수 없습니다.",
    "Cancel" : "취소",
    "Original location" : "원래 위치",
    "Deleted by" : "삭제한 사용자: ",
    "Deleted" : "삭제됨",
    "few seconds ago" : "몇 초 전",
    "A long time ago" : "오래 전",
    "Unknown" : "알 수 없음",
    "All files" : "모든 파일",
    "You" : "당신",
    "List of files that have been deleted." : "삭제된 파일들의 목록입니다.",
    "No deleted files" : "삭제된 파일 없음",
    "Files and folders you have deleted will show up here" : "삭제된 파일 및 폴더가 여기에 나타납니다",
    "All files have been permanently deleted" : "모든 파일이 영구 삭제되었습니다",
    "Failed to empty deleted files" : "삭제된 파일을 비우지 못했습니다"
},
"nplurals=1; plural=0;");
