.albums-list[data-v-48906c46]{display:flex;flex-direction:column}.albums-list .album__name[data-v-48906c46]{font-weight:400;overflow:hidden;white-space:nowrap;text-overflow:ellipsis;font-size:20px;margin-bottom:12px;line-height:30px;color:var(--color-main-text)}
