OC.L10N.register(
    "appstore",
    {
    "App store" : "Store delle app",
    "Apps" : "Applicazioni",
    "App name" : "Nome applicazione",
    "Version" : "Versione",
    "Groups" : "Gruppi",
    "Actions" : "Azioni",
    "Show details" : "Mostra dettagli",
    "Grid view" : "Vista griglia",
    "Cancel" : "Annulla",
    "Office suite switching is managed through the Nextcloud All-in-One interface." : "Il passaggio tra le suite Office è gestito dall’interfaccia Nextcloud All-in-One.",
    "Please use the AIO interface to switch between office suites." : "Si prega di utilizzare l’interfaccia AIO per cambiare suite Office.",
    "Disable office suites" : "Disabilita suite Office",
    "installed" : "installato",
    "Features" : "Funzionalità",
    "Learn more" : "Scopri altro",
    "Daemon" : "Demone",
    "Deploy Daemon" : "Distribuisci Daemon",
    "Type" : "Tipo",
    "Name" : "Nome",
    "Display Name" : "Nome visualizzato",
    "GPUs support" : "Supporto GPU",
    "Compute device" : "Dispositivo di calcolo",
    "Advanced deploy options" : "Opzioni di distribuzione avanzate",
    "Edit ExApp deploy options before installation" : "Modifica le opzioni di distribuzione di ExApp prima dell'installazione",
    "Configured ExApp deploy options. Can be set only during installation" : "Opzioni di distribuzione ExApp configurate. Possono essere impostate solo durante l'installazione.",
    "Environment variables" : "Variabili d'ambiente",
    "ExApp container environment variables" : "Variabili d'ambiente del contenitore ExApp",
    "No environment variables defined" : "Nessuna variabile d'ambiente definita",
    "Mounts" : "Montaggi",
    "Define host folder mounts to bind to the ExApp container" : "Definire i montaggi delle cartelle host da associare al contenitore ExApp",
    "Must exist on the Deploy daemon host prior to installing the ExApp" : "Deve essere presente sull'host del demone di distribuzione prima di installare ExApp.",
    "Host path" : "Percorso dell'host",
    "Container path" : "Percorso del container",
    "Read-only" : "Sola lettura",
    "Remove mount" : "Rimuovi montaggio",
    "New mount" : "Nuovo montaggio",
    "Enter path to host folder" : "Inserisci il percorso della cartella nell'host",
    "Enter path to container folder" : "Inserisci il percorso della cartella nel container",
    "Toggle read-only mode" : "Attiva/disattiva modalità di sola lettura",
    "Confirm adding new mount" : "Conferma aggiunta nuovo montaggio",
    "Confirm" : "Conferma",
    "Cancel adding mount" : "Annulla aggiunta montaggio",
    "Add mount" : "Aggiungi montaggio",
    "ExApp container mounts" : "Montaggi container ExApp",
    "No mounts defined" : "Nessun montaggio definito",
    "Description" : "Descrizione",
    "View in store" : "Visualizza nel negozio",
    "Visit website" : "Visita il sito web",
    "Usage documentation" : "Manuale d'uso",
    "Admin documentation" : "Documentazione di amministrazione",
    "Developer documentation" : "Documentazione dello sviluppatore",
    "Details" : "Dettagli",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Questa applicazione non può essere installata perché le seguenti dipendenze non sono soddisfatte:",
    "Latest updated" : "Ultimo aggiornamento",
    "Author" : "Autore",
    "Categories" : "Categorie",
    "Resources" : "Risorse",
    "Changelog" : "Novità",
    "Supported" : "Supportata",
    "Featured" : "In evidenza",
    "This app is supported via your current Nextcloud subscription." : "Questa applicazione è supportata tramite la tua sottoscrizione attuale di Nextcloud.",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Le applicazioni in evidenza sono sviluppate dalla comunità. Esse offrono nuove funzionalità e sono pronte per l'uso in produzione.",
    "Community rating: {score}/5" : "Valutazione della comunità: {score}/5",
    "Choose Deploy Daemon for {appName}" : "Scegli il Deploy Daemon per {appName}",
    "No Deploy daemons configured" : "Nessun daemon di deployment configurato",
    "Register a custom one or setup from available templates" : "Registra uno personalizzato o configuralo dai modelli disponibili",
    "Manage Deploy daemons" : "Gestisci daemon di deployment",
    "Registered Deploy daemons list" : "Elenco dei daemon di deployment registrati",
    "Default" : "Predefinito",
    "Carousel" : "Carosello",
    "Previous slide" : "Diapositiva precedente",
    "Next slide" : "Diapositiva successiva",
    "Choose slide to display" : "Scegli una slide da mostrare",
    "{index} of {total}" : "{index} di {total}",
    "Limit to groups" : "Limita a gruppi",
    "Save" : "Salva",
    "Update all" : "Aggiorna",
    "Loading app list" : "Caricamento lista app",
    "Search everywhere" : "Cerca ovunque",
    "Download and enable all" : "Scarica e abilita tutti",
    "Could not load app discover section" : "Impossibile caricare la sezione di rilevamento delle applicazioni",
    "Could not render element" : "Impossibile visualizzare l'elemento",
    "Nothing to show" : "Niente da mostrare",
    "Could not load section content from app store." : "Impossibile caricare il contenuto della sezione dall'app store.",
    "Loading" : "Caricamento",
    "Fetching the latest news…" : "Recupero delle ultime notizie...",
    "Loading categories" : "Caricamento categorie",
    "Version {version}, {license}-licensed" : "Versione{version}. Licenza-{license}",
    "Version {version}" : "Versione {version}",
    "Disable" : "Disabilita",
    "Enable" : "Abilita",
    "Download and enable" : "Scarica e abilita",
    "Rate the app" : "Valuta l'applicazione",
    "Report a bug" : "Segnala un bug",
    "Remove" : "Rimuovi",
    "Update to {version}" : "Aggiorna a {version}",
    "Discover" : "Scopri",
    "Your apps" : "Le tue applicazioni",
    "Active apps" : "Applicazioni attive",
    "Disabled apps" : "Applicazioni disabilitate",
    "Updates" : "Aggiornamenti",
    "App bundles" : "Pacchetti di applicazioni",
    "Featured apps" : "Applicazioni in evidenza",
    "Supported apps" : "Applicazioni supportate",
    "Good Nextcloud integration" : "Buona integrazione con Nextcloud",
    "Best performance" : "Miglior performance",
    "Best Nextcloud integration" : "Miglior integrazione Nextcloud",
    "Good performance" : "Buone performance",
    "Best security: documents never leave your server" : "Miglior sicurezza: i documenti non lasciano mai i tuoi server",
    "Best ODF compatibility" : "Miglior compatibilità con ODF",
    "Best support for legacy files" : "Miglior supporto per i file legacy",
    "An error occurred during the request. Unable to proceed." : "Si è verificato un errore durante la richiesta. Impossibile continuare."
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
