OC.L10N.register(
    "suspicious_login",
    {
    "New login location detected" : "Виявлено нове розташування входу користувача",
    "More info about the suspicious IP address available on %s" : "Більше інформації про підозрілі адреси IP доступно %s",
    "A new login into your account was detected. The IP address %s was classified as suspicious by an AI model. If this was you, you can ignore this message, as the AI model did not take any automated actions. Otherwise, you should change your password." : "Визначено новий вхід до вашого облікового запису. ШІ визначив адресу IP %s підозрілою. Якщо це були не ви, проігноруйте це сповіщення, оскільки модель ШІ не виконує автоматизованих дій. В іншому випадку вам потрібно змінити пароль.",
    "Open %s ↗" : "Відкрити %s ↗",
    "Suspicious Login" : "Підозрілий вхід",
    "New login detected" : "Виявлено новий вхід",
    "Detect and warn about suspicious IPs logging into Nextcloud\n\t" : "Виявляє та попереджає про підозрілі IP адреси, з яких здійснюється вхід до Nextcloud\n\t",
    "A new login into your account was detected. The IP address %s was classified as suspicious. If this was you, you can ignore this message. Otherwise you should change your password." : "Виявлено новий вхід до вашого облікового запису. IP-адресу %s визначено підозрілою. Якщо це були не ви, проігноруйте це повідомлення. В іншому випадку вам потрібно змінити ваш пароль."
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
