OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Λείπει το συνθηματικό του κλειδιού ανάκτησης",
    "Please repeat the recovery key password" : "Παρακαλούμε επαναλάβετε το συνθηματικό του κλειδιού ανάκτησης",
    "Repeated recovery key password does not match the provided recovery key password" : "Το επαναλαμβανόμενο συνθηματικό του κλειδιού ανάκτησης δεν ταιριάζει με το παρεχόμενο συνθηματικό κλειδιού ανάκτησης",
    "Recovery key successfully enabled" : "Το κλειδί ανάκτησης ενεργοποιήθηκε επιτυχώς",
    "Could not enable recovery key. Please check your recovery key password!" : "Αδυναμία ενεργοποίησης του κλειδιού ανάκτησης. Παρακαλούμε ελέγξτε το συνθηματικό του κλειδιού ανάκτησής σας!",
    "Recovery key successfully disabled" : "Το κλειδί ανάκτησης απενεργοποιήθηκε επιτυχώς",
    "Could not disable recovery key. Please check your recovery key password!" : "Αδυναμία απενεργοποίησης του κλειδιού ανάκτησης. Παρακαλούμε ελέγξτε το συνθηματικό του κλειδιού ανάκτησής σας!",
    "Please provide the old recovery password" : "Παρακαλούμε εισαγάγετε το παλιό συνθηματικό ανάκτησης",
    "Please provide a new recovery password" : "Παρακαλούμε εισαγάγετε ένα νέο συνθηματικό ανάκτησης",
    "Please repeat the new recovery password" : "Παρακαλούμε επαναλάβετε το νέο συνθηματικό ανάκτησης",
    "Password successfully changed." : "Το συνθηματικό άλλαξε επιτυχώς.",
    "Could not change the password. Maybe the old password was not correct." : "Αδυναμία αλλαγής του συνθηματικού. Ίσως το παλιό συνθηματικό δεν ήταν σωστό.",
    "Recovery Key disabled" : "Το κλειδί ανάκτησης απενεργοποιήθηκε",
    "Recovery Key enabled" : "Το κλειδί ανάκτησης ενεργοποιήθηκε",
    "Could not enable the recovery key, please try again or contact your administrator" : "Αδυναμία ενεργοποίησης του κλειδιού ανάκτησης, παρακαλούμε προσπαθήστε ξανά ή επικοινωνήστε με τον διαχειριστή σας",
    "Could not update the private key password." : "Αδυναμία ενημέρωσης του συνθηματικού του ιδιωτικού κλειδιού.",
    "The old password was not correct, please try again." : "Το παλιό συνθηματικό δεν ήταν σωστό, παρακαλούμε δοκιμάστε ξανά.",
    "The current log-in password was not correct, please try again." : "Το τρέχον συνθηματικό σύνδεσης δεν ήταν σωστό, παρακαλούμε δοκιμάστε ξανά.",
    "Private key password successfully updated." : "Το συνθηματικό του ιδιωτικού κλειδιού ενημερώθηκε επιτυχώς.",
    "Invalid private key for encryption app. Please update your private key password in your personal settings to recover access to your encrypted files." : "Μη έγκυρο ιδιωτικό κλειδί για την εφαρμογή κρυπτογράφησης. Παρακαλούμε ενημερώστε το συνθηματικό του ιδιωτικού κλειδιού σας στις προσωπικές ρυθμίσεις για να ανακτήσετε πρόσβαση στα κρυπτογραφημένα σας αρχεία.",
    "Encryption App is enabled, but your keys are not initialized. Please log-out and log-in again." : "Η εφαρμογή κρυπτογράφησης είναι ενεργοποιημένη, αλλά τα κλειδιά σας δεν έχουν αρχικοποιηθεί. Παρακαλούμε αποσυνδεθείτε και συνδεθείτε ξανά.",
    "Please enable server side encryption in the admin settings in order to use the encryption module." : "Παρακαλούμε ενεργοποιήστε την κρυπτογράφηση στην πλευρά του διακομιστή στις ρυθμίσεις διαχειριστή για να χρησιμοποιήσετε τη μονάδα κρυπτογράφησης.",
    "Encryption app is enabled and ready" : "Η εφαρμογή κρυπτογράφησης είναι ενεργοποιημένη και έτοιμη",
    "Bad Signature" : "Μη έγκυρη υπογραφή",
    "Missing Signature" : "Λείπει η υπογραφή",
    "one-time password for server-side-encryption" : "συνθηματικό μίας χρήσης για την κρυπτογράφηση στην πλευρά του διακομιστή",
    "Encryption password" : "Συνθηματικό κρυπτογράφησης",
    "The administration enabled server-side-encryption. Your files were encrypted using the password <strong>%s</strong>." : "Η διαχείριση ενεργοποίησε την κρυπτογράφηση στην πλευρά του διακομιστή. Τα αρχεία σας κρυπτογραφήθηκαν χρησιμοποιώντας το συνθηματικό <strong>%s</strong>.",
    "The administration enabled server-side-encryption. Your files were encrypted using the password \"%s\"." : "Η διαχείριση ενεργοποίησε την κρυπτογράφηση στην πλευρά του διακομιστή. Τα αρχεία σας κρυπτογραφήθηκαν χρησιμοποιώντας το συνθηματικό \"%s\".",
    "Please login to the web interface, go to the \"Security\" section of your personal settings and update your encryption password by entering this password into the \"Old login password\" field and your current login password." : "Παρακαλούμε συνδεθείτε στη διαδικτυακή διεπαφή, μεταβείτε στην ενότητα \"Ασφάλεια\" των προσωπικών σας ρυθμίσεων και ενημερώστε το συνθηματικό κρυπτογράφησής σας εισάγοντας αυτό το συνθηματικό στο πεδίο \"Παλιό συνθηματικό σύνδεσης\" και το τρέχον συνθηματικό σύνδεσής σας.",
    "Cannot decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Αδυναμία αποκρυπτογράφησης αυτού του αρχείου, πιθανόν πρόκειται για κοινόχρηστο αρχείο. Παρακαλούμε ζητήστε από τον κάτοχο του αρχείου να το διαμοιραστεί ξανά μαζί σας.",
    "Cannot read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Αδυναμία ανάγνωσης αυτού του αρχείου, πιθανόν πρόκειται για κοινόχρηστο αρχείο. Παρακαλούμε ζητήστε από τον κάτοχο του αρχείου να το διαμοιραστεί ξανά μαζί σας.",
    "Default Encryption Module" : "Προεπιλεγμένη μονάδα κρυπτογράφησης",
    "Default encryption module for Nextcloud Server-side Encryption (SSE)" : "Προεπιλεγμένη μονάδα κρυπτογράφησης για την κρυπτογράφηση στην πλευρά του διακομιστή (SSE) του Nextcloud",
    "This app provides the (default) cryptography implementation for Nextcloud's Server-side Encryption (SSE) feature.\n\n\t\t\t**Encryption Details**\n\t\t\t*   **Cipher Mode:** AES-256-CTR (default)\n\t\t\t*   **Authentication:** HMAC-SHA256\n\n\t\t\t**Important Warnings**\n\t\t\t*   **DANGER:** Do not disable this application until all files have been decrypted (`occ encryption:decrypt-all`).\n\t\t\t*   **WARNING**: Reverting to non-encrypted file storage after activation requires command-line access. The action is permanent via the Web UI.\"\n\n\t\t\t**Notes for Existing Files**\n\t\t\t*   By default, enabling SSE does not encrypt existing files; only new files will be encrypted.\n\t\t\t*   To encrypt all existing files, use the command `occ encryption:encrypt-all`.\n\n\t\t\t**Before You Begin**\n\t\t\t*   **Read the Documentation:** Before you enable SSE, encrypt existing files, or disable SSE, it is critical to\n\t\t\t\tread the documentation to understand implications and the appropriate procedures to avoid data loss." : "Αυτή η εφαρμογή παρέχει την (προεπιλεγμένη) υλοποίηση κρυπτογράφησης για τη λειτουργία Κρυπτογράφησης στην πλευρά του διακομιστή (SSE) του Nextcloud.\n\n\t\t\t**Λεπτομέρειες Κρυπτογράφησης**\n\t\t\t*   **Λειτουργία Κρυπτογράφου:** AES-256-CTR (προεπιλογή)\n\t\t\t*   **Έλεγχος Ταυτότητας:** HMAC-SHA256\n\n\t\t\t**Σημαντικές Προειδοποιήσεις**\n\t\t\t*   **ΚΙΝΔΥΝΟΣ:** Μην απενεργοποιήσετε αυτήν την εφαρμογή μέχρι να αποκρυπτογραφηθούν όλα τα αρχεία (`occ encryption:decrypt-all`).\n\t\t\t*   **ΠΡΟΕΙΔΟΠΟΙΗΣΗ**: Η επαναφορά σε μη κρυπτογραφημένο χώρο αποθήκευσης αρχείων μετά την ενεργοποίηση απαιτεί πρόσβαση μέσω γραμμής εντολών. Η ενέργεια είναι μόνιμη μέσω της διεπαφής ιστού (Web UI).\"\n\n\t\t\t**Σημειώσεις για Υπάρχοντα Αρχεία**\n\t\t\t*   Από προεπιλογή, η ενεργοποίηση του SSE δεν κρυπτογραφεί τα υπάρχοντα αρχεία· μόνο τα νέα αρχεία θα κρυπτογραφούνται.\n\t\t\t*   Για να κρυπτογραφήσετε όλα τα υπάρχοντα αρχεία, χρησιμοποιήστε την εντολή `occ encryption:encrypt-all`.\n\n\t\t\t**Πριν Ξεκινήσετε**\n\t\t\t*   **Διαβάστε την Τεκμηρίωση:** Πριν ενεργοποιήσετε το SSE, κρυπτογραφήσετε υπάρχοντα αρχεία ή απενεργοποιήσετε το SSE, είναι εξαιρετικά σημαντικό να\n\t\t\t\tδιαβάσετε την τεκμηρίωση για να κατανοήσετε τις επιπτώσεις και τις κατάλληλες διαδικασίες για την αποφυγή απώλειας δεδομένων.",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "Η ενεργοποίηση αυτής της επιλογής κρυπτογραφεί όλα τα αρχεία που είναι αποθηκευμένα στον κύριο αποθηκευτικό χώρο, διαφορετικά μόνο τα αρχεία σε εξωτερικούς αποθηκευτικούς χώρους θα κρυπτογραφηθούν",
    "Encrypt the home storage" : "Κρυπτογράφηση του προσωπικού χώρου αποθήκευσης",
    "Disable recovery key" : "Απενεργοποίηση κλειδιού ανάκτησης",
    "Enable recovery key" : "Ενεργοποίηση κλειδιού ανάκτησης",
    "The recovery key is an additional encryption key used to encrypt files. It is used to recover files from an account if the password is forgotten." : "Το κλειδί ανάκτησης είναι ένα πρόσθετο κλειδί κρυπτογράφησης που χρησιμοποιείται για την κρυπτογράφηση αρχείων. Χρησιμοποιείται για την ανάκτηση αρχείων από έναν λογαριασμό εάν ξεχαστεί το συνθηματικό.",
    "Recovery key password" : "Συνθηματικό κλειδιού ανάκτησης",
    "Passwords fields do not match" : "Τα πεδία των συνθηματικών δεν ταιριάζουν",
    "Repeat recovery key password" : "Επαναλάβετε το συνθηματικό κλειδιού ανάκτησης",
    "An error occurred while updating the recovery key settings. Please try again." : "Παρουσιάστηκε σφάλμα κατά την ενημέρωση των ρυθμίσεων του κλειδιού ανάκτησης. Παρακαλούμε δοκιμάστε ξανά.",
    "Change recovery key password" : "Αλλαγή συνθηματικού κλειδιού ανάκτησης",
    "Old recovery key password" : "Παλιό συνθηματικό κλειδιού ανάκτησης",
    "New recovery key password" : "Νέο συνθηματικό κλειδιού ανάκτησης",
    "Repeat new recovery key password" : "Επαναλάβετε το νέο συνθηματικό κλειδιού ανάκτησης",
    "An error occurred while changing the recovery key password. Please try again." : "Παρουσιάστηκε σφάλμα κατά την αλλαγή του συνθηματικού του κλειδιού ανάκτησης. Παρακαλούμε δοκιμάστε ξανά.",
    "Update private key password" : "Ενημέρωση συνθηματικού ιδιωτικού κλειδιού",
    "Your private key password no longer matches your log-in password. Set your old private key password to your current log-in password." : "Το συνθηματικό του ιδιωτικού κλειδιού σας δεν ταιριάζει πλέον με το συνθηματικό σύνδεσής σας. Ορίστε το παλιό συνθηματικό του ιδιωτικού κλειδιού σας στο τρέχον συνθηματικό σύνδεσής σας.",
    "If you do not remember your old password you can ask your administrator to recover your files." : "Εάν δεν θυμάστε το παλιό σας συνθηματικό, μπορείτε να ζητήσετε από τον διαχειριστή σας να ανακτήσει τα αρχεία σας.",
    "Old log-in password" : "Παλιό συνθηματικό σύνδεσης",
    "Current log-in password" : "Τρέχον συνθηματικό σύνδεσης",
    "Update" : "Ενημέρωση",
    "Updating recovery keys. This can take some time…" : "Ενημέρωση των κλειδιών ανάκτησης. Αυτό μπορεί να διαρκέσει λίγο χρόνο…",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Η ενεργοποίηση αυτής της επιλογής θα σας επιτρέψει να ανακτήσετε την πρόσβαση στα κρυπτογραφημένα σας αρχεία σε περίπτωση απώλειας του συνθηματικού σας",
    "Enable password recovery" : "Ενεργοποίηση ανάκτησης συνθηματικού",
    "Default encryption module" : "Προεπιλεγμένη μονάδα κρυπτογράφησης",
    "Encryption app is enabled but your keys are not initialized, please log-out and log-in again" : "Η εφαρμογή κρυπτογράφησης είναι ενεργοποιημένη αλλά τα κλειδιά σας δεν έχουν αρχικοποιηθεί, παρακαλούμε αποσυνδεθείτε και συνδεθείτε ξανά",
    "Basic encryption module" : "Βασική μονάδα κρυπτογράφησης",
    "Missing parameters" : "Ελλιπείς παράμετροι",
    "Default encryption module for server-side encryption" : "Προεπιλεγμένη μονάδα κρυπτογράφησης για κρυπτογράφηση στην πλευρά του διακομιστή",
    "In order to use this encryption module you need to enable server-side encryption in the admin settings. Once enabled this module will encrypt all your files transparently. The encryption is based on AES 256 keys.\nThe module will not touch existing files, only new files will be encrypted after server-side encryption was enabled. It is also not possible to disable the encryption again and switch back to an unencrypted system.\nPlease read the documentation to know all implications before you decide to enable server-side encryption." : "Για να χρησιμοποιήσετε αυτή τη μονάδα κρυπτογράφησης, πρέπει να ενεργοποιήσετε την κρυπτογράφηση στην πλευρά του διακομιστή στις ρυθμίσεις διαχειριστή. Μόλις ενεργοποιηθεί, αυτή η μονάδα θα κρυπτογραφεί όλα τα αρχεία σας με διαφανή τρόπο. Η κρυπτογράφηση βασίζεται σε κλειδιά AES 256.\nΗ μονάδα δεν θα επηρεάσει τα υπάρχοντα αρχεία, μόνο τα νέα αρχεία θα κρυπτογραφούνται μετά την ενεργοποίηση της κρυπτογράφησης στην πλευρά του διακομιστή. Επίσης, δεν είναι δυνατή η εκ νέου απενεργοποίηση της κρυπτογράφησης και η επιστροφή σε ένα μη κρυπτογραφημένο σύστημα.\nΠαρακαλούμε διαβάστε την τεκμηρίωση για να γνωρίζετε όλες τις επιπτώσεις πριν αποφασίσετε να ενεργοποιήσετε την κρυπτογράφηση στην πλευρά του διακομιστή.",
    "Change recovery key password:" : "Αλλαγή συνθηματικού κλειδιού ανάκτησης:",
    "Change Password" : "Αλλαγή συνθηματικού",
    "Your private key password no longer matches your log-in password." : "Το συνθηματικό του ιδιωτικού κλειδιού σας δεν ταιριάζει πλέον με το συνθηματικό σύνδεσής σας.",
    "Set your old private key password to your current log-in password:" : "Ορίστε το παλιό συνθηματικό του ιδιωτικού κλειδιού σας στο τρέχον συνθηματικό σύνδεσης:",
    "Update Private Key Password" : "Ενημέρωση συνθηματικού ιδιωτικού κλειδιού",
    "Enable password recovery:" : "Ενεργοποίηση ανάκτησης συνθηματικού:",
    "Enabled" : "Ενεργοποιημένο",
    "Disabled" : "Απενεργοποιημένο",
    "This app provides the (default) cryptography implementation for Nextcloud's Server-side Encryption (SSE) feature.\n\n\t\t\t**Encryption Details**\n\t\t\t*   **Cipher Mode:** AES-256-CTR (default)\n\t\t\t*   **Authentication:** HMAC-SHA256\n\n\t\t\t**Important Warnings**\n\t\t\t*   **DANGER:** Do not disable this application until all files have been decrypted (`occ encryption:decrypt-all`).\n\t\t\t*   **WARNING**: Reverting to non-encrypted file storage after activation requires command-line access. The action is permanent via the Web UI.\"\n\n\t\t\t**Notes for Existing Files**\n\t\t\t*   By default, enabling SSE does not encrypt existing files; only new files will be encrypted.\n\t\t\t*   To encrypt all existing files, use the command `occ encryption:encrypt-all`.\n\n\t\t\t**Before You Begin**\n\t\t\t*   **Read the Documentation:** Before you enable SSE, encrypt existing files, or disable SSE, it is critical to \n\t\t\t\tread the documentation to understand implications and the appropriate procedures to avoid data loss." : "Αυτή η εφαρμογή παρέχει την (προεπιλεγμένη) υλοποίηση κρυπτογράφησης για τη λειτουργία Κρυπτογράφησης στην πλευρά του διακομιστή (SSE) του Nextcloud.\n\n\t\t\t**Λεπτομέρειες Κρυπτογράφησης**\n\t\t\t*   **Λειτουργία Κρυπτογράφου:** AES-256-CTR (προεπιλογή)\n\t\t\t*   **Έλεγχος Ταυτότητας:** HMAC-SHA256\n\n\t\t\t**Σημαντικές Προειδοποιήσεις**\n\t\t\t*   **ΚΙΝΔΥΝΟΣ:** Μην απενεργοποιήσετε αυτήν την εφαρμογή μέχρι να αποκρυπτογραφηθούν όλα τα αρχεία (`occ encryption:decrypt-all`).\n\t\t\t*   **ΠΡΟΕΙΔΟΠΟΙΗΣΗ**: Η επαναφορά σε μη κρυπτογραφημένο χώρο αποθήκευσης αρχείων μετά την ενεργοποίηση απαιτεί πρόσβαση μέσω γραμμής εντολών. Η ενέργεια είναι μόνιμη μέσω της διεπαφής ιστού (Web UI).\"\n\n\t\t\t**Σημειώσεις για Υπάρχοντα Αρχεία**\n\t\t\t*   Από προεπιλογή, η ενεργοποίηση του SSE δεν κρυπτογραφεί τα υπάρχοντα αρχεία· μόνο τα νέα αρχεία θα κρυπτογραφούνται.\n\t\t\t*   Για να κρυπτογραφήσετε όλα τα υπάρχοντα αρχεία, χρησιμοποιήστε την εντολή `occ encryption:encrypt-all`.\n\n\t\t\t**Πριν Ξεκινήσετε**\n\t\t\t*   **Διαβάστε την Τεκμηρίωση:** Πριν ενεργοποιήσετε το SSE, κρυπτογραφήσετε υπάρχοντα αρχεία ή απενεργοποιήσετε το SSE, είναι εξαιρετικά σημαντικό να \n\t\t\t\tδιαβάσετε την τεκμηρίωση για να κατανοήσετε τις επιπτώσεις και τις κατάλληλες διαδικασίες για την αποφυγή απώλειας δεδομένων."
},
"nplurals=2; plural=(n != 1);");
