<?php
// This file is auto-generated. Do not edit!
return array('Adlm'=>'Adlam','Afak'=>'Afaka','Egyd'=>'Ägyptisch - Demotisch','Egyh'=>'Ägyptisch - Hieratisch','Egyp'=>'Ägyptische Hieroglyphen','Ahom'=>'Ahom','Ital'=>'Altitalisch','Cyrs'=>'Altkirchenslawisch','Narb'=>'Altnordarabisch','Perm'=>'Altpermisch','Xpeo'=>'Altpersisch','Sarb'=>'Altsüdarabisch','Hung'=>'Altungarisch','Arab'=>array(''=>'Arabisch','variant'=>array('Persisch')),'Armn'=>'Armenisch','Armi'=>'Armi','Ethi'=>'Äthiopisch','Avst'=>'Avestisch','Bali'=>'Balinesisch','Bamu'=>'Bamun','Bass'=>'Bassa','Batk'=>'Battakisch','Beng'=>'Bengalisch','Bhks'=>'Bhks','Mymr'=>'Birmanisch','Blis'=>'Bliss-Symbole','Bopo'=>'Bopomofo','Brah'=>'Brahmi','Brai'=>'Braille','Phli'=>'Buch-Pahlavi','Bugi'=>'Buginesisch','Buhd'=>'Buhid','Cakm'=>'Chakma','Cham'=>'Cham','Cher'=>'Cherokee','Hani'=>'Chinesisch','Chrs'=>'Chrs','Cirt'=>'Cirth','Cpmn'=>'Cpmn','Dsrt'=>'Deseret','Deva'=>'Devanagari','Diak'=>'Diak','Dogr'=>'Dogr','Dupl'=>'Duployanisch','Elba'=>'Elbasanisch','Elym'=>'Elym','Zsye'=>'Emoji','Lisu'=>'Fraser','Nshu'=>'Frauenschrift','Nkgb'=>'Geba','Sgnw'=>'Gebärdensprache','Zinh'=>'Geerbter Schriftwert','Geor'=>'Georgisch','Glag'=>'Glagolitisch','Gong'=>'Gong','Gonm'=>'Gonm','Goth'=>'Gotisch','Gran'=>'Grantha','Grek'=>'Griechisch','Gujr'=>'Gujarati','Guru'=>'Gurmukhi','Hanb'=>'Han mit Bopomofo','Hang'=>'Hangul','Rohg'=>'Hanifi Rohingya','Hano'=>'Hanunoo','Hatr'=>'Hatr','Hebr'=>'Hebräisch','Hluw'=>'Hieroglyphen-Luwisch','Hira'=>'Hiragana','Hmnp'=>'Hmnp','Inds'=>'Indus-Schrift','Jamo'=>'Jamo','Jpan'=>'Japanisch','Hrkt'=>'Japanische Silbenschrift','Java'=>'Javanesisch','Jurc'=>'Jurchen','Kthi'=>'Kaithi','Knda'=>'Kannada','Cari'=>'Karisch','Kana'=>'Katakana','Aghb'=>'Kaukasisch-Albanisch','Kawi'=>'Kawi','Kali'=>'Kayah Li','Khar'=>'Kharoshthi','Khmr'=>'Khmer','Khoj'=>'Khojki','Sind'=>'Khudawadi','Geok'=>'Khutsuri','Kits'=>'Kits','Copt'=>'Koptisch','Kore'=>'Koreanisch','Kpel'=>'Kpelle','Cyrl'=>'Kyrillisch','Lana'=>'Lanna','Laoo'=>'Laotisch','Latn'=>'Lateinisch','Latf'=>'Lateinisch - Fraktur-Variante','Latg'=>'Lateinisch - Gälische Variante','Lepc'=>'Lepcha','Limb'=>'Limbu','Lina'=>'Linear A','Linb'=>'Linear B','Loma'=>'Loma','Lydi'=>'Lydisch','Lyci'=>'Lykisch','Mahj'=>'Mahajani','Maka'=>'Maka','Mlym'=>'Malayalam','Mand'=>'Mandäisch','Mani'=>'Manichäisch','Marc'=>'Marc','Zmth'=>'Mathematische Notation','Maya'=>'Maya-Hieroglyphen','Medf'=>'Medf','Mtei'=>'Meitei-Mayek','Mend'=>'Mende','Mero'=>'Meroitisch','Merc'=>'Meroitisch kursiv','Modi'=>'Modi','Mong'=>'Mongolisch','Moon'=>'Moon','Mroo'=>'Mro','Mult'=>'Mult','Nkoo'=>'N’Ko','Nbat'=>'Nabatäisch','Nagm'=>'Nagm','Nand'=>'Nand','Aran'=>'Nastaliq','Newa'=>'Newa','Ogam'=>'Ogham','Olck'=>'Ol Chiki','Orkh'=>'Orchon-Runen','Orya'=>'Oriya','Osge'=>'Osge','Osma'=>'Osmanisch','Syrn'=>'Ostsyrisch','Ougr'=>'Ougr','Hmng'=>'Pahawh Hmong','Phlv'=>'Pahlavi','Palm'=>'Palmyrenisch','Prti'=>'Parthisch','Pauc'=>'Pau Cin Hau','Phag'=>'Phags-pa','Phnx'=>'Phönizisch','Plrd'=>'Pollard Phonetisch','Phlp'=>'Psalter-Pahlavi','Rjng'=>'Rejang','Roro'=>'Rongorongo','Runr'=>'Runenschrift','Samr'=>'Samaritanisch','Sara'=>'Sarati','Saur'=>'Saurashtra','Zxxx'=>'Schriftlos','Shrd'=>'Sharada','Shaw'=>'Shaw-Alphabet','Visp'=>'Sichtbare Sprache','Sidd'=>'Siddham','Sinh'=>'Singhalesisch','Sogd'=>'Sogd','Sogo'=>'Sogo','Sora'=>'Sora Sompeng','Soyo'=>'Soyo','Xsux'=>'Sumerisch-akkadische Keilschrift','Sund'=>'Sundanesisch','Sylo'=>'Syloti Nagri','Zsym'=>'Symbole','Syrc'=>'Syrisch','Syre'=>'Syrisch - Estrangelo-Variante','Tglg'=>'Tagalog','Tagb'=>'Tagbanwa','Tale'=>'Tai Le','Talu'=>'Tai Lue','Tavt'=>'Tai-Viet','Takr'=>'Takri','Taml'=>'Tamilisch','Telu'=>'Telugu','Teng'=>'Tengwar','Thaa'=>'Thaana','Thai'=>'Thai','Tibt'=>'Tibetisch','Tfng'=>'Tifinagh','Tirh'=>'Tirhuta','Tnsa'=>'Tnsa','Toto'=>'Toto','Hant'=>array(''=>'Traditionell','stand-alone'=>array('Traditionelles Chinesisch')),'Cans'=>'UCAS','Ugar'=>'Ugaritisch','Zzzz'=>'Unbekannte Schrift','Vaii'=>'Vai','Wara'=>'Varang Kshiti','Zyyy'=>'Verbreitet','Hans'=>array(''=>'Vereinfacht','stand-alone'=>array('Vereinfachtes Chinesisch')),'Vith'=>'Vith','Wcho'=>'Wcho','Syrj'=>'Westsyrisch','Wole'=>'Woleaianisch','Tang'=>'Xixia','Yezi'=>'Yezi','Yiii'=>'Yi','Zanb'=>'Zanb','Qaag'=>'Zawgyi','Cprt'=>'Zypriotisch');
