OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Приватност",
    "-" : "-",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "Центарот за приватност ви покажува каде се складираат вашите податоци и кој има пристап до нив, или затоа што сте ги споделиле со некој или затоа што тие се администратори.",
    "Error loading additional administrator." : "Грешка при вчитување на дополнителен администратор.",
    "Error adding new administrator." : "Грешка при додавање на нов администратор.",
    "Error deleting new administrator." : "Грешка при бришење на нов администратор.",
    "Administrators" : "Администратори",
    "The following accounts are designated administrators and may potentially have access to your data through system storage or backups. However, they do not have easy access to your data via the web interface or client applications." : "Следниве сметки се назначени за администратори и може потенцијално да имаат пристап до вашите податоци преку системско складирање или резервни копии. Сепак, тие немаат лесен пристап до вашите податоци преку веб-интерфејсот или клиентските апликации.",
    "Remove external {propertyName} admin" : "Отстрани го надворешниот {propertyName} администратор",
    "Add external admin" : "Додади надворешен администратор",
    "Cancel" : "Откажи",
    "Add" : "Додади",
    "Name of external admin" : "Име на надворешен администратор",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key. It means that administrators can access your files, but not read their content." : "Вашата домашна меморија е шифрирана со {linkopen}шифрирање од страна на серверот ↗{linkclose} со главен клуч. Тоа значи дека администраторите можат да пристапат до вашите датотеки, но не и да ја читаат нивната содржина.",
    "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key based on their configuration." : "Вашите датотеки надворешните складишта може да се криптираат со {linkopen}енкрипција од страна на серверот ↗{linkclose} со главен клуч базиран според конфигурацијата.",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual user key. It means that administrators can access your files, but not read their content." : "Вашата домашна меморија е шифрирана со {linkopen}шифрирање од страна на серверот ↗{linkclose} со индивидуален корснички клуч. Тоа значи дека администраторите можат да пристапат до вашите датотеки, но не и да ја читаат нивната содржина.",
    "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual key based on their configuration." : "Вашите датотеки надворешните складишта може да се криптираат со {linkopen}енкрипција од страна на серверот ↗{linkclose} со индивидуален клуч базиран според конфигурацијата.",
    "Additionally, this server is protected with full-disk-encryption." : "Овој сервер е заштитен со целосно енкриптиран диск.",
    "This server is protected with full-disk-encryption." : "Овој сервер е заштитен со целосно енкриптиран диск.",
    "Your files are not protected by encryption." : "Вашите датотеки не се заштитени со енкрипција.",
    "Error saving new state of full-disk-encryption" : "Грешка при зачувување на нова состојба full-disk-encryption",
    "Encryption" : "Енкрипција",
    "Edit encryption" : "Измени енкрипција",
    "Edit" : "Уреди",
    "This server is using full-disk-encryption." : "Овој сервер користи целосно енкриптиран диск.",
    "Privacy policy" : "Политика за приватност",
    "Read the privacy policy ↗" : "Прочитај ја политиката за приватност ↗",
    "Error loading information about shares." : "Грешка при вчитување на информациите за споделување.",
    "People you've shared with" : "Луѓе со кои сте споделувале",
    "You do not have any shares with individual users." : "Вие не споделувате податоци со индивидуални корисници.",
    "Your {serverName} account" : "Вашата сметка на {serverName}",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Вашите податоци ве претставуваат вас и лесно можат да бидат злоупотребени. Ние во Nextcloud веруваме дека имате право да одлучите што ќе случува со вашите податоци. Nextcloud ги штити вашите права како што е дефинирано во Манифестот за кориснички податоци!",
    "Who has access to your data?" : "Кој има пристап до вашите податоци?",
    "Error saving new location of the server" : "Грешка при зачувување на нова локација на сервер",
    "Where is your data?" : "Каде се вашите податоци?",
    "Your data is located in:" : "Вашите податоци се наоѓаат во:",
    "An admin has not selected the location of the server yet." : "Администраторот сеуште нема избрано локација на серверот.",
    "Change data location" : "Промени ја локацијата на податоците",
    "Region" : "Регион",
    "Please select a region" : "Изберете регион",
    "User Data Manifesto 2.0" : "Манифест за кориснички податоци 2.0",
    "Defining basic rights for people to control their own data in the internet age." : "Дефинирање на основни права за луѓето да ги контролираат сопствените податоци во ерата на интернет.",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Податоците експлицитно и доброволно поставени од корисникот треба да бидат под неограничена контрола на корисникот. Корисниците треба сами да одлучат кому да му дадат директен пристап до нивните податоци и со какви дозволи и лиценци треба да им се овозможи пристап.",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Кога податоците се поставуваат на одреден давател на услуги, корисниците треба да бидат информирани за тоа каде тој конкретен давател на услуга чува податоци, колку долго, во која надлежност работи специфичниот давател на услуги и кој закони се применуваат.",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Корисниците треба секогаш да бидат во можност да ги повлечат своите податоци во кое било време, без да искусат заклучување на добавувачот. Отворени стандарди за формати и протоколи се неопходни за да се гарантира ова.",
    "Learn more ↗" : "Научи повеќе ↗",
    "Somaliland" : "Сомалија",
    "Andorra" : "Андора",
    "United Arab Emirates" : "Обединети Арапски Емирати",
    "Afghanistan" : "Афганистан",
    "Antigua and Barbuda" : "Антигва и Барбуда",
    "Anguilla" : "Ангила",
    "Albania" : "Албанија",
    "Armenia" : "Ерменија",
    "Angola" : "Ангола",
    "Antarctica" : "Антарктик",
    "Argentina" : "Аргентина",
    "American Samoa" : "Американска Самоа",
    "Austria" : "Австрија",
    "Australia" : "Австралија",
    "Aruba" : "Аруба",
    "Åland Islands" : "Оландски острови",
    "Azerbaijan" : "Азербејџан",
    "Bosnia and Herzegovina" : "Босна и Херцеговина",
    "Barbados" : "Барбадос",
    "Bangladesh" : "Бангладеш",
    "Belgium" : "Белгија",
    "Burkina Faso" : "Буркина Фасо",
    "Bulgaria" : "Бугарија",
    "Bahrain" : "Бахреин",
    "Burundi" : "Бурунди",
    "Benin" : "Бенин",
    "Saint Barthélemy" : "Свети Вартоломеј",
    "Bermuda" : "Бермуда",
    "Brunei" : "Брунеј",
    "Bolivia" : "Боливија",
    "Bonaire, Sint Eustatius and Saba" : "Бонер, Свети Евстахиј и Саба",
    "Brazil" : "Бразил",
    "Bahamas" : "Бахами",
    "Bhutan" : "Бутан",
    "Bouvet Island" : "Остров Буве",
    "Botswana" : "Боцвана",
    "Belarus" : "Белорусија",
    "Belize" : "Белизе",
    "Canada" : "Канада",
    "Cocos (Keeling) Islands" : "Кокосови Острови",
    "Democratic Republic of the Congo" : "Демократска Република Конго",
    "Central African Republic" : "Централна Африканска Република",
    "Congo" : "Конго",
    "Switzerland" : "Швајцарија",
    "Cote d'Ivoire" : "Брегот на Слоновата Коска",
    "Cook Islands" : "Кукови Острови",
    "Chile" : "Чиле",
    "Cameroon" : "Камерун",
    "China" : "Кина",
    "Colombia" : "Колумбија",
    "Costa Rica" : "Костарика",
    "Cuba" : "Куба",
    "Cabo Verde" : "Зелен ’Рт",
    "Curaçao" : "Курасао",
    "Christmas Island" : "Божиќен Остров",
    "Cyprus" : "Кипар",
    "Czech" : "Чешка",
    "Germany" : "Германија",
    "Djibouti" : "Џибути",
    "Denmark" : "Данска",
    "Dominican Republic" : "Доминиканска Република",
    "Algeria" : "Алжир",
    "Ecuador" : "Еквадор",
    "Estonia" : "Естонија",
    "Egypt" : "Египет",
    "West Sahara" : "Западна Сахара",
    "Eritrea" : "Еритреја",
    "Spain" : "Шпанија",
    "Ethiopia" : "Етиопија",
    "Finland" : "Финска",
    "Fiji" : "Фиџи",
    "Falkland Islands" : "Фолкландски острови",
    "Micronesia" : "Микронезија",
    "Faroe Islands" : "Фарски Острови",
    "France" : "Франција",
    "Gabon" : "Габон",
    "United Kingdom" : "Обединето Кралство",
    "Grenada" : "Гренада",
    "Georgia" : "Грузија",
    "French Guiana" : "Француска Гвајана",
    "Guernsey" : "Гернзи",
    "Ghana" : "Гана",
    "Gibraltar" : "Гибралтар",
    "Greenland" : "Гренланд",
    "Gambia" : "Гамбија",
    "Guinea" : "Гвинеја",
    "Guadeloupe" : "Гваделуп",
    "Equatorial Guinea" : "Екваторијална Гвинеја",
    "Greece" : "Грција",
    "South Georgia and the South Sandwich Islands" : "Јужна Џорџија и Јужни Сендвички Острови",
    "Guatemala" : "Гватемала",
    "Guam" : "Гуам",
    "Guinea-Bissau" : "Гвинеја-Бисао",
    "Guyana" : "Гвајана",
    "Hong Kong" : "Хонгконг",
    "Heard Island and McDonald Islands" : "Островите Хард и Мекдоналдс",
    "Honduras" : "Хондурас",
    "Croatia" : "Хрватска",
    "Haiti" : "Хаити",
    "Hungary" : "Унгарија",
    "Indonesia" : "Индонезија",
    "Ireland" : "Ирска",
    "Israel" : "Израел",
    "Isle of Man" : "Остров Ман",
    "India" : "Индија",
    "British Indian Ocean Territory" : "Британска Индоокеанска Територија",
    "Iraq" : "Ирак",
    "Iran" : "Иран",
    "Iceland" : "Исланд",
    "Italy" : "Италија",
    "Jamaica" : "Јамајка",
    "Jordan" : "Јордан",
    "Japan" : "Јапонија",
    "Kenya" : "Кенија",
    "Kyrgyzstan" : "Киргистан",
    "Cambodia" : "Камбоџа",
    "Kiribati" : "Кирибати",
    "Comores" : "Комори",
    "Saint Kitts and Nevis" : "Свети Кристофер и Невис",
    "North Korea" : "Северна Кореа",
    "South Korea" : "Јужна Кореа",
    "Kuwait" : "Кувајт",
    "Cayman Islands" : "Кајмански Острови",
    "Kazakhstan" : "Казахстан",
    "Laos" : "Лаос",
    "Lebanon" : "Либан",
    "Saint Lucia" : "Света Луција",
    "Liechtenstein" : "Лихтенштајн",
    "Sri Lanka" : "Шри Ланка",
    "Liberia" : "Либерија",
    "Lesotho" : "Лесото",
    "Lithuania" : "Литванија",
    "Luxembourg" : "Луксембург",
    "Latvia" : "Летонија",
    "Libya" : "Либија",
    "Morocco" : "Мароко",
    "Monaco" : "Монако",
    "Moldova" : "Молдавија",
    "Montenegro" : "Црна Гора",
    "Saint Martin" : "Свети Мартин",
    "Madagascar" : "Мадагаскар",
    "Marshall Islands" : "Маршалски Острови",
    "Macedonia" : "Македонија",
    "Mali" : "Мали",
    "Myanmar" : "Мјанмар",
    "Mongolia" : "Монголија",
    "Macao" : "Макао",
    "Northern Mariana Islands" : "Северни Маријански Острови",
    "Mauritania" : "Мавританија",
    "Montserrat" : "Монтсерат",
    "Malta" : "Малта",
    "Mauritius" : "Маврициус",
    "Maldives" : "Малдиви",
    "Malawi" : "Малави",
    "Mexico" : "Мексико",
    "Malaysia" : "Малезија",
    "Mozambique" : "Мозамбик",
    "Namibia" : "Намибија",
    "New Caledonia" : "Нова Каледонија",
    "Niger" : "Нигер",
    "Norfolk Island" : "Норфолшки Остров",
    "Nigeria" : "Нигерија",
    "Nicaragua" : "Никарагва",
    "Netherlands" : "Холандија",
    "Norway" : "Норвешка",
    "Nepal" : "Непал",
    "Nauru" : "Република Науру",
    "Niue" : "Ниуе",
    "New Zealand" : "Нов Зеланд",
    "Oman" : "Оман",
    "Panama" : "Панама",
    "Peru" : "Перу",
    "French Polynesia" : "Француска Полинезија",
    "Papua New Guinea" : "Папуа Нова Гвинеја",
    "Philippines" : "Филипини",
    "Pakistan" : "Пакистан",
    "Poland" : "Полска",
    "Saint Pierre and Miquelon" : "Свети Пјер и Микелон",
    "Pitcairn" : "Питкерн",
    "Puerto Rico" : "Порто Рико",
    "Palestine" : "Палестина",
    "Portugal" : "Португалија",
    "Palau" : "Република Палау",
    "Paraguay" : "Парагвај",
    "Qatar" : "Катар",
    "Réunion" : "Реинион",
    "Romania" : "Романија",
    "Serbia" : "Србија",
    "Russia" : "Русија",
    "Rwanda" : "Руанда",
    "Saudi Arabia" : "Саудиска Арабија",
    "Solomon Islands" : "Соломонски острови",
    "Seychelles" : "Сејшели",
    "Sudan" : "Судан",
    "Sweden" : "Шведска",
    "Singapore" : "Сингапур",
    "Saint Helena, Ascension and Tristan da Cunha" : "Света Елена, Вознесение и Тристан да Куња",
    "Slovenia" : "Словенија",
    "Svalbard and Jan Mayen" : "Свалбард и Јан Мејн\n ",
    "Slovakia" : "Словачка",
    "Sierra Leone" : "Сиера Леоне",
    "San Marino" : "Сан Марино",
    "Senegal" : "Сенегал",
    "Somalia" : "Сомалија",
    "Suriname" : "Суринам",
    "South Sudan" : "Јужен Судан",
    "Sao Tome and Principe" : "Сао Томе и Принсипе",
    "El Salvador" : "Ел Салвадор",
    "Sint Maarten" : "Свети Мартин",
    "Syria" : "Сирија",
    "Swaziland" : "Есватини",
    "Turks and Caicos Islands" : "Туркс и Кајкос",
    "Chad" : "Чад",
    "Fr. S. Antarctic Lands" : "Окрузи на Француските Јужни и Антарктички Земји",
    "Togo" : "Того",
    "Thailand" : "Тајланд",
    "Tajikistan" : "Таџикистан",
    "Tokelau" : "Токелау",
    "Timor-Leste" : "Тимор-Лест",
    "Turkmenistan" : "Туркменистан",
    "Tunisia" : "Тунис",
    "Tonga" : "Tonga",
    "Turkey" : "Турција",
    "Trinidad and Tobago" : "Тринидад и Тобаго",
    "Tuvalu" : "Тувалу",
    "Taiwan" : "Тајван",
    "Tanzania" : "Танзанија",
    "Ukraine" : "Украина",
    "Uganda" : "Уганда",
    "United States Minor Outlying Islands" : "Мали оддалечени острови на САД",
    "United States" : "Соединети Држави",
    "Uruguay" : "Уругвај",
    "Uzbekistan" : "Узбекистан",
    "Holy See" : "Света столица",
    "Saint Vincent and the Grenadines" : "Свети Винцент и Гренадини",
    "Venezuela" : "Венецуела",
    "Virgin Islands (British)" : "Британски Девствени Острови",
    "Virgin Islands (U.S.)" : "Американски Девствени Острови",
    "Vietnam" : "Виетнам",
    "Vanuatu" : "Вануату",
    "Wallis and Futuna" : "Валис и Футуна",
    "Samoa" : "Самоа",
    "Yemen" : "Јемен",
    "Mayotte" : "Мајот",
    "South Africa" : "Јужна Африка",
    "Zambia" : "Замбија",
    "Zimbabwe" : "Зимбабве",
    "Loading administrators …" : "Вчитување администратори ...",
    "Loading people you've shared with …" : "Вчитување на луѓето со кои сте споделувале",
    "Control" : "Контрола",
    "over user data access" : "на пристап до податоци од корисници",
    "Knowledge" : "Знаење",
    "of how the data is stored" : "за тоа како се чуваат податоци",
    "Freedom" : "Слобода",
    "to choose a platform" : "за избор на платформа"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
