OC.L10N.register(
    "files_sharing",
    {
    "File shares" : "Archivos compartidos",
    "Downloaded via public link" : "Descargado mediante una liga pública",
    "Downloaded by {email}" : "Descargado por {email}",
    "{file} downloaded via public link" : "{file} descargado mediante una liga pública",
    "{email} downloaded {file}" : "{email} descargó {file}",
    "Shared with group {group}" : "Compartido con el grupo {group}",
    "Removed share for group {group}" : "Se eliminó el elemento compartido del grupo {group}",
    "{actor} shared with group {group}" : "{actor} compartió con el grupo {group}",
    "{actor} removed share for group {group}" : "{actor} eliminó el elemento compartido del grupo {group}",
    "Share for group {group} expired" : "El recurso compartido para el grupo {group} ha caducado",
    "You shared {file} with group {group}" : "Compartiste {file} con el grupo {group}",
    "You removed group {group} from {file}" : "Eliminaste al grupo {group} de {file}",
    "{actor} shared {file} with group {group}" : "{actor} compartió {file} con el grupo {group}",
    "{actor} removed group {group} from {file}" : "{actor} eliminó el grupo {group} de {file}",
    "Share for file {file} with group {group} expired" : "El archivo {file} compartido con el grupo {group} ha caducado",
    "Shared as public link" : "Compartido como una liga pública",
    "Removed public link" : "Liga pública eliminada",
    "Public link expired" : "La liga pública ha expirado",
    "{actor} shared as public link" : "{actor} compartió como una liga pública",
    "{actor} removed public link" : "{actor} eliminó la liga pública",
    "Public link of {actor} expired" : "La liga pública de {actor} ha expirado",
    "You shared {file} as public link" : "Compartiste {file} como una liga pública",
    "You removed public link for {file}" : "Eliminaste la liga pública de {file}",
    "Public link expired for {file}" : "La liga pública para {file} ha expirado",
    "{actor} shared {file} as public link" : "{actor} ha compartido {file} como una liga pública",
    "{actor} removed public link for {file}" : "{actor} eliminó la liga pública de {file}",
    "Public link of {actor} for {file} expired" : "La liga pública de {actor} para {file} ha expirado",
    "{user} accepted the remote share" : "{user} aceptó el elemento compartido remoto",
    "{user} declined the remote share" : "{user} declinó el elemento compartido remoto",
    "You received a new remote share {file} from {user}" : "Recibiste un nuevo elemento compartido remoto {file} de {user}",
    "{user} accepted the remote share of {file}" : "{user} aceptó el elemento compartido remoto de {file}",
    "{user} declined the remote share of {file}" : "{user} declinó el elemento compartido remoto de {file}",
    "{user} unshared {file} from you" : "{user} ha dejado de compartir {file} contigo",
    "Shared with {user}" : "Compartido con {user}",
    "Removed share for {user}" : "Se eliminó el elemento compartido para {user}",
    "You removed yourself" : "Se eliminó a sí mismo",
    "{actor} removed themselves" : "{actor} se ha eliminado",
    "{actor} shared with {user}" : "{actor} compartió con {user}",
    "{actor} removed share for {user}" : "{actor} eliminó el elemento compartido para {user}",
    "Shared by {actor}" : "Compartido por {actor}",
    "{actor} removed share" : "{actor} eliminó el elemento compartido",
    "Share for {user} expired" : "El recurso compartido para {user} ha caducado",
    "Share expired" : "El recurso compartido ha caducado",
    "You shared {file} with {user}" : "Compartiste {file} con {user}",
    "You removed {user} from {file}" : "Eliminaste a {user} de {file}",
    "You removed yourself from {file}" : "Se eliminó a sí mismo de {file}",
    "{actor} removed themselves from {file}" : "{actor} se eliminó a sí mismo de {file}",
    "{actor} shared {file} with {user}" : "{actor} compartió {file} con {user}",
    "{actor} removed {user} from {file}" : "{actor} eliminó a {user} de {file}",
    "{actor} shared {file} with you" : "{actor} ha compartido {file} contigo",
    "{actor} removed you from the share named {file}" : "{actor} lo ha removido del recurso compartido llamado {file}",
    "Share for file {file} with {user} expired" : "El archivo {file} compartido con {user} ha caducado",
    "Share for file {file} expired" : "El archivo compartido {file} ha caducado",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Un archivo o carpeta comparitdo por correo o por liga pública ha sido <strong>descargado</strong>",
    "Files have been <strong>uploaded</strong> to a folder shared by mail or by public link" : "Los archivos se <strong>cargaron</strong> a una carpeta compartida por correo o enlace público",
    "A file or folder was shared from <strong>another server</strong>" : "Un archivo o carpeta fue compartido desde <strong>otro servidor</strong>",
    "Sharing" : "Compartiendo",
    "A file or folder has been <strong>shared</strong>" : "Un archivo o carpeta ha sido <strong>compartido</strong>",
    "Shared link" : "Enlace compartido",
    "Wrong share ID, share does not exist" : "Identificador de recurso compartido incorrecto, el recurso no existe",
    "Could not delete share" : "No fue posible borrar el elemento compartido",
    "Please specify a file or folder path" : "Por favor especifica un archivo o ruta de carpeta",
    "Wrong path, file/folder does not exist" : "Ruta incorrecta, el archivo/carpeta no existe",
    "Could not create share" : "No fue posible crear el elemento compartido",
    "Please specify a valid account to share with" : "Por favor, especifique una cuenta válida para compartir",
    "Please specify a valid group" : "Por favor especifica un grupo válido",
    "Please specify a valid email address" : "Por favor, especifique un correo electrónico válido",
    "Sharing %s sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "Compartir %s enviando la contraseña por Nextcloud Talk falló porque Nextcloud Talk no está habilitado",
    "Please specify a valid federated account ID" : "Por favor, especifique un identificador de cuenta federada válido",
    "Please specify a valid federated group ID" : "Por favor, especifique un identificador de grupo federado válido",
    "You cannot share to a Team if the app is not enabled" : "No puede compartir a un equipo si la aplicación no está habilitada",
    "Please specify a valid team" : "Por favor, especifique un equipo válido",
    "Sharing %s failed because the back end does not support room shares" : "Compartir %s falló porque el servidor no soporta salas compartidas",
    "Unknown share type" : "Tipo de elemento compartido desconocido",
    "Not a directory" : "No es una carpeta",
    "Could not lock node" : "No se pudo bloquear el nodo",
    "Public upload is only possible for publicly shared folders" : "Las cargas públicas son posibles sólo para carpetas compartidas públicamente",
    "Share must at least have READ or CREATE permissions" : "El recurso compartido debe tener al menos el permiso de LECTURA o CREACIÓN",
    "Share must have READ permission if UPDATE or DELETE permission is set" : "El recurso compartido debe tener el permiso de LECTURA si el permiso de ACTUALIZAR o ELIMINAR está configurado",
    "Could not lock path" : "No fue posible bloquear la ruta",
    "no sharing rights on this item" : "sin permisos para compartir este elemento",
    "You are not allowed to edit incoming shares" : "No tiene permitido editar los recursos compartidos entrantes",
    "Wrong or no update parameter given" : "El parametro de actualización está erróneo o falta",
    "\"Sending the password by Nextcloud Talk\" for sharing a file or folder failed because Nextcloud Talk is not enabled." : "\"Enviar la contraseña por Nextcloud Talk\" para compartir un archivo o carpeta falló porque Nextcloud Talk no está habilitado.",
    "Invalid date. Format must be YYYY-MM-DD" : "Fecha inválida. El formato debe ser AAAA-MM-DD",
    "No sharing rights on this item" : "Sin permisos para compartir este elemento",
    "Invalid share attributes provided: \"%s\"" : "Se proporcionaron atributos inválidos del recurso compartido: \"%s\"",
    "You are not allowed to send mail notifications" : "No tiene permitido enviar notificaciones por correo",
    "No mail notification configured for this share type" : "No hay notificaciones por correo configuradas para este tipo de recurso compartido",
    "Wrong password" : "Contraseña incorrecta",
    "Error while sending mail notification" : "Error al enviar el correo de notificación",
    "This share does not exist or is no longer available" : "El recurso compartido no existe o ya no está disponible",
    "shared by %s" : "compartido por %s",
    "Download" : "Descargar",
    "Add to your %s" : "Añadir a su %s",
    "Direct link" : "Liga directa",
    "Share API is disabled" : "El API para compartir está deshabilitado",
    "File sharing" : "Compartir archivos",
    "Share will expire tomorrow" : "El recurso compartido caducará mañana",
    "Your share of {node} will expire tomorrow" : "Su recurso compartido {node} caducará mañana",
    "You received {share} as a share by {user}" : "Ha recibido {share} como un recurso compartido por {user}",
    "You received {share} to group {group} as a share by {user}" : "Ha recibido {share} para el grupo {group} como un recurso compartido por {user}",
    "Accept" : "Aceptar",
    "Decline" : "Rechazar",
    "Filter accounts" : "Filtrar cuentas",
    "you" : "tú",
    "The request will expire on {date} at midnight and will be password protected." : "La solicitud caducará el {date} a la medianoche y estará protegida por contraseña.",
    "The request will expire on {date} at midnight." : "La solicitud caducará el {date} a la medianoche.",
    "The request will be password protected." : "La solicitud estará protegida por contraseña.",
    "When should the request expire?" : "¿Cuándo debería caducar la solicitud?",
    "Set a submission expiration date" : "Establecer una fecha de caducidad para el envío",
    "Expiration date" : "Fecha de expiración",
    "Select a date" : "Seleccionar una fecha",
    "Your administrator has enforced a {count} days expiration policy." : "Su administrador ha impuesto una política de caducidad de {count} días.",
    "What password should be used for the request?" : "¿Qué contraseña debería usarse para la solicitud?",
    "Set a password" : "Establecer una contraseña",
    "Password" : "Contraseña",
    "Enter a valid password" : "Ingrese una contraseña válida",
    "Generate a new password" : "Generar una nueva contraseña",
    "Your administrator has enforced a password protection." : "Su administrador ha impuesto la protección por contraseña.",
    "Automatically copying failed, please copy the share link manually" : "La copia automática falló, por favor, copie el enlace compartido manualmente",
    "Link copied" : "Vinculo copiado",
    "Email already added" : "El correo electrónico ya está añadido",
    "Invalid email address" : "Correo electrónico inválido",
    "_The following email address is not valid: {emails}_::_The following email addresses are not valid: {emails}_" : ["Las siguiente dirección de correo electrónico es inválida: {emails}","Las siguientes direcciones de correo electrónico son inválidas: {emails}","Las siguientes direcciones de correo electrónico son inválidas: {emails}"],
    "You can now share the link below to allow people to upload files to your directory." : "Ahora puede compartir el enlace de abajo para permitir a otros que carguen archivos a su directorio.",
    "Share link" : "Compartir liga",
    "Copy" : "Copiar",
    "Send link via email" : "Enviar la liga por correo electrónico",
    "Enter an email address or paste a list" : "Ingrese una dirección de correo electrónico o pegue una lista",
    "Remove email" : "Eliminar correo electrónico",
    "Select a destination" : "Seleccionar un destino",
    "Select" : "Seleccionar",
    "What are you requesting?" : "¿Qué está solicitando?",
    "Request subject" : "Asunto de la solicitud",
    "Birthday party photos, History assignment…" : "Fotos de fiestas de cumpleaños, tarea de historia...",
    "Where should these files go?" : "¿Dónde deberían de ir estos archivos?",
    "Upload destination" : "Destino de la carga",
    "Revert to default" : "Revertir a los valores predeterminados",
    "The uploaded files are visible only to you unless you choose to share them." : "Los archivos cargados son visibles únicamente para Ud., a menos que elija compartirlos.",
    "Add a note" : "Añadir una nota",
    "Note for recipient" : "Nota para el destinatario",
    "Add a note to help people understand what you are requesting." : "Añada una nota para ayudar a que los demás entiendan su solicitud.",
    "You can add links, date or any other information that will help the recipient understand what you are requesting." : "Puede añadir enlaces, fecha o cualquier información adicional para ayudar a que el destinatario entienda su solicitud.",
    "Close" : "Cerrar",
    "_Send email and close_::_Send {count} emails and close_" : ["Enviar el correo electrónico y cerrar","Enviar {count} correos electrónicos y cerrar","Enviar {count} correos electrónicos y cerrar"],
    "Please select a folder, you cannot share the root directory." : "Por favor seleccione una carpeta, no puede compartir el directorio raíz.",
    "File request created" : "Solicitud de archivo creada",
    "_File request created and email sent_::_File request created and {count} emails sent_" : ["Solicitud de archivo creada y un correo electrónico enviado","Solicitud de archivo creada y {count} correos electrónicos enviados","Solicitud de archivo creada y {count} correos electrónicos enviados"],
    "Error creating the share: {errorMessage}" : "Error al crear el recurso compartido: {errorMessage}",
    "Error creating the share" : "Error al crear el recurso compartido",
    "Error sending emails: {errorMessage}" : "Error al mandar los correos electrónicos: {errorMessage}",
    "Error sending emails" : "Error al mandar los correos electrónicos",
    "Create a file request" : "Crear una solicitud de archivo",
    "Collect files from others even if they do not have an account." : "Recolectar archivo de otros incluso cuando no tengan una cuenta.",
    "To ensure you can receive files, verify you have enough storage available." : "Para asegurar que pueda recibir archivos, compruebe que tenga suficiente espacio de almacenamiento disponible.",
    "File request" : "Solicitud de archivo",
    "Previous step" : "Paso anterior",
    "Cancel" : "Cancelar",
    "Cancel the file request creation" : "Cancelar la creación de solicitud de archivo",
    "Close without sending emails" : "Cerrar sin enviar los correos electrónicos",
    "Continue" : "Continuar",
    "Error while toggling options" : "Error al alternar las opciones",
    "Accept shares from other accounts and groups by default" : "Aceptar recursos compartidos de otros usuarios y grupos por defecto",
    "Choose a default folder for accepted shares" : "Elegir la carpeta predeterminada para los recursos compartidos aceptados",
    "Invalid path selected" : "Ruta seleccionada no válida.",
    "Unknown error" : "Se presentó un error desconocido",
    "Set default folder for accepted shares" : "Establecer la carpeta predeterminada para los recursos compartidos aceptados",
    "Reset" : "Reiniciar",
    "Reset folder to system default" : "Restablecer carpeta a la predeterminada del sistema",
    "group" : "grupo",
    "conversation" : "conversación",
    "remote" : "remoto",
    "remote group" : "grupo remoto",
    "guest" : "invitado",
    "Shared with the group {user} by {owner}" : "Compartido con el grupo {user} por {owner}",
    "Shared with the conversation {user} by {owner}" : "Compartido con la conversación {user} por {owner}",
    "Shared with {user} by {owner}" : "Compartido con {user} por {owner}",
    "Open Sharing Details" : "Abrir detalles de compartir",
    "Added by {initiator}" : "Añadido por {initiator}",
    "Via “{folder}”" : "Vía \"{folder}\"",
    "Unshare" : "Dejar de compartir",
    "Cannot copy, please copy the link manually" : "No se ha podido copiar, por favor, copia el enlace manualmente",
    "Copy internal link" : "Copiar enlace interno",
    "Internal link" : "Enlace interno",
    "{shareWith} by {initiator}" : "{shareWith} por {initiator}",
    "Shared via link by {initiator}" : "Compartido vía enlace por {initiator}",
    "File request ({label})" : "Solicitud de archivo ({label})",
    "Mail share ({label})" : "Compartir correo ({label})",
    "Share link ({label})" : "Compartir enlace ({label})",
    "Mail share" : "Compartido por correo",
    "Share link ({index})" : "Compartir enlace ({index})",
    "Create public link" : "Crear enlace público",
    "Actions for \"{title}\"" : "Acciones para \"{title}\"",
    "Error, please enter proper password and/or expiration date" : "Error, por favor ingrese una contraseña y/o fecha de caducidad adecuadas",
    "Link share created" : "Enlace compartido creado",
    "Error while creating the share" : "Error al crear el recurso compartido",
    "Please enter the following required information before creating the share" : "Por favor, ingrese la siguiente información requerida antes de crear el recurso compartido",
    "Password protection (enforced)" : "Protección con contraseña (exigida)",
    "Password protection" : "Protección con contraseña",
    "Enter a password" : "Ingresa una contraseña",
    "Create share" : "Crear recurso compartido",
    "Customize link" : "Personalizar enlace",
    "Generate QR code" : "Generar código QR",
    "Add another link" : "Añadir otro enlace",
    "Create a new share link" : "Crear un nuevo enlace compartido",
    "Quick share options, the current selected is \"{selectedOption}\"" : "Opciones rápidas de compartir, la seleccionada actualmente es \"{selectedOption}\"",
    "View only" : "Sólo lectura",
    "Can edit" : "Puede editar",
    "Custom permissions" : "Permisos personalizados",
    "Resharing is not allowed" : "No está permitido recompartir",
    "No elements found." : "No se encontraron elementos",
    "Search everywhere" : "Buscar en todas partes",
    "Guest" : "Invitado",
    "Group" : "Grupo",
    "Email" : "Correo electrónico",
    "Team" : "Equipo",
    "Talk conversation" : "Conversación de Talk",
    "Deck board" : "Tablero de Deck",
    "ScienceMesh" : "ScienceMesh",
    "on {server}" : "en {server}",
    "Note from" : "Nota de",
    "Note:" : "Nota:",
    "File drop" : "Soltar archivo",
    "Terms of service" : "Términos del servicio",
    "Share with email {email}" : "Compartir al correo electrónico {email}",
    "Share with group" : "Compartir con el grupo",
    "Share in conversation" : "Compartir en la conversación",
    "Share with {user} on remote server {server}" : "Compartir con {user} en el servidor remoto {server}",
    "Share with remote group" : "Compartir con un grupo remoto",
    "Share with guest" : "Compartir con un invitado",
    "Update share" : "Actualizar recurso compartido",
    "Save share" : "Guardar recurso compartido",
    "Read" : "Leer",
    "Create" : "Crear",
    "Edit" : "Editar",
    "Share" : "Compartir",
    "Delete" : "Borrar",
    "Allow upload and editing" : "Permitir carga y edición",
    "Allow editing" : "Permitir edición",
    "Upload only" : "Sólo carga",
    "Advanced settings" : "Configuraciones avanzadas",
    "Share label" : "Etiqueta del recurso compartido",
    "Set password" : "Establecer contraseña",
    "Password expires {passwordExpirationTime}" : "La contraseña caduca el {passwordExpirationTime}",
    "Password expired" : "Contraseña caduca",
    "Video verification" : "Verificación de video",
    "Expiration date (enforced)" : "Fecha de caducidad (impuesta)",
    "Set expiration date" : "Establece la fecha de expiración",
    "Hide download" : "Ocultar descarga",
    "Note to recipient" : "Nota al destinatario",
    "Enter a note for the share recipient" : "Ingrese una nota para el destinatario del recurso compartido",
    "Delete share" : "Borrar recurso compartido",
    "Others with access" : "Otros con acceso",
    "No other accounts with access found" : "No se encontraron otros usuarios con acceso",
    "Toggle list of others with access to this directory" : "Alternar lista de otros con acceso a este directorio",
    "Toggle list of others with access to this file" : "Alternar lista de otros con acceso a este archivo",
    "Unable to fetch inherited shares" : "No se pueden obtener los recursos compartidos heredados",
    "Shares" : "Elementos compartidos",
    "Unable to load the shares list" : "No se pudo cargar la lista de recursos compartidos",
    "Expires {relativetime}" : "Caduca en {relativetime}",
    "this share just expired." : "este recurso compartido acaba de caducar.",
    "Shared with you by {owner}" : "Compartido contigo por {owner}",
    "Link to a file" : "Enlazar a un archivo",
    "_Accept share_::_Accept shares_" : ["Aceptar recurso compartido","Aceptar recursos compartidos","Aceptar recursos compartidos"],
    "Open in Files" : "Abrir en Archivos",
    "_Reject share_::_Reject shares_" : ["Rechazar recurso compartido","Rechazar recursos compartidos","Rechazar recursos compartidos"],
    "_Restore share_::_Restore shares_" : ["Restaurar recurso compartido","Restaurar recursos compartidos","Restaurar recursos compartidos"],
    "Shared" : "Compartido",
    "Shared by {ownerDisplayName}" : "Compartido por {ownerDisplayName}",
    "Shared multiple times with different people" : "Compartido múltiples veces con diferentes personas",
    "Shared with others" : "Compartido con otros",
    "People" : "Personas",
    "Create file request" : "Crear solicitud de archivo",
    "No file" : "Sin archivo",
    "Overview of shared files." : "Resumen de archivos compartidos.",
    "No shares" : "No hay recursos compartidos",
    "Files and folders you shared or have been shared with you will show up here" : "Aquí aparecerán los archivos y carpetas que ha compartido o que se han compartido con Ud.",
    "Shared with you" : "Compartido contigo",
    "List of files that are shared with you." : "Lista de archivos compartidos con Ud.",
    "Nothing shared with you yet" : "Nada ha sido compartido contigo aún",
    "Files and folders others shared with you will show up here" : "Aquí aparecerán los archivos y carpetas que otros han compartido con Ud.",
    "List of files that you shared with others." : "Lista de archivos que ha compartido con otros.",
    "Nothing shared yet" : "Nada compartido aún",
    "Files and folders you shared will show up here" : "Aquí aparecerán los archivos y carpetas que ha compartido",
    "Shared by link" : "Compartido por liga",
    "List of files that are shared by link." : "Lista de archivos compartidos mediante enlace.",
    "No shared links" : "No hay ligas compartidas",
    "Files and folders you shared by link will show up here" : "Aquí aparecerán los archivos y carpetas que ha compartido mediante enlace",
    "File requests" : "Solicitudes de archivos",
    "List of file requests." : "Lista de solicitudes de archivos.",
    "No file requests" : "No hay solicitudes de archivos",
    "File requests you have created will show up here" : "Las solicitudes de archivos que haya creado aparecerán aquí",
    "Deleted shares" : "Recursos compartidos eliminados",
    "List of shares you left." : "Lista de recursos compartidos que abandonó.",
    "No deleted shares" : "No hay recursos compartidos eliminados",
    "Shares you have left will show up here" : "Aquí aparecerán los recursos compartidos que ha abandonado",
    "Pending shares" : "Recursos compartidos pendientes",
    "List of unapproved shares." : "Lista de recursos compartidos no aprobados",
    "No pending shares" : "No hay recursos compartidos pendientes",
    "Shares you have received but not approved will show up here" : "Aquí aparecerán los recursos compartidos que ha recibido pero que no ha aprobado",
    "Error updating the share" : "Error al actualizar el recurso compartido",
    "File \"{path}\" has been unshared" : "Se dejó de compartir el archivo \"{path}\"",
    "Folder \"{path}\" has been unshared" : "Se dejó de compartir la carpeta \"{path}\"",
    "Upload files to {folder}" : "Cargar archivos a {folder}",
    "{ownerDisplayName} shared a folder with you." : "{ownerDisplayName} le compartió una carpeta.",
    "Password created successfully" : "Contraseña creada exitosamente",
    "Error generating password from password policy" : "Error al generar la contraseña según la política de contraseñas",
    "Shared with you and the group {group} by {owner}" : "Compartido contigo y con el grupo {group} por {owner}",
    "Shared with you and {circle} by {owner}" : "Compartido con Ud. y {circle} por {owner}",
    "Shared with you and the conversation {conversation} by {owner}" : "Compartido con Ud. y la conversación {conversation} por {owner}",
    "Shared with you in a conversation by {owner}" : "Compartido con Ud. en una conversación por {owner}",
    "Share not found" : "No se encontró el elemento compartido",
    "Back to %s" : "Volver a %s",
    "Add to your Nextcloud" : "Agregar a tu Nextcloud",
    "Group sharing is disabled by the administrator" : "Compartir en grupos está deshabilitado por el administrador",
    "Public link sharing is disabled by the administrator" : "Compartir ligas públicas está deshabilitado por el administrador",
    "Sharing %1$s failed because the back end does not allow shares from type %2$s" : "Compartir %1$s falló porque el servidor no permite compartir recursos del tipo %2$s",
    "Sharing %s failed because the back end does not support ScienceMesh shares" : "Compartir %s falló porque el servidor no soporta recursos compartidos de ScienceMesh",
    "Public upload disabled by the administrator" : "Cargas públicas deshabilitadas por el administrador",
    "Name or email …" : "Nombre o correo electrónico …",
    "Name, email, or Federated Cloud ID …" : "Nombre, correo electrónico o identificador de la nube federada ...",
    "Searching …" : "Buscando  …"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
