OC.L10N.register(
    "logreader",
    {
    "Logging" : "Registravimas",
    "Errors in the log" : "Klaidos žurnale",
    "Failed to get an iterator for log entries: %s" : "Nepavyko gauti žurnalo įrašų iteratoriaus: %s",
    "No errors in the logs since %s" : "Nuo %s žurnaluose nėra jokių klaidų",
    "_%n error in the logs since %s_::_%n errors in the logs since %s_" : ["%n klaida žurnaluose nuo %s","%n klaidos žurnaluose nuo %s","%n klaidų žurnaluose nuo %s","%n klaidų žurnaluose nuo %s"],
    "_%n warning in the logs since %s_::_%n warnings in the logs since %s_" : ["%n įspėjimas žurnaluose nuo %s","%n įspėjimai žurnaluose nuo %s","%n įspėjimų žurnaluose nuo %s","%n įspėjimų žurnaluose nuo %s"],
    "Log Reader" : "Žurnalų skaitytuvė",
    "A log reader for Nextcloud" : "Žurnalo skaitytuvė, skirta „Nextcloud“",
    "Log reader for Nextcloud" : "Žurnalo skaitytuvė, skirta „Nextcloud“",
    "If you feel this is an error, please verify {setting} in your {config} and check the Nextcloud Administration Manual." : "Jei manote, kad tai klaida, patikrinkite {setting}savo {config} ir peržiūrėkite „Nextcloud“ administravimo vadovą.",
    "Log reader" : "Žurnalo skaitytuvas",
    "Open log reader settings" : "Atidaryti žurnalo skaitytuvo nustatymus",
    "Log reader settings" : "Žurnalo skaitytuvo nustatymai",
    "Currently the log file {file} is shown" : "Šiuo metu rodomas {file} žurnalo failas",
    "Show server log" : "Rodyti serverio žurnalą",
    "Live view is disabled" : "Tiesioginis vaizdas išjungtas",
    "No log file" : "Nėra žurnalo failo",
    "File-based logging must be enabled to access logs from the Web UI." : "Norint pasiekti žurnalus per žiniatinklio vartotojo sąsają, turi būti įjungtas failais pagrįstas registravimas.",
    "Log entry successfully copied" : "Žurnalo įrašas sėkmingai nukopijuotas",
    "Level" : "Lygmuo",
    "App" : "Programėlė",
    "No app in context" : "Nėra programos kontekste",
    "Time" : "Laikas",
    "Copy raw entry" : "Kopijuoti neapdorotą įrašą",
    "Copy formatted entry" : "Nukopijuokite suformatuotą įrašą",
    "Hide exception details" : "Slėpti išimties detales",
    "View exception details" : "Peržiūrėti išimties detales",
    "Raw log entry" : "Neapdorotas žurnalo įrašas",
    "Search log entries" : "Ieškoti žurnalo įrašų",
    "Caused by {exception}" : "Sukėlė {exception}",
    "Line {line}" : "Eilutė {line}",
    "Filter log levels" : "Filtruoti žurnalo lygius",
    "Set log level" : "Nustatyti žurnalo lygį",
    "Time format" : "Laiko formatas",
    "Live view" : "Tiesioginis vaizdas",
    "Download/Upload logs" : "Atsisiųsti / įkelti žurnalus",
    "Ctrl" : "Ctrl",
    "Could not parse local log file" : "Nepavyko išanalizuoti vietinio žurnalo failo",
    "You can also show log entries copied from your clipboard by pasting them on the log view using: {keyboardShortcut}" : "Taip pat galite rodyti iš iškarpinės nukopijuotus žurnalo įrašus, įklijuodami juos į žurnalo peržiūros langą: {keyboardShortcut}",
    "Download logs" : "Atsisiųsti žurnalus",
    "Show local log file" : "Rodyti vietinį žurnalo failą",
    "Upload local log file to be displayed" : "Įkelkite vietinį žurnalo failą, kad jis būtų rodomas",
    "Time format used for displaying the timestamp" : "Laiko formatas, naudojamas laiko žymai rodyti",
    "(Local log files only support the \"raw\" time format)" : "(Vietiniai žurnalų failai palaiko tik „neapdorotą“ laiko formatą)",
    "Could not change date time format." : "Nepavyko pakeisti datos ir laiko formato.",
    "Raw data" : "Neapdoroti duomenys",
    "Local time" : "Vietos laikas",
    "UTC time" : "UTC laikas",
    "Relative" : "Santykinis laikas",
    "Could not change live view setting." : "Nepavyko pakeisti tiesioginio vaizdo nustatymų.",
    "Polling is disabled because server is not configured to log to file" : "Apklausa išjungta, nes serveris nesukonfigūruotas registruoti į failą",
    "Polling (live view)" : "Apklausa (tiesioginė peržiūra)",
    "Could not set logging levels to show" : "Nepavyko nustatyti, kad būtų rodomi registravimo lygiai",
    "Filter logging levels" : "Filtruoti registravimo lygius",
    "Could not set logging level" : "Nepavyko nustatyti registravimo lygio",
    "Set backend loglevel" : "Nustatyti posistemės žurnalo lygį",
    "Application" : "Programėlė",
    "Message" : "Žinutė",
    "Log entry actions" : "Veiksmai su žurnalo įrašais",
    "Loading older log entries" : "Įkeliami senesni žurnalo įrašai",
    "No older log entries available" : "Senesnių įrašų nėra",
    "Collapse row" : "Suskleisti eilutę",
    "Expand row" : "Išskleisti eilutę",
    "Show details" : "Rodyti išsamiau",
    "Debug" : "Derinimas",
    "Info" : "Informacija",
    "Warning" : "Įspėjimas",
    "Error" : "Klaida",
    "Fatal" : "Lemtinga klaida",
    "Could not load log entries" : "Nepavyko įkelti žurnalo įrašų",
    "Clipboard" : "Iškarpinė",
    "Could not parse clipboard content" : "Nepavyko išanalizuoti iškarpinės turinio",
    "Could not fetch new log entries (server unavailable)" : "Nepavyko gauti naujų žurnalo įrašų (serveris nepasiekiamas)",
    "Could not fetch new entries" : "Nepavyko atsisiųsti naujų įrašų",
    "Could not copy to clipboard, please copy manually:" : "Nepavyko nukopijuoti į iškarpinę, nukopijuokite rankiniu būdu:",
    "\tfrom {address} by {user} at {time}\n" : "\tiš {address}, pateikta {user}, {time}\n"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
