OC.L10N.register(
    "related_resources",
    {
    "Calendar" : "يىلنامە",
    "Calendar \"%s\"" : "كالېندار \"%s\"",
    "Deck" : "پالۋان",
    "Deck board \"%s\"" : "پالۋان تاختىسى \"%s\"",
    "Files" : "ھۆججەتلەر",
    "File \"%s\"" : "ھۆججەت \"%s\"",
    "Group Folder" : "گۇرۇپپا ھۆججەت قىسقۇچى",
    "Group Folder \"%s\"" : "گۇرۇپپا ھۆججەت قىسقۇچى \"%s\"",
    "Talk conversation" : "پاراڭلىشىش",
    "Conversation with %s" : "%s بىلەن سۆھبەت",
    "Talk" : "پاراڭ",
    "Talk conversation \"%s\"" : "پاراڭلىشىش \"%s\"",
    "Related Resources" : "مۇناسىۋەتلىك مەنبەلەر",
    "Displays resources related to current item in right panel" : "ئوڭ تەرەپتىكى نۆۋەتتىكى تۈرگە مۇناسىۋەتلىك مەنبەلەرنى كۆرسىتىدۇ",
    "Displays resources related to current item in right panel." : "ئوڭ تەرەپتىكى نۆۋەتتىكى تۈرگە مۇناسىۋەتلىك مەنبەلەرنى كۆرسىتىدۇ."
},
"nplurals=2; plural=(n != 1);");
