<?php
// This file is auto-generated. Do not edit!
return array('localeDisplayPattern'=>array('localePattern'=>'%1$s (%2$s)','localeSeparator'=>'%1$s、%2$s','localeKeyTypePattern'=>'%1$s: %2$s'),'subdivisions'=>array('gbeng'=>'イングランド','gbsct'=>'スコットランド','gbwls'=>'ウェールズ'),'keys'=>array('calendar'=>'暦法','cf'=>'通貨フォーマット','colAlternate'=>'記号を無視した並べ替え','colBackwards'=>'アクセント（逆方向）による並べ替え','colCaseFirst'=>'大文字順/小文字順による並べ替え','colCaseLevel'=>'大文字小文字を区別した並べ替え','collation'=>'並べ替え順序','colNormalization'=>'正規化による並べ替え','colNumeric'=>'数値による並べ替え','colStrength'=>'強度による並べ替え','currency'=>'通貨','hc'=>'時間制(12 / 24)','lb'=>'禁則処理','ms'=>'単位系','numbers'=>'数値書式','timezone'=>'タイムゾーン','va'=>'ロケールのバリアント','x'=>'私用'),'types'=>array('calendar'=>array('buddhist'=>'仏暦','chinese'=>'中国暦','coptic'=>'コプト暦','dangi'=>'ダンギ暦','ethiopic'=>'エチオピア暦','ethiopic-amete-alem'=>'エチオピア創世紀元暦','gregorian'=>'西暦(グレゴリオ暦)','hebrew'=>'ユダヤ暦','indian'=>'インド国定暦','islamic'=>'イスラム暦','islamic-civil'=>'イスラム暦(定周期、公民紀元)','islamic-rgsa'=>'イスラム暦(サウジアラビア、月観測)','islamic-tbla'=>'イスラム歴(定周期、天文紀元)','islamic-umalqura'=>'イスラム暦(ウンム・アルクラー)','iso8601'=>'ISO-8601','japanese'=>'和暦','persian'=>'ペルシア暦','roc'=>'中華民国暦'),'cf'=>array('account'=>'会計通貨フォーマット','standard'=>'標準通貨フォーマット'),'colAlternate'=>array('non-ignorable'=>'記号で並べ替え','shifted'=>'記号を無視して並べ替え'),'colBackwards'=>array('no'=>'アクセント（順方向）で並べ替え','yes'=>'アクセント（逆方向）で並べ替え'),'colCaseFirst'=>array('lower'=>'小文字優先で並べ替え','no'=>'大文字小文字を通常の順序で並べ替え','upper'=>'大文字優先で並べ替え'),'colCaseLevel'=>array('no'=>'大文字小文字を区別しないで並べ替え','yes'=>'大文字小文字を区別して並べ替え'),'collation'=>array('big5han'=>'繁体字中国語順(Big5)','compat'=>'以前の順序（互換性）','dictionary'=>'辞書順','ducet'=>'ユニコード照合順','emoji'=>'emoji','eor'=>'ヨーロッパ言語文字の並べ替え規則','gb2312han'=>'簡体字中国語順(GB2312)','phonebook'=>'電話帳順','phonetic'=>'音声順による並べ替え','pinyin'=>'ピンイン順','reformed'=>'リフォーム','search'=>'汎用検索','searchjl'=>'ハングル語頭子音による並べ替え','standard'=>'標準並べ替え順序','stroke'=>'画数順','traditional'=>'トラディッショナル','unihan'=>'部首順','zhuyin'=>'注音順'),'colNormalization'=>array('no'=>'正規化しないで並べ替え','yes'=>'Unicode 正規化で並べ替え'),'colNumeric'=>array('no'=>'数値を独立して並べ替え','yes'=>'数値を数値として並べ替え'),'colStrength'=>array('identical'=>'すべてを区別して並べ替え','primary'=>'基本文字のみで並べ替え','quaternary'=>'アクセント/大文字小文字/全角半角/仮名で並べ替え','secondary'=>'アクセントで並べ替え','tertiary'=>'アクセント/大文字小文字/全角半角で並べ替え'),'d0'=>array('fwidth'=>'全角','hwidth'=>'半角','npinyin'=>'数字'),'hc'=>array('h11'=>'12時間制(0〜11)','h12'=>'12時間制(1〜12)','h23'=>'24時間制(0〜23)','h24'=>'24時間制(1〜24)'),'lb'=>array('loose'=>'禁則処理(弱)','normal'=>'禁則処理(標準)','strict'=>'禁則処理(強)'),'m0'=>array('bgn'=>'BGN','ungegn'=>'UNGEGN'),'ms'=>array('metric'=>'メートル法','uksystem'=>'ヤード・ポンド法','ussystem'=>'米慣習単位'),'numbers'=>array('ahom'=>'ahom','arab'=>'アラビア・インド数字','arabext'=>'ペルシア数字','armn'=>'アルメニア数字','armnlow'=>'アルメニア数字(小文字)','bali'=>'バリ数字','beng'=>'ベンガル数字','brah'=>'ブラーフミー数字','cakm'=>'チャクマ数字','cham'=>'チャム数字','cyrl'=>'cyrl','deva'=>'デーバナーガリー数字','diak'=>'diak','ethi'=>'エチオピア数字','finance'=>'財務用漢数字','fullwide'=>'全角数字','geor'=>'ジョージア数字','gong'=>'gong','gonm'=>'gonm','grek'=>'ギリシャ数字','greklow'=>'ギリシャ数字(小文字)','gujr'=>'グジャラート数字','guru'=>'グルムキー数字','hanidec'=>'漢数字(位取り記数法)','hans'=>'簡体漢数字','hansfin'=>'簡体大字','hant'=>'繁体漢数字','hantfin'=>'繁体大字','hebr'=>'ヘブライ数字','hmng'=>'hmng','hmnp'=>'hmnp','java'=>'ジャワ数字','jpan'=>'漢数字','jpanfin'=>'大字','kali'=>'カヤー数字','kawi'=>'kawi','khmr'=>'クメール数字','knda'=>'カンナダ数字','lana'=>'ラーンナー数字','lanatham'=>'ラーンナー・タム数字','laoo'=>'ラオ数字','latn'=>'算用数字','lepc'=>'レプチャ数字','limb'=>'リンブ数字','mathbold'=>'mathbold','mathdbl'=>'mathdbl','mathmono'=>'mathmono','mathsanb'=>'mathsanb','mathsans'=>'mathsans','mlym'=>'マラヤーラム数字','modi'=>'modi','mong'=>'モンゴル数字','mroo'=>'mroo','mtei'=>'マニプリ数字','mymr'=>'ミャンマー数字','mymrshan'=>'ミャンマー・シャン数字','mymrtlng'=>'mymrtlng','nagm'=>'nagm','native'=>'独自の記数法','nkoo'=>'ンコ数字','olck'=>'オルチキ数字','orya'=>'オディア数字','osma'=>'オスマニア数字','rohg'=>'rohg','roman'=>'ローマ数字','romanlow'=>'ローマ数字(小文字)','saur'=>'サウラーシュトラ数字','shrd'=>'シャーラダー数字','sind'=>'sind','sinh'=>'sinh','sora'=>'ソラ・ソンペン数字','sund'=>'スンダ数字','takr'=>'タークリー数字','talu'=>'新タイ・ルー数字','taml'=>'伝統的タミル数字','tamldec'=>'タミル数字','telu'=>'テルグ数字','thai'=>'タイ数字','tibt'=>'チベット数字','tirh'=>'tirh','tnsa'=>'tnsa','traditional'=>'従来の記数法','vaii'=>'ヴァイ文字の記数法','wara'=>'wara','wcho'=>'wcho')),'codePatterns'=>array('language'=>'言語: %1$s','script'=>'文字: %1$s','territory'=>'地域: %1$s'));
