OC.L10N.register(
    "logreader",
    {
    "App" : "Ilova",
    "Time" : "Vaqt",
    "Show details" : "Tafsilotlarni ko'rsatish",
    "Warning" : "Ogohlantirish",
    "Error" : "Xatolik"
},
"nplurals=1; plural=0;");
