OC.L10N.register(
    "contactsinteraction",
    {
    "Recently contacted" : "Nyligen kontaktade",
    "Contacts Interaction" : "Kontaktinteraktioner",
    "Manages interaction between accounts and contacts" : "Hanterar interaktioner mellan konton och kontakter",
    "Collect data about accounts and contacts interactions and provide an address book for the data" : "Samlar in uppgifter om interaktioner mellan konton och kontakter och tillhandahåller en adressbok för uppgifterna"
},
"nplurals=2; plural=(n != 1);");
