OC.L10N.register(
    "office",
    {
    "Office" : "Office",
    "Office overview" : "Office overview",
    "Office overview app for Nextcloud" : "Office overview app for Nextcloud",
    "Create new" : "Create new",
    "Scroll left" : "Scroll left",
    "Scroll right" : "Scroll right",
    "Blank" : "Blank",
    "Search {category}" : "Search {category}",
    "Search" : "Search",
    "Failed to create file" : "Failed to create file",
    "Failed to load files" : "Failed to load files",
    "No office suite installed" : "No office suite installed",
    "{count} found in {category}" : "{count} found in {category}",
    "Recent {category}" : "Recent {category}",
    "Filter files" : "Filter files",
    "All" : "All",
    "Mine" : "Mine",
    "Shared with me" : "Shared with me",
    "Switch to grid view" : "Switch to grid view",
    "Switch to list view" : "Switch to list view",
    "No {category} found" : "No {category} found",
    "Switch to \"All\" to see every file you have access to" : "Switch to \"All\" to see every file you have access to",
    "Search all in Files" : "Search all in Files",
    "Show all in Files" : "Show all in Files",
    "Create" : "Create",
    "Filename" : "Filename",
    "Documents" : "Documents",
    "Spreadsheets" : "Spreadsheets",
    "Presentations" : "Presentations",
    "Diagrams" : "Diagrams",
    "Filename cannot be empty" : "Filename cannot be empty",
    "Filename contains invalid characters" : "Filename contains invalid characters",
    "{count} {category} found" : "{count} {category} found"
},
"nplurals=2; plural=(n != 1);");
