OC.L10N.register(
    "contactsinteraction",
    {
    "Recently contacted" : "Rinneadh teagmháil le déanaí",
    "Contacts Interaction" : "Teagmhálaithe Idirghníomhaíocht",
    "Manages interaction between accounts and contacts" : "Bainistíonn sé idirghníomhaíocht idir cuntais agus teagmhálaithe",
    "Collect data about accounts and contacts interactions and provide an address book for the data" : "Bailigh sonraí faoi idirghníomhaíochtaí cuntais agus teagmhálaithe agus cuir leabhar seoltaí ar fáil do na sonraí"
},
"nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");
