OC.L10N.register(
    "files_sharing",
    {
    "File shares" : "Bendrinami failai",
    "Downloaded via public link" : "Atsisiųstas per viešąją nuorodą",
    "Downloaded by {email}" : "Atsisiuntė {email}",
    "{file} downloaded via public link" : "{file} atsisiųstas per viešąją nuorodą",
    "{email} downloaded {file}" : "{email} atsisiuntė {file}",
    "Shared with group {group}" : "Bendrinama su grupe {group}",
    "Removed share for group {group}" : "Nebebendrinama su grupe: {group}",
    "{actor} shared with group {group}" : "{actor} pradėjo bendrinti su grupe {group}",
    "{actor} removed share for group {group}" : "{actor} nustojo bendrinti su {group} grupe",
    "Share for group {group} expired" : "Pasibaigė bendrinimo su grupe {group} galiojimo laikas",
    "You shared {file} with group {group}" : "Jūs pradėjote bendrinti {file} su grupe {group}",
    "You removed group {group} from {file}" : "Pašalinote grupę {group} iš {file}",
    "{actor} shared {file} with group {group}" : "{actor} pradėjo bendrinti {file} su grupe {group}",
    "{actor} removed group {group} from {file}" : "{actor} pašalino grupę {group} iš {file}",
    "Share for file {file} with group {group} expired" : "Failo {file} bendrinimas su grupe {group} baigė galioti",
    "Shared as public link" : "Bendrinama kaip viešoji nuoroda",
    "Removed public link" : "Pašalinta viešoji nuoroda",
    "Public link expired" : "Pasibaigė viešosios nuorodos galiojimo laikas",
    "{actor} shared as public link" : "{actor} pradėjo bendrinti kaip viešąją nuorodą",
    "{actor} removed public link" : "{actor} pašalino viešąją nuorodą",
    "Public link of {actor} expired" : "Pasibaigė {actor}  viešosios nuorodos galiojimo laikas",
    "You shared {file} as public link" : "Jūs pradėjote bendrinti {file} kaip viešąją nuorodą",
    "You removed public link for {file}" : "Jūs pašalinote viešąją {file} nuorodą",
    "Public link expired for {file}" : "Viešoji nuoroda, skirta {file}, nebegalioja",
    "{actor} shared {file} as public link" : "{actor} pradėjo bendrinti {file} kaip viešąją nuorodą",
    "{actor} removed public link for {file}" : "{actor} pašalino viešąją „{file}“ nuorodą",
    "Public link of {actor} for {file} expired" : "Pasibaigė {actor} failo {file} viešosios nuorodos galiojimo laikas",
    "{user} accepted the remote share" : "{user} priėmė nuotolinį bendrinimą",
    "{user} declined the remote share" : "{user} atmetė nuotolinį bendrinimą",
    "You received a new remote share {file} from {user}" : "Jūs iš {user} gavote naują nuotolinį bendrinimą „{file}“",
    "{user} accepted the remote share of {file}" : "{user} priėmė nuotolinį bendrinimą „{file}“",
    "{user} declined the remote share of {file}" : "{user} atmetė nuotolinį bendrinimą „{file}“",
    "{user} unshared {file} from you" : "{user} nustojo bendrinti su jumis {file}",
    "Shared with {user}" : "Pradėta bendrinti su {user}",
    "Removed share for {user}" : "Pašalintas bendrinimas su {user}",
    "You removed yourself" : "Jūs pašalinote save",
    "{actor} removed themselves" : "{actor} pašalino save",
    "{actor} shared with {user}" : "{actor} pradėjo bendrinti su {user}",
    "{actor} removed share for {user}" : "{actor} pašalino bendrinimą su {user}",
    "Shared by {actor}" : "Bendrina {actor}",
    "{actor} removed share" : "{actor} pašalino bendrinimą",
    "Share for {user} expired" : "Pasibaigė bendrinimo su  {user} galiojimo laikas",
    "Share expired" : "Bendrinimas nebegalioja",
    "You shared {file} with {user}" : "Jūs pradėjote bendrinti failą {file} su {user}",
    "You removed {user} from {file}" : "Nebesidalinate {file} su {user}",
    "You removed yourself from {file}" : "Nebesidalinate {file} su savimi",
    "{actor} removed themselves from {file}" : "{actor} nebesidalina {file} su savimi",
    "{actor} shared {file} with {user}" : "{actor} pradėjo bendrinti {file} su {user}",
    "{actor} removed {user} from {file}" : "{actor} nebesidalina {file} su {user}",
    "{actor} shared {file} with you" : "{actor} pradėjo bendrinti su jumis {file}",
    "{actor} removed you from the share named {file}" : "{actor} pašalino jus iš viešinio, pavadinimu „{file}“",
    "Share for file {file} with {user} expired" : "Pasibaigė failo {file} bendrinimo su {user} galiojimo laikas",
    "Share for file {file} expired" : "Failo {file} bendrinimas nebegalioja",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Buvo <strong>atsisiųstas</strong> el. paštu ar viešąja nuoroda bendrinamas failas ar aplankas",
    "Files have been <strong>uploaded</strong> to a folder shared by mail or by public link" : "Failai buvo <strong>įkelti</strong> į aplanką, kuriuo dalijamasi el. paštu arba per viešą nuorodą",
    "A file or folder was shared from <strong>another server</strong>" : "Failas ar aplankas buvo pradėtas bendrinti iš <strong>kito serverio</strong>",
    "Sharing" : "Bendrinimas",
    "A file or folder has been <strong>shared</strong>" : "Failas ar aplankas <strong>bendrintas</strong>",
    "Shared link" : "Bendrinama nuoroda",
    "Wrong share ID, share does not exist" : "Neteisingas bendrinimo ID, bendrinimo nėra",
    "Could not delete share" : "Nepavyko ištrinti bendrinimo",
    "Please specify a file or folder path" : "Nurodykite kelią iki duomenų",
    "Wrong path, file/folder does not exist" : "Neteisingas kelias, failo/aplanko nėra",
    "Could not create share" : "Nepavyko sukurti bendrinimo",
    "Please specify a valid account to share with" : "Nurodykite tinkamą paskyrą, su kuria bendrinti",
    "Please specify a valid group" : "Nurodykite teisingą grupę",
    "Please specify a valid email address" : "Nurodykite tinkamą el. pašto adresą",
    "Sharing %s sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "Nepavyko išsiųsti slaptažodžio bendrinimui %s panaudojant „Nextcloud Pokalbiai“, kadangi „Nextcloud Pokalbiai“ neįjungtas ",
    "Please specify a valid federated account ID" : "Nurodykite galiojantį federacinės paskyros ID",
    "Please specify a valid federated group ID" : "Nurodykite galiojantį federacinės grupės ID",
    "You cannot share to a Team if the app is not enabled" : "Negali dalytis su komanda, jei programa nėra įjungta",
    "Please specify a valid team" : "Nurodykite tinkamą komandą",
    "Sharing %s failed because the back end does not support room shares" : "Bendrinimas %s nepavyko, kadangi sistema nepalaiko kambario bendrinimo",
    "Unknown share type" : "Nežinomas bendrinimo tipas",
    "Not a directory" : "Nėra katalogas",
    "Could not lock node" : "Nepavyko užrakinti mazgo",
    "Public upload is only possible for publicly shared folders" : "Duomenų įkėlimas viešam naudojimui galimas tik į viešai dalinamus aplankus",
    "Share must at least have READ or CREATE permissions" : "Vartotojas turi turėti bent jau SKAITYMO arba KŪRIMO teises",
    "Share must have READ permission if UPDATE or DELETE permission is set" : "Jei nustatytas leidimas „UPDATE“/\"ATNAUJINTI\" arba „DELETE“/\"IŠTRINTI\", leidimui „Share“/\"Bendrinti\" turi būti suteiktas leidimas „READ“/\"SKAITYTI\"",
    "Could not lock path" : "Nepavyko užrakinti kelio",
    "no sharing rights on this item" : "šiam elementui nesuteikta dalijimosi teisių",
    "You are not allowed to edit incoming shares" : "Jums neleidžiama redaguoti gaunamų bendrinimų",
    "Wrong or no update parameter given" : "Neperduoti atnaujinimo parametrai",
    "\"Sending the password by Nextcloud Talk\" for sharing a file or folder failed because Nextcloud Talk is not enabled." : "„Siųsti slaptažodį per „Nextcloud Pokalbiai““, norint pasidalinti failu ar aplanku, nepavyko, nes „Nextcloud Pokalbiai“ nėra įjungta.",
    "Custom share link tokens have been disabled by the administrator" : "Administratorius išjungė pasirinktinius nuorodų dalijimosi žymenis",
    "Tokens must be between 1 and %s characters long and may only contain letters, numbers, or a hyphen" : "Žymenys turi būti nuo 1 iki %s simbolių ilgio ir gali būti sudaryti tik iš raidžių, skaičių arba brūkšnelio.",
    "Invalid date. Format must be YYYY-MM-DD" : "Neteisinga data. Formatas turi būti YYYY-MM-DD",
    "No sharing rights on this item" : "Šio elemento dalijimosi teisės nesuteiktos",
    "Invalid share attributes provided: \"%s\"" : "Nurodyti neteisingi dalijimosi parametrai: „%s“",
    "You are not allowed to send mail notifications" : "Jums neleidžiama siųsti pranešimų el. paštu",
    "No mail notification configured for this share type" : "Šiam bendrinimo tipui nėra sukonfigūruotas pranešimas el. paštu",
    "Wrong password" : "Neteisingas slaptažodis",
    "Error while sending mail notification" : "Klaida siunčiant pranešimą el. paštu",
    "Failed to generate a unique token" : "Nepavyko sugeneruoti išskirtinio žymens",
    "This share does not exist or is no longer available" : "Šio viešinio nebėra arba jis daugiau nebeprieinamas",
    "shared by %s" : "bendrina %s",
    "Download" : "Atsisiųsti",
    "Add to your %s" : "Pridėti į jūsų %s",
    "Direct link" : "Tiesioginė nuoroda",
    "You are not allowed to share \"%s\"." : "Jums neleidžiama bendrinti „%s“.",
    "You cannot share your home folder." : "Jūs negalite bendrinti savo namų aplanko.",
    "File cannot be shared with delete permission." : "Failo negalima bendrinti suteikiant teisę jį ištrinti.",
    "File cannot be shared with create permission." : "Failo negalima bendrinti suteikiant leidimą kurti.",
    "File share needs at least read permission." : "Norint naudotis bendrai naudojamu failu, reikia turėti bent jau skaitymo teises.",
    "Public upload is not allowed." : "Viešas įkėlimas nėra leidžiamas.",
    "You cannot share \"%s\" with more permission than you have yourself." : "Jūs negalite bendrinti „%s“ suteikdami daugiau teisių, nei turite patys.",
    "Share API is disabled" : "Bendrinimo API yra išjungtas",
    "File sharing" : "Failų bendrinimas",
    "Share will expire tomorrow" : "Bendrinimo laikas baigiasi rytoj.",
    "Your share of {node} will expire tomorrow" : "Jūsų {node} bendrinimas baigs galioti rytoj",
    "You received {share} as a share by {user}" : "Jūs gavote bendrinimą {share}, kuriuo pasidalino {user}",
    "You received {share} to group {group} as a share by {user}" : "Jūs gavote bendrinimą {share} prie grupės {group}, kuriuo pasidalino {user}",
    "Accept" : "Priimti",
    "Decline" : "Atmesti",
    "Remember to upload the files to %s" : "Nepamirškite įkelti failų į %s",
    "We would like to kindly remind you that you have not yet uploaded any files to the shared folder." : "Norėtume maloniai priminti, kad į bendrinamą aplanką dar nesate išsiuntę jokių failų.",
    "Open \"%s\"" : "Atverti „%s“",
    "This application enables people to share files within Nextcloud. If enabled, the admin can choose which groups can share files. The applicable people can then share files and folders with other accounts and groups within Nextcloud. In addition, if the admin enables the share link feature, an external link can be used to share files with other people outside of Nextcloud. Admins can also enforce passwords, expirations dates, and enable server to server sharing via share links, as well as sharing from mobile devices.\nTurning the feature off removes shared files and folders on the server for all share recipients, and also on the sync clients and mobile apps. More information is available in the Nextcloud Documentation." : "Ši programa leidžia vartotojams dalytis failais „Nextcloud“ sistemoje. Jei ši funkcija įjungta, administratorius gali pasirinkti, kurios grupės gali dalytis failais. Tada atitinkami vartotojai gali dalytis failais ir aplankais su kitomis paskyromis bei grupėmis „Nextcloud“ sistemoje. Be to, jei administratorius įjungia nuorodos dalijimosi funkciją, išorinė nuoroda gali būti naudojama dalytis failais su kitais žmonėmis už „Nextcloud“ ribų. Administratoriai taip pat gali nustatyti slaptažodžius, galiojimo datas ir įjungti dalijimąsi tarp serverių per dalijimosi nuorodas, taip pat dalijimąsi iš mobiliųjų įrenginių.\nIšjungus šią funkciją, dalijamasi failai ir aplankai bus pašalinti iš serverio visiems dalijimosi gavėjams, taip pat sinchronizavimo klientams ir mobiliosioms programėlėms. Daugiau informacijos rasite „Nextcloud“ dokumentacijoje.",
    "Filter accounts" : "Filtruoti paskyras",
    "you" : "jūs",
    "The request will expire on {date} at midnight and will be password protected." : "Prašymas nustos galioti {date} vidurnaktį ir bus apsaugotas slaptažodžiu.",
    "The request will expire on {date} at midnight." : "Prašymas nustos galioti {date} vidurnaktį.",
    "The request will be password protected." : "Prašymas bus apsaugotas slaptažodžiu.",
    "When should the request expire?" : "Kada turėtų baigtis prašymo galiojimo terminas?",
    "Set a submission expiration date" : "Nustatyti pateikimo galiojimo pabaigos datą",
    "Expiration date" : "Galiojimo pabaigos data",
    "Select a date" : "Pasirinkti datą",
    "Your administrator has enforced a {count} days expiration policy." : "Jūsų administratorius nustatė galiojimo terminą, kuris baigiasi po {count} dienų.",
    "What password should be used for the request?" : "Kokį slaptažodį reikia nurodyti užklausai?",
    "Set a password" : "Nustatyti slaptažodį",
    "Password" : "Slaptažodis",
    "Enter a valid password" : "Įveskite teisingą slaptažodį",
    "Generate a new password" : "Generuoti naują slaptažodį",
    "Your administrator has enforced a password protection." : "Jūsų administratorius įjungė slaptažodžio apsaugą.",
    "Automatically copying failed, please copy the share link manually" : "Nepavyko automatiškai nukopijuoti, nukopijuokite nuorodą rankiniu būdu",
    "Link copied" : "Nuoroda nukopijuota",
    "Email already added" : "El. paštas jau pridėtas",
    "Invalid email address" : "Neteisingas el. pašto adresas",
    "_The following email address is not valid: {emails}_::_The following email addresses are not valid: {emails}_" : ["Šis elektroninio pašto adresas yra neteisingas: {emails}","Šie elektroninio pašto adresai yra neteisingi: {emails}","Šie elektroninio pašto adresai yra neteisingi: {emails}","Šie elektroninio pašto adresai yra neteisingi: {emails}"],
    "_{count} email address already added_::_{count} email addresses already added_" : ["Jau pridėtas {count} el. pašto adresas","Jau pridėti {count} el. pašto adresai","Jau pridėta {count} el. pašto adresų","Jau pridėtas {count} el. pašto adresas"],
    "_{count} email address added_::_{count} email addresses added_" : ["Pridėtas {count} el. pašto adresas","Pridėti {count} el. pašto adresai","Pridėta {count} el. pašto adresų","Pridėtas {count} el. pašto adresas"],
    "You can now share the link below to allow people to upload files to your directory." : "Dabar galite pasidalinti žemiau pateikta nuoroda, kad leistumėte kitiems išsiųsti failus į jūsų katalogą.",
    "Share link" : "Bendrinimo nuoroda",
    "Copy" : "Kopijuoti",
    "Send link via email" : "Siųsti nuorodą el. paštu",
    "Enter an email address or paste a list" : "Įveskite el. pašto adresą arba įdėkite sąrašą",
    "Remove email" : "Šalinti el. paštą",
    "Select a destination" : "Pasirinkite kelionės tikslą",
    "Select" : "Žymėti",
    "What are you requesting?" : "Ko prašote?",
    "Request subject" : "Prašymo tema",
    "Birthday party photos, History assignment…" : "Gimtadienio nuotraukos, istorijos užduotis…",
    "Where should these files go?" : "Kur šiuos failus reikėtų įdėti?",
    "Upload destination" : "Išsiuntimo vieta",
    "Revert to default" : "Sugrąžinti į numatytąjį",
    "The uploaded files are visible only to you unless you choose to share them." : "Išsiųsti failai yra matomi tik jums, nebent nuspręsite juos bendrinti.",
    "Add a note" : "Pridėti pastabą",
    "Note for recipient" : "Pastaba gavėjui",
    "Add a note to help people understand what you are requesting." : "Pridėkite pastabą, kad kiti geriau suprastų, ko prašote.",
    "You can add links, date or any other information that will help the recipient understand what you are requesting." : "Galite įtraukti nuorodas, datą ar bet kokią kitą informaciją, kuri padės gavėjui suprasti, ko prašote.",
    "Close" : "Užverti",
    "_Send email and close_::_Send {count} emails and close_" : ["Išsiųsti el. laišką ir užverti","Išsiųsti {count} el. laiškus ir užverti","Išsiųsti {count} el. laiškų ir užverti","Išsiųsti {count} el. laišką ir užverti"],
    "Please select a folder, you cannot share the root directory." : "Prašome pasirinkti aplanką – negalima bendrinti pagrindinio katalogo.",
    "File request created" : "Failo užklausa sukurta",
    "_File request created and email sent_::_File request created and {count} emails sent_" : ["Sukurtas failo užklausimas ir išsiųstas el. laiškas","Sukurtas failo užklausimas ir išsiųsti {count} el. laiškai","Sukurtas failo užklausimas ir išsiųsti {count} el. laiškai","Sukurtas failo užklausimas ir išsiųsti {count} el. laiškai"],
    "Error creating the share: {errorMessage}" : "Klaida kuriant bendrinimą: {errorMessage}",
    "Error creating the share" : "Klaida kuriant bendrinimą",
    "Error sending emails: {errorMessage}" : "Klaida siunčiant el. laiškus: {errorMessage}",
    "Error sending emails" : "Klaida siunčiant el. laiškus",
    "Create a file request" : "Sukurti failo užklausą",
    "Collect files from others even if they do not have an account." : "Rinkite failus iš kitų, net jei jie neturi paskyros.",
    "To ensure you can receive files, verify you have enough storage available." : "Norėdami įsitikinti, kad galėsite gauti failus, patikrinkite, ar turite pakankamai laisvos vietos saugykloje.",
    "File request" : "Failo užklausa",
    "Previous step" : "Ankstesnis žingsnis",
    "Cancel" : "Atsisakyti",
    "Cancel the file request creation" : "Atšaukti failo užklausos sukūrimą",
    "Close without sending emails" : "Užverti nesiunčiant el. laiškų",
    "Continue" : "Tęsti",
    "Error while toggling options" : "Klaida perjungiant parinktis",
    "Accept shares from other accounts and groups by default" : "Pagal numatymą priimti bendrinimus iš kitų paskyrų ir grupių",
    "Choose a default folder for accepted shares" : "Pasirinkite numatytąjį aplanką priimtiems bendrinimams",
    "Invalid path selected" : "Pasirinktas netinkamas kelias",
    "Unknown error" : "Nežinoma klaida",
    "Set default folder for accepted shares" : "Nustatykite numatytąjį priimtų bendrinimų aplanką",
    "Reset" : "Atstatyti",
    "Reset folder to system default" : "Atstatyti aplanką į sistemos numatytąjį",
    "Share expiration: {date}" : "Bendrinimo galiojimas baigiasi: {date}",
    "Share Expiration" : "Bendrinimo galiojimo laikas",
    "group" : "grupė",
    "conversation" : "pokalbis",
    "remote" : "nuotolinis",
    "remote group" : "nuotolinė grupė",
    "guest" : "svečias",
    "by {initiator}" : "autorius {initiator}",
    "Shared with the group {user} by {owner}" : "{owner} pasidalino su {user} grupe ",
    "Shared with the conversation {user} by {owner}" : "Bendrinimas su pokalbiu {user}, kurį aliko {owner}",
    "Shared with {user} by {owner}" : "Bendrinimas su {user}, kurį aliko {owner}",
    "Open Sharing Details" : "Atidaryti Bendrinimo Informaciją",
    "Added by {initiator}" : "Pridėjo {initiator}",
    "Via “{folder}”" : "Per „{folder}“",
    "Unshare" : "Nustoti bendrinti",
    "Cannot copy, please copy the link manually" : "Nepavyksta nukopijuoti, nukopijuokite nuorodą rankiniu būdu",
    "Copy internal link" : "Kopijuoti vidinę nuorodą",
    "For people who already have access" : "Tiems, kurie jau turi prieigą",
    "Internal link" : "Vidinė nuoroda",
    "{shareWith} by {initiator}" : "{initiator} pasidalino {shareWith}",
    "Shared via link by {initiator}" : "{initiator} bendrina per nuorodą",
    "File request ({label})" : "Failo užklausa ({label})",
    "Mail share ({label})" : "Bendrinimas paštu ({label})",
    "Share link ({label})" : "Bendrinimo nuoroda ({label})",
    "Mail share" : "Bendrinimas paštu",
    "Share link ({index})" : "Dalintis nuoroda ({index})",
    "Create public link" : "Sukurti viešąją nuorodą",
    "Actions for \"{title}\"" : "Veiksmai, susiję su „{title}“",
    "Copy public link of \"{title}\"" : "Kopijuoti viešąją nuorodą į „{title}“",
    "Error, please enter proper password and/or expiration date" : "Įvyko klaida, įveskite teisingą slaptažodį ir/ar galiojimo datą",
    "Link share created" : "Bendrinimo nuoroda sukurta",
    "Error while creating the share" : "Klaida kuriant bendrinimą",
    "Your browser does not support copying, please copy the link manually:" : "Jūsų naršyklė nepalaiko kopijavimo funkcijos, todėl nuorodą kopijuokite rankiniu būdu:",
    "Successfully copied public link" : "Viešoji nuoroda sėkmingai nukopijuota",
    "Please enter the following required information before creating the share" : "Prieš sukurdami bendrinimą, įveskite šią reikiamą informaciją",
    "Password protection (enforced)" : "Apsauga slaptažodžiu (priverstinė)",
    "Password protection" : "Apsauga slaptažodžiu",
    "Enter a password" : "Enter a password",
    "Enable link expiration (enforced)" : "Įjungti nuorodų galiojimo pabaigą (privaloma)",
    "Enable link expiration" : "Įjungti nuorodų galiojimo pabaigą",
    "Enter expiration date (enforced)" : "Įveskite galiojimo pabaigos datą (privaloma)",
    "Enter expiration date" : "Įveskite galiojimo pabaigos datą",
    "Create share" : "Sukurti bendrinimą",
    "Customize link" : "Tinkinti nuorodą",
    "Generate QR code" : "Generuoti QR kodą",
    "Add another link" : "Pridėti kitą nuorodą",
    "Create a new share link" : "Sukurti naują bendrinimo nuorodą",
    "Quick share options, the current selected is \"{selectedOption}\"" : "Greito dalijimosi parinktys, šiuo metu pasirinkta „{selectedOption}“",
    "View only" : "Tik peržiūrėti",
    "Can edit" : "Gali taisyti",
    "Custom permissions" : "Tinkinti leidimai",
    "Resharing is not allowed" : "Bendrinimas iš naujo yra neleidžiamas",
    "Name or email …" : "Vardas arba el. paštas…",
    "Name, email, or Federated Cloud ID …" : "Vardas, el. paštas arba federacinės debesijos ID  …",
    "Searching …" : "Ieškoma…",
    "No elements found." : "Nerasta jokių elementų.",
    "Search everywhere" : "Ieškoti visur",
    "Guest" : "Svečias",
    "Group" : "Grupė",
    "Email" : "El. paštas",
    "Team" : "Komanda",
    "Talk conversation" : "„Pokalbiai\" pokalbis",
    "Deck board" : "Darbų lenta",
    "ScienceMesh" : "\"ScienceMesh\"",
    "on {server}" : "serveryje {server}",
    "Enter external recipients" : "Įveskite išorinius gavėjus",
    "Search for internal recipients" : "Ieškoti vidinių gavėjų",
    "Note from" : "Pastaba iš",
    "Note:" : "Pastaba:",
    "File drop" : "Failų įkėlimas",
    "Upload files to {foldername}." : "Įkelkite failus į {foldername}.",
    "By uploading files, you agree to the terms of service." : "Įkeldami failus, jūs sutinkate su paslaugų teikimo sąlygomis.",
    "Successfully uploaded files" : "Failai sėkmingai įkelti",
    "View terms of service" : "Peržiūrėti paslaugų teikimo sąlygas",
    "Terms of service" : "Naudojimosi sąlygos",
    "Share with {user}" : "Bendrinti su {user}",
    "Share with email {email}" : "Bendrinti su el. pašto adresu {email}",
    "Share with group" : "Bendrinti su grupe",
    "Share in conversation" : "Bendrinti pokalbyje",
    "Share with {user} on remote server {server}" : "Bendrinti su {user} nuotoliniame serveryje {server}",
    "Share with remote group" : "Bendrinti su nuotoline grupe",
    "Share with guest" : "Bendrinti su svečiu",
    "Update share" : "Atnaujinti bendrinimą",
    "Save share" : "Įrašyti bendrinimą",
    "Read" : "Skaityti",
    "Create" : "Sukurti",
    "Edit" : "Taisyti",
    "Share" : "Bendrinti",
    "Delete" : "Ištrinti",
    "Password field cannot be empty" : "Slaptažodžio laukelis negali būti tuščias",
    "Replace current password" : "Pakeisti esamą slaptažodį",
    "Failed to generate a new token" : "Nepavyko sugeneruoti naujo žymens",
    "Allow upload and editing" : "Leisti įkelti ir redaguoti",
    "Allow editing" : "Leisti redaguoti",
    "Upload only" : "Tik įkelti",
    "Advanced settings" : "Išplėstiniai nustatymai",
    "Share label" : "Bendrinimo etiketė",
    "Share link token" : "Pasidalinti nuorodos žymeniu",
    "Set the public share link token to something easy to remember or generate a new token. It is not recommended to use a guessable token for shares which contain sensitive information." : "Nustatykite viešosios nuorodos žymenį taip, kad jį būtų lengva įsiminti, arba sugeneruokite naują žymenį. Nerekomenduojama naudoti lengvai atspėjamą žymenį, jei dalinatės slapta informacija.",
    "Generating…" : "Generuojama…",
    "Generate new token" : "Generuoti naują žymenį",
    "Set password" : "Nustatyti slaptažodį",
    "Password expires {passwordExpirationTime}" : "Slaptažodis galioja iki {passwordExpirationTime}",
    "Password expired" : "Slaptažodis nebegalioja",
    "Video verification" : "Video patikrinimas",
    "Expiration date (enforced)" : "Galiojimo pabaigos data (nustatyta)",
    "Set expiration date" : "Nustatyti galiojimo pabaigos datą",
    "Hide download" : "Slėpti atsisiuntimą",
    "Allow download and sync" : "Leisti atsisiųsti ir sinchronizuoti",
    "Note to recipient" : "Pastaba gavėjui",
    "Enter a note for the share recipient" : "Įrašykite pranešimą bendrinimo gavėjui",
    "Show files in grid view" : "Rodyti failus lentelės formatu",
    "Delete share" : "Ištrinti bendrinimą",
    "Others with access" : "Kiti asmenys, turintys prieigą",
    "No other accounts with access found" : "Nerasta jokių kitų paskyrų, turinčių prieigą",
    "Toggle list of others with access to this directory" : "Perjungti sąrašą kitų asmenų, turinčių prieigą prie šio katalogo",
    "Toggle list of others with access to this file" : "Perjungti sąrašą kitų asmenų, turinčių prieigą prie šio failo",
    "Unable to fetch inherited shares" : "Nepavyko gauti paveldėtų bendrinimų",
    "Link shares" : "Nuorodos dalijimasis",
    "Shares" : "Bendrinimai",
    "Share files within your organization. Recipients who can already view the file can also use this link for easy access." : "Dalykitės failais savo organizacijoje. Gavėjai, kurie jau gali peržiūrėti failą, taip pat gali naudoti šią nuorodą, kad lengvai prie jo prisijungtų.",
    "Share files with others outside your organization via public links and email addresses. You can also share to {productName} accounts on other instances using their federated cloud ID." : "Dalinkitės failais su asmenimis už organizacijos ribų naudodami viešas nuorodas ir el. pašto adresus. Taip pat galite dalintis su {productName} paskyromis kitose instancijose, naudodami jų federacinės debesijos ID.",
    "Shares from apps or other sources which are not included in internal or external shares." : "Dalijimasis iš programėlių ar kitų šaltinių, kurie nėra įtraukti į vidinį ar išorinį dalijimąsi.",
    "Type names, teams, federated cloud IDs" : "Tipų pavadinimai, komandos, federaciniės debesijos identifikatoriai",
    "Type names or teams" : "Įveskite vardus arba komandas",
    "Type a federated cloud ID" : "Įveskite federacinės debesijos ID",
    "Type an email" : "Įveskite el. pašto adresą",
    "Type an email or federated cloud ID" : "Įveskite el. pašto adresą arba federacinės debesijos ID",
    "Unable to load the shares list" : "Nepavyko įkelti bendrinimų sąrašo",
    "Expires {relativetime}" : "Galioja iki {relativetime}",
    "this share just expired." : "šis bendrinimas ką tik nustojo galioti.",
    "Shared with you by {owner}" : "{owner} pasidalino su jumis",
    "Internal shares" : "Vidiniai bendrinimai",
    "Internal shares explanation" : "Vidinių bendrinimų paaiškinimas",
    "External shares" : "Išoriniai bendrinimai",
    "External shares explanation" : "Išorinių bendrinimų paaiškinimas",
    "Additional shares" : "Papildomi bendrinimai",
    "Additional shares explanation" : "Papildomų bendrinimų paaiškinimas",
    "Link to a file" : "Nuoroda į failą",
    "_Accept share_::_Accept shares_" : ["Priimti bendrinimą","Priimti bendrinimus","Priimti bendrinimus","Priimti bendrinimus"],
    "Open in Files" : "Atidaryti programėlėje „Failai“",
    "_Reject share_::_Reject shares_" : ["Atmesti bendrinimą","Atmesti bendrinimus","Atmesti bendrinimus","Atmesti bendrinimus"],
    "_Restore share_::_Restore shares_" : ["Atkurti bendrinimą","Atkurti bendrinimus","Atkurti bendrinimus","Atkurti bendrinimus"],
    "Shared" : "Bendrinama",
    "Shared by {ownerDisplayName}" : "Bendrina {ownerDisplayName}",
    "Shared multiple times with different people" : "Dalijimasis kelis kartus su skirtingais žmonėmis",
    "Sharing options" : "Bendrinimo parinktys",
    "Shared with others" : "Bendrinama su kitais",
    "You do not have enough permissions to share this file." : "Jūs neturite pakankamų teisių bendrinti šį failą.",
    "People" : "Žmonės",
    "Create file request" : "Sukurti failo užklausą",
    "Upload files to {foldername}" : "Įkelti failus į {foldername}",
    "Public file share" : "Viešas failų bendrinimas",
    "Publicly shared file." : "Viešai bendrinamas failas.",
    "No file" : "Failo nėra",
    "The file shared with you will show up here" : "Čia bus rodomas su jumis bendrinamas failas",
    "Public share" : "Viešasis bendrinimas",
    "Publicly shared files." : "Viešai pasidalintas failas.",
    "No files" : "Failų nėra",
    "Files and folders shared with you will show up here" : "Čia bus rodomi su jumis bendrinami failai ir aplankai",
    "Overview of shared files." : "Bendrinamų failų apžvalga.",
    "No shares" : "Nėra jokių bendrinimų",
    "Files and folders you shared or have been shared with you will show up here" : "Čia bus rodomi failai ir aplankai, kuriais pasidalinote arba kurie buvo pasidalinti su jumis",
    "Shared with you" : "Bendrinama su jumis",
    "List of files that are shared with you." : "Failų, kurie yra bendrinami su jumis, sąrašas.",
    "Nothing shared with you yet" : "Kol kas su jumis nieko nėra bendrinama",
    "Files and folders others shared with you will show up here" : "Čia bus rodomi failai ir aplankai, kuriuos su jumis bendrina kiti asmenys",
    "List of files that you shared with others." : "Failų, kuriuos bendrinote su kitais, sąrašas.",
    "Nothing shared yet" : "Kol kas nieko nebendrinama",
    "Files and folders you shared will show up here" : "Čia atsiras visi jūsų bendrinami failai ar aplankai",
    "Shared by link" : "Bendrinama pagal nuorodą",
    "List of files that are shared by link." : "Failų, kurie yra bendrinami su jumis, sąrašas.",
    "No shared links" : "Nėra bendrinamų nuorodų",
    "Files and folders you shared by link will show up here" : "Čia bus rodomi failai ir aplankai, kuriuos bendrinate per nuorodą",
    "File requests" : "Failų užklausos",
    "List of file requests." : "Failų užklausų sąrašas",
    "No file requests" : "Nėra failų užklausų",
    "File requests you have created will show up here" : "Čia bus rodomos jūsų sukurtos failų užklausos",
    "Deleted shares" : "Ištrinti bendrinimai",
    "List of shares you left." : "Jūsų paliktų bendrinimų sąrašas.",
    "No deleted shares" : "Ištrintų bendrinimų nėra",
    "Shares you have left will show up here" : "Čia bus rodomi Jūsų palikti bendrinimai",
    "Pending shares" : "Laukiantys bendrinimai",
    "List of unapproved shares." : "Nepatvirtintų bedrinimų sąrašas",
    "No pending shares" : "Nėra jokių laukiančių bendrinimų",
    "Shares you have received but not approved will show up here" : "Čia bus rodomi gauti, bet nepatvirtinti bendrinimai",
    "Error deleting the share" : "Klaida ištrinant bendrinimą",
    "Error updating the share" : "Klaida atnaujinant bendrinimą",
    "File \"{path}\" has been unshared" : "Failas „{path}“ nustotas bendrinti",
    "Folder \"{path}\" has been unshared" : "Aplankas „{path}“ nustotas bendrinti",
    "Could not update share" : "Nepavyko atnaujinti bendrinimo",
    "Share saved" : "Bendrinimas įrašytas",
    "Share expiry date saved" : "Bendrinimo galiojimo data išsaugota",
    "Share hide-download state saved" : "Bendrinimo slėpimo ir atsisiuntimo būsena išsaugota",
    "Share label saved" : "Bendrinimo etiketė įrašyta",
    "Share note for recipient saved" : "Gavėjo bendrinimo pastaba išsaugota",
    "Share password saved" : "Bendrinimo slaptažodis įrašytas",
    "Share permissions saved" : "Bendrinimo leidimai įrašyti",
    "To upload files to {folder}, you need to provide your name first." : "Norėdami įkelti failus į {folder}, pirmiausia turite pateikti savo vardą.",
    "Upload files to {folder}" : "Įkelti failus į {folder}",
    "Please confirm your name to upload files to {folder}" : "Patvirtinkite savo vardą, kad galėtumėte įkelti failus į {folder}",
    "{ownerDisplayName} shared a folder with you." : "{ownerDisplayName} pradėjo bendrinti su jumis aplanką.",
    "Names must not be empty." : "Laukelis „Vardai“ negali būti tušti.",
    "Names must not start with a dot." : "Vardai negali prasidėti tašku.",
    "\"{char}\" is not allowed inside a name." : "„{char}“ negalima naudoti vardo sudėtyje.",
    "\"{segment}\" is a reserved name and not allowed." : "„{segment}“ yra rezervuotas vardas, todėl jo naudoti negalima.",
    "\"{extension}\" is not an allowed name." : "„{extension}“ nėra leidžiamas vardas.",
    "Names must not end with \"{extension}\"." : "Vardo pabaiga negali būti „{extension}“.",
    "Invalid name." : "Negalimas vardas",
    "Password created successfully" : "Slaptažodis sėkmingai sukurtas",
    "Error generating password from password policy" : "Klaida kuriant slaptažodį pagal slaptažodžių politiką",
    "Shared with you and the group {group} by {owner}" : "{owner} pradėjo bendrinti su jumis ir grupe {group}",
    "Shared with you and {circle} by {owner}" : "{owner} pradėjo bendrinti su jumis ir {circle}",
    "Shared with you and the conversation {conversation} by {owner}" : "{owner} pasidalino su jumis ir pokalbiu {conversation}",
    "Shared with you in a conversation by {owner}" : "{owner} pasidalino su jumis pokalbyje",
    "Share not found" : "Bendrinimas nerastas",
    "Back to %s" : "Atgal į %s",
    "Add to your Nextcloud" : "Pridėti į savo „Nextcloud“",
    "Group sharing is disabled by the administrator" : "Administratorius išjungė bendrinimą su grupėmis",
    "Public link sharing is disabled by the administrator" : "Administratorius išjungė bendrinimą per viešąsias nuorodas",
    "Sharing %1$s failed because the back end does not allow shares from type %2$s" : "Bendrinimas %1$s nepavyko, kadangi sistema nepalaiko bendrinimų šio tipo %2$s",
    "Sharing %s failed because the back end does not support ScienceMesh shares" : "Dalijimasis %s nepavyko, nes serveris nepalaiko „ScienceMesh“ dalijimosi",
    "Public upload disabled by the administrator" : "Įkėlimas viešam naudojimui yra išjungtas",
    "Tokens must contain at least 1 character and may only contain letters, numbers, or a hyphen" : "Žymuo turi būti sudarytas iš ne mažiau kaip 1 simbolio ir gali būti sudarytas tik iš raidžių, skaičių arba brūkšnelio",
    "Name or email …" : "Vardas ar el. paštas…",
    "Name, email, or Federated Cloud ID …" : "Vardas, el. paštas ar federacinės debesijos ID…",
    "Searching …" : "Ieškoma…"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
