OC.L10N.register(
    "files_trashbin",
    {
    "restored" : "restaurado",
    "Deleted files" : "Archivos borrados",
    "Deleted files and folders in the trash bin (may expire during export if you are low on storage space)" : "Archivos y carpetas eliminados en la papelera de reciclaje (pueden expirar durante la exportación si tienes poco espacio de almacenamiento)",
    "Restore" : "Restaurar",
    "Cancel" : "Cancelar",
    "Deleted" : "Borrado",
    "A long time ago" : "Hace mucho tiempo.",
    "Unknown" : "Desconocido",
    "All files" : "Todos los archivos",
    "List of files that have been deleted." : "Lista de archivos que han sido eliminados.",
    "No deleted files" : "No hay archivos borrados",
    "Files and folders you have deleted will show up here" : "Los archivos y carpetas que has eliminado aparecerán aquí. "
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
