OC.L10N.register(
    "bruteforcesettings",
    {
    "Brute-force settings" : "Axustes contra ataques por forza bruta",
    "Whitelist IPs" : "Lista de autorización de IP",
    "Brute-force protection is meant to protect Nextcloud servers from attempts to\nguess account passwords in various ways. Besides the obvious \"*let's try a big\nlist of commonly used passwords*\" attack, it also makes it harder to use\nslightly more sophisticated attacks via the reset password form or trying to\nfind app password tokens.\n\nIf triggered, brute-force protection makes requests coming from an IP on a\nbrute-force protected controller with the same API slower for a 24 hour period.\n\nWith this app, the admin can exempt an IP address or range from this\nprotection which can be useful for testing purposes or when there are false\npositives due to a lot of accounts on one IP address." : "A protección contra ataques por forza bruta está deseñada para protexer os\nservidores NextCloud de intentos de obter os contrasinais das contas de varias\nmaneiras. Ademais do ataque máis obvio «*imos probar unha gran lista de\ncontrasinais frecuentes*», tamén dificulta o uso de ataques máis sofisticados como\nos feitos a través do formulario de restabelecemento do contrasinal ou tentando\natopar os testemuños de contrasinais da aplicación.\n\nSe está activada, a protección fai que as solicitudes que proveñan dese IP se\nredirixan a un controlador protexido contra forza bruta coa mesma API de xeito\nmáis lento durante un período de 24 horas.\n\nCon esta aplicación, o administrador pode eximir un IP ou un intervalo deles desta\nprotección, pode ser útil para fins de proba ou cando haxa falsos positivos\npor mor dunha gran cantidade de usuarios nun mesmo enderezo IP.",
    "The comment cannot exceed {max} characters." : "O comentario non pode superar {max} caracteres.",
    "Leave an internal comment explaining why this IP address is allowed, for example its location, so the entry can be removed when it is no longer needed." : "Deixa un comentario interno explicando por que este enderezo IP está permitido, por exemplo a súa localización, para que a entrada poida ser eliminada cando xa non sexa necesaria.",
    "Your current IP address is detected as \"{remoteAddress}\". This address is currently throttled. Current delay: {delay} ms." : "O teu enderezo IP actual é detectado como \"{remoteAddress}\". Este enderezo está actualmente limitado. Atraso actual: {delay} ms.",
    "Your current IP address is detected as \"{remoteAddress}\". This address bypasses brute-force protection." : "O teu enderezo IP actual é detectado como \"{remoteAddress}\". Este enderezo evita a protección contra ataques de forza bruta.",
    "Your current IP address is detected as \"{remoteAddress}\". This address is not currently throttled." : "O teu enderezo IP actual é detectado como \"{remoteAddress}\". Este enderezo non está actualmente limitado.",
    "Failed to add the IP address to the allow list." : "Fallou ao engadir o enderezo IP á lista de permitidos.",
    "Failed to save the rate limit setting." : "Fallou ao gardar o axuste de límite de taxa.",
    "Failed to update the allow list entry." : "Fallou ao actualizar a entrada da lista de permitidos.",
    "Brute-force allow list" : "Lista de permitidos para ataques por forza bruta",
    "To exclude IP ranges from the brute-force protection specify them below. Note that any allowed IP can perform authentication attempts without any throttling. For security reasons, it is recommended to list as few remote addresses as possible or ideally even none at all." : "Para incluír intervalos de IP na lista de permitidos da protección contra ataques por forza bruta, especifíqueos embaixo. Teña en conta que calquera IP na lista de IP permitidos pode realizar intentos de autenticación sen ningunha restrición. Por mor da seguranza, recomendase incluír na lista de permitidos o menor número posíbel de enderezos remotos ou incluso, idealmente, ningún.",
    "Bypass rate limiting for allowed IPs" : "Omisión da taxa de limitación para os IP permitidos",
    "Add new IP address" : "Engadir un novo enderezo IP",
    "IP address" : "Enderezo IP",
    "Mask" : "Máscara",
    "Comment" : "Comentario",
    "Add" : "Engadir",
    "Edit comment for {subnet}" : "Editar o comentario para {subnet}",
    "Save" : "Gardar",
    "Delete entry for {subnet}" : "Eliminar a entrada para {subnet}",
    "Comment cannot exceed {max} characters." : "O comentario non pode exceder de {max} caracteres.",
    "Leave an internal comment, why this IP is allowed, e.g. the  location, so it can be revoked, when it is no longer needed." : "Deixe un comentario interno explicando por que está permitida este IP, p. ex., a localización, para que poida ser revogada, cando xa non sexa necesaria.",
    "Your remote address was identified as \"{remoteAddress}\" and is throttled at the moment by {delay}ms." : "O seu enderezo remoto foi identificado como «{remoteAddress}» e neste momento ten unha estrangulación de {delay}ms.",
    "Your remote address was identified as \"{remoteAddress}\" and is bypassing brute-force protection." : "O seu enderezo remoto foi identificado como «{remoteAddress}» e está a eludir a protección da forza bruta.",
    "Your remote address was identified as \"{remoteAddress}\" and is not actively throttled at the moment." : "O seu enderezo remoto foi identificado como «{remoteAddress}» e non está a ser estrangulada activamente neste momento",
    "There was an error adding the IP to the allow list." : "Produciuse un erro ao engadir o IP á lista de permitidos.",
    "There was an error updating the allow list entry." : "Produciuse un erro ao actualizar a entrada da lista de permitidos."
},
"nplurals=2; plural=(n != 1);");
