OC.L10N.register(
    "files_pdfviewer",
    {
    "Failed to load settings" : "Mistókst að hlaða inn stillingum",
    "Failed to save settings" : "Mistókst að vista stillingar"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
