OC.L10N.register(
    "app_api",
    {
    "Cancel" : "Prekliči",
    "Delete" : "Izbriši",
    "Default" : "privzeto",
    "Edit" : "Uredi",
    "Unlimited" : "Neomejeno",
    "Name" : "Ime",
    "Host" : "Gostitelj",
    "Nextcloud URL" : "Naslov URL Nextcloud",
    "Memory limit" : "Omejitev pomnilnika",
    "Enabled" : "Omogočeno",
    "More information" : "Več podrobnosti",
    "Remove" : "Odstrani",
    "From" : "Od",
    "To" : "Za",
    "Add" : "Dodaj",
    "Display name" : "Prikazno ime",
    "Confirm" : "Potrdi",
    "Save" : "Shrani",
    "Register" : "Vpis računa",
    "{license}-licensed" : "dovoljenje {license}",
    "Update to {version}" : "Posodobitev na različico {version}",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Program nima določene omejitve različice okolja Nextcloud. V prihodnosti se bo manjkajoči podatek pokazal kot napaka.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Program nima določene omejitve različice okolja Nextcoud. V prihodnosti se bo manjkajoči podatek pokazal kot napaka.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Programa ni mogoče namestiti zaradi nerazrešenih odvisnosti:",
    "View in store" : "Pokaži v trgovini",
    "Visit website" : "Odpri spletno stran",
    "Report a bug" : "Pošlji poročilo o hrošču",
    "User documentation" : "Uporabniška dokumentacija",
    "Admin documentation" : "Skrbniška dokumentacija",
    "Developer documentation" : "Dokumentacija za razvijalce",
    "This app is supported via your current Nextcloud subscription." : "Program je podprt prek trenutne naročnine Nextcloud",
    "Supported" : "Podprto",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Uradne programe razvijajo posamezniki, ki sodelujejo s skupnostjo. Paketi vključujejo osrednje zmožnosti programa, uporaba pa je namenjena tudi končnim uporabnikom.",
    "Featured" : "Izbrano",
    "Update to {update}" : "Posodobi na različico {update}",
    "Icon" : "Ikona",
    "Version" : "Različica",
    "Daemon" : "Ozadnji program",
    "Level" : "Vloga",
    "Actions" : "Dejanja",
    "Results from other categories" : "Rezultati iskanja med drugimi kategorijami",
    "_Update_::_Update all_" : ["Posodobi","Posodobi","Posodobi","Posodobi vse"],
    "Type" : "Vrsta",
    "Network" : "Omrežje",
    "by {author}\n{license}" : "Razvoj: {author}\nDovoljenje: {license}",
    "Your apps" : "Vsi programi",
    "Documentation" : "Dokumentacija",
    "Details" : "Podrobnosti",
    "Changelog" : "Dnevnik sprememb",
    "Active apps" : "Zagnani programi",
    "Disabled apps" : "Onemogočeni programi",
    "Updates" : "Posodobitve",
    "Featured apps" : "Predlagani programi",
    "Supported apps" : "Podprti programi",
    "Enable" : "Omogoči",
    "Disable" : "Onemogoči",
    "Allow untested app" : "Omogoči nepreizkušen program",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Ta program ni označen kot skladen z nameščeno različico oblaka Nextcloud. Če nameravate nadaljevati, boste program lahko namestili, vendar ta morda ne bo deloval po pričakovanjih, ali pa bo vplival na stabilnost sistema.",
    "An error occurred during the request. Unable to proceed." : "Med izvajanjem zahteve je prišlo do napake, zato ni mogoče nadaljevati.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Napaka: tega programa ni mogoče namestiti, ker povzroča nestabilnost strežnika."
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
