OC.L10N.register(
    "lookup_server_connector",
    {
    "Lookup Server Connector" : "Conector de Servidor de Pesquisa",
    "Sync public account information with the lookup server" : "Sincronize informações de contas públicas com o servidor de pesquisa"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
