OC.L10N.register(
    "office",
    {
    "Office" : "Oifig",
    "Office overview" : "Forbhreathnú ar an oifig",
    "Office overview app for Nextcloud" : "Aip forbhreathnaithe Oifige do Nextcloud",
    "Create new" : "Cruthaigh nua",
    "Scroll left" : "Scrollaigh ar chlé",
    "Scroll right" : "Scrollaigh ar dheis",
    "Blank" : "Bán",
    "Search {category}" : "Cuardaigh {category}",
    "Search" : "Cuardach",
    "Failed to create file" : "Theip ar chomhad a chruthú",
    "Failed to load files" : "Theip ar na comhaid a luchtú",
    "No office suite installed" : "Gan aon shraith oifige suiteáilte",
    "{count} found in {category}" : "{count} aimsithe i {category}",
    "Recent {category}" : "Le déanaí {category}",
    "Filter files" : "Scag comhaid",
    "All" : "Gach",
    "Mine" : "Mianach",
    "Shared with me" : "Roinnte liom",
    "Switch to grid view" : "Téigh go dtí an radharc greille",
    "Switch to list view" : "Athraigh go dtí an amharc liosta",
    "No {category} found" : "Níor aimsíodh aon {category}",
    "Switch to \"All\" to see every file you have access to" : "Athraigh go \"Uile\" chun gach comhad a bhfuil rochtain agat air a fheiceáil",
    "Search all in Files" : "Cuardaigh gach rud i gComhaid",
    "Show all in Files" : "Taispeáin gach rud i gComhaid",
    "Create" : "Cruthaigh",
    "Filename" : "Ainm comhaid",
    "Documents" : "Doiciméid",
    "Spreadsheets" : "Scarbhileoga",
    "Presentations" : "Cur i láthair",
    "Diagrams" : "Léaráidí",
    "Filename cannot be empty" : "Ní féidir leis an ainm comhaid a bheith folamh",
    "Filename contains invalid characters" : "Tá carachtair neamhbhailí san ainm comhaid",
    "{count} {category} found" : "{count} {category} aimsithe"
},
"nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");
