OC.L10N.register(
    "suspicious_login",
    {
    "New login location detected" : "Примећена нова локација пријаве",
    "More info about the suspicious IP address available on %s" : "На %s се налази још информација у вези са сумњивом IP адресом",
    "Open %s ↗" : "Отвори %s ↗",
    "Suspicious Login" : "Сумњиве Пријаве",
    "New login detected" : "Примећена нова пријава",
    "Detect and warn about suspicious IPs logging into Nextcloud\n\t" : "Детектуј и обавештавај о сумњивим IP адресама које се пријављују на Некстклауд\n\t",
    "A new login into your account was detected. The IP address %s was classified as suspicious. If this was you, you can ignore this message. Otherwise you should change your password." : "Примећена је нова пријава на Ваш налог. IP адреса %s хе класификована као сумњива. Ако сте ово били ви, игноришите ову поруку. Иначе бисте требали да измените лозинку."
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
