OC.L10N.register(
    "files",
    {
    "Added to favorites" : "Ajouté aux favoris",
    "Removed from favorites" : "Retiré des favoris",
    "You added {file} to your favorites" : "Vous avez ajouté {file} à vos favoris",
    "You removed {file} from your favorites" : "Vous avez retiré {file} de vos favoris",
    "Favorites" : "Favoris",
    "File changes" : "Modifications de fichiers",
    "Created by {user}" : "Créé par {user}",
    "Changed by {user}" : "Modifié par {user}",
    "Deleted by {user}" : "Supprimé par {user}",
    "Restored by {user}" : "Restauré par {user}",
    "Renamed by {user}" : "Renommé par {user}",
    "Moved by {user}" : "Déplacé par {user}",
    "\"remote account\"" : "\"compte distant\"",
    "You created {file}" : "Vous avez créé {file}",
    "You created an encrypted file in {file}" : "Vous avez créé un fichier chiffré dans {file}",
    "{user} created {file}" : "{user} a créé {file}",
    "{user} created an encrypted file in {file}" : "{user} a créé un fichier chiffré dans {file}",
    "{file} was created in a public folder" : "{file} a été créé dans un dossier public",
    "You changed {file}" : "Vous avez modifié {file}",
    "You changed an encrypted file in {file}" : "Vous avez modifié un fichier chiffré dans {file}",
    "{user} changed {file}" : "{user} a modifié {file}",
    "{user} changed an encrypted file in {file}" : "{user} a modifié un fichier chiffré dans {file}",
    "You deleted {file}" : "Vous avez supprimé {file}",
    "You deleted an encrypted file in {file}" : "Vous avez supprimé un fichier chiffré dans {file}",
    "{user} deleted {file}" : "{user} a supprimé {file}",
    "{user} deleted an encrypted file in {file}" : "{user} a supprimé un fichier chiffré dans {file}",
    "You restored {file}" : "Vous avez restauré {file}",
    "{user} restored {file}" : "{user} a restauré {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Vous avez renommé {oldfile} (hidden) en {newfile} (hidden)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Vous avez renommé {oldfile} (hidden) en {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Vous avez renommé {oldfile} en {newfile} (hidden)",
    "You renamed {oldfile} to {newfile}" : "Vous avez renommé {oldfile} en {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} a renommé {oldfile} (hidden) en {newfile} (hidden)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} a renommé {oldfile} (hidden) en {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} a renommé {oldfile} en {newfile} (hidden)",
    "{user} renamed {oldfile} to {newfile}" : "{user} a renommé {oldfile} en {newfile}",
    "You moved {oldfile} to {newfile}" : "Vous avez déplacé {oldfile} dans {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} a déplacé {oldfile} dans {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Un fichier a été ajouté ou retiré de vos <strong>favoris</strong>",
    "Files" : "Fichiers",
    "A file or folder has been <strong>changed</strong>" : "Un fichier ou un dossier a été <strong>modifié</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "Un fichier ou un dossier favori a été <strong>modifié </strong>",
    "Failed to authorize" : "Échec de l'autorisation",
    "Invalid folder path" : "Chemin d'accès du dossier invalide",
    "Folder not found" : "Dossier introuvable",
    "The file cannot be found" : "Le fichier n'a pas pu être trouvé",
    "The destination path does not exist: %1$s" : "Le chemin de destination %1$s n'existe pas",
    "You do not have permission to create a file at the specified location" : "Vous n'avez pas la permission de créer un fichier à l'endroit spécifié",
    "The file could not be converted." : "Le fichier n'a pas pu être converti",
    "Could not get relative path to converted file" : "Impossible de récupérer le chemin relatif du fichier converti",
    "Limit must be a positive integer." : "La limite doit être un nombre entier positif.",
    "The replacement character may only be a single character." : "Le caractère de remplacement ne peut être qu'un caractère seul.",
    "Filename sanitization already started." : "Le nettoyage des noms de fichiers a déjà commencé.",
    "No filename sanitization in progress." : "Aucun nettoyage de nom de fichier en cours.",
    "Favorite files" : "Fichiers favoris",
    "No favorites" : "Aucun favori",
    "More favorites" : "Plus de favoris",
    "No read permission on file." : "Aucune autorisation de lecture sur le fichier.",
    "Accept" : "Accepter",
    "Reject" : "Refuser",
    "Incoming ownership transfer from {user}" : "Transfert de propriété de la part de {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Voulez-vous accepter {path} ?\n\nN. B. : L'opération de transfert après acceptation peut prendre jusqu'à 1 heure.",
    "Ownership transfer denied" : "Transfert de propriété refusé",
    "Your ownership transfer of {path} was denied by {user}." : "Votre transfert de propriété de {path} a été refusé par {user}.",
    "Ownership transfer failed" : "Le transfert de propriétaire a échoué",
    "Your ownership transfer of {path} to {user} failed." : "Votre transfert de propriété de {path} à {user} a échoué.",
    "The ownership transfer of {path} from {user} failed." : "Le transfert de propriété de {path} de {user} a échoué.",
    "Ownership transfer done" : "Transfert de propriétaire terminé",
    "Your ownership transfer of {path} to {user} has completed." : "Votre transfert de propriété de {path} à {user} est terminé.",
    "The ownership transfer of {path} from {user} has completed." : "Le transfert de propriété de {path} de {user} est terminé.",
    "in %s" : "dans %s",
    "Transferred from %1$s on %2$s" : "Transféré de %1$s à %2$s",
    "Create files" : "Créer des fichiers",
    "Delete files" : "Supprimer les fichiers",
    "Download files" : "Télécharger des fichiers",
    "When disabled, the option to download will be hidden" : "Lorsque cette option est désactivée, l'option de téléchargement est masquée.",
    "View files" : "Afficher les fichiers",
    "Edit files" : "Modifier les fichiers",
    "Show files in grid view" : "Afficher les fichiers dans la vue en grille",
    "File" : "Fichier",
    "File Management" : "Gestion de fichiers",
    "Home" : "Accueil",
    "Target folder does not exist any more" : "Le dossier cible n'existe plus",
    "Reload current directory" : "Rafraîchir le dossier courant",
    "Go to the \"{dir}\" directory" : "Aller au dossier \"{dir}\"",
    "Current directory path" : "Chemin du répertoire courant",
    "Share" : "Partager",
    "Reload content" : "Recharger le contenu",
    "Your have used your space quota and cannot upload files anymore" : "Vous avez utilisé votre quota d'espace et vous ne pouvez plus téléverser de fichiers",
    "You do not have permission to upload or create files here." : "Vous n'avez pas la permission de téléverser ou créer des fichiers ici.",
    "Drag and drop files here to upload" : "Glissez-déposez les fichiers ici pour les téléverser",
    "Favorite" : "Favoris",
    "Back" : "Retour",
    "Toggle selection for file \"{displayName}\"" : "Basculer la sélection pour le fichier \"{displayName}\"",
    "Toggle selection for folder \"{displayName}\"" : "Basculer la sélection pour le dossier \"{displayName}\"",
    "File is loading" : "Fichier en cours de chargement",
    "Folder is loading" : "Dossier en cours de chargement",
    "Filename" : "Nom du fichier",
    "Folder name" : "Nom du dossier",
    "{displayName} (unavailable)" : "{displayName} (indisponible)",
    "Another entry with the same name already exists." : "Une autre entrée avec le même nom existe déjà.",
    "Invalid filename." : "Nom de fichier invalide.",
    "Rename file" : "Renommer le fichier",
    "Recently created" : "Créé récemment",
    "Folder" : "Dossier",
    "Unknown file type" : "Type de fichier inconnu",
    "{ext} image" : "{ext} image",
    "{ext} video" : "{ext} vidéo",
    "{ext} audio" : "{ext} audio",
    "{ext} text" : "{ext} texte",
    "Pending" : "En attente",
    "Unknown date" : "Date inconnue",
    "Active filters" : "Filtres actifs",
    "Remove filter" : "Retirer le filtre",
    "Today" : "Aujourd’hui",
    "Last 7 days" : "7 derniers jours",
    "Last 30 days" : "30 derniers jours",
    "This year ({year})" : "Cette année ({year})",
    "Last year ({year})" : "L'année dernière ({year})",
    "Custom range" : "Plage personnalisée",
    "Custom date range" : "Plage de dates personnalisée",
    "Search everywhere" : "Rechercher partout",
    "Documents" : "Documents",
    "Spreadsheets" : "Feuilles de calcul",
    "Presentations" : "Présentations",
    "PDFs" : "PDFs",
    "Folders" : "Dossiers",
    "Audio" : "Audio",
    "Images" : "Images",
    "Videos" : "Vidéos",
    "Filters" : "Filtres",
    "Back to filters" : "Retour aux filtres",
    "Appearance" : "Apparence",
    "Show hidden files" : "Montrer les fichiers masqués",
    "Show file type column" : "Afficher la colonne du type de fichier",
    "Show file extensions" : "Afficher les extensions de fichiers",
    "Crop image previews" : "Afficher en miniatures carrées",
    "General" : "Général",
    "Sort favorites first" : "Trier les favoris en premier",
    "Sort folders before files" : "Trier les dossiers avant les fichiers",
    "Enable folder tree view" : "Activer la vue en arborescence des dossiers",
    "Default view" : "Vue par défaut",
    "All files" : "Tous les fichiers",
    "Personal files" : "Fichiers personnels",
    "Additional settings" : "Paramètres supplémentaires",
    "Actions" : "Actions",
    "File actions" : "Actions sur le fichier",
    "Selection" : "Choix",
    "Select all files" : "Sélectionner tous les fichiers",
    "Deselect all" : "Tout désélectionner",
    "Select or deselect" : "Sélectionner ou désélectionner",
    "Select a range" : "Sélectionner une plage",
    "Navigation" : "Navigation",
    "Go to parent folder" : "Aller au dossier parent",
    "Go to file above" : "Aller au fichier au-dessus",
    "Go to file below" : "Aller au fichier au-dessous",
    "Go left in grid" : "Aller à gauche dans la grille",
    "Go right in grid" : "Aller à droite dans la grille",
    "View" : "Voir",
    "Toggle grid view" : "Activer/Désactiver l'affichage mosaïque",
    "Show those shortcuts" : "Montrer ces raccourcis",
    "Warnings" : "Avertissements",
    "Warn before changing a file extension" : "Avertir avant de modifier l'extension d'un fichier",
    "Warn before deleting a file" : "Avertir avant de supprimer un fichier",
    "WebDAV URL" : "URL WebDAV",
    "Create an app password" : "Créer un mot de passe d'application",
    "Required for WebDAV authentication because Two-Factor Authentication is enabled for this account." : "Requis pour l'authentification WebDAV car l'authentification à deux facteurs est activée pour ce compte.",
    "How to access files using WebDAV" : "Comment accéder aux fichiers en utilisant WebDAV",
    "Total rows summary" : "Récapitulatif du nombre total de lignes",
    "Toggle selection for all files and folders" : "Basculer la sélection pour tous les fichiers et dossiers",
    "Name" : "Nom",
    "File type" : "Type de fichier",
    "Size" : "Taille",
    "Modified" : "Modifié",
    "{displayName}: failed on some elements" : "{displayName} : a échoué pour certains éléments",
    "{displayName}: done" : "{displayName} : terminé",
    "{displayName}: failed" : "{displayName} : échec",
    "(selected)" : "(sélectionné)",
    "List of files and folders." : "Liste des fichiers et dossiers.",
    "You have used your space quota and cannot upload files anymore." : "Vous avez utilisé votre quota d'espace et vous ne pouvez plus téléverser de fichiers",
    "Column headers with buttons are sortable." : "L'entête des colonnes avec des boutons sont triables.",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Cette liste n'est pas entièrement affichée pour des raisons de performances. Les fichiers seront affichés au fur et à mesure que vous naviguerez dans la liste.",
    "File not found" : "Fichier non trouvé",
    "_{count} selected_::_{count} selected_" : ["{count} sélectionné","{count} sélectionné(s)","{count} sélectionné(s)"],
    "Views" : "Vues",
    "Search everywhere …" : "Rechercher partout …",
    "Search here …" : "Rechercher ici …",
    "Search scope options" : "Options de portée de recherche",
    "Search here" : "Rechercher ici",
    "Owner" : "Propriétaire",
    "{usedQuotaByte} used" : "{usedQuotaByte} utilisés",
    "{used} of {quota} used" : "{used} utilisés sur {quota}",
    "{relative}% used" : "{relative}% utilisés",
    "Could not refresh storage stats" : "Impossible de rafraîchir les statistiques de stockage",
    "Your storage is full, files can not be updated or synced anymore!" : "Votre espace de stockage est plein. Les fichiers ne peuvent plus être mis à jour ni synchronisés !",
    "Storage information" : "Informations sur le stockage",
    "Storage quota" : "Quota de stockage",
    "New folder" : "Nouveau dossier",
    "Create new folder" : "Créer un nouveau dossier",
    "This name is already in use." : "Ce nom est déjà utilisé.",
    "Create" : "Créer",
    "Files starting with a dot are hidden by default" : "Les fichiers commençants par un point sont masqués par défaut",
    "Failed to start filename sanitization." : "Impossible de lancer le nettoyage de nom de fichier.",
    "Failed to refresh filename sanitization status." : "Impossible d'actualiser le statut du nettoyage de nom de fichier.",
    "Filename sanitization in progress." : "Nettoyage de nom de fichier en cours.",
    "Currently {processedUsers} of {totalUsers} accounts are already processed." : "Actuellement, {processedUsers} sur {totalUsers} comptes ont déjà été traités.",
    "Preparing …" : "Préparation …",
    "Refresh" : "Actualiser",
    "All files have been santized for Windows filename support." : "Tous les fichiers ont été nettoyés pour être compatibles avec Windows.",
    "Some files could not be sanitized, please check your logs." : "Certains fichiers n'ont pas pu être nettoyés, veuillez vérifier les logs du serveur.",
    "Sanitization errors" : "Erreurs de nettoyage",
    "Not sanitized filenames" : "Noms de fichiers non nettoyés",
    "Windows filename support has been enabled." : "La prise en charge des noms de fichiers pour Windows a été activée.",
    "While this blocks users from creating new files with unsupported filenames, existing files are not yet renamed and thus still may break sync on Windows." : "Bien que cela empêche les utilisateurs de créer de nouveaux fichiers avec des noms non pris en charge, les fichiers existants ne sont pas encore renommés et peuvent donc toujours perturber la synchronisation sous Windows.",
    "You can trigger a rename of files with invalid filenames, this will be done in the background and may take some time." : "Vous pouvez déclencher le renommage des fichiers dont le nom n'est pas valide. Cette opération s'effectuera en arrière-plan et pourra prendre un certain temps.",
    "Please note that this may cause high workload on the sync clients." : "Veuillez noter que cela peut entraîner une charge importante pour les clients de synchronisation.",
    "Limit" : "Limite",
    "This allows to configure how many users should be processed in one background job run." : "Cela permet de configurer le nombre d'utilisateurs à traiter lors de l'exécution d'une tâche en arrière-plan.",
    "Sanitize filenames" : "Nettoyer les noms de fichiers",
    "(starting)" : "(démarrage)",
    "Fill template fields" : "Remplir les champs modèle",
    "Submitting fields …" : "Soumission des champs …",
    "Submit" : "Envoyer",
    "Choose a file or folder to transfer" : "Sélectionnez un fichier ou un dossier à transférer",
    "Transfer \"{path}\"" : "Transfert \"{path}\"",
    "Select file or folder" : "Sélectionnez un fichier ou un dossier",
    "Transfer" : "Transférer",
    "Transfer {path} to {userid}" : "Transférer {path} à {userid}",
    "Error while opening file picker for transfer ownership" : "Erreur lors de l’ouverture du sélecteur de fichiers pour le transfert de propriété",
    "Error while searching for users" : "Erreur lors de la recherche d'utilisateurs",
    "Ownership transfer request sent" : "Requête de transfert de propriété envoyée",
    "Cannot transfer ownership of a file or folder you do not own" : "Impossible de transférer la propriété d'un fichier ou d'un dossier que vous ne possédez pas",
    "Error while sending ownership transfer request" : "Erreur lors de l’envoi de la demande de transfert de propriété.",
    "Transfer ownership of a file or folder" : "Transférer la propriété d'un fichier ou d'un dossier",
    "File or folder to transfer" : "Fichier ou dossier à transférer",
    "No file or folder selected" : "Aucun fichier ou dossier sélectionné",
    "New owner" : "Nouveau propriétaire",
    "You need to select a file or folder to transfer ownership." : "Vous devez sélectionner un fichier ou un dossier pour transférer sa propriété.",
    "You need to select a new owner for the file or folder." : "Vous devez sélectionner un nouveau propriétaire pour le fichier ou le dossier.",
    "Keep {old}" : "Garder {old}",
    "Keep without extension" : "Garder sans extension",
    "Use {new}" : "Utiliser {new}",
    "Remove extension" : "Retirer l'extension du fichier",
    "Change file extension" : "Changer l'extension du fichier",
    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "Changer l'extension du fichier de \"{old}\" à \"{new}\" peut rendre le fichier illisible.",
    "Removing the file extension \"{old}\" may render the file unreadable." : "Retirer l'extension de fichier \"{old}\" peut rendre le fichier illisible.",
    "Adding the file extension \"{new}\" may render the file unreadable." : "Ajouter l'extension de fichier \"{new}\" peut rendre le fichier illisible.",
    "Do not show this dialog again." : "Ne plus montrer cette boite de dialogue.",
    "Rename file to hidden" : "Renommer le fichier en caché",
    "Prefixing a filename with a dot may render the file hidden." : "Le fait de préfixer un nom de fichier avec un point peut rendre le fichier caché.",
    "Are you sure you want to rename the file to \"{filename}\"?" : "Voulez-vous vraiment renommer le fichier en \"{filename}\" ?",
    "Cancel" : "Annuler",
    "Rename" : "Renommer",
    "Select file or folder to link to" : "Sélection d'un fichier ou d'un dossier à lier",
    "Choose {file}" : "Choisir {file}",
    "Files settings" : "Paramètres de Fichiers",
    "Switch to list view" : "Passer à la vue en liste",
    "Switch to grid view" : "Basculer en vue en grille",
    "The file could not be found" : "Le fichier n'a pas pu être trouvé",
    "Upload was cancelled by user" : "Le téléversement a été annulé par l'utilisateur",
    "Not enough free space" : "Espace disponible insuffisant",
    "Operation is blocked by access control" : "L'opération est bloquée par le contrôle d'accès",
    "Error during upload: {message}" : "Erreur lors du téléversement : {message}",
    "Error during upload, status code {status}" : "Erreur lors du téléversement, code de statut {status}",
    "Unknown error during upload" : "Erreur inconnue lors du téléversement",
    "File list is reloading" : "La liste des fichiers est en cours de rechargement",
    "Loading current folder" : "Chargement du dossier courant",
    "Retry" : "Réessayer",
    "No files in here" : "Aucun fichier",
    "Upload some content or sync with your devices!" : "Déposez du contenu ou synchronisez vos appareils !",
    "Go back" : "Revenir en arrière",
    "Loading …" : "Chargement...",
    "Your files" : "Vos fichiers",
    "Open in files" : "Ouvrir dans Fichiers",
    "File cannot be accessed" : "Impossible d'accéder au fichier",
    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Le fichier n'a pas été trouvé ou vous n'avez pas les permissions pour le voir. Demandez à l'expéditeur de le partager.",
    "No search results for “{query}”" : "Aucun résultat de recherche pour “{query}”",
    "Search for files" : "Rechercher des fichiers",
    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Permet de restreindre les noms de fichiers pour s'assurer que les fichiers peuvent être synchronisés avec tous les clients. Par défaut, tous les noms de fichier valides sur POSIX (c'est à dire sur Linux ou MacOS) sont acceptés.",
    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Après avoir activé les noms de fichiers compatibles Windows, les fichiers existants ne peuvent plus être modifiés mais peuvent être renommés avec de nouveaux noms valides par leur propriétaire.",
    "Failed to toggle Windows filename support" : "Échec d'activation/désactivation de la prise en charge des noms de fichiers compatibles Windows",
    "Files compatibility" : "Compatibilité des fichiers",
    "Enforce Windows compatibility" : "Forcer la compatibilité Windows",
    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Cela va bloquer les noms de fichier non valides sur les systèmes Windows, comme utiliser des noms réservés ou des caractères spéciaux. Mais cela ne renforcera pas la compatibilité de la sensibilité à la casse.",
    "Blank" : "Vide",
    "Unable to create new file from template" : "Impossible de créer un nouveau fichier à partir du modèle",
    "Pick a template for {name}" : "Choisissez un modèle pour {name}",
    "Create a new file with the selected template" : "Créer un nouveau fichier avec le modèle sélectionné",
    "Creating file" : "Créer un fichier",
    "Save as {displayName}" : "Enregistrer sous {displayName}",
    "Save as …" : "Enregistrer sous …",
    "Converting files …" : "Conversion des fichiers …",
    "Failed to convert files: {message}" : "Impossible de convertir les fichiers : {message}",
    "All files failed to be converted" : "Aucun fichier n'a pu être converti",
    "One file could not be converted: {message}" : "Le fichier {message} n'a pas pu être converti",
    "_%n file could not be converted_::_%n files could not be converted_" : ["Un fichier n'a pas pu être converti","%n fichiers n'ont pas pu être convertis","%n fichiers n'ont pas pu être convertis"],
    "_%n file converted_::_%n files converted_" : ["%n fichier converti","%n fichiers convertis","%n fichiers convertis"],
    "Files converted" : "Fichiers convertis",
    "Failed to convert files" : "Impossible de convertir les fichiers",
    "Converting file …" : "Conversion du fichier …",
    "File successfully converted" : "Fichier converti avec succès",
    "Failed to convert file: {message}" : "Impossible de convertir le fichier : {message}",
    "Failed to convert file" : "Impossible de convertir le fichier",
    "Delete" : "Supprimer",
    "Leave this share" : "Quitter ce partage",
    "Leave these shares" : "Quitter ces partages",
    "Disconnect storage" : "Déconnecter ce support de stockage",
    "Disconnect storages" : "Déconnecter ces supports de stockage",
    "Delete permanently" : "Supprimer définitivement",
    "Delete and unshare" : "Supprimer et quitter le(s) partage(s)",
    "Delete file" : "Supprimer le fichier ",
    "Delete folder" : "Supprimer ce dossier",
    "Delete folders" : "Supprimer ces dossiers",
    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Vous êtes sur le point de supprimer définitivement {count} élément","Vous êtes sur le point de supprimer définitivement {count} éléments","Vous êtes sur le point de supprimer définitivement {count} éléments"],
    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Vous êtes sur le point de supprimer {count} élément","Vous êtes sur le point de supprimer {count} éléments","Vous êtes sur le point de supprimer {count} éléments"],
    "Confirm deletion" : "Confirmer la suppression",
    "Download" : "Télécharger",
    "The requested file is not available." : "Le fichier demandé n'est pas disponible.",
    "The requested files are not available." : "Les fichiers demandés ne sont pas disponibles.",
    "Add to favorites" : "Ajouter aux favoris",
    "Remove from favorites" : "Retirer des favoris",
    "Add or remove favorite" : "Ajouter ou supprimer un favoris",
    "Move" : "Déplacer",
    "Copy" : "Copier",
    "Move or copy" : "Déplacer ou copier",
    "Destination is not a folder" : "La destination n'est pas un dossier",
    "This file/folder is already in that directory" : "Ce fichier/dossier se trouve déjà dans ce dossier",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "Vous ne pouvez pas déplacer un fichier/dossier sur lui-même ou dans un sous-dossier de celui-ci",
    "A file or folder with that name already exists in this folder" : "Un fichier ou un dossier portant ce nom existe déjà dans ce dossier",
    "The files are locked" : "Les fichiers sont verrouillés",
    "The file does not exist anymore" : "Le fichier n'existe plus",
    "Moving \"{source}\" to \"{destination}\" …" : "Déplacement de \"{source}\" vers \"{destination}\" …",
    "_Moving %n file to \"{destination}\" …_::_Moving %n files to \"{destination}\" …_" : ["Déplacement de %n fichier dans \"{destination}\" ...","Déplacement de %n fichiers dans \"{destination}\" ...","Déplacement de %n fichiers dans \"{destination}\" ..."],
    "Copying \"{source}\" to \"{destination}\" …" : "Copie de \"{source}\" vers \"{destination}\" …",
    "_Copying %n file to \"{destination}\" …_::_Copying %n files to \"{destination}\" …_" : ["Copie de %n fichier dans \"{destination}\" ...","Copie de %n fichiers dans \"{destination}\" ...","Copie de %n fichiers dans \"{destination}\" ..."],
    "Choose destination" : "Choisir la destination",
    "Copy to {target}" : "Copier vers {target}",
    "Move to {target}" : "Déplacer vers {target}",
    "Move or copy operation failed" : "L'opération de copie ou de déplacement a échoué",
    "Open folder" : "Ouvrir le dossier",
    "Open folder {displayName}" : "Ouvrir le dossier {displayName}",
    "Open in Files" : "Ouvrir dans Fichiers",
    "Open locally" : "Ouvrir localement",
    "Failed to redirect to client" : "Échec de la redirection vers le client",
    "Open file locally" : "Ouvrir le fichier localement",
    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Le fichier devrait maintenant s'ouvrir sur votre appareil. Si ce n'est pas le cas, vérifiez que vous avez installé l'application de bureau.",
    "Retry and close" : "Réessayer et fermer",
    "Open online" : "Ouvrir en ligne",
    "Details" : "Détails",
    "Open the details sidebar" : "Ouvrir la barre latéral des détails",
    "Unfavorite" : "Retirer des favoris",
    "View in folder" : "Afficher dans le dossier",
    "Type" : "Type",
    "Created new folder \"{name}\"" : "Nouveau dossier \"{name}\" créé",
    "Unable to initialize the templates directory" : "Impossible d'initialiser le dossier des modèles",
    "Create templates folder" : "Créer le dossier des modèles",
    "Templates" : "Modèles",
    "New template folder" : "Nouveau modèle de dossier",
    "In folder" : "Dans le dossier",
    "Pick folder to search in" : "Choisir le dossier pour la recherche",
    "Search in all files" : "Rechercher dans tous les fichiers",
    "Search in folder: {folder}" : "Rechercher dans le dossier : {folder}",
    "One of the dropped files could not be processed" : "L'un des fichiers déposés n'a pas pu être traité",
    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Votre navigateur n’est pas compatible avec l’API Filesystem. Les dossiers ne seront pas téléversés",
    "No files to upload" : "Aucun fichier à téléverser",
    "Unable to create the directory {directory}" : "Impossible de créer le répertoire {directory}",
    "Some files could not be uploaded" : "Certains fichiers n'ont pu être téléversés",
    "Files uploaded successfully" : "Fichiers téléversés avec succès",
    "No files to process" : "Aucun fichier à traiter",
    "Files copied successfully" : "Fichiers copiés avec succès",
    "Files moved successfully" : "Fichiers déplacés avec succès",
    "Some files could not be copied" : "Certains des fichiers n’ont pas pu être copiés",
    "Some files could not be moved" : "Certains fichiers n’ont pu être déplacés",
    "Conflicts resolution skipped" : "Résolution des conflits ignorée",
    "Upload cancelled" : "Téléversement annulé",
    "Could not rename \"{oldName}\", it does not exist any more" : "Impossible de renommer \"{oldName}\", il n'existe plus.",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Le nom \"{newName}\" est déjà utilisé dans le dossier \"{dir}\". Veuillez choisir un autre nom.",
    "Could not rename \"{oldName}\"" : "Impossible de renommer \"{oldName}\"",
    "This operation is forbidden" : "Cette opération est interdite",
    "This folder is unavailable, please try again later or contact the administration" : "Ce dossier n'est pas disponible, veuillez réessayer plus tard ou contacter l'administrateur",
    "Storage is temporarily not available" : "Le support de stockage est temporairement indisponible",
    "Unexpected error: {error}" : "Erreur inattendue: {error}",
    "Unknown error" : "Erreur inconnue ",
    "_%n file_::_%n files_" : ["%n fichier","%n fichiers","%n fichiers"],
    "_%n folder_::_%n folders_" : ["%n dossier","%n dossiers","%n dossiers"],
    "_%n hidden_::_%n hidden_" : ["%n caché","%n cachés","%n cachés"],
    "Folder name must not be empty." : "Le nom du dossier ne peut pas être vide.",
    "Filename must not be empty." : "Le nom du fichier ne doit pas être vide.",
    "\"{char}\" is not allowed inside a folder name." : "\"{char}\" n'est pas autorisé dans un nom de dossier.",
    "\"{char}\" is not allowed inside a filename." : "\"{char}\" n'est pas autorisé dans un nom de fichier.",
    "\"{segment}\" is a reserved name and not allowed for folder names." : "\"{segment}\" est un nom réservé et ne peut pas être utilisé comme nom de dossier.",
    "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" est un nom réservé et il n'est pas autorisé dans les noms de fichier.",
    "\"{extension}\" is not an allowed filetype." : "\"{extension}\" est un type de fichier interdit.",
    "Folder names must not end with \"{extension}\"." : "Les noms de dossier ne doivent pas se terminer par \"{extension}\".",
    "Filenames must not end with \"{extension}\"." : "Les noms de fichier ne doivent pas se terminer par \"{extension}\".",
    "Invalid folder name." : "Nom de dossier invalide.",
    "List of favorite files and folders." : "Liste des fichiers et dossiers favoris.",
    "No favorites yet" : "Aucun favori pour l'instant",
    "Files and folders you mark as favorite will show up here" : "Les fichiers et dossiers ajoutés à vos favoris apparaîtront ici",
    "List of your files and folders." : "Liste de vos fichiers et dossiers.",
    "Folder tree" : "Arborescence des dossiers",
    "List of your files and folders that are not shared." : "Liste de vos fichiers et dossiers non partagés.",
    "No personal files found" : "Aucun fichier personnel trouvé",
    "Files that are not shared will show up here." : "Les fichiers qui ne sont pas partagés apparaîtront ici.",
    "Recent" : "Récents",
    "List of recently modified files and folders." : "Liste des fichiers et dossiers récemment modifiés.",
    "No recently modified files" : "Pas de fichiers récemment modifiés",
    "Files and folders you recently modified will show up here." : "Les fichiers et dossiers que vous avez récemment modifiés apparaîtront ici",
    "Search" : "Rechercher",
    "Search results within your files." : "Résultats de recherche dans vos fichiers.",
    "This node is unavailable" : "Ce nœud est indisponible ",
    "Renamed \"{oldName}\" to \"{newName}\"" : "\"{oldName}\" renommé en \"{newName}\"",
    "Clear filter" : "Supprimer le filtre",
    "Open file sidebar" : "Ouvrir le panneau latéral du fichier",
    "Search everywhere …" : "Rechercher partout...",
    "Search here …" : "Rechercher ici...",
    "Preparing …" : "Préparation...",
    "Submitting fields …" : "Soumission des champs...",
    "Invalid path selected" : "Chemin sélectionné non valide",
    "Choose file or folder to transfer" : "Sélectionnez un fichier ou un dossier à transférer",
    "Change" : "Modifier",
    "Shared by link" : "Partagés par lien",
    "Shared" : "Partagé",
    "You" : "Vous",
    "Shared multiple times with different people" : "Partagé plusieurs fois avec plusieurs personnes",
    "Unable to change the favorite state of the file" : "Impossible de modifier l'état de mise en favori du fichier",
    "Error while loading the file data" : "Erreur lors du chargement du fichier de données",
    "Tags" : "Étiquettes",
    "Save as …" : "Enregistrer sous...",
    "Converting files …" : "Conversion des fichiers...",
    "Converting file …" : "Conversion du fichier...",
    "No entries found in this folder" : "Aucune entrée trouvée dans ce dossier",
    "Select all" : "Tout sélectionner",
    "Upload too large" : "Données envoyées trop volumineuses",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Les fichiers que vous essayez d’envoyer dépassent la taille maximale d’envoi permise par ce serveur."
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
