OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "Файлын сануулгууд",
    "Reminder for {name}" : "{name}-н сануулга",
    "View file" : "Файл харах",
    "View folder" : "Хавтас харах",
    "Files reminder" : "Файлын сануулга",
    "The \"files_reminders\" app can work properly." : "\"files_reminders\" апп зөв ажиллаж чадна.",
    "The \"files_reminders\" app needs the notification app to work properly. You should either enable notifications or disable files_reminder." : "\"files_reminders\" програм зөв ажиллахын тулд мэдэгдлийн програм шаардлагатай. Та мэдэгдлийг идэвхжүүлэх эсвэл files_reminder-ийг идэвхгүй болгох хэрэгтэй.",
    "Set file reminders" : "Файлын сануулга тохируулах",
    "Please choose a valid date & time" : "Зөв огноо ба цаг сонгоно уу",
    "Reminder set for \"{fileName}\"" : "\"{fileName}\"-д сануулга тохируулагдсан",
    "Failed to set reminder" : "Сануулга тохируулж чадсангүй",
    "Reminder cleared for \"{fileName}\"" : "\"{fileName}\"-н сануулга цэвэрлэгдсэн",
    "Failed to clear reminder" : "Сануулга цэвэрлэж чадсангүй",
    "Reminder at custom date & time" : "Хувийн огноо ба цагийн сануулга",
    "We will remind you of this file" : "Бид танд энэ файлын тухай сануулах болно",
    "Cancel" : "Ð¦ÑƒÑ†Ð»Ð°Ñ…",
    "Clear reminder" : "Сануулга цэвэрлэх",
    "Set reminder" : "Сануулга тохируулах",
    "Set reminder for " : "Сануулга тохируулах ",
    "Reminder set" : "Сануулга тохируулагдсан",
    "Custom reminder" : "Хувийн сануулга",
    "Later today" : "Өнөөдөр дараа",
    "Set reminder for later today" : "Өнөөдөр дараа нь сануулга тохируулах",
    "Tomorrow" : "Ð¼Ð°Ñ€Ð³Ð°Ð°Ñˆ",
    "Set reminder for tomorrow" : "Маргааш сануулга тохируулах",
    "This weekend" : "Энэ амралтын өдөр",
    "Set reminder for this weekend" : "Энэ амралтын өдөр сануулга тохируулах",
    "Next week" : "Ð”Ð°Ñ€Ð°Ð° 7 Ñ…Ð¾Ð½Ð¾Ð³",
    "Set reminder for next week" : "Дараа долоо хоног сануулга тохируулах",
    "Set reminder for \"{fileName}\"" : "\"{fileName}\"-д сануулга тохируулах"
},
"nplurals=2; plural=(n != 1);");
