OC.L10N.register(
    "profile",
    {
    "View profile" : "عرض الملف الشخصي",
    "Profile" : "لمحة تعريفية",
    "This application provides the profile" : "هذا التطبيق يوفر اللمحة التعريفية",
    "Not found" : "غير موجود",
    "Insert" : "إدخال",
    "You have not added any info yet" : "لم تقم بإضافة أي معلومات حتى الآن",
    "{user} has not added any info yet" : "لم يقم المستخدم {user} بإضافة أي معلومات بعد",
    "Error opening the user status modal, try hard refreshing the page" : "خطأ في فتح حالة المستخدم ، حاول تحديث الصفحة",
    "The headline and about sections will show up here" : "سيظهر هنا العنوان والأقسام الخاصة بالملف الشخصي",
    "Profile not found" : "ملف المستخدم غير موجود",
    "Back to %s" : "عودة إلى %s",
    "Provides a customisable user profile interface." : "يُوفِّر واجهة مخصصة للمحة التعريفية عن المستخدِم",
    "Edit Profile" : "تعديل الملف الشخصي",
    "The profile does not exist." : "الملف الشخصي غير موجود."
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
