OC.L10N.register(
    "profile",
    {
    "View profile" : "Ver perfil",
    "Profile" : "Perfil",
    "Not found" : "No encontrado",
    "Insert" : "Insertar",
    "You have not added any info yet" : "No has agregado ninguna información todavía",
    "{user} has not added any info yet" : "{user} no ha agregado ninguna información aún",
    "Error opening the user status modal, try hard refreshing the page" : "Error al abrir el modal de estado del usuario, intenta actualizar la página",
    "The headline and about sections will show up here" : "El titular y la sección Acerca de se mostrarán aquí",
    "Profile not found" : "Perfil no encontrado",
    "Back to %s" : "Volver a %s",
    "Edit Profile" : "Editar perfil",
    "The profile does not exist." : "El perfil no existe."
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
