OC.L10N.register(
    "bruteforcesettings",
    {
    "Brute-force settings" : "Cunfiguratzione de fortza bruta",
    "Whitelist IPs" : "Lista bianca de is IP",
    "Comment" : "Cummentu",
    "Add" : "Agiunghe ",
    "Save" : "Sarva"
},
"nplurals=2; plural=(n != 1);");
