OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "Ajouté à la liste des serveurs de confiance",
    "No server found with ID: %s" : "Aucun serveur trouvé avec l'identifiant %s",
    "Could not remove server" : "Impossible de supprimer le serveur",
    "Server is already in the list of trusted servers." : "Le serveur est déjà dans la liste des serveurs de confiance.",
    "No server to federate with found" : "Aucun serveur avec lequel fédérer n’a été trouvé",
    "Could not add server" : "Impossible d’ajouter le serveur",
    "Trusted servers" : "Serveurs de confiance",
    "Federation" : "Fédération",
    "Federation allows you to connect with other trusted servers to exchange the account directory." : "Une fédération vous permet de vous connecter avec d'autres serveurs de confiance pour échanger la liste des comptes.",
    "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing." : "Une fédération vous permet de vous connecter avec d'autres serveurs de confiance pour échanger la liste des comptes. Par exemple, ce sera utilisé pour auto-compléter les comptes externes lors du partage fédéré.",
    "Could not add trusted server. Please try again later." : "Impossible d'ajouter un serveur de confiance. Veuillez réessayer plus tard.",
    "Add trusted server" : "Ajouter un serveur de confiance",
    "Server url" : "URL du serveur",
    "Add" : "Ajouter",
    "Server ok" : "Serveur Ok",
    "User list was exchanged at least once successfully with the remote server." : "La liste des utilisateurs a été échangée au moins une fois avec succès avec le serveur distant.",
    "Server pending" : "Serveur en attente",
    "Waiting for shared secret or initial user list exchange." : "En attente du partage du secret ou de l'échange initial de la liste des utilisateurs.",
    "Server access revoked" : "Accès du serveur révoqué",
    "Server failure" : "Échec du serveur",
    "Connection to the remote server failed or the remote server is misconfigured." : "La connexion avec le serveur distant a échoué ou le serveur distant est mal configuré.",
    "Failed to delete trusted server. Please try again later." : "Échec de suppression du serveur de confiance. Veuillez réessayer plus tard.",
    "Delete" : "Supprimer",
    "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "Une fédération vous permet de vous connecter avec d'autres serveurs de confiance pour échanger la liste des comptes. Par exemple, ce sera utilisé pour auto-compléter les comptes externes lors du partage fédéré. Il n'est pas nécessaire d'ajouter un serveur comme serveur de confiance afin de créer un partage fédéré.",
    "Each server must validate the other. This process may require a few cron cycles." : "Chaque serveur doit valider l'autre. Ce processus peut prendre plusieurs cycles de tâches planifiées.",
    "External documentation for Federated Cloud Sharing" : "Documentation externe sur le partage de Cloud Fédéré",
    "+ Add trusted server" : "+ Ajouter un serveur de confiance",
    "Trusted server" : "Serveur de confiance"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
