OC.L10N.register(
    "oauth2",
    {
    "Your client is not authorized to connect. Please inform the administrator of your client." : "Su klient ei ole ühenduseks autoriseeritud. Palun teavita oma kliendi peakasutajat.",
    "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path" : "Ümbersuunamise URL peab olema täis URL, näiteks: https://sinudomeen.com/asukoht",
    "OAuth 2.0" : "OAuth 2.0",
    "Allows OAuth2 compatible authentication from other web applications." : "Võimaldab OAuth2-ga ühilduvat autentimist teistest veebirakendustest.",
    "The OAuth2 app allows administrators to configure the built-in authentication workflow to also allow OAuth2 compatible authentication from other web applications." : "Rakendus OAuth2 võimaldab administraatoritel konfigureerida sisseehitatud autentimise töövoogu, et võimaldada ka OAuth2-ga ühilduvat autentimist teistest veebirakendustest.",
    "Secret key" : "Salavõti",
    "Delete" : "Kustuta",
    "An unknown error occurred." : "Tekkis tundmatu viga.",
    "OAuth 2.0 clients" : "OAuth 2.0 kliendid",
    "OAuth 2.0 allows external services to request access to {instanceName}." : "OAuth 2.0 võimaldab välisteenustel taotleda juurdepääsu {instanceName}ile",
    "Name" : "Nimi",
    "Redirection URI" : "Suunamise URI",
    "Client identifier" : "Klienditunnus",
    "Delete client" : "Kustuta klient",
    "Make sure you store the secret key, it cannot be recovered." : "Salvesta salajane võti, seda ei saa taastada.",
    "Add client" : "Lisa klient",
    "Add" : "Lisa",
    "Client Identifier" : "Klienditunnus",
    "Show client secret" : "Näita kliendi salakoodi",
    "Hide client secret" : "Peida kliendi salakood"
},
"nplurals=2; plural=(n != 1);");
