OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "Rappels de fichiers",
    "Reminder for {name}" : "Rappel pour {name}",
    "View file" : "Voir le fichier",
    "View folder" : "Voir le dossier",
    "Files reminder" : "Rappel des fichiers",
    "The \"files_reminders\" app can work properly." : "L'application « files_reminders » peut fonctionner correctement.",
    "The \"files_reminders\" app needs the notification app to work properly. You should either enable notifications or disable files_reminder." : "L'application « files_reminders » a besoin de l'application de notifications pour fonctionner correctement. Vous devez activer les notifications ou désactiver « files_reminder ».",
    "Set file reminders" : "Définir des rappels pour des fichiers",
    "**📣 File reminders**\n\nSet file reminders.\n\nNote: to use the `File reminders` app, ensure that the `Notifications` app is installed and enabled. The `Notifications` app provides the necessary APIs for the `File reminders` app to work correctly." : "**📣 Rappels de fichiers**\n\nDéfinit des rappels de fichiers.\n\nNote: pour utiliser l'application `Rappels de fichiers`, assurez-vous que l'application `Notifications` est installée et activée. L'application `Notifications` fournit les APIs nécessaires pour que l'application `Rappels de fichiers` fonctionne correctement.",
    "Please choose a valid date & time" : "Veuillez choisir une date et une heure valables",
    "Reminder set for \"{fileName}\"" : "Définition d’un rappel pour « {fileName} »",
    "Failed to set reminder" : "Échec de la définition du rappel",
    "Reminder cleared for \"{fileName}\"" : "Rappel effacé pour « {fileName} »",
    "Failed to clear reminder" : "Échec de l'effacement du rappel",
    "Reminder at custom date & time" : "Rappel à une date et une heure personnalisées",
    "We will remind you of this file" : "Nous vous rappellerons de ce fichier",
    "Cancel" : "Annuler",
    "Clear reminder" : "Effacer le rappel",
    "Set reminder" : "Définir un rappel",
    "Set reminder for " : "Définir un rappel pour ",
    "Reminder set" : "Rappel défini",
    "Custom reminder" : "Rappel personnalisé",
    "Later today" : "Plus tard aujourd'hui",
    "Set reminder for later today" : "Définir un rappel pour plus tard aujourd'hui",
    "Tomorrow" : "Demain",
    "Set reminder for tomorrow" : "Définir un rappel pour demain",
    "This weekend" : "Ce week-end",
    "Set reminder for this weekend" : "Définir un rappel pour ce week-end",
    "Next week" : "Semaine suivante",
    "Set reminder for next week" : "Définir un rappel pour la semaine prochaine",
    "Set reminder for \"{fileName}\"" : "Définir un rappel pour « {fileName} »"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
