OC.L10N.register(
    "files",
    {
    "Added to favorites" : "Προστέθηκε στα αγαπημένα",
    "Removed from favorites" : "Αφαιρέθηκε από τα αγαπημένα",
    "You added {file} to your favorites" : "Προσθέσατε το {file} στα αγαπημένα σας",
    "You removed {file} from your favorites" : "Αφαιρέσατε το {file} από τα αγαπημένα σας",
    "Favorites" : "Αγαπημένα",
    "File changes" : "Αλλαγές αρχείου",
    "Created by {user}" : "Δημιουργήθηκε από τον {user}",
    "Changed by {user}" : "Άλλαξε από τον {user}",
    "Deleted by {user}" : "Διαγράφτηκε από τον {user}",
    "Restored by {user}" : "Επαναφέρθηκε από τον {user}",
    "Renamed by {user}" : "Μετονομάστηκε από τον {user}",
    "Moved by {user}" : "Μετακινήθηκε από τον {user}",
    "\"remote account\"" : "\"απομακρυσμένος λογαριασμός\"",
    "You created {file}" : "Δημιουργήσατε το {file}",
    "You created an encrypted file in {file}" : "Δημιουργήσατε ένα κρυπτογραφημένο αρχείο στο {file}",
    "{user} created {file}" : "Ο/η {user} δημιούργησε {file}",
    "{user} created an encrypted file in {file}" : "Ο/η {user} δημιούργησε ένα κρυπτογραφημένο αρχείο στο {file}",
    "{file} was created in a public folder" : "Το {file} δημιουργήθηκε σε δημόσιο φάκελο",
    "You changed {file}" : "Αλλάξατε το {file}",
    "You changed an encrypted file in {file}" : "Αλλάξατε ένα κρυπτογραφημένο αρχείο στο {file}",
    "{user} changed {file}" : "Ο/η {user} άλλαξε το {file}",
    "{user} changed an encrypted file in {file}" : "Ο/η {user} άλλαξε ένα κρυπτογραφημένο αρχείο στο {file}",
    "You deleted {file}" : "Διαγράψατε το {file}",
    "You deleted an encrypted file in {file}" : "Διαγράψατε ένα κρυπτογραφημένο αρχείο στο {file}",
    "{user} deleted {file}" : "Ο/η {user} διέγραψε το {file}",
    "{user} deleted an encrypted file in {file}" : "Ο/η {user} διέγραψε ένα κρυπτογραφημένο αρχείο στο {file}",
    "You restored {file}" : "Επαναφέρατε το {file}",
    "{user} restored {file}" : "Ο/η {user} επανέφερε το {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Μετονομάσατε το {oldfile} (κρυφό) σε {newfile} (κρυφό)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Μετονομάσατε το {oldfile} (κρυφό) σε {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Μετονομάσατε το {oldfile} σε {newfile} (κρυφό)",
    "You renamed {oldfile} to {newfile}" : "Μετονομάσατε το {oldfile} σε {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "Ο/η {user} μετονόμασε το {oldfile} (κρυφό) σε {newfile} (κρυφό)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "Ο/η {user} μετονόμασε το {oldfile} (κρυφό) σε {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "Ο/η {user} μετονόμασε το {oldfile} σε {newfile} (κρυφό)",
    "{user} renamed {oldfile} to {newfile}" : "Ο/η {user} μετονόμασε το {oldfile} σε {newfile}",
    "You moved {oldfile} to {newfile}" : "Μετακινήσατε το {oldfile} σε {newfile}",
    "{user} moved {oldfile} to {newfile}" : "Ο/η {user} μετακίνησε το {oldfile} σε {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Ένα αρχείο έχει προστεθεί ή αφαιρεθεί από τα <strong>αγαπημένα</strong> σας",
    "Files" : "Αρχεία",
    "A file or folder has been <strong>changed</strong>" : "Ένα αρχείο ή φάκελος έχει <strong>αλλάξει</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "Ένα αγαπημένο αρχείο ή φάκελος έχει <strong>αλλάξει</strong>",
    "Failed to authorize" : "Αποτυχία εξουσιοδότησης",
    "Invalid folder path" : "Μη έγκυρη διαδρομή φακέλου",
    "Folder not found" : "Ο φάκελος δεν βρέθηκε",
    "The file cannot be found" : "Το αρχείο δεν μπορεί να βρεθεί",
    "The destination path does not exist: %1$s" : "Η διαδρομή προορισμού δεν υπάρχει: %1$s",
    "You do not have permission to create a file at the specified location" : "Δεν έχετε δικαίωμα να δημιουργήσετε αρχείο στην καθορισμένη τοποθεσία",
    "The file could not be converted." : "Το αρχείο δεν ήταν δυνατό να μετατραπεί.",
    "Could not get relative path to converted file" : "Αδυναμία λήψης σχετικής διαδρομής προς το μετατραπέν αρχείο",
    "Limit must be a positive integer." : "Το όριο πρέπει να είναι θετικός ακέραιος.",
    "The replacement character may only be a single character." : "Ο χαρακτήρας αντικατάστασης μπορεί να είναι μόνο ένας χαρακτήρας.",
    "Filename sanitization already started." : "Ο καθαρισμός ονομάτων αρχείων έχει ήδη ξεκινήσει.",
    "No filename sanitization in progress." : "Δεν εκτελείται καθαρισμός ονομάτων αρχείων.",
    "Favorite files" : "Αγαπημένα αρχεία",
    "No favorites" : "Δεν υπάρχουν αγαπημένα",
    "More favorites" : "Περισσότερα αγαπημένα",
    "No read permission on file." : "Δεν υπάρχει δικαίωμα ανάγνωσης στο αρχείο.",
    "Accept" : "Αποδοχή",
    "Reject" : "Απόρριψη",
    "Incoming ownership transfer from {user}" : "Εισερχόμενη μεταβίβαση κυριότητας από τον {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Θέλετε να αποδεχτείτε το {path};\n\nΣημείωση: Η διαδικασία μεταφοράς μετά την αποδοχή μπορεί να διαρκέσει έως 1 ώρα.",
    "Ownership transfer denied" : "Η μεταφορά κυριότητας απορρίφθηκε",
    "Your ownership transfer of {path} was denied by {user}." : "Η μεταφορά κυριότητας του {path} απορρίφθηκε από τον {user}.",
    "Ownership transfer failed" : "Η μεταφορά κυριότητας απέτυχε",
    "Your ownership transfer of {path} to {user} failed." : "Η μεταφορά κυριότητας του {path} στον {user} απέτυχε.",
    "The ownership transfer of {path} from {user} failed." : "Η μεταφορά κυριότητας του {path} από τον {user} απέτυχε.",
    "Ownership transfer done" : "Η μεταφορά κυριότητας ολοκληρώθηκε",
    "Your ownership transfer of {path} to {user} has completed." : "Η μεταφορά κυριότητας του {path} στον {user} ολοκληρώθηκε.",
    "The ownership transfer of {path} from {user} has completed." : "Η μεταφορά κυριότητας του {path} από τον {user} ολοκληρώθηκε.",
    "in %s" : "σε %s",
    "Transferred from %1$s on %2$s" : "Μεταβιβάστηκε από %1$s στις %2$s",
    "Create files" : "Δημιουργία αρχείων",
    "Delete files" : "Διαγραφή αρχείων",
    "Download files" : "Λήψη αρχείων",
    "When disabled, the option to download will be hidden" : "Όταν είναι απενεργοποιημένη, η επιλογή λήψης θα είναι κρυφή",
    "View files" : "Προβολή αρχείων",
    "Edit files" : "Επεξεργασία αρχείων",
    "Show files in grid view" : "Εμφάνιση αρχείων σε προβολή πλέγματος",
    "File" : "Αρχείο",
    "File Management" : "Διαχείριση αρχείων",
    "Home" : "Αρχική",
    "Target folder does not exist any more" : "Ο φάκελος προορισμού δεν υπάρχει πια",
    "Reload current directory" : "Επαναφόρτωση τρέχοντος καταλόγου",
    "Go to the \"{dir}\" directory" : "Μετάβαση στον κατάλογο \"{dir}\"",
    "Current directory path" : "Τρέχουσα διαδρομή καταλόγου",
    "Share" : "Διαμοιρασμός",
    "Reload content" : "Επαναφόρτωση περιεχομένου",
    "Your have used your space quota and cannot upload files anymore" : "Έχετε εξαντλήσει το όριο χώρου σας και δεν μπορείτε να μεταφορτώσετε πλέον άλλα αρχεία",
    "You do not have permission to upload or create files here." : "Δεν έχετε δικαίωμα να μεταφορτώσετε ή να δημιουργήσετε αρχεία εδώ.",
    "Drag and drop files here to upload" : "Σύρετε και αφήστε αρχεία εδώ για να τα μεταφορτώσετε",
    "Favorite" : "Αγαπημένο",
    "Back" : "Επιστροφή",
    "Toggle selection for file \"{displayName}\"" : "Εναλλαγή επιλογής για το αρχείο \"{displayName}\"",
    "Toggle selection for folder \"{displayName}\"" : "Εναλλαγή επιλογής για τον φάκελο \"{displayName}\"",
    "File is loading" : "Το αρχείο φορτώνεται",
    "Folder is loading" : "Ο φάκελος φορτώνεται",
    "Filename" : "Όνομα αρχείου",
    "Folder name" : "Όνομα φακέλου",
    "{displayName} (unavailable)" : "{displayName} (μη διαθέσιμο)",
    "Another entry with the same name already exists." : "Μια άλλη καταχώρηση με το ίδιο όνομα υπάρχει ήδη.",
    "Invalid filename." : "Μη έγκυρο όνομα αρχείου.",
    "Rename file" : "Μετονομασία αρχείου",
    "Recently created" : "Δημιουργήθηκε πρόσφατα",
    "Folder" : "Φάκελος",
    "Unknown file type" : "Άγνωστος τύπος αρχείου",
    "{ext} image" : "Εικόνα {ext}",
    "{ext} video" : "Βίντεο {ext}",
    "{ext} audio" : "Ήχος {ext}",
    "{ext} text" : "Κείμενο {ext}",
    "Pending" : "Εκκρεμεί",
    "Unknown date" : "Άγνωστη ημερομηνία",
    "Active filters" : "Ενεργά φίλτρα",
    "Remove filter" : "Αφαιρέστε το φίλτρο",
    "Today" : "Σήμερα",
    "Last 7 days" : "Τελευταίες 7 ημέρες",
    "Last 30 days" : "Τελευταίες 30 ημέρες",
    "This year ({year})" : "Φέτος ({year})",
    "Last year ({year})" : "Πέρυσι ({year})",
    "Custom range" : "Προσαρμοσμένο εύρος",
    "Custom date range" : "Προσαρμοσμένο εύρος ημερομηνιών",
    "Search everywhere" : "Αναζήτηση παντού",
    "Documents" : "Έγγραφα",
    "Spreadsheets" : "Υπολογιστικά φύλλα",
    "Presentations" : "Παρουσιάσεις",
    "PDFs" : "PDF",
    "Folders" : "Φάκελοι",
    "Audio" : "Ήχος",
    "Images" : "Εικόνες",
    "Videos" : "Βίντεο",
    "Filters" : "Φίλτρα",
    "Back to filters" : "Επιστροφή στα φίλτρα",
    "Appearance" : "Εμφάνιση",
    "Show hidden files" : "Εμφάνιση κρυφών αρχείων",
    "Show file type column" : "Εμφάνιση στήλης τύπου αρχείου",
    "Show file extensions" : "Εμφάνιση επεκτάσεων αρχείων",
    "Crop image previews" : "Περικοπή προεπισκοπήσεων εικόνας",
    "General" : "Γενικά",
    "Sort favorites first" : "Ταξινόμηση αγαπημένων πρώτα",
    "Sort folders before files" : "Ταξινόμηση φακέλων πριν από τα αρχεία",
    "Enable folder tree view" : "Ενεργοποίηση προβολής δέντρου φακέλων",
    "Default view" : "Προεπιλεγμένη προβολή",
    "All files" : "Όλα τα αρχεία",
    "Personal files" : "Προσωπικά αρχεία",
    "Additional settings" : "Επιπρόσθετες ρυθμίσεις",
    "Actions" : "Ενέργειες",
    "File actions" : "Ενέργειες αρχείου",
    "Selection" : "Επιλογή",
    "Select all files" : "Επιλογή όλων των αρχείων",
    "Deselect all" : "Αποεπιλογή όλων",
    "Select or deselect" : "Επιλογή ή αποεπιλογή",
    "Select a range" : "Επιλογή εύρους",
    "Navigation" : "Πλοήγηση",
    "Go to parent folder" : "Μετάβαση στον γονικό φάκελο",
    "Go to file above" : "Μετάβαση στο παραπάνω αρχείο",
    "Go to file below" : "Μετάβαση στο παρακάτω αρχείο",
    "Go left in grid" : "Μετάβαση αριστερά στο πλέγμα",
    "Go right in grid" : "Μετάβαση δεξιά στο πλέγμα",
    "View" : "Προβολή",
    "Toggle grid view" : "Εναλλαγή προβολής πλέγματος",
    "Show those shortcuts" : "Εμφάνιση αυτών των συντομεύσεων",
    "Warnings" : "Προειδοποιήσεις",
    "Warn before changing a file extension" : "Προειδοποίηση πριν από την αλλαγή επέκτασης αρχείου",
    "Warn before deleting a file" : "Προειδοποίηση πριν από τη διαγραφή αρχείου",
    "WebDAV URL" : "WebDAV URL",
    "Create an app password" : "Δημιουργία κωδικού πρόσβασης εφαρμογής",
    "Required for WebDAV authentication because Two-Factor Authentication is enabled for this account." : "Απαιτείται για την επαλήθευση WebDAV επειδή είναι ενεργοποιημένος ο έλεγχος ταυτότητας δύο παραγόντων για αυτόν τον λογαριασμό.",
    "How to access files using WebDAV" : "Πώς να αποκτήσετε πρόσβαση σε αρχεία χρησιμοποιώντας WebDAV",
    "Total rows summary" : "Σύνοψη συνολικών γραμμών",
    "Toggle selection for all files and folders" : "Εναλλαγή επιλογής για όλα τα αρχεία και τους φακέλους",
    "Name" : "Όνομα",
    "File type" : "Τύπος αρχείου",
    "Size" : "Μέγεθος",
    "Modified" : "Τροποποιήθηκε",
    "{displayName}: failed on some elements" : "{displayName}: απέτυχε σε ορισμένα στοιχεία",
    "{displayName}: done" : "{displayName}: ολοκληρώθηκε",
    "{displayName}: failed" : "{displayName}: απέτυχε",
    "(selected)" : "(επιλεγμένα)",
    "List of files and folders." : "Λίστα αρχείων και φακέλων.",
    "You have used your space quota and cannot upload files anymore." : "Έχετε χρησιμοποιήσει το όριο χώρου σας και δεν μπορείτε να μεταφορτώσετε πλέον άλλα αρχεία.",
    "Column headers with buttons are sortable." : "Οι επικεφαλίδες στηλών με κουμπιά μπορούν να ταξινομηθούν.",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Αυτή η λίστα δεν εμφανίζεται πλήρως για λόγους απόδοσης. Τα αρχεία θα εμφανίζονται καθώς πλοηγείστε στη λίστα.",
    "File not found" : "Το αρχείο δεν βρέθηκε",
    "_{count} selected_::_{count} selected_" : ["{count} επιλεγμένο","{count} επιλεγμένα"],
    "Views" : "Προβολές",
    "Search everywhere …" : "Αναζήτηση παντού …",
    "Search here …" : "Αναζήτηση εδώ …",
    "Search scope options" : "Επιλογές εμβέλειας αναζήτησης",
    "Search here" : "Αναζήτηση εδώ",
    "Owner" : "Κάτοχος",
    "{usedQuotaByte} used" : "{usedQuotaByte} χρησιμοποιούνται",
    "{used} of {quota} used" : "{used} από {quota} χρησιμοποιούνται",
    "{relative}% used" : "{relative}% χρησιμοποιούνται",
    "Could not refresh storage stats" : "Δεν ήταν δυνατή η ανανέωση των στατιστικών αποθήκευσης",
    "Your storage is full, files can not be updated or synced anymore!" : "Ο αποθηκευτικός χώρος σας είναι γεμάτος, τα αρχεία δεν μπορούν να ενημερωθούν ή να συγχρονιστούν πλέον!",
    "Storage information" : "Πληροφορίες αποθηκευτικού χώρου",
    "Storage quota" : "Όριο αποθηκευτικού χώρου",
    "New folder" : "Νέος φάκελος",
    "Create new folder" : "Δημιουργία νέου φακέλου",
    "This name is already in use." : "Αυτό το όνομα χρησιμοποιείται ήδη.",
    "Create" : "Δημιουργία",
    "Files starting with a dot are hidden by default" : "Τα αρχεία που ξεκινούν με τελεία είναι κρυφά από προεπιλογή",
    "Failed to start filename sanitization." : "Αποτυχία εκκίνησης καθαρισμού ονομάτων αρχείων.",
    "Failed to refresh filename sanitization status." : "Αποτυχία ανανέωσης της κατάστασης καθαρισμού ονομάτων αρχείων.",
    "Filename sanitization in progress." : "Ο καθαρισμός ονομάτων αρχείων βρίσκεται σε εξέλιξη.",
    "Currently {processedUsers} of {totalUsers} accounts are already processed." : "Προς το παρόν έχουν ήδη υποβληθεί σε επεξεργασία {processedUsers} από {totalUsers} λογαριασμούς.",
    "Preparing …" : "Προετοιμασία …",
    "Refresh" : "Ανανέωση",
    "All files have been santized for Windows filename support." : "Όλα τα αρχεία έχουν καθαριστεί για υποστήριξη ονομάτων αρχείων Windows.",
    "Some files could not be sanitized, please check your logs." : "Ορισμένα αρχεία δεν ήταν δυνατό να καθαριστούν, παρακαλούμε ελέγξτε τις καταγραφές σας.",
    "Sanitization errors" : "Σφάλματα καθαρισμού",
    "Not sanitized filenames" : "Μη καθαρισμένα ονόματα αρχείων",
    "Windows filename support has been enabled." : "Η υποστήριξη ονομάτων αρχείων Windows έχει ενεργοποιηθεί.",
    "While this blocks users from creating new files with unsupported filenames, existing files are not yet renamed and thus still may break sync on Windows." : "Ενώ αυτό εμποδίζει τους χρήστες από τη δημιουργία νέων αρχείων με μη υποστηριζόμενα ονόματα, τα υπάρχοντα αρχεία δεν έχουν ακόμη μετονομαστεί και επομένως μπορεί ακόμη να διακόψουν τον συγχρονισμό στα Windows.",
    "You can trigger a rename of files with invalid filenames, this will be done in the background and may take some time." : "Μπορείτε να ενεργοποιήσετε τη μετονομασία αρχείων με μη έγκυρα ονόματα, αυτό θα γίνει στο παρασκήνιο και μπορεί να πάρει κάποιο χρόνο.",
    "Please note that this may cause high workload on the sync clients." : "Παρακαλώ σημειώστε ότι αυτό μπορεί να προκαλέσει υψηλό φόρτο εργασίας στους πελάτες συγχρονισμού.",
    "Limit" : "Όριο",
    "This allows to configure how many users should be processed in one background job run." : "Αυτό επιτρέπει τη ρύθμιση του πόσοι χρήστες πρέπει να υποβληθούν σε επεξεργασία σε μία εκτέλεση εργασίας παρασκηνίου.",
    "Sanitize filenames" : "Καθαρισμός ονομάτων αρχείων",
    "(starting)" : "(εκκίνηση)",
    "Fill template fields" : "Συμπλήρωση πεδίων προτύπου",
    "Submitting fields …" : "Υποβολή πεδίων …",
    "Submit" : "Υποβολή",
    "Choose a file or folder to transfer" : "Επιλέξτε αρχείο ή φάκελο για μεταφορά",
    "Transfer \"{path}\"" : "Μεταφορά \"{path}\"",
    "Select file or folder" : "Επιλογή αρχείου ή φακέλου",
    "Transfer" : "Μεταφορά",
    "Transfer {path} to {userid}" : "Μεταφορά {path} στον {userid}",
    "Error while opening file picker for transfer ownership" : "Σφάλμα κατά το άνοιγμα του επιλογέα αρχείων για τη μεταβίβαση κυριότητας",
    "Error while searching for users" : "Σφάλμα κατά την αναζήτηση χρηστών",
    "Ownership transfer request sent" : "Το αίτημα μεταβίβασης κυριότητας στάλθηκε",
    "Cannot transfer ownership of a file or folder you do not own" : "Δεν είναι δυνατή η μεταβίβαση της κυριότητας ενός αρχείου ή φακέλου που δεν σας ανήκει",
    "Error while sending ownership transfer request" : "Σφάλμα κατά την αποστολή του αιτήματος μεταβίβασης κυριότητας",
    "Transfer ownership of a file or folder" : "Μεταβίβαση κυριότητας αρχείου ή φακέλου",
    "File or folder to transfer" : "Αρχείο ή φάκελος προς μεταφορά",
    "No file or folder selected" : "Δεν έχει επιλεγεί αρχείο ή φάκελος",
    "New owner" : "Νέος κάτοχος",
    "You need to select a file or folder to transfer ownership." : "Πρέπει να επιλέξετε ένα αρχείο ή φάκελο για να μεταβιβάσετε την κυριότητα.",
    "You need to select a new owner for the file or folder." : "Πρέπει να επιλέξετε έναν νέο κάτοχο για το αρχείο ή τον φάκελο.",
    "Keep {old}" : "Διατήρηση {old}",
    "Keep without extension" : "Διατήρηση χωρίς επέκταση",
    "Use {new}" : "Χρήση {new}",
    "Remove extension" : "Αφαίρεση επέκτασης",
    "Change file extension" : "Αλλαγή επέκτασης αρχείου",
    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "Η αλλαγή της επέκτασης αρχείου από \"{old}\" σε \"{new}\" μπορεί να καταστήσει το αρχείο μη αναγνώσιμο.",
    "Removing the file extension \"{old}\" may render the file unreadable." : "Η αφαίρεση της επέκτασης αρχείου \"{old}\" μπορεί να καταστήσει το αρχείο μη αναγνώσιμο.",
    "Adding the file extension \"{new}\" may render the file unreadable." : "Η προσθήκη της επέκτασης αρχείου \"{new}\" μπορεί να καταστήσει το αρχείο μη αναγνώσιμο.",
    "Do not show this dialog again." : "Να μην εμφανιστεί ξανά αυτό το παράθυρο διαλόγου.",
    "Rename file to hidden" : "Μετονομασία αρχείου σε κρυφό",
    "Prefixing a filename with a dot may render the file hidden." : "Η προσθήκη μιας τελείας στην αρχή ενός ονόματος αρχείου μπορεί να καταστήσει το αρχείο κρυφό.",
    "Are you sure you want to rename the file to \"{filename}\"?" : "Είστε σίγουροι ότι θέλετε να μετονομάσετε το αρχείο σε \"{filename}\";",
    "Cancel" : "Ακύρωση",
    "Rename" : "Μετονομασία",
    "Select file or folder to link to" : "Επιλέξτε αρχείο ή φάκελο για σύνδεση",
    "Choose {file}" : "Επιλέξτε {file}",
    "Files settings" : "Ρυθμίσεις αρχείων",
    "Switch to list view" : "Αλλαγή σε προβολή λίστας",
    "Switch to grid view" : "Εναλλαγή σε προβολή πλέγματος",
    "The file could not be found" : "Το αρχείο δεν βρέθηκε",
    "Upload was cancelled by user" : "Η μεταφόρτωση ακυρώθηκε από τον χρήστη",
    "Not enough free space" : "Δεν επαρκεί ο ελεύθερος χώρος",
    "Operation is blocked by access control" : "Η λειτουργία παρεμποδίζεται από τον έλεγχο πρόσβασης",
    "Error during upload: {message}" : "Σφάλμα κατά τη μεταφόρτωση: {message}",
    "Error during upload, status code {status}" : "Σφάλμα κατά τη μεταφόρτωση, κωδικός κατάστασης {status}",
    "Unknown error during upload" : "Άγνωστο σφάλμα κατά τη μεταφόρτωση",
    "File list is reloading" : "Γίνεται επαναφόρτωση της λίστας αρχείων",
    "Loading current folder" : "Φόρτωση τρέχοντος φακέλου",
    "Retry" : "Δοκιμάστε ξανά",
    "No files in here" : "Δεν υπάρχουν αρχεία εδώ",
    "Upload some content or sync with your devices!" : "Μεταφορτώστε περιεχόμενο ή συγχρονίστε με τις συσκευές σας!",
    "Go back" : "Επιστροφή",
    "Loading …" : "Φόρτωση …",
    "Your files" : "Τα αρχεία σας",
    "Open in files" : "Άνοιγμα στα αρχεία",
    "File cannot be accessed" : "Δεν είναι δυνατή η πρόσβαση στο αρχείο",
    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Το αρχείο δεν βρέθηκε ή δεν έχετε δικαιώματα προβολής του. Ζητήστε από τον αποστολέα να το κοινοποιήσει.",
    "No search results for “{query}”" : "Δεν υπάρχουν αποτελέσματα αναζήτησης για «{query}»",
    "Search for files" : "Αναζήτηση αρχείων",
    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Επιτρέπει τον περιορισμό ονομάτων αρχείων για να διασφαλιστεί ότι τα αρχεία μπορούν να συγχρονιστούν με όλους τους πελάτες. Από προεπιλογή επιτρέπονται όλα τα ονόματα αρχείων που είναι έγκυρα στο POSIX (π.χ. Linux ή macOS).",
    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Μετά την ενεργοποίηση των συμβατών ονομάτων αρχείων Windows, τα υπάρχοντα αρχεία δεν μπορούν πλέον να τροποποιηθούν αλλά μπορούν να μετονομαστούν σε έγκυρα νέα ονόματα από τον κάτοχό τους.",
    "Failed to toggle Windows filename support" : "Αποτυχία εναλλαγής υποστήριξης ονομάτων αρχείων Windows",
    "Files compatibility" : "Συμβατότητα αρχείων",
    "Enforce Windows compatibility" : "Επιβολή συμβατότητας με Windows",
    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Αυτό θα αποκλείσει ονόματα αρχείων που δεν είναι έγκυρα σε συστήματα Windows, όπως η χρήση δεσμευμένων ονομάτων ή ειδικών χαρακτήρων. Αλλά αυτό δεν θα επιβάλει τη συμβατότητα ως προς τη διάκριση πεζών-κεφαλαίων.",
    "Blank" : "Κενό",
    "Unable to create new file from template" : "Αδυναμία δημιουργίας νέου αρχείου από το πρότυπο",
    "Pick a template for {name}" : "Επιλέξτε ένα πρότυπο για το {name}",
    "Create a new file with the selected template" : "Δημιουργήστε ένα νέο αρχείο με το επιλεγμένο πρότυπο",
    "Creating file" : "Δημιουργία αρχείου",
    "Save as {displayName}" : "Αποθήκευση ως {displayName}",
    "Save as …" : "Αποθήκευση ως …",
    "Converting files …" : "Μετατροπή αρχείων …",
    "Failed to convert files: {message}" : "Αποτυχία μετατροπής αρχείων: {message}",
    "All files failed to be converted" : "Όλα τα αρχεία απέτυχαν να μετατραπούν",
    "One file could not be converted: {message}" : "Ένα αρχείο δεν μπόρεσε να μετατραπεί: {message}",
    "_%n file could not be converted_::_%n files could not be converted_" : ["%n αρχείο δεν μπόρεσε να μετατραπεί","%n αρχεία δεν μπόρεσαν να μετατραπούν"],
    "_%n file converted_::_%n files converted_" : ["%n αρχείο μετατράπηκε","%n αρχεία μετατράπηκαν"],
    "Files converted" : "Τα αρχεία μετατράπηκαν",
    "Failed to convert files" : "Αποτυχία μετατροπής αρχείων",
    "Converting file …" : "Μετατροπή αρχείων …",
    "File successfully converted" : "Το αρχείο μετατράπηκε με επιτυχία",
    "Failed to convert file: {message}" : "Αποτυχία μετατροπής αρχείου: {message}",
    "Failed to convert file" : "Αποτυχία μετατροπής αρχείου",
    "Delete" : "Διαγραφή",
    "Leave this share" : "Αποχώρηση από αυτό το κοινόχρηστο",
    "Leave these shares" : "Αποχώρηση από αυτά τα κοινόχρηστα",
    "Disconnect storage" : "Αποσύνδεση αποθηκευτικού χώρου",
    "Disconnect storages" : "Αποσύνδεση αποθηκευτικών χώρων",
    "Delete permanently" : "Οριστική διαγραφή",
    "Delete and unshare" : "Διαγραφή και κατάργηση κοινής χρήσης",
    "Delete file" : "Διαγραφή αρχείου",
    "Delete folder" : "Διαγραφή φακέλου",
    "Delete folders" : "Διαγραφή φακέλων",
    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Πρόκειται να διαγράψετε οριστικά {count} αντικείμενο","Πρόκειται να διαγράψετε οριστικά {count} αντικείμενα"],
    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Πρόκειται να διαγράψετε {count} αντικείμενο","Πρόκειται να διαγράψετε {count} αντικείμενα"],
    "Confirm deletion" : "Επιβεβαίωση διαγραφής",
    "Download" : "Λήψη",
    "The requested file is not available." : "Το ζητούμενο αρχείο δεν είναι διαθέσιμο.",
    "The requested files are not available." : "Τα ζητούμενα αρχεία δεν είναι διαθέσιμα.",
    "Add to favorites" : "Προσθήκη στα αγαπημένα",
    "Remove from favorites" : "Αφαίρεση από τα αγαπημένα",
    "Add or remove favorite" : "Προσθήκη ή αφαίρεση αγαπημένου",
    "Move" : "Μετακίνηση",
    "Copy" : "Αντιγραφή",
    "Move or copy" : "Μετακίνηση ή αντιγραφή",
    "Destination is not a folder" : "Ο προορισμός δεν είναι φάκελος",
    "This file/folder is already in that directory" : "Αυτό το αρχείο/φάκελος βρίσκεται ήδη σε αυτόν τον κατάλογο",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "Δεν μπορείτε να μετακινήσετε ένα αρχείο/φάκελο στον εαυτό του ή σε έναν υποφάκελό του",
    "A file or folder with that name already exists in this folder" : "Ένα αρχείο ή ένας φάκελος με αυτό το όνομα υπάρχει ήδη σε αυτόν τον φάκελο",
    "The files are locked" : "Τα αρχεία είναι κλειδωμένα",
    "The file does not exist anymore" : "Το αρχείο δεν υπάρχει πλέον",
    "Moving \"{source}\" to \"{destination}\" …" : "Μετακίνηση του \"{source}\" στο \"{destination}\" …",
    "_Moving %n file to \"{destination}\" …_::_Moving %n files to \"{destination}\" …_" : ["Μετακίνηση %n αρχείου στο \"{destination}\"  …","Μετακίνηση %n αρχείων στο \"{destination}\" …"],
    "Copying \"{source}\" to \"{destination}\" …" : "Αντιγραφή του \"{source}\" στο \"{destination}\" …",
    "_Copying %n file to \"{destination}\" …_::_Copying %n files to \"{destination}\" …_" : ["Αντιγραφή %n αρχείου στο \"{destination}\" …","Αντιγραφή %n αρχείων στο \"{destination}\" …"],
    "Choose destination" : "Επιλέξτε προορισμό",
    "Copy to {target}" : "Αντιγραφή σε {target}",
    "Move to {target}" : "Μετακίνηση σε {target}",
    "Move or copy operation failed" : "Η λειτουργία μετακίνησης ή αντιγραφής απέτυχε",
    "Open folder" : "Άνοιγμα φακέλου",
    "Open folder {displayName}" : "Άνοιγμα φακέλου {displayName}",
    "Open in Files" : "Άνοιγμα στα Αρχεία",
    "Open locally" : "Άνοιγμα τοπικά",
    "Failed to redirect to client" : "Αποτυχία ανακατεύθυνσης στον πελάτη",
    "Open file locally" : "Άνοιγμα αρχείου τοπικά",
    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Το αρχείο θα πρέπει τώρα να ανοίξει στη συσκευή σας. Εάν δεν ανοίξει, παρακαλούμε ελέγξτε ότι έχετε εγκατεστημένη την εφαρμογή επιφάνειας εργασίας.",
    "Retry and close" : "Δοκιμάστε ξανά και κλείσιμο",
    "Open online" : "Άνοιγμα προβολής στο διαδίκτυο",
    "Details" : "Λεπτομέρειες",
    "Open the details sidebar" : "Άνοιγμα πλευρικής στήλης λεπτομερειών",
    "Unfavorite" : "Αφαίρεση από τα αγαπημένα",
    "View in folder" : "Προβολή στον φάκελο",
    "Type" : "Τύπος",
    "Created new folder \"{name}\"" : "Δημιουργήθηκε νέος φάκελος \"{name}\"",
    "Unable to initialize the templates directory" : "Αδυναμία αρχικοποίησης του καταλόγου προτύπων",
    "Create templates folder" : "Δημιουργία φακέλου προτύπων",
    "Templates" : "Πρότυπα",
    "New template folder" : "Νέος φάκελος προτύπων",
    "In folder" : "Σε φάκελο",
    "Pick folder to search in" : "Επιλέξτε φάκελο για αναζήτηση",
    "Search in all files" : "Αναζήτηση σε όλα τα αρχεία",
    "Search in folder: {folder}" : "Αναζήτηση στον φάκελο: {folder}",
    "One of the dropped files could not be processed" : "Ένα από τα αρχεία που σύρθηκαν δεν μπόρεσε να υποβληθεί σε επεξεργασία",
    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Το πρόγραμμα περιήγησής σας δεν υποστηρίζει το Filesystem API. Οι κατάλογοι δεν θα μεταφορτωθούν",
    "No files to upload" : "Δεν υπάρχουν αρχεία προς μεταφόρτωση",
    "Unable to create the directory {directory}" : "Αδυναμία δημιουργίας του καταλόγου {directory}",
    "Some files could not be uploaded" : "Ορισμένα αρχεία δεν μπόρεσαν να μεταφορτωθούν",
    "Files uploaded successfully" : "Τα αρχεία μεταφορτώθηκαν με επιτυχία",
    "No files to process" : "Δεν υπάρχουν αρχεία προς επεξεργασία",
    "Files copied successfully" : "Τα αρχεία αντιγράφηκαν με επιτυχία",
    "Files moved successfully" : "Τα αρχεία μετακινήθηκαν με επιτυχία",
    "Some files could not be copied" : "Ορισμένα αρχεία δεν μπόρεσαν να αντιγραφούν",
    "Some files could not be moved" : "Ορισμένα αρχεία δεν μπόρεσαν να μετακινηθούν",
    "Conflicts resolution skipped" : "Η επίλυση διενέξεων παραλείφθηκε",
    "Upload cancelled" : "Η μεταφόρτωση ακυρώθηκε",
    "Could not rename \"{oldName}\", it does not exist any more" : "Δεν ήταν δυνατή η μετονομασία του \"{oldName}\", δεν υπάρχει πλέον",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Το όνομα \"{newName}\" χρησιμοποιείται ήδη στον φάκελο \"{dir}\". Παρακαλούμε επιλέξτε ένα διαφορετικό όνομα.",
    "Could not rename \"{oldName}\"" : "Δεν ήταν δυνατή η μετονομασία του \"{oldName}\"",
    "This operation is forbidden" : "Αυτή η λειτουργία απαγορεύεται",
    "This folder is unavailable, please try again later or contact the administration" : "Αυτός ο φάκελος δεν είναι διαθέσιμος, παρακαλούμε δοκιμάστε ξανά αργότερα ή επικοινωνήστε με τη διαχείριση",
    "Storage is temporarily not available" : "Ο αποθηκευτικός χώρος δεν είναι προσωρινά διαθέσιμος",
    "Unexpected error: {error}" : "Απρόσμενο σφάλμα: {error}",
    "Unknown error" : "Άγνωστο σφάλμα",
    "_%n file_::_%n files_" : ["%n αρχείο","%n αρχεία"],
    "_%n folder_::_%n folders_" : ["%n φάκελος","%n φάκελοι"],
    "_%n hidden_::_%n hidden_" : ["%n κρυφό","%n κρυφά"],
    "Folder name must not be empty." : "Το όνομα του φακέλου δεν πρέπει να είναι κενό.",
    "Filename must not be empty." : "Το όνομα αρχείου δεν πρέπει να είναι κενό.",
    "\"{char}\" is not allowed inside a folder name." : "Το \"{char}\" δεν επιτρέπεται μέσα σε όνομα φακέλου.",
    "\"{char}\" is not allowed inside a filename." : "Το \"{char}\" δεν επιτρέπεται μέσα σε όνομα αρχείου.",
    "\"{segment}\" is a reserved name and not allowed for folder names." : "Το \"{segment}\" είναι δεσμευμένο όνομα και δεν επιτρέπεται για ονόματα φακέλων.",
    "\"{segment}\" is a reserved name and not allowed for filenames." : "Το \"{segment}\" είναι δεσμευμένο όνομα και δεν επιτρέπεται για ονόματα αρχείων.",
    "\"{extension}\" is not an allowed filetype." : "Το \"{extension}\" δεν είναι επιτρεπτός τύπος αρχείου.",
    "Folder names must not end with \"{extension}\"." : "Τα ονόματα φακέλων δεν πρέπει να τελειώνουν με \"{extension}\".",
    "Filenames must not end with \"{extension}\"." : "Τα ονόματα αρχείων δεν πρέπει να τελειώνουν με \"{extension}\".",
    "Invalid folder name." : "Μη έγκυρο όνομα φακέλου.",
    "List of favorite files and folders." : "Λίστα αγαπημένων αρχείων και φακέλων.",
    "No favorites yet" : "Κανένα αγαπημένο ακόμη",
    "Files and folders you mark as favorite will show up here" : "Τα αρχεία και οι φάκελοι που επισημαίνετε ως αγαπημένα θα εμφανίζονται εδώ",
    "List of your files and folders." : "Λίστα των αρχείων και φακέλων σας.",
    "Folder tree" : "Δέντρο φακέλων",
    "List of your files and folders that are not shared." : "Λίστα των αρχείων και φακέλων σας που δεν είναι κοινόχρηστα.",
    "No personal files found" : "Δεν βρέθηκαν προσωπικά αρχεία",
    "Files that are not shared will show up here." : "Τα αρχεία που δεν είναι κοινόχρηστα θα εμφανίζονται εδώ.",
    "Recent" : "Πρόσφατα",
    "List of recently modified files and folders." : "Λίστα των πρόσφατα τροποποιημένων αρχείων και φακέλων.",
    "No recently modified files" : "Δεν υπάρχουν πρόσφατα τροποποιημένα αρχεία",
    "Files and folders you recently modified will show up here." : "Τα αρχεία και οι φάκελοι που τροποποιήσατε πρόσφατα θα εμφανίζονται εδώ.",
    "Search" : "Αναζήτηση",
    "Search results within your files." : "Αποτελέσματα αναζήτησης στα αρχεία σας.",
    "This node is unavailable" : "Αυτός ο κόμβος δεν είναι διαθέσιμος",
    "Renamed \"{oldName}\" to \"{newName}\"" : "Μετονομασία του \"{oldName}\" σε \"{newName}\"",
    "Clear filter" : "Εκκαθάριση φίλτρου",
    "Open file sidebar" : "Άνοιγμα πλευρικής στήλης αρχείου",
    "Search everywhere …" : "Αναζήτηση παντού …",
    "Search here …" : "Αναζήτηση εδώ …",
    "Preparing …" : "Προετοιμασία …",
    "Submitting fields …" : "Υποβολή πεδίων …",
    "Invalid path selected" : "Επιλέχθηκε μη έγκυρη διαδρομή",
    "Choose file or folder to transfer" : "Επιλέξτε αρχείο ή φάκελο για μεταφορά",
    "Change" : "Αλλαγή",
    "Shared by link" : "Κοινοποιήθηκε μέσω συνδέσμου",
    "Shared" : "Κοινοποιήθηκε",
    "You" : "Εσείς",
    "Shared multiple times with different people" : "Κοινοποιήθηκε πολλές φορές με διαφορετικά άτομα",
    "Unable to change the favorite state of the file" : "Αδυναμία αλλαγής της κατάστασης αγαπημένου του αρχείου",
    "Error while loading the file data" : "Σφάλμα κατά τη φόρτωση των δεδομένων αρχείου",
    "Tags" : "Ετικέτες",
    "Save as …" : "Αποθήκευση ως …",
    "Converting files …" : "Μετατροπή αρχείων …",
    "Converting file …" : "Μετατροπή αρχείου …",
    "No entries found in this folder" : "Δεν βρέθηκαν καταχωρήσεις σε αυτόν τον φάκελο",
    "Select all" : "Επιλογή όλων",
    "Upload too large" : "Πολύ μεγάλο αρχείο για μεταφόρτωση",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Τα αρχεία που προσπαθείτε να μεταφορτώσετε υπερβαίνουν το μέγιστο μέγεθος μεταφόρτωσης αρχείων σε αυτόν τον διακομιστή."
},
"nplurals=2; plural=(n != 1);");
