OC.L10N.register(
    "photos",
    {
    "Public link" : "Нийтийн холбоос",
    "Photos" : "Зурагнууд",
    "On This Day" : "Энэ өдөр",
    "Your memories under your control" : "Таны дурсамжууд таны хяналтанд",
    "All media" : "Бүх медиа",
    "Videos" : "Бичлэгүүд",
    "Albums" : "Цомгууд",
    "Collaborative albums" : "Хамтарсан цомгууд",
    "People" : "Хүмүүс",
    "Folders" : "Хавтсууд",
    "Favorites" : "Онцолсон",
    "On this day" : "Энэ өдөр",
    "Shared with you" : "тантай хуваалцсан",
    "Tags" : "Tag-үүд",
    "Places" : "Газрууд",
    "Map" : "Газрын зураг",
    "Photos settings" : "Зургийн тохиргоо",
    "Mark selection as favorite" : "Сонголтыг дуртайд нэмэх",
    "Add selection to favorites" : "Сонголтыг дуртайд нэмэх",
    "Remove selection from favorites" : "Сонголтыг дуртайгаас хасах",
    "This name is already in use." : "Энэ нэр аль хэдийн ашиглагдаж байна.",
    "\"{char}\" is not allowed inside a filename." : "\"{char}\" файлын нэрэнд зөвшөөрөгдөхгүй.",
    "Invalid filename." : "Буруу файлын нэр.",
    "Name of the album" : "Цомгийн нэр",
    "Location of the album" : "Цомгийн байршил",
    "Back" : "буцах",
    "Add collaborators" : "Хамтрагч нэмэх",
    "Save" : "Хадгалах",
    "Create album" : "Цомог үүсгэх",
    "Add to Album" : "Цомогт нэмэх",
    "Add selection to album {albumName}" : "Сонголтыг {albumName} цомогт нэмэх",
    "Shared by" : "Хуваалцсан",
    "Create a new album." : "Шинэ цомог үүсгэх.",
    "Create new album" : "Шинэ цомог үүсгэх",
    "New album" : "Шинэ цомог",
    "_%n item_::_%n photos and videos_" : ["%n зүйл","%n зураг, видео"],
    "Failed to fetch collaborators list." : "Хамтрагчдын жагсаалтыг авахад алдаа гарлаа.",
    "Failed to update album." : "Цомог шинэчлэхэд алдаа гарлаа.",
    "Add people or groups who can edit your album" : "Цомгийг засах боломжтой хүмүүс эсвэл бүлгүүд нэмэх",
    "Search people or groups" : "Хүмүүс эсвэл бүлгүүд хайх",
    "No recommendations. Start typing." : "Санал байхгүй. Бичиж эхлээрэй.",
    "Copy the public link" : "Нийтийн холбоосыг хуулах",
    "Public link copied!" : "Нийтийн холбоос хуулагдлаа!",
    "Copy public link" : "Нийтийн холбоос хуулах",
    "Delete the public link" : "Нийтийн холбоосыг устгах",
    "Create public link share" : "Нийтийн холбоосоор хуваалцах",
    "Share via public link" : "Нийтийн холбоосоор хуваалцах",
    "This collection does not exist" : "Энэ цуглуулга байхгүй байна",
    "An error occurred" : "Алдаа гарлаа",
    "No picture for this day" : "Энэ өдөр зураг байхгүй",
    "Picture taken on this day will show up here." : "Энэ өдөр авсан зургууд энд харагдана.",
    "More photos from this day" : "Энэ өдрийн бусад зургууд",
    "_%n photos_::_%n photos_" : ["%n зураг","%n зураг"],
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n оноогоогүй зураг","%n оноогоогүй зураг"],
    "Favorite" : "Дуртай",
    "Favorite image, open the full size \"{name}\" image" : "Дуртай зураг, \"{name}\" зургийг бүтэн хэмжээгээр нээх",
    "Open the full size \"{name}\" image" : "\"{name}\" зургийг бүтэн хэмжээгээр нээх",
    "Select image {imageName}" : "{imageName} зураг сонгох",
    "Open the \"{name}\" folder" : "\"{name}\" хавтас нээх",
    "Go back" : "Буцах",
    "Select a custom date range" : "Өөрийн огнооны хүрээ сонгох",
    "Select a date range" : "Огнооны хүрээ сонгох",
    "Date range" : "Огнооны хүрээ",
    "Select filters" : "Шүүлтүүр сонгох",
    "Dates" : "Огноонууд",
    "Jump to specific date in list" : "Жагсаалтад тодорхой огноо руу очих",
    "Jump to {date}" : "{date} руу очих",
    "Add to {destination}" : "{destination}-т нэмэх",
    "The destination folder is owned by {owner}" : "Очих хавтас {owner}-ийн эзэмшилд байна",
    "There are no photos or videos yet!" : "Одоогоор зураг эсвэл видео байхгүй байна!",
    "_{years} year ago_::_{years} years ago_" : ["{years} жилийн өмнө","{years} жилийн өмнө"],
    "Squared photos view" : "Дөрвөлжин зургийн харагдац",
    "Delete source directory" : "Эх хавтас устгах",
    "Pick folder" : "Хавтас сонгох",
    "Select a source folder for your media" : "Медиад зориулсан эх хавтас сонгоно уу",
    "Media folders" : "Медиа хавтаснууд",
    "Choose the folders from where photos and videos are shown." : "Зураг болон видео харуулах хавтаснуудыг сонгоно уу.",
    "All folders" : "Бүх хавтас",
    "Add a Photos source for the timelines" : "Цаг хугацааны шугамд зургийн эх үүсвэр нэмэх",
    "Add folder" : "Хавтас нэмэх",
    "Home" : "Нүүр",
    "Select the default upload location for your media" : "Медиагийн өгөгдмөл оруулах байршлыг сонгоно уу",
    "Upload folder" : "Оруулах хавтас",
    "General" : "ерөнхий",
    "_%n photo_::_%n photos_" : ["%n зураг","%n зураг"],
    "Unselect all" : "Бүгдийг сонголтоос хасах",
    "Add photos to this album" : "Энэ цомогт зураг нэмэх",
    "Manage collaborators for this album" : "Энэ цомгийн хамтрагчдыг удирдах",
    "Open actions menu" : "Үйлдлийн цэс нээх",
    "Edit album details" : "Цомгийн дэлгэрэнгүйг засах",
    "Download all files in album" : "Цомог дахь бүх файлыг татах",
    "Delete album" : "Цомог устгах",
    "Download selected files" : "Сонгосон файлуудыг татах",
    "Remove selection from album" : "Сонголтыг цомгоос хасах",
    "This album does not have any photos or videos yet!" : "Энэ цомогт одоогоор зураг эсвэл видео байхгүй байна!",
    "Add photos to {albumName}" : "{albumName}-т зураг нэмэх",
    "Manage collaborators" : "Хамтрагчдыг удирдах",
    "Save collaborators for this album." : "Энэ цомгийн хамтрагчдыг хадгалах.",
    "Cover photo for album {albumName}" : "{albumName} цомгийн нүүр зураг",
    "There is no album yet!" : "Одоогоор цомог байхгүй байна!",
    "This person could not be found" : "Энэ хүнийг олсонгүй",
    "Rename person" : "Хүний нэр өөрчлөх",
    "Merge with different person" : "Өөр хүнтэй нэгтгэх",
    "Download selected photos" : "Сонгосон зургуудыг татах",
    "Remove from favorites" : "Remove from favorites",
    "Remove person" : "Хүн устгах",
    "Name of this person" : "Энэ хүний нэр",
    "Save." : "Хадгалах.",
    "Merge person" : "Хүн нэгтгэх",
    "Move to different person" : "Өөр хүн рүү зөөх",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Зургийг өөр хүн рүү зөөх","Зургуудыг өөр хүн рүү зөөх"],
    "_Remove photo from person_::_Remove photos from person_" : ["Хүнээс зураг хасах","Хүнээс зургуудыг хасах"],
    "This might take some time depending on the size of your photo library." : "Таны зургийн сангийн хэмжээнээс хамаарч хэсэг хугацаа шаардагдаж магадгүй.",
    "Recognized people will show up here" : "Таних хүмүүс энд харагдана",
    "This folder does not exist" : "Энэ хавтас байхгүй байна",
    "Loading folders…" : "Хавтаснуудыг ачааллаж байна…",
    "No photos in here" : "Энд зураг байхгүй",
    "Taken on {date} at {time}" : "{date}-нд {time}-д авсан",
    "This place does not have any photos or videos yet!" : "Энэ газарт одоогоор зураг эсвэл видео байхгүй байна!",
    "Add photos to this place" : "Энэ газарт зураг нэмэх",
    "Cover photo for place {placeName}" : "{placeName} газрын нүүр зураг",
    "There is no place yet!" : "Одоогоор газар байхгүй байна!",
    "Cover photo for shared album {albumName}" : "Хуваалцсан {albumName} цомгийн нүүр зураг",
    "Back to tags overview" : "Тагуудын тоймд буцах",
    "No photos with this tag yet" : "Энэ тагтай зураг одоогоор байхгүй",
    "No tags yet" : "Одоогоор таг байхгүй",
    "Photos with tags will show up here" : "Тагтай зургууд энд харагдана",
    "Popular tags" : "Түгээмэл тагууд",
    "All tags" : "Бүх таг",
    "Create new album from filters" : "Шүүлтүүрүүдээс шинэ цомог үүсгэх",
    "One of the source folders does not exist" : "Эх хавтаснуудын нэг байхгүй байна",
    "Add to album" : "Цомогт нэмэх",
    "Delete selection" : "Сонголтыг устгах",
    "No photos or videos in here" : "Энд зураг эсвэл видео байхгүй",
    "Unassigned faces" : "Хуваарилаагүй царайнууд",
    "Failed to fetch collection." : "Цуглуулга авахад алдаа гарлаа.",
    "Failed to fetch collections list." : "Цуглуулгуудын жагсаалтыг авахад алдаа гарлаа.",
    "Failed to fetch faces list." : "Царайнуудын жагсаалтыг авахад алдаа гарлаа.",
    "Error fetching files" : "Файлуудыг авахад алдаа гарлаа",
    "All your media" : "Таны бүх медиа",
    "Album {title}" : "{title} цомог",
    "Shared Albums" : "Хуваалцсан цомгууд",
    "Shared album {title}" : "Хуваалцсан {title} цомог",
    "Public album {title}" : "Нийтийн {title} цомог",
    "Tagged photos" : "Таглагдсан зургууд",
    "Tagged photo {title}" : "Таглагдсан {title} зураг",
    "{title}'s face" : "{title}-ийн царай",
    "Last week" : "Өнгөрсөн долоо хоног",
    "Last Month" : "Өнгөрсөн сар",
    "Custom…" : "Өөрийн…",
    "{startDate} to {endDate}" : "{startDate}-с {endDate}",
    "Failed to add {fileBaseName} to collection {collectionFileName}" : "{fileBaseName}-г {collectionFileName} цуглуулгад нэмэхэд алдаа гарлаа",
    "Failed to delete {fileBaseName}" : "{fileBaseName} устгахад алдаа гарлаа",
    "Failed to create {collectionFileName}" : "{collectionFileName} үүсгэхэд алдаа гарлаа",
    "Failed to rename {currentCollectionFileName} to {newCollectionFileName}" : "{currentCollectionFileName}-г {newCollectionFileName} болгож нэрлэх амжилтгүй боллоо",
    "Failed to update properties of {collectionFileName} with {properties}" : "{collectionFileName}-ийн шинж чанарыг {properties}-ээр шинэчлэхэд алдаа гарлаа",
    "Delete collection" : "Цуглуулга устгах",
    "Leave shared album" : "Хуваалцсан цомгоос гарах",
    "Are you sure you want to delete {collectionName}? This action cannot be undone." : "{collectionName}-г устгахдаа итгэлтэй байна уу? Энэ үйлдлийг буцаах боломжгүй.",
    "Failed to delete {collectionFileName}" : "{collectionFileName} устгахад алдаа гарлаа",
    "Failed to move {fileBaseName} to person {faceName}" : "{fileBaseName}-г {faceName} хүн рүү зөөхөд алдаа гарлаа",
    "Failed to remove {fileBaseName}" : "{fileBaseName} устгахад алдаа гарлаа",
    "Failed to rename {oldName} to {faceName}" : "{oldName}-г {faceName} болгож өөрчлөхөд алдаа гарлаа",
    "Failed to delete {faceName}" : "{faceName} устгахад алдаа гарлаа",
    "Failed to delete {fileId}" : "{fileId} устгахад алдаа гарлаа",
    "Failed to delete {fileName}" : "{fileName} устгахад алдаа гарлаа",
    "Failed to set favorite state for {fileId}" : "{fileId}-ийн дуртай төлөвийг тохируулахад алдаа гарлаа",
    "Failed to set favorite state for {fileName}" : "{fileName}-ийн дуртай төлөвийг тохируулахад алдаа гарлаа",
    "Could not load photos folder" : "Зургийн хавтас ачаалах боломжгүй",
    "Group" : "Бүлэг",
    "Remove {collaboratorLabel} from the collaborators list" : "{collaboratorLabel}-г хамтрагчдын жагсаалтаас хасах",
    "Enable squared photos view" : "Дөрвөлжин зургийн харагдацыг идэвхжүүлэх",
    "Choose default Photos upload and Albums location" : "Зураг оруулах болон цомгийн өгөгдмөл байршлыг сонгох",
    "Choose a different folder" : "Өөр хавтас сонгох",
    "View" : "Харах",
    "Choose the folder where photos and albums are uploaded to." : "Зураг болон цомгуудыг оруулах хавтсыг сонгоно уу.",
    "Loading folders …" : "Хавтасуудыг ачааллаж байна …",
    "Details" : "Дэлгэрэнгүй",
    "Cancel" : "Cancel",
    "Confirm" : "Батлах"
},
"nplurals=2; plural=(n != 1);");
