OC.L10N.register(
    "files",
    {
    "Added to favorites" : "Sık kullanılanlara eklendi",
    "Removed from favorites" : "Sık kullanılanlardan çıkarıldı",
    "You added {file} to your favorites" : "{file} dosyasını sık kullandıklarınıza eklediniz",
    "You removed {file} from your favorites" : "{file} dosyasını sık kullandıklarınızdan çıkardınız",
    "Favorites" : "Sık kullanılanlar",
    "File changes" : "Dosya değişikleri",
    "Created by {user}" : "{user} tarafından oluşturuldu",
    "Changed by {user}" : "{user} tarafından değiştirildi",
    "Deleted by {user}" : "{user} tarafından silindi",
    "Restored by {user}" : "{user} tarafından geri yüklendi",
    "Renamed by {user}" : "{user} tarafından adı değiştirildi",
    "Moved by {user}" : "{user} tarafından taşındı",
    "\"remote account\"" : "\"uzak hesap\"",
    "You created {file}" : "{file} dosyasını oluşturdunuz",
    "You created an encrypted file in {file}" : "{file} içinde şifrelenmiş bir dosya oluşturdunuz",
    "{user} created {file}" : "{user}, {file} dosyasını oluşturdu",
    "{user} created an encrypted file in {file}" : "{user} kullanıcısı {file} içinde şifrelenmiş bir dosya oluşturdu",
    "{file} was created in a public folder" : "{file} herkese açık klasör içinde oluşturuldu",
    "You changed {file}" : "{file} dosyasını değiştirdiniz",
    "You changed an encrypted file in {file}" : "{file} içindeki şifrelenmiş bir dosyayı değiştirdiniz",
    "{user} changed {file}" : "{user}, {file} dosyasını değiştirdi",
    "{user} changed an encrypted file in {file}" : "{user} kullanıcısı {file} içindeki şifrelenmiş bir dosyayı değiştirdi",
    "You deleted {file}" : "{file} dosyasını sildiniz",
    "You deleted an encrypted file in {file}" : "{file} içindeki şifrelenmiş bir dosyayı sildiniz",
    "{user} deleted {file}" : "{user}, {file} dosyasını sildi",
    "{user} deleted an encrypted file in {file}" : "{user} kullanıcısı {file} içindeki şifrelenmiş bir dosyayı sildi",
    "You restored {file}" : "{file} dosyasını geri yüklediniz",
    "{user} restored {file}" : "{user}, {file} dosyasını geri yükledi",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "{oldfile} (gizli) dosyasını {newfile} (gizli) olarak yeniden adlandırdınız",
    "You renamed {oldfile} (hidden) to {newfile}" : "{oldfile} (gizli) dosyasını {newfile} olarak yeniden adlandırdınız",
    "You renamed {oldfile} to {newfile} (hidden)" : "{oldfile} dosyasını {newfile} (gizli) olarak yeniden adlandırdınız",
    "You renamed {oldfile} to {newfile}" : "{oldfile} dosyasının adını {newfile} olarak değiştirdiniz",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "[user], {oldfile} (gizli) dosyasını {newfile} (gizli) olarak yeniden adlandırdı",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "[user], {oldfile} (gizli) dosyasını {newfile} olarak yeniden adlandırdı",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "[user], {oldfile} dosyasını {newfile} (gizli) olarak yeniden adlandırdı",
    "{user} renamed {oldfile} to {newfile}" : "{user}, {oldfile} dosyasının adını {newfile} olarak değiştirdi",
    "You moved {oldfile} to {newfile}" : "{oldfile} dosyasını {newfile} klasörüne taşıdınız",
    "{user} moved {oldfile} to {newfile}" : "{user}, {oldfile} dosyasının {newfile} dosyasına taşıdı",
    "A file has been added to or removed from your <strong>favorites</strong>" : "<strong>Sık kullandıklarınıza</strong> bir dosya eklendi ya da silindi",
    "Files" : "Dosyalar",
    "A file or folder has been <strong>changed</strong>" : "Bir dosya ya da klasör <strong>değiştirildiğinde</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "Sık kullanılan bir dosya ya da klasör <strong>değiştirildiğinde</strong>",
    "Failed to authorize" : "İzin verilemedi",
    "Invalid folder path" : "Klasör yolu geçersiz",
    "Folder not found" : "Klasör bulunamadı",
    "The file cannot be found" : "Dosya bulunamadı",
    "The destination path does not exist: %1$s" : "Hedef yolu bulunamadı: %1$s",
    "You do not have permission to create a file at the specified location" : "Belirtilen konumda bir dosya oluşturma izniniz yok",
    "The file could not be converted." : "Dosya dönüştürülemedi.",
    "Could not get relative path to converted file" : "Dönüştürülen dosyanın yolu göreli yolu alınamadı",
    "Limit must be a positive integer." : "Sınır değeri bir pozitif tam sayı olmalıdır.",
    "The replacement character may only be a single character." : "Değiştirilecek karakter yalnızca tek bir karakter olabilir.",
    "Filename sanitization already started." : "Dosya adı sadeleştirme işlemi zaten başlatılmış.",
    "No filename sanitization in progress." : "İşlenen bir dosya sadeleştirmesi yok.",
    "Favorite files" : "Sık kullanılan dosyalar",
    "No favorites" : "Sık kullanılan bir öge yok",
    "More favorites" : "Diğer sık kullanılanlar",
    "No read permission on file." : "Dosyayı okuma izni yok.",
    "Accept" : "Kabul et",
    "Reject" : "Reddet",
    "Incoming ownership transfer from {user}" : "{user} kullanıcısından gelen sahiplik aktarımı ",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "{path} yolunu onaylamak istiyor musunuz?\n\nNot: Onay verdikten sonra aktarım işleminin tamamlanması 1 saat kadar sürebilir.",
    "Ownership transfer denied" : "Sahiplik aktarımı reddedildi",
    "Your ownership transfer of {path} was denied by {user}." : "{path} sahipliğini aktarma işleminiz {user} tarafından reddedildi.",
    "Ownership transfer failed" : "Sahiplik aktarılamadı",
    "Your ownership transfer of {path} to {user} failed." : "{path} yolundaki sahipliğiniz {user} kullanıcısına aktarılamadı.",
    "The ownership transfer of {path} from {user} failed." : "{path} yolundaki {user} kullanıcısının sahipliği size aktarılamadı.",
    "Ownership transfer done" : "Sahiplik aktarıldı",
    "Your ownership transfer of {path} to {user} has completed." : "{path} yolundaki sahipliğiniz {user} kullanıcısına aktarıldı.",
    "The ownership transfer of {path} from {user} has completed." : "{path} yolundaki {user} kullanıcısının sahipliği size aktarıldı.",
    "in %s" : "%s içinde",
    "Transferred from %1$s on %2$s" : "%1$s üzerinden %2$s zamanında aktarıldı",
    "Create files" : "Dosya oluşturma",
    "Delete files" : "Dosyaları sil",
    "Download files" : "Dosya indirme",
    "When disabled, the option to download will be hidden" : "Kapatıldığında, indirme seçeneği gizlenir",
    "View files" : "Dosyaları görüntüleme",
    "Edit files" : "Dosyaları düzenleme",
    "Show files in grid view" : "Dosyaları ızgara yerleşiminde görüntüle",
    "File" : "Dosya",
    "File Management" : "Dosya yönetimi",
    "Home" : "Giriş",
    "Target folder does not exist any more" : "Hedef klasör artık yok",
    "Reload current directory" : "Geçerli klasörü yeniden yükle",
    "Go to the \"{dir}\" directory" : "\"{dir}\" klasörüne git",
    "Current directory path" : "Geçerli klasör yolu",
    "Share" : "Paylaş",
    "Reload content" : "İçeriği yeniden yükle",
    "Your have used your space quota and cannot upload files anymore" : "Depolama alanınızın tümünü kullandığınız için başka dosya yüklemezsiniz",
    "You do not have permission to upload or create files here." : "Buraya dosya yükleme ya da oluşturma izniniz yok.",
    "Drag and drop files here to upload" : "Yüklemek istediğiniz dosyaları sürükleyip buraya bırakın",
    "Favorite" : "Sık kullanılanlara ekle",
    "Back" : "Geri",
    "Toggle selection for file \"{displayName}\"" : "\"{displayName}\" dosyasını seç/bırak",
    "Toggle selection for folder \"{displayName}\"" : "\"{displayName}\" klasörünü seç/bırak",
    "File is loading" : "Dosya yükleniyor",
    "Folder is loading" : "Klasör yükleniyor",
    "Filename" : "Dosya adı",
    "Folder name" : "Klasör adı",
    "{displayName} (unavailable)" : "{displayName} (kullanılamıyor)",
    "Another entry with the same name already exists." : "Aynı adlı bir kayıt zaten var.",
    "Invalid filename." : "Dosya adı geçersiz.",
    "Rename file" : "Dosyayı yeniden adlandır",
    "Recently created" : "Son oluşturulanlar",
    "Folder" : "Klasör",
    "Unknown file type" : "Dosya türü bilinmiyor",
    "{ext} image" : "{ext} görsel",
    "{ext} video" : "{ext} görüntü",
    "{ext} audio" : "{ext} ses",
    "{ext} text" : "{ext} yazı",
    "Pending" : "Bekliyor",
    "Unknown date" : "Tarih bilinmiyor",
    "Active filters" : "Etkin süzgeçler",
    "Remove filter" : "Süzgeci kaldır",
    "Today" : "Bugün",
    "Last 7 days" : "Önceki 7 gün",
    "Last 30 days" : "Önceki 30 gün",
    "This year ({year})" : "Bu yıl ({year})",
    "Last year ({year})" : "Önceki yıl ({year})",
    "Custom range" : "Özel aralık",
    "Custom date range" : "Özel tarih aralığı",
    "Search everywhere" : "Her yerde ara",
    "Documents" : "Belgeler",
    "Spreadsheets" : "Elektronik tablolar",
    "Presentations" : "Sunumlar",
    "PDFs" : "PDF dosyaları",
    "Folders" : "Klasörler",
    "Audio" : "Ses",
    "Images" : "Görseller",
    "Videos" : "Görüntüler",
    "Filters" : "Süzgeçler",
    "Back to filters" : "Süzgeçlere dön",
    "Appearance" : "Görünüm",
    "Show hidden files" : "Gizli dosyaları görüntüle",
    "Show file type column" : "Dosya türü sütunu görüntülensin",
    "Show file extensions" : "Dosya uzantıları görüntülensin",
    "Crop image previews" : "Görsel ön izlemeleri kırpılsın",
    "General" : "Genel",
    "Sort favorites first" : "Sık kullanılanlar üstte sıralansın",
    "Sort folders before files" : "Klasörler dosyaların üzerinde sıralansın",
    "Enable folder tree view" : "Klasör ağacı görünümünü aç",
    "Default view" : "Varsayılan görünüm",
    "All files" : "Tüm dosyalar",
    "Personal files" : "Kişisel dosyalar",
    "Additional settings" : "Ek ayarlar",
    "Actions" : "İşlemler",
    "File actions" : "Dosya işlemleri",
    "Selection" : "Seçim",
    "Select all files" : "Tüm dosyaları seçer",
    "Deselect all" : "Tümünü bırak",
    "Select or deselect" : "Seç ya da bırak",
    "Select a range" : "Bir aralık seçin",
    "Navigation" : "Gezinme",
    "Go to parent folder" : "Üst klasöre git",
    "Go to file above" : "Yukarıdaki dosyaya git",
    "Go to file below" : "Aşağıdaki dosyaya git",
    "Go left in grid" : "Izgarada sola git",
    "Go right in grid" : "Izgarada sağa git",
    "View" : "Görüntüle",
    "Toggle grid view" : "Tablo görünümünü aç/kapat",
    "Show those shortcuts" : "Bu kısayolları görüntüler",
    "Warnings" : "Uyarılar",
    "Warn before changing a file extension" : "Dosya uzantıları değiştirilmeden önce uyarı görüntülensin",
    "Warn before deleting a file" : "Bir dosya silinmeden önce uyarı verilsin",
    "WebDAV URL" : "WebDAV adresi",
    "Create an app password" : "Bir uygulama parolası oluştur",
    "Required for WebDAV authentication because Two-Factor Authentication is enabled for this account." : "Bu hesap için iki adımlı doğrulama açıldığından WebDAV kimlik doğrulaması için gereklidir.",
    "How to access files using WebDAV" : "WebDAV ile dosyalara nasıl erişilir",
    "Total rows summary" : "Toplam satır özeti",
    "Toggle selection for all files and folders" : "Tüm dosyaları ve klasörleri seç/bırak",
    "Name" : "Ad",
    "File type" : "Dosya türü",
    "Size" : "Boyut",
    "Modified" : "Değiştirilme",
    "{displayName}: failed on some elements" : "{displayName}: Bazı bileşenlerde tamamlanamadı",
    "{displayName}: done" : "{displayName}: Tamamlandı",
    "{displayName}: failed" : "{displayName}: Tamamlanamadı",
    "(selected)" : "(seçilmiş)",
    "List of files and folders." : "Dosya ve klasörlerin listesi.",
    "You have used your space quota and cannot upload files anymore." : "Depolama alanınızın tümünü kullandığınız için başka dosya yüklemezsiniz.",
    "Column headers with buttons are sortable." : "Düğmeler olan sütunlar sıralanabilir.",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Başarımı olumsuz etkilememek için listenin tümü görüntülenmiyor. Listede ilerledikçe dosyalar görüntülenecek.",
    "File not found" : "Dosya bulunamadı",
    "_{count} selected_::_{count} selected_" : ["{count} seçilmiş","{count} seçilmiş"],
    "Views" : "Görünümler",
    "Search everywhere …" : "Her yerde ara…",
    "Search here …" : "Burada ara…",
    "Search scope options" : "Arama kapsamı seçenekleri",
    "Search here" : "Burada ara",
    "Owner" : "Sahibi",
    "{usedQuotaByte} used" : "{usedQuotaByte} kullanılmış",
    "{used} of {quota} used" : "{used} / {quota} kullanılmış",
    "{relative}% used" : "%{relative} kullanılmış",
    "Could not refresh storage stats" : "Depolama istatistikleri yenilenemedi",
    "Your storage is full, files can not be updated or synced anymore!" : "Boş depolama alanınız kalmadı. Artık dosyalar güncellenmeyecek ya da eşitlenmeyecek!",
    "Storage information" : "Depolama alanı bilgileri",
    "Storage quota" : "Depolama alanı kotası",
    "New folder" : "Yeni klasör",
    "Create new folder" : "Yeni klasör oluştur",
    "This name is already in use." : "Bu ad zaten kullanılıyor.",
    "Create" : "Oluştur",
    "Files starting with a dot are hidden by default" : "Bir nokta ile başlayan dosyalar varsayılan olarak gizlidir",
    "Failed to start filename sanitization." : "Dosya adı sadeleştirmesi başlatılamadı.",
    "Failed to refresh filename sanitization status." : "Dosya adı sadeleştirmesi durumu yenilenemedi.",
    "Filename sanitization in progress." : "Dosya adı sadeleştirmesi işleniyor.",
    "Currently {processedUsers} of {totalUsers} accounts are already processed." : "{processedUsers} / {totalUsers} hesap zaten işlenmiş.",
    "Preparing …" : "Hazırlanıyor…",
    "Refresh" : "Yenlle",
    "All files have been santized for Windows filename support." : "Tüm dosya adları Windows dosya adı desteğine göre temizlendi.",
    "Some files could not be sanitized, please check your logs." : "Bazı dosya adları sadeleştirilemedi. Lütfen günlük kayıtlarına bakın.",
    "Sanitization errors" : "Sadeleştirme sorunları",
    "Not sanitized filenames" : "Sadeleştirilmeyen dosya adları",
    "Windows filename support has been enabled." : "Windows dosya adı desteği açıldı.",
    "While this blocks users from creating new files with unsupported filenames, existing files are not yet renamed and thus still may break sync on Windows." : "Kullanıcıların desteklenmeyen dosya adlarıyla yeni dosyalar oluşturmasını engelleniyor ancak var olan dosyalar henüz yeniden adlandırılmadı ve bu nedenle Windows ile eşitlemeyi aksatabilir.",
    "You can trigger a rename of files with invalid filenames, this will be done in the background and may take some time." : "Geçersiz adları olan dosyaların yeniden adlandırılması işlemini başlatabilirsiniz. Bu işlem arka planda yapılır ve biraz zaman alabilir.",
    "Please note that this may cause high workload on the sync clients." : "Bu işlemin eşitleme istemcilerinde yüksek iş yüküne neden olabileceğini lütfen unutmayın.",
    "Limit" : "Sınır",
    "This allows to configure how many users should be processed in one background job run." : "Bu seçenek, bir arka plan işleminde kaç kullanıcının işlenebileceğini yapılandırır.",
    "Sanitize filenames" : "Dosya adlarını sadeleştir",
    "(starting)" : "(başlatılıyor)",
    "Fill template fields" : "Kalıp alanlarını doldur",
    "Submitting fields …" : "Alanlar gönderiliyor…",
    "Submit" : "Gönder",
    "Choose a file or folder to transfer" : "Sahipliği aktarılacak bir dosya ya da klasör seçin",
    "Transfer \"{path}\"" : "\"{path}\" aktar",
    "Select file or folder" : "Dosya ya da klasör seçin",
    "Transfer" : "Sahipliği aktar",
    "Transfer {path} to {userid}" : "{path} yolunun sahipliğini {userid} kullanıcısına aktar",
    "Error while opening file picker for transfer ownership" : "Sahipliğin aktarılması için dosya seçici açılırken sorun çıktı",
    "Error while searching for users" : "Kullanıcılar aranırken sorun çıktı",
    "Ownership transfer request sent" : "Sahiplik aktarımı isteği gönderildi",
    "Cannot transfer ownership of a file or folder you do not own" : "Sahibi olmadığınız bir dosya ya da klasörün sahipliğini aktaramazsınız",
    "Error while sending ownership transfer request" : "Sahiplik aktarımı isteği gönderilirken sorun çıktı",
    "Transfer ownership of a file or folder" : "Bir dosya ya da klasörün sahipliğini aktarabilirsiniz",
    "File or folder to transfer" : "Aktarılacak dosya ya da klasör",
    "No file or folder selected" : "Herhangi bir dosya ya da klasör seçilmemiş",
    "New owner" : "Yeni sahip",
    "You need to select a file or folder to transfer ownership." : "Sahipliği aktarmak için bir dosya veya klasör seçmelisiniz.",
    "You need to select a new owner for the file or folder." : "Dosya ya da klasör için yeni bir sahip seçmelisiniz.",
    "Keep {old}" : "{old} kalsın",
    "Keep without extension" : "Uzantı olmadan kalsın",
    "Use {new}" : "{new} kullanılsın",
    "Remove extension" : "Uzantıyı kaldır",
    "Change file extension" : "Dosya uzantısını değiştir",
    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "\"{old}\" dosya uzantısının \"{new}\" olarak değiştirilmesi dosyayı okunamaz yapabilir.",
    "Removing the file extension \"{old}\" may render the file unreadable." : "\"{old}\" dosya uzantısının kaldırılması dosyayı okunamaz yapabilir.",
    "Adding the file extension \"{new}\" may render the file unreadable." : "\"{new}\" dosya uzantısının eklenmesi dosyayı okunamaz yapabilir.",
    "Do not show this dialog again." : "Bu ileti bir daha görüntülenmesin.",
    "Rename file to hidden" : "Gizlemek için dosyayı yeniden adlandırın",
    "Prefixing a filename with a dot may render the file hidden." : "Dosya adının başına nokta koymak onu görünümlerde gizler.",
    "Are you sure you want to rename the file to \"{filename}\"?" : "Dosyanın adını \"{filename}\" olarak değiştirmek istediğinize emin misiniz?",
    "Cancel" : "İptal",
    "Rename" : "Yeniden adlandır",
    "Select file or folder to link to" : "Bağlantı verilecek dosya ya da klasörü seçin",
    "Choose {file}" : "{file} seçin",
    "Files settings" : "Dosyalar ayarları",
    "Switch to list view" : "Liste görünümüne geç",
    "Switch to grid view" : "Tablo görünümüne geç",
    "The file could not be found" : "Dosya bulunamadı",
    "Upload was cancelled by user" : "Kullanıcı yüklemeyi iptal etti",
    "Not enough free space" : "Yeterli boş alan yok",
    "Operation is blocked by access control" : "İşlem erişim denetimi tarafından engellendi",
    "Error during upload: {message}" : "Yükleme sırasında sorun çıktı: {message}",
    "Error during upload, status code {status}" : "Yüklenirken sorun çıktı, durum kodu {status}",
    "Unknown error during upload" : "Yükleme sırasında bilinmeyen bir sorun çıktı",
    "File list is reloading" : "Dosya listesi yeniden yükleniyor",
    "Loading current folder" : "Geçerli klasör yükleniyor",
    "Retry" : "Yeniden dene",
    "No files in here" : "Burada herhangi bir dosya yok",
    "Upload some content or sync with your devices!" : "Bir şeyler yükleyin ya da aygıtlarınızla eşitleyin!",
    "Go back" : "Geri dön",
    "Loading …" : "Yükleniyor…",
    "Your files" : "Dosyalarınız",
    "Open in files" : "Dosyalar uygulamasında aç",
    "File cannot be accessed" : "Dosyaya erişilemedi",
    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Dosya bulunamadı ya da görüntüleme izniniz olmayabilir. Gönderenden paylaşmasını isteyin",
    "No search results for “{query}”" : "“{query}” için bir arama sonucu bulunamadı",
    "Search for files" : "Dosya ara",
    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Dosyaların tüm istemcilerle eşitlenebilmesi için dosya adlarının kısıtlanmasını sağlar. Varsayılan olarak POSIX içinde geçerli olan tüm dosya adlarına (Linux veya macOS) izin verilir.",
    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Windows uyumlu dosya adları açıldıktan sonra, var olan dosyalar artık değiştirilemez. Ancak sahipleri tarafından geçerli yeni adlarla yeniden adlandırılabilir.",
    "Failed to toggle Windows filename support" : "Windows dosya adları desteğinin durumu değiştirilemedi",
    "Files compatibility" : "Dosyalar uygulaması uyumluluğu",
    "Enforce Windows compatibility" : "Windows uyumluluğu zorunlu kılınsın",
    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Ayrılmış adlar veya özel karakterler kullanmak gibi Windows sistemlerinde geçerli olmayan dosya adlarını engeller. Ancak büyük/küçük harf duyarlılığı uyumluluğunu zorunlu kılmaz.",
    "Blank" : "Boş",
    "Unable to create new file from template" : "Kalıptan yeni dosya oluşturulamadı",
    "Pick a template for {name}" : "{name} için bir kalıp seçin",
    "Create a new file with the selected template" : "Seçilmiş kalıp ile yeni bir dosya oluştur",
    "Creating file" : "Dosya ekleniyor",
    "Save as {displayName}" : "{displayName} olarak kaydet",
    "Save as …" : "Farklı kaydet…",
    "Converting files …" : "Dosyalar dönüştürülüyor…",
    "Failed to convert files: {message}" : "Dosyalar dönüştürülemedi: {message}",
    "All files failed to be converted" : "Tüm dosyalar dönüştürülemedi",
    "One file could not be converted: {message}" : "Bir dosya dönüştürülemedi: {message}",
    "_%n file could not be converted_::_%n files could not be converted_" : ["%n dosya dönüştürülemedi","%n dosya dönüştürülemedi"],
    "_%n file converted_::_%n files converted_" : ["%n dosya dönüştürüldü","%n dosya dönüştürüldü"],
    "Files converted" : "Dosyalar dönüştürüldü",
    "Failed to convert files" : "Dosyalar dönüştürülemedi",
    "Converting file …" : "Dosya dönüştürülüyor…",
    "File successfully converted" : "Dosya dönüştürüldü",
    "Failed to convert file: {message}" : "Dosya dönüştürülemedi: {message}",
    "Failed to convert file" : "Dosya dönüştürülemedi",
    "Delete" : "Sil",
    "Leave this share" : "Bu paylaşımdan ayrıl",
    "Leave these shares" : "Bu paylaşımlardan ayrıl",
    "Disconnect storage" : "Depolama bağlantısını kes",
    "Disconnect storages" : "Depolama alanlarının bağlantısını kes",
    "Delete permanently" : "Kalıcı olarak sil",
    "Delete and unshare" : "Sil ve paylaşımdan kaldır",
    "Delete file" : "Dosyayı sil",
    "Delete folder" : "Klasörü sil",
    "Delete folders" : "Klasörleri sil",
    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["{count} ögeyi kalıcı olarak silmek üzeresiniz","{count} ögeyi kalıcı olarak silmek üzeresiniz"],
    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["{count} ögeyi silmek üzeresiniz","{count} ögeyi silmek üzeresiniz"],
    "Confirm deletion" : "Silmeyi onaylayın",
    "Download" : "İndir",
    "The requested file is not available." : "İstenilen dosya kullanılamıyor.",
    "The requested files are not available." : "İstenilen dosyalar kullanılamıyor.",
    "Add to favorites" : "Sık kullanılanlara ekle",
    "Remove from favorites" : "Sık kullanılanlardan kaldır",
    "Add or remove favorite" : "Sık kullanılanlara ekle ya da kaldır",
    "Move" : "Taşı",
    "Copy" : "Kopyala",
    "Move or copy" : "Taşı ya da kopyala",
    "Destination is not a folder" : "Hedef bir klasör değil",
    "This file/folder is already in that directory" : "Dosya ya da klasör bu klasörde zaten var",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "Bir dosyayı ya da klasörü kendi üzerine veya kendisinin alt klasörüne taşıyamazsınız",
    "A file or folder with that name already exists in this folder" : "Bu klasörde aynı adlı bir dosya ya da klasör zaten var",
    "The files are locked" : "Dosyalar kilitli",
    "The file does not exist anymore" : "Dosya artık yok",
    "Moving \"{source}\" to \"{destination}\" …" : "\"{source}\", \"{destination}\" üzerine taşınıyor…",
    "_Moving %n file to \"{destination}\" …_::_Moving %n files to \"{destination}\" …_" : ["%n dosya \"{destination}\" hedefine taşınıyor…","%n dosya \"{destination}\" hedefine taşınıyor…"],
    "Copying \"{source}\" to \"{destination}\" …" : "\"{source}\", \"{destination}\" üzerine kopyalanıyor…",
    "_Copying %n file to \"{destination}\" …_::_Copying %n files to \"{destination}\" …_" : ["%n dosya \"{destination}\" hedefine kopyalanıyor…","%n dosya \"{destination}\" hedefine kopyalanıyor…"],
    "Choose destination" : "Hedefi seçin",
    "Copy to {target}" : "{target} içine kopyala",
    "Move to {target}" : "{target} içine taşı",
    "Move or copy operation failed" : "Taşıma ya da kopyalama yapılamadı",
    "Open folder" : "Klasörü aç",
    "Open folder {displayName}" : "{displayName} klasörünü aç",
    "Open in Files" : "Dosyalar uygulamasında aç",
    "Open locally" : "Yerel olarak aç",
    "Failed to redirect to client" : "İstemciye yönlendirilemedi",
    "Open file locally" : "Dosyayı yerel olarak aç",
    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Dosya artık aygıtınızda açılmalıdır. Açılmazsa lütfen bilgisayar uygulamasının kurulu olduğundan emin olun.",
    "Retry and close" : "Yeniden deneyip kapat",
    "Open online" : "Çevrim içi aç",
    "Details" : "Ayrıntılar",
    "Open the details sidebar" : "Ayrıntılar kenar çubuğunu aç",
    "Unfavorite" : "Sık kullanılanlardan kaldır",
    "View in folder" : "Klasörde görüntüle",
    "Type" : "Tür",
    "Created new folder \"{name}\"" : "\"{name}\" yeni klasörü oluşturuldu",
    "Unable to initialize the templates directory" : "Kalıp klasörü hazırlanamadı",
    "Create templates folder" : "Kalıplar klasörü oluştur",
    "Templates" : "Kalıplar",
    "New template folder" : "Yeni kalıp klasörü",
    "In folder" : "Klasörde",
    "Pick folder to search in" : "Aranacak klasörü seçin",
    "Search in all files" : "Tüm dosyalarda ara",
    "Search in folder: {folder}" : "Şu klasörde ara: {folder}",
    "One of the dropped files could not be processed" : "Bırakılan dosyalardan biri işlenemedi",
    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Tarayıcınız dosya sistemi API uygulamasını desteklemiyor. Klasörler yüklenemeyecek",
    "No files to upload" : "Yüklenecek bir dosya yok",
    "Unable to create the directory {directory}" : "{directory} klasörü oluşturulamadı",
    "Some files could not be uploaded" : "Bazı dosyalar yüklenemedi",
    "Files uploaded successfully" : "Dosyalar yüklendi",
    "No files to process" : "İşlenecek bir dosya yok",
    "Files copied successfully" : "Dosyalar kopyalandı",
    "Files moved successfully" : "Dosyalar taşındı",
    "Some files could not be copied" : "Bazı dosyalar kopyalanamadı",
    "Some files could not be moved" : "Bazı dosyalar taşınamadı",
    "Conflicts resolution skipped" : "Çakışma çözümleme atlandı",
    "Upload cancelled" : "Yükleme iptal edildi",
    "Could not rename \"{oldName}\", it does not exist any more" : "\"{oldName}\" adı artık olmadığından değiştirilemedi. ",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "\"{newName}\" adı \"{dir}\" klasöründe zaten kullanılmış. Lütfen başka bir ad seçin.",
    "Could not rename \"{oldName}\"" : "\"{oldName}\" adı değiştirilemedi",
    "This operation is forbidden" : "Bu işleme izin verilmiyor",
    "This folder is unavailable, please try again later or contact the administration" : "Bu klasör kullanılamıyor. Lütfen bir süre sonra yeniden deneyin ya da BT yöneticiniz ile görüşün",
    "Storage is temporarily not available" : "Depolama geçici olarak kullanılamıyor",
    "Unexpected error: {error}" : "Beklenmeyen bir sorun çıktı: {error}",
    "Unknown error" : "Bilinmeyen sorun",
    "_%n file_::_%n files_" : ["%n dosya","%n dosya"],
    "_%n folder_::_%n folders_" : ["%n klasör","%n klasör"],
    "_%n hidden_::_%n hidden_" : ["%n gizli","%n gizli"],
    "Folder name must not be empty." : "Klasör adı boş olamaz.",
    "Filename must not be empty." : "Dosya adı boş olamaz.",
    "\"{char}\" is not allowed inside a folder name." : "Klasör adlarında \"{char}\" karakteri kullanılamaz.",
    "\"{char}\" is not allowed inside a filename." : "Dosya adlarında \"{char}\" kullanılamaz.",
    "\"{segment}\" is a reserved name and not allowed for folder names." : "\"{segment}\" ayrılmış bir ad olduğundan klasör adlarında kullanılamaz.",
    "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" ayrılmış bir ad olduğundan dosya adlarında kullanılamaz.",
    "\"{extension}\" is not an allowed filetype." : "\"{extension}\" dosya uzantısına izin verilmiyor.",
    "Folder names must not end with \"{extension}\"." : "Klasör adları \"{extension}\" ile bitemez.",
    "Filenames must not end with \"{extension}\"." : "Dosya adları \"{extension}\" ile bitemez.",
    "Invalid folder name." : "Klasör adı geçersiz",
    "List of favorite files and folders." : "Sık kullanılan dosya ve klasör listesi.",
    "No favorites yet" : "Henüz sık kullanılan bir öge yok",
    "Files and folders you mark as favorite will show up here" : "Sık kullanılanlara eklediğiniz dosya ve klasörler burada görüntülenir",
    "List of your files and folders." : "Dosya ve klasörlerinizin listesi",
    "Folder tree" : "Klasör ağacı",
    "List of your files and folders that are not shared." : "Paylaşılmayan dosya ve klasörlerinizin listesi.",
    "No personal files found" : "Herhangi bir kişisel dosya bulunamadı",
    "Files that are not shared will show up here." : "Paylaşımayan dosyalar burada görüntülenir.",
    "Recent" : "Son",
    "List of recently modified files and folders." : "Son değiştirilen dosya ve klasörlerin listesi.",
    "No recently modified files" : "Yakınlarda değiştirilmiş bir dosya yok",
    "Files and folders you recently modified will show up here." : "Son zamanlarda değiştirdiğiniz dosya ve klasörler burada görüntülenir.",
    "Search" : "Ara",
    "Search results within your files." : "Dosyalarınızda arama sonuçları.",
    "This node is unavailable" : "Bu düğüm kullanılamıyor",
    "Renamed \"{oldName}\" to \"{newName}\"" : "\"{oldName}\" adı \"{newName}\" olarak değiştirildi",
    "Clear filter" : "Süzgeci temizle",
    "Open file sidebar" : "Dosya kenar çubuğunu aç",
    "Search everywhere …" : "Her yerde ara…",
    "Search here …" : "Burada ara…",
    "Preparing …" : "Hazırlanıyor…",
    "Submitting fields …" : "Alanlar gönderiliyor…",
    "Invalid path selected" : "Seçilen yol geçersiz",
    "Choose file or folder to transfer" : "Sahipliği aktarılacak dosya ya da klasörü seçin",
    "Change" : "Değiştir",
    "Shared by link" : "Bağlantı ile paylaşılmış",
    "Shared" : "Paylaşılan",
    "You" : "Siz",
    "Shared multiple times with different people" : "Farklı kişilerle birkaç kez paylaşılmış",
    "Unable to change the favorite state of the file" : "Dosyanın sık kullanılan durumu değiştirilemedi",
    "Error while loading the file data" : "Dosya verileri yüklenirken sorun çıktı",
    "Tags" : "Etiketler",
    "Save as …" : "Farklı kaydet…",
    "Converting files …" : "Dosyalar dönüştürülüyor…",
    "Converting file …" : "Dosya dönüştürülüyor…",
    "No entries found in this folder" : "Bu klasörde herhangi bir kayıt bulunamadı",
    "Select all" : "Tümünü seç",
    "Upload too large" : "Yükleme boyutu çok büyük",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Yüklemeye çalıştığınız dosyalar bu sunucuya yüklenmesine izin verilen en büyük dosya boyutunu aşıyor."
},
"nplurals=2; plural=(n > 1);");
