OC.L10N.register(
    "support",
    {
    "Link:" : "Link:",
    "Password:" : "Wachtwoord :",
    "Generating system report failed." : "Systeem rapport maken is gefaald.",
    "Could not create folder \"System information\" to store generated report." : "Kan geen map \"System information\" aanmaken om het gemaakte rapport op te slaan.",
    "Could not create file \"%s\" to store generated report." : "Kan geen bestand \" %s\" aanmaken om het gemaakte rapport op te slaan.",
    "Could not share file \"%s\". Nevertheless, you can find it in the folder \"System information\"." : "Kan de file  \"1%s\" niet delen. Desondanks kan je hem terug vinden in de maps \"System information\".",
    "Subscription notifications" : "Abonnementen op meldingen",
    "Nextcloud Subscription" : "Nextcloud abonnement",
    "Your server has no Nextcloud Subscription or your Subscription has expired." : "Je server heeft geen Nextcloud abonnement of het abonnement is verlopen. ",
    "Your Nextcloud server subscription does not cover your number of users." : "Je Nextcloud server-abonnement dekt dit aantal gebruikers niet.",
    "Your Nextcloud Subscription has expired!" : "Je Nextcloud abonnement is verlopen!",
    "Your server has no Nextcloud Subscription" : "Je server heeft geen Nextcloud abonnement",
    "Your Nextcloud server is not backed by a Nextcloud Enterprise Subscription." : "Je Nextcloud server is niet gedekt door een zakelijk Nextcloud Enterprise abonnement.",
    "If your server setup breaks and employees can't work anymore, you don't have to rely on searching online forums for a solution. You have direct access to our experienced engineers!" : "Als je server het niet meer doet en werknemers niet meer kunnen werken, hoef je niet alleen te vertrouwen op online forums voor een oplossing. Je hebt directe toegang tot onze ervaren ontwikkelaars!",
    "You have a contract with the vendor providing early security information, mitigations, patches and updates." : "Je hebt een contract met de leverancier die zo tijdig beveiligingsinformatie, oplossingen, patches en updates levert.",
    "If you need to stay longer on your current version without disruptions, you don't have to run software without security updates." : "Als je zonder onderbrekingen langer je huidige versie wilt blijven gebruiken, hoef je geen software te gebruiken zonder beveiligingsupdates.",
    "You have the best expertise at hand to deal with performance and scalability issues." : "Je hebt toegang tot de beste expertise om te kunnen omgaan met prestatie- en schaalbaarheidsproblemen.",
    "You have access to the right documentation and expertise to quickly answer compliance questions or deliver on GDPR, HIPAA and other regulation requirements." : "Jehebt toegang tot de juiste documentatie en expertise om snel compliance-vragen te beantwoorden of te voldoen aan GDPR, HIPAA en andere regelgevingseisen.",
    "We can also provide Outlook integration, Online Office, scalable integrated audio-video and chat communication and other features only available in a limited form for free or develop further integrations and capabilities to your needs." : "We kunnen ook Outlook integratie, Online Office, schaalbare geïntegreerde audio-video en chat communicatie bieden en hebben ook andere mogelijkheden die gratis in een beperkte vorm beschikbaar zijn of we kunnen meer integraties en mogelijkheden ontwikkelen als die nodig zijn.",
    "A subscription helps you get the most out of Nextcloud!" : "Een abonnement geeft meerwaarde aan Nextcloud!",
    "Learn more now" : "Nu meer weten",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %1$s because you have over %2$s registered users." : "Deze mail is door de ondersteuningsapp aan alle beheerders op je Nexcloudserver op %1$s gestuurd, omdat je meer dan %2$sgeregistreerde gebruikers hebt.",
    "Your Nextcloud server Subscription is over limit" : "Je Nextcloud server -bonnement is over de limiet",
    "Dear admin," : "Beste beheerder,",
    "Your Nextcloud Subscription doesn't cover the number of users who are currently active on this server. Please contact your Nextcloud account manager to get your subscription updated!" : "Je Nextcloud abonnement is niet geschikt voor het aantal actieve gebruikers. Neem contact op met je Nextcloud accountmanager om je abonnement te laten aanpassen!",
    "%1$s is your account manager and can be reached by email via %2$s or by phone via %3$s." : "%1$s is je accountmanager en is per e-mail te bereiken via %2$s of telefonisch via %3$s.",
    "Thank you," : "Dank u wel,",
    "Your Nextcloud team" : "Je Nextcloud team",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %s because you have more users than your subscription covers." : "Deze mail is door de ondersteuningsapp aan alle beheerders op je Nexcloudserver op %sgestuurd, omdat je meer gebruikers hebt dan je licentie toestaat.",
    "Your Nextcloud server Subscription is expired" : "Je Nextcloud server abonnement is verlopen",
    "Your Nextcloud server Subscription is expired!" : "Je Nextcloud server-abonnement is verlopen!",
    "Your Nextcloud Subscription has expired! Please contact your Nextcloud account manager to get your subscription updated!" : "Je Nextcloud server abonnement is verlopen! Graag contact opnemen met je Nextcloud accountmanager om je abonnement te laten vernieuwen!",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %s because your subscription expired." : "Deze mail is door de ondersteuningsapp aan alle beheerders op je Nexcloudserver op %sgestuurd, omdat je licentie is verlopen.",
    "Support" : "Ondersteuning",
    "Getting support and help for your Nextcloud" : "Ondersteuning en hulp voor je Nextcloud",
    "The support app covers you with direct access to help and consulting resources, dedicated contact options to your account manager and an overview of your enterprise subscription." : "De ondersteuningsapp biedt rechtstreekse toegang tot hulp en adviesdiensten, toegesneden contact met je accountmanager en een overzicht van je zakelijke abonnement.",
    "Basic subscription" : "Basis abonnement",
    "Standard subscription" : "Standaard abonnement",
    "Premium subscription" : "Premium abonnement",
    "Géant subscription" : "Géant abonnement",
    "Silver partner subscription" : "Zilver partner abonnement",
    "Gold partner subscription" : "Gouden partner abonnement",
    "Subscription" : "Abonnement",
    "Over subscription limit" : "Over de limiet van abonnement",
    "Valid subscription" : "Geldig abonnement",
    "Expired subscription" : "Verlopen abonnement",
    "Subscription key:" : "Abonnement sleutel:",
    "Expires in: " : "Vervalt over:",
    "_%n year_::_%n years_" : ["%n jaar","%n jaar"],
    "_%n month_::_%n months_" : ["%n maand","%n maanden"],
    "_%n week_::_%n weeks_" : ["%n week","weken"],
    "_%n day_::_%n days_" : ["%n dag","%n dagen"],
    "For an unlimited amount of users" : "Voor een onbeperkt aantal gebruikers",
    "_For %n active users_::_For %n active users_" : ["Voor %n actieve gebruiker","Voor %n actieve gebruikers"],
    "_For %n users_::_For %n users_" : ["Voor %n gebruiker","Voor %n gebruikers"],
    "_currently at %n user_::_currently at %n users_" : ["momenteel met %n gebruiker","momenteel met %n gebruikers"],
    "Includes support for %s" : "Omvat ondersteuning voor %s",
    "Includes support for %1$s & %2$s" : "Met ondersteuning voor %1$s & %2$s",
    "Includes support for %1$s, %2$s & %3$s" : "Met ondersteuning voor %1$s, %2$s & %3$s",
    "Extended maintenance life cycle" : "Uitgebreid onderhoud levenscyclus",
    "Update subscription key" : "Bijwerken abonnementssleutel",
    "%s is your account manager. Don't hesitate to reach out to us if you have questions regarding your subscription." : "%s is je accountmanager. Aarzel niet contact op te nemen als je vragen hebt over je abonnement.",
    "You can find answers to common question in our portal and also file support requests there." : "Je kunt antwoorden op veel gestelde vragen krijgen in ons portaal en daar ook ondersteuningsvragen stellen.",
    "Access Nextcloud portal" : "Openen Nextcloud portaal",
    "System information" : "Systeeminformatie",
    "Collect system information for support cases. The button below generates a text file in the folder \"System information\" and shares it as password protected public link. The link is valid for 2 weeks." : "Verzamel systeeminformatie voor support cases. De knop hieronder genereert een tekstbestand in de map \"System information\" en deelt het als een wachtwoordbeveiligde openbare link. Deze link is 2 weken geldig.",
    "Generate system report" : "Genereren systeemrapportage",
    "Enterprise subscription recommended" : "Zakelijk abonnement aanbevolen",
    "No active enterprise subscription" : "Geen actief zakelijk abonnement",
    "Unsupported" : "Niet ondersteund",
    "This Nextcloud server has no Enterprise Subscription." : "Deze Nextcloud server heeft geen zakelijk abonnement",
    "A Nextcloud Enterprise Subscription helps you get the most out of your Nextcloud, keep your data secure and your server working reliably at all times." : "Een zakelijk Nextcloud abonnement laat je de meeste waarde uit je Nextcloud halen, je gegevens veilig houden en je server betrouwbaar te laten werken.",
    "Advantages" : "Voordelen",
    "Access to the technical expertise of the Nextcloud developers through documentation and support" : "Toegang tot technische kennis van de Nextcloud ontwikkelaars via documentatie en ondersteuning",
    "Access to additional capabilities like Outlook integration, online office and more" : "Toegang tot aanvullende mogelijkheden zoals Outlook integratie, online office en meer",
    "Access to scalability expertise and scalability capabilities for Files and Talk" : "Toegang tot schaalbaarheids-expertise en schaalbare mogelijkheden voor Bestanden en Talk",
    "Optional branding, consulting, architecture advice" : "Optionele huisstijl aanpassing, consultancy, architectuur advies",
    "Confidential security notification service, mitigations, patches and advice" : "Vertrouwelijke beveiligingsmeldingenservice, oplossingen, patches en advies",
    "Compliance certification, advice and documentation" : "Compliance certificering, advies en documentatie",
    "Get a quote" : "Vraag een offerte",
    "More information" : "Meer informatie",
    "Subscription benefits" : "Abonnementsvoordelen",
    "Pricing" : "Prijsstelling",
    "Community support" : "Commmunity ondersteuning",
    "Forum" : "Forum",
    "Nextcloud is free software which is supported by a very active community. Please register at the forum to ask questions and discuss with others." : "Nextcloud is vrije software die wordt ondersteund door een zeer actieve community. Registreer je op ons forum om vragen te stellen en met anderen te discussiëren.",
    "Nextcloud forum" : "Nextcloud forum",
    "GitHub" : "GitHub",
    "Nextcloud uses GitHub as platform to collaboratively work. You can file bug reports directly there." : "Nextcloud gebruikt GitHub als platform voor samenwerking. Je kunt bugs hier direct melden.",
    "Nextcloud at GitHub" : "Nextcloud op GitHub",
    "Subscription key" : "Abonnementssleutel",
    "If you have an active Nextcloud Subscription please enter your subscription key here." : "Als je een actief Nextcloud abonnement hebt, voer dan hier je abonnementssleutel in. ",
    "Learn more about an enterprise subscription." : "Lees meer over zakelijke abonnementen.",
    "Set subscription key" : "Abonnementssleutel instellen",
    "The subscription info could not properly fetched right now. A retry is scheduled. Please check back later." : "De abonnementsinformatie kon niet goed worden opgehaald. Een hercontrole is ingepland. Kom later terug.",
    "The subscription key was invalid." : "De abonnementssleutel was ongeldig.",
    "The subscription key could not be verified, because this server has no internet connection. Please reach out to the support team to get this resolved." : "De abonnementssleutel kon niet worden geverifieerd omdat deze server geen internetverbinding heeft. Neem contact op met het supportteam om het probleem op te lossen.",
    "The subscription key had an invalid format." : "De abonnementssleutel heeft een ongeldig formaat.",
    "While fetching the subscription information an error happened." : "Er trad een fout op bij het ophalen van abonnementsinformatie.",
    "The button below generates a text file in the folder \"System information\" and shares it as password protected public link. The link is valid for 2 weeks." : "De knop hieronder genereert een tekstbestand in de map \"System information\" en deelt dit als een met een wachtwoord beveiligde openbare link. De link is 2 weken geldig.",
    "News" : "Nieuws",
    "To get up to date information what is going on at Nextcloud sign up for the newsletter and follow us on our social media accounts." : "Om actuele informatie over Nextcloud te krijgen, kun je je aanmelden voor de nieuwsbrief en ons volgen op sociale media.",
    "Like our Facebook page" : "Vind onze Facebook pagina leuk",
    "Follow us on Twitter" : "Volg ons op Twitter",
    "Check out our blog" : "Lees ons blog",
    "Subscribe to our newsletter" : "Abonneer jezelf op onze nieuwsbrief"
},
"nplurals=2; plural=(n != 1);");
