OC.L10N.register(
    "support",
    {
    "Link:" : "Bağlantı:",
    "Password:" : "Parola:",
    "Generating system report failed." : "Sistem raporu hazırlanamadı.",
    "Could not create folder \"System information\" to store generated report." : "Hazırlanan raporun kaydedilmesi için \"Sistem Bilgileri\" klasörü oluşturulamadı.",
    "Could not create file \"%s\" to store generated report." : "Hazırlanan raporun kaydedilmesi için \"%s\" dosyası oluşturulamadı.",
    "Could not share file \"%s\". Nevertheless, you can find it in the folder \"System information\"." : "\"%s\" dosyası paylaşılamadı. Gene de dosyayı \"System information\" klasöründe bulabilirsiniz.",
    "Subscription notifications" : "Abonelik bildirimleri",
    "Nextcloud Subscription" : "Nextcloud aboneliği",
    "Your server has no Nextcloud Subscription or your Subscription has expired." : "Sunucunuzun bir Nextcloud aboneliği yok ya da aboneliğin geçerlilik süresi dolmuş.",
    "Your Nextcloud server subscription does not cover your number of users." : "Nextcloud sunucunuzun aboneliği geçerli kullanıcı sayınız için yeterli değil.",
    "Your Nextcloud Subscription has expired!" : "Nextcloud aboneliğinizin geçerlilik süresi dolmuş!",
    "Your server has no Nextcloud Subscription" : "Sunucunuzun bir Nextcloud aboneliği yok",
    "Your Nextcloud server is not backed by a Nextcloud Enterprise Subscription." : "Nextcloud sunucunuzun kurumsal bir Nextcloud Enterprise Aboneliği yok.",
    "If your server setup breaks and employees can't work anymore, you don't have to rely on searching online forums for a solution. You have direct access to our experienced engineers!" : "Sunucu kurulumunuzda bir sorun çıkarsa ve iş arkadaşlarınızın çalışması kesintiye uğrarsa bir çözüm bulmak için yalnızca çevrimiçi forumlarda yapacağınız araştırmalara güvenemezsiniz. Deneyimli mühendislerimize doğrudan erişebilirsiniz!",
    "You have a contract with the vendor providing early security information, mitigations, patches and updates." : "Üretici ile güvenlik bilgilerini, düzeltmeleri, yamaları ve güncellemeleri erkenden almanızı sağlayan bir sözleşmeniz olur.",
    "If you need to stay longer on your current version without disruptions, you don't have to run software without security updates." : "Kullandığınız sürüm üzerinde biraz daha uzun süre kalmak için uygulamayı güvenlik güncellemeleri olmadan kullanmak zorunda değilsiniz.",
    "You have the best expertise at hand to deal with performance and scalability issues." : "Başarım ve ölçeklenebilirlik sorunlarını çözebilecek en iyi deneyimden yararlanabilirsiniz.",
    "You have access to the right documentation and expertise to quickly answer compliance questions or deliver on GDPR, HIPAA and other regulation requirements." : "GDPR, HIPAA ya da diğer düzenlemelerle ilgili gereksinimlerin karşılanması hakkında uyumluluk ya da uygulama ile ilgili sorularınızla ilgili doğru belge ve deneyimlere erişebilirsiniz.",
    "We can also provide Outlook integration, Online Office, scalable integrated audio-video and chat communication and other features only available in a limited form for free or develop further integrations and capabilities to your needs." : "Ayrıca Outlook bütünleştirmesi, Çevrimiçi Ofis,  ölçeklenebilir bütünleşik sesli ya da görüntülü görüşme ve diğer özellikleri ücretsiz olarak sınırlı bir biçimde sunabilir ya da gerek duyacağınız diğer özellik ve bütünleştirmeleri geliştirebiliriz.",
    "A subscription helps you get the most out of Nextcloud!" : "Bir abonelik satın alarak Nextcloud uygulamanızdan en iyi sonucu alırsınız!",
    "Learn more now" : "Şimdi ayrıntılı bilgi alın",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %1$s because you have over %2$s registered users." : "Bu e-posta destek uygulaması tarafından tüm yöneticilere %1$s üzerindeki Nextcloud kopyasında %2$s kullanıcı sayısının aşıldığını bildirmek için gönderilmiştir.",
    "Your Nextcloud server Subscription is over limit" : "Nextcloud sunucu aboneliğinizin sınırı aşılmış",
    "Dear admin," : "Sayın yönetici,",
    "Your Nextcloud Subscription doesn't cover the number of users who are currently active on this server. Please contact your Nextcloud account manager to get your subscription updated!" : "Nextcloud aboneliğiniz şu anda sunucunuz üzerindeki etkin kullanıcı sayısını desteklemiyor. Aboneliğinizi yükseltmek için lütfen Nextcloud müşteri temsilciniz ile görüşün!",
    "%1$s is your account manager and can be reached by email via %2$s or by phone via %3$s." : "%1$s adındaki müşteri temsilcinize %2$s  e-posta adresinden ya da %3$s numaralı telefondan ulaşabilirsiniz.",
    "Thank you," : "Teşekkürler,",
    "Your Nextcloud team" : "Nextcloud ekibiniz",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %s because you have more users than your subscription covers." : "Bu e-posta destek uygulaması tarafından tüm yöneticilere %s üzerindeki Nextcloud kopyasında abonelik kapsamındaki kullanıcı sayısının aşıldığını bildirmek için gönderilmiştir.",
    "Your Nextcloud server Subscription is expired" : "Nextcloud sunucu aboneliğinizin geçerlilik süresi dolmuş",
    "Your Nextcloud server Subscription is expired!" : "Nextcloud sunucu aboneliğinizin geçerlilik süresi dolmuş!",
    "Your Nextcloud Subscription has expired! Please contact your Nextcloud account manager to get your subscription updated!" : "Nextcloud sunucu aboneliğinizin geçerlilik süresi dolmuş! Aboneliğinizi yükseltmek için lütfen Nextcloud müşteri temsilciniz ile görüşün!",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %s because your subscription expired." : "Bu e-posta destek uygulaması tarafından tüm yöneticilere %s üzerindeki Nextcloud kopyası aboneliğinin geçerlilik süresinin dolduğunu bildirmek için gönderilmiştir.",
    "Support" : "Destek",
    "Getting support and help for your Nextcloud" : "Nextcloud uygulamanız için destek ve yardım alın",
    "The support app covers you with direct access to help and consulting resources, dedicated contact options to your account manager and an overview of your enterprise subscription." : "Destek uygulaması üzerinden doğrudan yardım ve danışmanlık desteği alabilirsiniz. Kolayca ulaşabileceğiniz size özel bir müşteri temsilciniz ve kurumsal aboneliğiniz olur.",
    "Basic subscription" : "Temel abonelik",
    "Standard subscription" : "Standart abonelik",
    "Premium subscription" : "Premium abonelik",
    "Géant subscription" : "Géant abonelik",
    "Silver partner subscription" : "Silver iş ortağı aboneliği",
    "Gold partner subscription" : "Gold iş ortağı aboneliği",
    "Subscription" : "Abonelik",
    "Over subscription limit" : "Abonelik aşımı sınırı",
    "Valid subscription" : "Abonelik geçerli",
    "Expired subscription" : "Aboneliğin geçerlilik süresi dolmuş",
    "Subscription key:" : "Abonelik kodu:",
    "Expires in: " : "Geçerlilik süresi sonu:",
    "_%n year_::_%n years_" : ["%n yıl","%n yıl"],
    "_%n month_::_%n months_" : ["%n ay","%n ay"],
    "_%n week_::_%n weeks_" : ["%n hafta","%n hafta"],
    "_%n day_::_%n days_" : ["%n gün","%n gün"],
    "For an unlimited amount of users" : "Sınırsız sayıda kullanıcı için",
    "_For %n active users_::_For %n active users_" : ["%n etkin kullanıcı için","%n etkin kullanıcı için"],
    "_For %n users_::_For %n users_" : ["%n kullanıcı için","%n kullanıcı için"],
    "_currently at %n user_::_currently at %n users_" : ["şu anda %n kullanıcı","şu anda %n kullanıcı"],
    "Includes support for %s" : "%s için destek ile birlikte",
    "Includes support for %1$s & %2$s" : "%1$s ve %2$s için destek ile birlikte",
    "Includes support for %1$s, %2$s & %3$s" : "%1$s, %2$s ve %3$s için destek ile birlikte",
    "Extended maintenance life cycle" : "Uzatılmış bakım yaşam döngüsü",
    "Update subscription key" : "Abonelik kodunu güncelle",
    "%s is your account manager. Don't hesitate to reach out to us if you have questions regarding your subscription." : "%s müşteri temsilcinizdir. Aboneliğiniz ile ilgili sorularınız için bizimle görüşmekten çekinmeyin.",
    "You can find answers to common question in our portal and also file support requests there." : "Portal üzerinden sık sorulan soruların yanıtlarını bulabilir ve destek isteğinde bulunabilirsiniz.",
    "Access Nextcloud portal" : "Nextcloud portali",
    "System information" : "Sistem bilgileri",
    "Collect system information for support cases. The button below generates a text file in the folder \"System information\" and shares it as password protected public link. The link is valid for 2 weeks." : "Destek kayıtları için sistem bilgilerini toplayın. Aşağıdaki düğme \"System Information\" klasöründe bir metin dosyası oluşturur ve 2 hafta süreyle gereçli olan, herkese açık ancak parola ile korunan bir bağlantı ile paylaşır. ",
    "Generate system report" : "Sistem raporu hazırla",
    "Enterprise subscription recommended" : "Enterprise sürüm aboneliği önerilir",
    "No active enterprise subscription" : "Herhangi bir etkin Enterprise sürüm aboneliği bulunamadı",
    "Unsupported" : "Desteklenmiyor",
    "This Nextcloud server has no Enterprise Subscription." : "Bu Nextcloud sunucusunda Enterprise sürüm aboneliği yok.",
    "A Nextcloud Enterprise Subscription helps you get the most out of your Nextcloud, keep your data secure and your server working reliably at all times." : "Kurumlar için yayınlanan Nextcloud Enterprise sürüm aboneliği Nextcloud uygulamanızdan en iyi sonucu almanızı sağlar. Verilerinizin güvende olduğundan ve sunucunuzun her zaman doğru şekilde çalıştığından emin olursunuz.",
    "Advantages" : "Yararları",
    "Access to the technical expertise of the Nextcloud developers through documentation and support" : "Belgeler ve ayrıcalıklı destek sayesinde Nextcloud geliştiricilerinin teknik deneyiminden yararlanırsınız",
    "Access to additional capabilities like Outlook integration, online office and more" : "Outlook bütünleştirmesi, çevrimiçi ofis, ek özellikler gibi seçenekleri kullanabilirsiniz",
    "Access to scalability expertise and scalability capabilities for Files and Talk" : "Files ve Talk uygulamaları için ölçeklenebilirlik özelliklerini ve deneyimimizi kullanabilirsiniz",
    "Optional branding, consulting, architecture advice" : "Gereksinim ve isteklerinize göre marka oluşturm, danışmanlık ve yapılandırma önerileri alabilirsiniz",
    "Confidential security notification service, mitigations, patches and advice" : "Gizli güvenlik bildirimi hizmeti, hafifletici sebepler, yamalar ve öneriler alırsınız",
    "Compliance certification, advice and documentation" : "Uyumluluk sertifikası, öneriler ve belgeler alabilirsiniz",
    "Get a quote" : "Teklif isteyin",
    "More information" : "Ayrıntılı bilgi alın",
    "Subscription benefits" : "Abone olmanın yararları",
    "Pricing" : "Fiyatlar",
    "Community support" : "Topluluk desteği",
    "Forum" : "Forum",
    "Nextcloud is free software which is supported by a very active community. Please register at the forum to ask questions and discuss with others." : "Nextcloud çok etkin bir topluluk tarafından desteklenmektedir. Lütfen soru sormak ve başkaları ile çeşitli konularda yazışmak için bir forum hesabı açın.",
    "Nextcloud forum" : "Nextcloud forum",
    "GitHub" : "GitHub",
    "Nextcloud uses GitHub as platform to collaboratively work. You can file bug reports directly there." : "Nextcloud birlikte çalışma platformu olarak GitHub kullanır. Hata bildirimlerini doğrudan GitHub üzerinden yapabilirsiniz.",
    "Nextcloud at GitHub" : "GitHub üzerinde Nextcloud ",
    "Subscription key" : "Abonelik kodu",
    "If you have an active Nextcloud Subscription please enter your subscription key here." : "Etkin bir Nextcloud aboneliğiniz varsa abonelik kodunuzu buraya yazın.",
    "Learn more about an enterprise subscription." : "Enterprise sürüm aboneliği hakkında ayrıntılı bilgi alın.",
    "Set subscription key" : "Abonelik kodunu kaydet",
    "The subscription info could not properly fetched right now. A retry is scheduled. Please check back later." : "Şu anda abonelik bilgileri tam olarak alınamadı. Daha sonra yeniden denenecek. Bir süre sonra buraya yeniden bakın.",
    "The subscription key was invalid." : "Abonelik kodu geçersiz.",
    "The subscription key could not be verified, because this server has no internet connection. Please reach out to the support team to get this resolved." : "Bu sunucunun İnternet bağlantısı olmadığından abonelik kodu doğrulanamadı. Bu sorunu çözmek için destek ekibimizle görüşün.",
    "The subscription key had an invalid format." : "Abonelik kodunun biçimi geçersiz.",
    "While fetching the subscription information an error happened." : "Abonelik bilgileri alınırken bir sorun çıktı.",
    "The button below generates a text file in the folder \"System information\" and shares it as password protected public link. The link is valid for 2 weeks." : "Aşağıdaki düğme \"System Information\" klasöründe bir metin dosyası oluşturur ve 2 hafta süreyle geçerli olacak, herkese açık olan ancak parola ile korunan bir bağlantı ile paylaşır. ",
    "News" : "Haberler",
    "To get up to date information what is going on at Nextcloud sign up for the newsletter and follow us on our social media accounts." : "Nextcloud ile ilgili gelişmeleri öğrenmek için bültenimize abone olabilir ya da sosyal ağlar üzerinden bizi izleyebilirsiniz.",
    "Like our Facebook page" : "Facebook sayfamızı beğenin",
    "Follow us on Twitter" : "Bizi Twitter üzerinde izleyin",
    "Check out our blog" : "Bloğumuza bakın",
    "Subscribe to our newsletter" : "Bültenimize abone olun"
},
"nplurals=2; plural=(n > 1);");
