.loader[data-v-a6eb2bbc]{margin-top:30vh}.photos-navigation[data-v-a6eb2bbc]{display:flex;height:44px;padding:0 40px;align-items:center;max-width:100%}.photos-navigation h2[data-v-a6eb2bbc]{padding:0;margin:0}.heading-subline[data-v-a6eb2bbc]{margin-inline-start:85px;margin-top:-11px;color:var(--color-text-maxcontrast)}.tag__photos[data-v-a6eb2bbc]{padding:0 64px}
