OC.L10N.register(
    "serverinfo",
    {
    "System" : "Sistem",
    "Unknown" : "I panjohur",
    "Monitoring" : "Vëzhgim",
    "Active users" : "Përdoruesit aktivë",
    "Background jobs" : "Punët në background",
    "Never" : "Kurrë",
    "Current usage" : "Perdorimi aktual",
    "Load average" : "Ngarkesa mesatare",
    "Database" : "Databazë",
    "Type:" : "Lloji:",
    "Version:" : "Versioni: ",
    "Size:" : "Madhësia:",
    "Available" : "i disponueshëm",
    "Files" : "Skedarë",
    "Status" : "Statusi",
    "Started" : "Filloi",
    "Duration" : "Kohëzgjatja",
    "Details" : "Detajet",
    "Total" : "Total",
    "Authentication" : "Mirëfilltësim",
    "Hostname" : "Strehëemër",
    "PHP extensions" : "Zgjerimet e PHP",
    "PHP" : "PHP",
    "seconds" : "sekonda",
    "Upload max size:" : "Ngarkoni madhësinë maksimale: ",
    "Shares" : "Shpërndarje",
    "Users:" : "Përdoruesit:",
    "Warning" : "Kujdes",
    "Temperature" : "Temperatura",
    "Copied!" : "I kopjuar!",
    "Not supported!" : "Nuk mbështetet!",
    "Press ⌘-C to copy." : "Shtyp ⌘-C për të kopjuar.",
    "Press Ctrl-C to copy." : "Shtyp Ctrl-C për të kopjuar",
    "Files:" : "Skedarët: ",
    "External monitoring tool" : "Mjet i kontrollit të jashtëm",
    "Copy" : "Kopjo"
},
"nplurals=2; plural=(n != 1);");
