OC.L10N.register(
    "bruteforcesettings",
    {
    "Brute-force settings" : "Inställningar för brute force-skydd",
    "Whitelist IPs" : "Tillåt IP-adresser",
    "Brute-force protection is meant to protect Nextcloud servers from attempts to\nguess account passwords in various ways. Besides the obvious \"*let's try a big\nlist of commonly used passwords*\" attack, it also makes it harder to use\nslightly more sophisticated attacks via the reset password form or trying to\nfind app password tokens.\n\nIf triggered, brute-force protection makes requests coming from an IP on a\nbrute-force protected controller with the same API slower for a 24 hour period.\n\nWith this app, the admin can exempt an IP address or range from this\nprotection which can be useful for testing purposes or when there are false\npositives due to a lot of accounts on one IP address." : "Brute force-skyddet är avsett att skydda Nextcloud-servrar mot försök att\ngissa kontolösenord på olika sätt. Förutom den uppenbara attacken \"*prova en stor\nlista med vanliga lösenord*\" försvårar det även mer avancerade attacker via\nformuläret för lösenordsåterställning eller försök att hitta applösenordstoken.\n\nNär skyddet utlöses fördröjs anrop från en IP-adress till ett brute force-skyddat\nAPI under 24 timmar.\n\nMed den här appen kan administratören undanta en IP-adress eller ett IP-intervall\nfrån skyddet. Det kan vara användbart vid tester eller vid falska positiva resultat\nsom orsakas av att många konton använder samma IP-adress.",
    "The comment cannot exceed {max} characters." : "Kommentaren får inte överstiga {max} tecken.",
    "Leave an internal comment explaining why this IP address is allowed, for example its location, so the entry can be removed when it is no longer needed." : "Lämna en intern kommentar som förklarar varför denna IP-adress är tillåten, till exempel dess plats, så att posten kan tas bort när den inte längre behövs.",
    "Your current IP address is detected as \"{remoteAddress}\". This address is currently throttled. Current delay: {delay} ms." : "Din nuvarande IP-adress identifieras som \"{remoteAddress}\". Denna adress är för närvarande begränsad. Aktuell fördröjning: {delay} ms.",
    "Your current IP address is detected as \"{remoteAddress}\". This address bypasses brute-force protection." : "Din nuvarande IP-adress identifieras som \"{remoteAddress}\". Denna adress kringgår skydd mot brute force-attacker.",
    "Your current IP address is detected as \"{remoteAddress}\". This address is not currently throttled." : "Din nuvarande IP-adress identifieras som \"{remoteAddress}\". Denna adress är för närvarande inte begränsad.",
    "Failed to add the IP address to the allow list." : "Det gick inte att lägga till IP-adressen i tillåtelselistan.",
    "Failed to save the rate limit setting." : "Det gick inte att spara inställningen för hastighetsbegränsning.",
    "Failed to update the allow list entry." : "Det gick inte att uppdatera posten i tillåtelselistan.",
    "Brute-force allow list" : "Tillåtelselista för brute force-skydd",
    "To exclude IP ranges from the brute-force protection specify them below. Note that any allowed IP can perform authentication attempts without any throttling. For security reasons, it is recommended to list as few remote addresses as possible or ideally even none at all." : "För att undanta IP-intervall från brute-force-skyddet, ange dem nedan. Observera att alla tillåtna IP-adresser kan utföra autentiseringsförsök utan begränsning. Av säkerhetsskäl rekommenderas att ange så få fjärradresser som möjligt, eller helst inga alls.",
    "Bypass rate limiting for allowed IPs" : "Åsidosätt hastighetsbegränsning för tillåtna IP-adresser",
    "Add new IP address" : "Lägg till ny IP-adress",
    "IP address" : "IP-adress",
    "Mask" : "Mask",
    "Comment" : "Kommentar",
    "Add" : "Lägg till",
    "Edit comment for {subnet}" : "Redigera kommentar för {subnet}",
    "Save" : "Spara",
    "Delete entry for {subnet}" : "Ta bort post för {subnet}",
    "Comment cannot exceed {max} characters." : "Kommentaren får inte överstiga {max} tecken.",
    "Leave an internal comment, why this IP is allowed, e.g. the  location, so it can be revoked, when it is no longer needed." : "Lämna en intern kommentar om varför denna IP är tillåten, t.ex. platsen, så att den kan återkallas när den inte längre behövs.",
    "Your remote address was identified as \"{remoteAddress}\" and is throttled at the moment by {delay}ms." : "Din fjärradress identifierades som ”{remoteAddress}” och begränsas för närvarande med en fördröjning på {delay} ms.",
    "Your remote address was identified as \"{remoteAddress}\" and is bypassing brute-force protection." : "Din fjärradress identifierades som ”{remoteAddress}” och kringgår brute force-skyddet.",
    "Your remote address was identified as \"{remoteAddress}\" and is not actively throttled at the moment." : "Din fjärradress identifierades som ”{remoteAddress}” och begränsas inte för närvarande.",
    "There was an error adding the IP to the allow list." : "Det gick inte att lägga till IP-adressen i tillåtelselistan.",
    "There was an error updating the allow list entry." : "Det gick inte att uppdatera posten i tillåtelselistan."
},
"nplurals=2; plural=(n != 1);");
