OC.L10N.register(
    "dav",
    {
    "Calendar" : "Kalender",
    "Tasks" : "Ülesanded",
    "Personal" : "Isiklik",
    "{actor} created calendar {calendar}" : "{actor} lõi kalendri {calendar}",
    "You created calendar {calendar}" : "Sa lõid kalendri {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} kustutas kalendri {calendar}",
    "You deleted calendar {calendar}" : "Sa kustutasid kalendri {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} uuendas kalendrit {calendar}",
    "You updated calendar {calendar}" : "Sa uuendasid kalendrit {calendar}",
    "{actor} restored calendar {calendar}" : "{actor} taastas kalendri {calendar}",
    "You restored calendar {calendar}" : "Sina taastasid kalendri {calendar}",
    "You shared calendar {calendar} as public link" : "Sina jagasid „{calendar}“ kalendrit avaliku lingina",
    "You removed public link for calendar {calendar}" : "Sa eemaldasid „{calendar}“ kalendri avaliku lingi",
    "{actor} shared calendar {calendar} with you" : "{actor} jagas kalendrit {calendar} sinuga",
    "You shared calendar {calendar} with {user}" : "Sa jagasid kalendrit {calendar} kasutajaga {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} jagas kalendrit {calendar} kasutajaga {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} lõpetas sinuga kalendri {calendar} jagamise",
    "You unshared calendar {calendar} from {user}" : "Sa lõpetasid kalendri {calendar} jagamise kasutajaga {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} lõpetas kalendri {calendar} jagamise kasutajaga {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} lõpetas iseendaga kalendri {calendar} jagamise",
    "You shared calendar {calendar} with group {group}" : "Sa jagasid kalendrit {calendar} grupiga {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} jagas kalendrit {calendar} grupiga {group}",
    "You unshared calendar {calendar} from group {group}" : "Sa lõpetasid kalendri {calendar} jagamise grupiga {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} lõpetas kalendri {calendar} jagamise grupiga {group}",
    "Untitled event" : "Ilma nimeta sündmus",
    "{actor} created event {event} in calendar {calendar}" : "{actor} lõi sündmuse {event} kalendrisse {calendar}",
    "You created event {event} in calendar {calendar}" : "Sa lõid sündmuse {event} kalendrisse {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} kustutas sündmuse {event} kalendrist {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Sa kustutasid sündmuse {event} kalendrist {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} uuendas sündmust {event} kalendris {calendar}",
    "You updated event {event} in calendar {calendar}" : "Sa uuendasid „{event}“ sündmust „{calendar}“ kalendris",
    "{actor} moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "{actor} teisaldas „{event}“ sündmuse „{sourceCalendar}“ kalendrist „{targetCalendar}“ kalendrisse",
    "You moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "Sina teisaldasid „{event}“ sündmuse „{sourceCalendar}“ kalendrist „{targetCalendar}“ kalendrisse",
    "{actor} restored event {event} of calendar {calendar}" : "{actor} taastas „{event}“ sündmuse „{calendar}“ kalendris",
    "You restored event {event} of calendar {calendar}" : "Sina taastasid „{event}“ sündmuse „{calendar}“ kalendris",
    "Busy" : "Hõivatud",
    "{actor} created to-do {todo} in list {calendar}" : "{actor} lisas {todo} ülesande {calendar} loendissse",
    "You created to-do {todo} in list {calendar}" : "Sina lisasid {todo} ülesande {calendar} loendisse",
    "{actor} deleted to-do {todo} from list {calendar}" : "{actor} kustutas {todo} ülesande {calendar} loendist",
    "You deleted to-do {todo} from list {calendar}" : "Sina kustutasid {todo} ülesande {calendar} loendist",
    "{actor} updated to-do {todo} in list {calendar}" : "{actor} uuendas {todo} ülesannnet {calendar} loendist",
    "You updated to-do {todo} in list {calendar}" : "Sina uuendasid {todo} ülesannet {calendar} loendist",
    "{actor} solved to-do {todo} in list {calendar}" : "{actor} lahendas {todo} ülesande {calendar} loendist",
    "You solved to-do {todo} in list {calendar}" : "Sina lahendasid {todo} ülesande {calendar} loendist",
    "{actor} reopened to-do {todo} in list {calendar}" : "{actor} avas uuesti {todo} ülesande {calendar} loendist",
    "You reopened to-do {todo} in list {calendar}" : "Sina avasid uuesti {todo} ülesande {calendar} loendist",
    "{actor} moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "{actor} teisaldas {todo} ülesande {sourceCalendar} loendist {targetCalendar} loendisse",
    "You moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "Sina teisaldasid {todo} ülesande {sourceCalendar} loendist {targetCalendar} loendisse",
    "Calendar, contacts and tasks" : "Kalender, kontaktid ja ülesanded",
    "A <strong>calendar</strong> was modified" : " <strong>Kalendrit</strong> muudeti",
    "A calendar <strong>event</strong> was modified" : "Kalendri <strong>sündmust </strong> muudeti",
    "A calendar <strong>to-do</strong> was modified" : "Kalendri <strong>ülesannet</strong> muudeti",
    "Contact birthdays" : "Kontaktide sünnipäevad",
    "Death of %s" : "%s surm",
    "Calendar federation" : "Kalendri kasutamine liitpilves (födereerimine)",
    "{user} has shared the calendar {calendar} with you" : "{user} on sinuga jaganud „{calendar}“ kalendrit",
    "Accept" : "Nõustu",
    "Decline" : "Keeldu",
    "Untitled calendar" : "Nimetu kalender",
    "Calendar:" : "Kalender:",
    "Date:" : "Kuupäev:",
    "Where:" : "Kus:",
    "Description:" : "Kirjeldus:",
    "_%n year_::_%n years_" : ["%n aasta","%n aastat"],
    "_%n month_::_%n months_" : ["%n kuu","%n kuud"],
    "_%n day_::_%n days_" : ["%n päev","%n päeva"],
    "_%n hour_::_%n hours_" : ["%n tund","%n tundi"],
    "_%n minute_::_%n minutes_" : ["%n minut","%n minutit"],
    "%s (in %s)" : "%s (%s pärast)",
    "%s (%s ago)" : "%s (%s eest)",
    "Calendar: %s" : "Kalender: %s",
    "Date: %s" : "Kuupäev: %s",
    "Description: %s" : "Kirjeldus: %s",
    "Where: %s" : "Kus: %s",
    "%1$s via %2$s" : "%1$s %2$s kaudu",
    "In the past on %1$s for the entire day" : "Minevikus kogu päeva kestel: %1$s",
    "_In %n minute on %1$s for the entire day_::_In %n minutes on %1$s for the entire day_" : ["%n minuti pärast %1$s kogu päeva kestel","%n minuti pärast %1$s kogu päeva kestel"],
    "_In %n hour on %1$s for the entire day_::_In %n hours on %1$s for the entire day_" : ["%n tunni pärast %1$s kogu päeva kestel","%n tunni pärast %1$s kogu päeva kestel"],
    "_In %n day on %1$s for the entire day_::_In %n days on %1$s for the entire day_" : ["%n tunni päeva %1$s kogu päeva kestel","%n tunni pärast %1$s kogu päeva kestel"],
    "_In %n week on %1$s for the entire day_::_In %n weeks on %1$s for the entire day_" : ["%n nädala pärast %1$s kogu päeva kestel","%n nädala pärast %1$s kogu päeva kestel"],
    "_In %n month on %1$s for the entire day_::_In %n months on %1$s for the entire day_" : ["%n kuu pärast %1$s kogu päeva kestel","%n kuu pärast %1$s kogu päeva kestel"],
    "_In %n year on %1$s for the entire day_::_In %n years on %1$s for the entire day_" : ["%n aasta pärast %1$s kogu päeva kestel","%n aasta pärast %1$s kogu päeva kestel"],
    "In the past on %1$s between %2$s - %3$s" : "Minevikus: %1$s ajavahemikus %2$s - %3$s",
    "_In %n minute on %1$s between %2$s - %3$s_::_In %n minutes on %1$s between %2$s - %3$s_" : ["%n minuti pärast %1$s ajavahemikus %2$s kuni %3$s","%n minuti pärast %1$s ajavahemikus %2$s kuni %3$s"],
    "_In %n hour on %1$s between %2$s - %3$s_::_In %n hours on %1$s between %2$s - %3$s_" : ["%n tunni pärast %1$s ajavahemikus %2$s kuni %3$s","%n tunni pärast %1$s ajavahemikus %2$s kuni %3$s"],
    "_In %n day on %1$s between %2$s - %3$s_::_In %n days on %1$s between %2$s - %3$s_" : ["%n päeva pärast %1$s ajavahemikus %2$s kuni %3$s","%n päeva pärast %1$s ajavahemikus %2$s kuni %3$s"],
    "_In %n week on %1$s between %2$s - %3$s_::_In %n weeks on %1$s between %2$s - %3$s_" : ["%n nädala pärast %1$s ajavahemikus %2$s kuni %3$s","%n nädala pärast %1$s ajavahemikus %2$s kuni %3$s"],
    "_In %n month on %1$s between %2$s - %3$s_::_In %n months on %1$s between %2$s - %3$s_" : ["%n kuu pärast %1$s ajavahemikus %2$s kuni %3$s","%n kuu pärast %1$s ajavahemikus %2$s kuni %3$s"],
    "_In %n year on %1$s between %2$s - %3$s_::_In %n years on %1$s between %2$s - %3$s_" : ["%n aasta pärast %1$s ajavahemikus %2$s kuni %3$s","%n aasta pärast %1$s ajavahemikus %2$s kuni %3$s"],
    "Could not generate when statement" : "Ei õnnestunud koostada tingimuslikku „when“ lausendit",
    "Every Day for the entire day" : "Iga päev kogu päeva jooksul",
    "Every Day for the entire day until %1$s" : "Iga päev kogu päeva jooksul kuni %1$s",
    "Every Day between %1$s - %2$s" : "Iga päev ajavahemikus %1$s - %2$s",
    "Every Day between %1$s - %2$s until %3$s" : "Iga päev ajavahemikus %1$s - %2$s kuni %3$s",
    "Every %1$d Days for the entire day" : "Iga %1$d. päev kogu päeva jooksul",
    "Every %1$d Days for the entire day until %2$s" : "Iga %1$d. päev kogu päeva jooksul kuni %2$s",
    "Every %1$d Days between %2$s - %3$s" : "Iga %1$d. päev kogu päeva jooksul ajavahemikus %2$s - %3$s",
    "Every %1$d Days between %2$s - %3$s until %4$s" : "Iga %1$d. päev kogu päeva jooksul ajavahemikus %2$s - %3$s, kuni %4$s",
    "Could not generate event recurrence statement" : "Ei õnnestunud koostada ürituse kordumise lausendit",
    "Every Week on %1$s for the entire day" : "Kogu päeva kestel igal nädalal: %1$s",
    "Every Week on %1$s for the entire day until %2$s" : "Kogu päeva kestel igal nädalal kuni %2$s: %1$s",
    "Every Week on %1$s between %2$s - %3$s" : "Igal nädalal: %1$s ajavahemikus %2$s - %3$s",
    "Every Week on %1$s between %2$s - %3$s until %4$s" : "Igal nädalal kuni %2$s: %1$s ajavahemikus %3$s - %4$s",
    "Every %1$d Weeks on %2$s for the entire day" : "Igal %1$d-l nädalal kogu päeva kestel: %2$s",
    "Every %1$d Weeks on %2$s for the entire day until %3$s" : "Igal %1$d-l nädalal kuni %3$s kogu päeva kestel: %2$s",
    "Every %1$d Weeks on %2$s between %3$s - %4$s" : "Igal %1$d-l nädalal ajavahemikus %3$s - %4$s: %2$s",
    "Every %1$d Weeks on %2$s between %3$s - %4$s until %5$s" : "Igal %1$d-l nädalal kuni %5$s ajavahemikus %3$s - %4$s: %2$s",
    "Every Month on the %1$s for the entire day" : "Kogu päeva kestel igal kuul: %1$s",
    "Every Month on the %1$s for the entire day until %2$s" : "Kogu päeva kestel igal kuul kuni %2$s: %1$s",
    "Every Month on the %1$s between %2$s - %3$s" : "Igal kuul: %1$s ajavahemikus %2$s - %3$s",
    "Every Month on the %1$s between %2$s - %3$s until %4$s" : "Igal kuul kuni %2$s: %1$s ajavahemikus %3$s - %4$s",
    "Every %1$d Months on the %2$s for the entire day" : "Igal %1$d-l kuul kogu päeva kestel: %2$s",
    "Every %1$d Months on the %2$s for the entire day until %3$s" : "Igal %1$d-l kuul kuni %3$s kogu päeva kestel: %2$s",
    "Every %1$d Months on the %2$s between %3$s - %4$s" : "Igal %1$d-l kuul ajavahemikus %3$s - %4$s: %2$s",
    "Every %1$d Months on the %2$s between %3$s - %4$s until %5$s" : "Igal %1$d-l kuul kuni %5$s ajavahemikus %3$s - %4$s: %2$s",
    "Every Year in %1$s on the %2$s for the entire day" : "Kogu päeva kestel igal aastal: %1$s,  %2$s",
    "Every Year in %1$s on the %2$s for the entire day until %3$s" : "Kogu päeva kestel igal aastal kuni %3$s: %1$s,  %2$s",
    "Every Year in %1$s on the %2$s between %3$s - %4$s" : "Igal aastal ajavahemikus %3$s - %4$s: %1$s, %2$s",
    "Every Year in %1$s on the %2$s between %3$s - %4$s until %5$s" : "Igal aastal kuni %5$sajavahemikus %3$s - %4$s: %1$s, %2$s",
    "Every %1$d Years in %2$s on the %3$s for the entire day" : "Igal %1$d-l aastal kogu päeva kestel: %2$s, %3$s",
    "Every %1$d Years in %2$s on the %3$s for the entire day until %4$s" : "Kogu päeva kestel igal %1$d-l aastal kuni %4$s: %2$s, %3$s",
    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s" : "Igal %1$d-l aastal ajavahemikus %4$s - %5$s: %2$s, %3$s",
    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s until %6$s" : "Igal %1$d-l aastal kuni %6$s ajavahemikus %4$s - %5$s: %2$s, %3$s",
    "On specific dates for the entire day until %1$s" : "Kindlatel päevadel kogu päeva jooksul kuni %1$s",
    "On specific dates between %1$s - %2$s until %3$s" : "Kindlatel päevadel ajavahemikus %1$s - %2$s kuni %3$s",
    "In the past on %1$s" : "Minevikus %1$s",
    "_In %n minute on %1$s_::_In %n minutes on %1$s_" : ["%n minuti pärast %1$s","%n minuti pärast %1$s"],
    "_In %n hour on %1$s_::_In %n hours on %1$s_" : ["%n tunni pärast %1$s","%n tunni pärast %1$s"],
    "_In %n day on %1$s_::_In %n days on %1$s_" : ["%n päeva pärast %1$s","%n päeva pärast %1$s"],
    "_In %n week on %1$s_::_In %n weeks on %1$s_" : ["%n nädala pärast %1$s","%n nädala pärast %1$s"],
    "_In %n month on %1$s_::_In %n months on %1$s_" : ["%n kuu pärast %1$s","%n kuu pärast %1$s"],
    "_In %n year on %1$s_::_In %n years on %1$s_" : ["%n aasta pärast %1$s","%n aasta pärast %1$s"],
    "In the past on %1$s then on %2$s" : "Minevikus: %1$s ja siis %2$s",
    "_In %n minute on %1$s then on %2$s_::_In %n minutes on %1$s then on %2$s_" : ["%n minuti pärast %1$s, seejärel %2$s","%n minuti pärast %1$s, seejärel %2$s"],
    "_In %n hour on %1$s then on %2$s_::_In %n hours on %1$s then on %2$s_" : ["%n tunni pärast %1$s, seejärel %2$s","%n tunni pärast %1$s, seejärel %2$s"],
    "_In %n day on %1$s then on %2$s_::_In %n days on %1$s then on %2$s_" : ["%n päeva pärast %1$s, seejärel %2$s","%n päeva pärast %1$s, seejärel %2$s"],
    "_In %n week on %1$s then on %2$s_::_In %n weeks on %1$s then on %2$s_" : ["%n nädala pärast %1$s, seejärel %2$s","%n nädala pärast %1$s, seejärel %2$s"],
    "_In %n month on %1$s then on %2$s_::_In %n months on %1$s then on %2$s_" : ["%n kuu pärast %1$s, seejärel %2$s","%n kuu pärast %1$s, seejärel %2$s"],
    "_In %n year on %1$s then on %2$s_::_In %n years on %1$s then on %2$s_" : ["%n aasta pärast %1$s, seejärel %2$s","%n aasta pärast %1$s, seejärel %2$s"],
    "In the past on %1$s then on %2$s and %3$s" : "Minevikus: %1$s ja siis %2$s ning %3$s",
    "_In %n minute on %1$s then on %2$s and %3$s_::_In %n minutes on %1$s then on %2$s and %3$s_" : ["%n minuti pärast %1$s, seejärel %2$s ja %3$s","%n minuti pärast %1$s, seejärel %2$s ja %3$s"],
    "_In %n hour on %1$s then on %2$s and %3$s_::_In %n hours on %1$s then on %2$s and %3$s_" : ["%n tunni pärast %1$s, seejärel %2$s ja %3$s","%n tunni pärast %1$s, seejärel %2$s ja %3$s"],
    "_In %n day on %1$s then on %2$s and %3$s_::_In %n days on %1$s then on %2$s and %3$s_" : ["%n päeva pärast %1$s, seejärel %2$s ja %3$s","%n päeva pärast %1$s, seejärel %2$s ja %3$s"],
    "_In %n week on %1$s then on %2$s and %3$s_::_In %n weeks on %1$s then on %2$s and %3$s_" : ["%n nädala pärast %1$s, seejärel %2$s ja %3$s","%n nädala pärast %1$s, seejärel %2$s ja %3$s"],
    "_In %n month on %1$s then on %2$s and %3$s_::_In %n months on %1$s then on %2$s and %3$s_" : ["%n kuu pärast %1$s, seejärel %2$s ja %3$s","%n kuu pärast %1$s, seejärel %2$s ja %3$s"],
    "_In %n year on %1$s then on %2$s and %3$s_::_In %n years on %1$s then on %2$s and %3$s_" : ["%n aasta pärast %1$s, seejärel %2$s ja %3$s","%n aasta pärast %1$s, seejärel %2$s ja %3$s"],
    "Could not generate next recurrence statement" : "Ei õnnestunud koostada korduva ürituse järgmise toimumise lausendit",
    "Cancelled: %1$s" : "Tühistatud: %1$s",
    "\"%1$s\" has been canceled" : "„%1$s“ on tühistatud",
    "Re: %1$s" : "Re: %1$s",
    "%1$s has accepted your invitation" : "„%1$s“ on nõustunud sinu kutsega",
    "%1$s has tentatively accepted your invitation" : "„%1$s“ on esialgselt nõustunud sinu kutsega",
    "%1$s has declined your invitation" : "„%1$s“ on sinu kutsest keeldunud",
    "%1$s has responded to your invitation" : "„%1$s“ on vastanud sinu kutsele",
    "Invitation updated: %1$s" : "Kutse on uuendatud: %1$s",
    "%1$s updated the event \"%2$s\"" : "„%1$s“ uuendas sündmust „%2$s“",
    "Invitation: %1$s" : "Kutse: %1$s",
    "%1$s would like to invite you to \"%2$s\"" : "„%1$s“ soovib saata sulle „%2$s“ kutset",
    "Organizer:" : "Korraldaja:",
    "Attendees:" : "Osalejad:",
    "Title:" : "Pealkiri:",
    "When:" : "Millal:",
    "Location:" : "Asukoht:",
    "Link:" : "Link:",
    "Occurring:" : "Toimub:",
    "More options …" : "Täiendavad valikud…",
    "More options at %s" : "Lisavalikud: %s",
    "Monday" : "Esmaspäev",
    "Tuesday" : "Teisipäev",
    "Wednesday" : "Kolmapäev",
    "Thursday" : "Neljapäev",
    "Friday" : "Reede",
    "Saturday" : "Laupäev",
    "Sunday" : "Pühapäev",
    "January" : "Jaanuar",
    "February" : "Veebruar",
    "March" : "Märts",
    "April" : "Aprill",
    "May" : "Mai",
    "June" : "Juuni",
    "July" : "Juuli",
    "August" : "August",
    "September" : "September",
    "October" : "Oktoober",
    "November" : "November",
    "December" : "Detsember",
    "First" : "Esimene",
    "Second" : "Teine",
    "Third" : "Kolmas",
    "Fourth" : "Neljas",
    "Fifth" : "Viies",
    "Last" : "Viimane",
    "Second Last" : "Teiseks viimane",
    "Third Last" : "Kolmandks viimane",
    "Fourth Last" : "Neljandaks viimane",
    "Fifth Last" : "Viiendaks viimane",
    "Contacts" : "Kontaktid",
    "{actor} created address book {addressbook}" : "{actor} lõi aadressiraamatu „{addressbook}“",
    "You created address book {addressbook}" : "Sa lõid aadressiraamatu „{addressbook}“",
    "{actor} deleted address book {addressbook}" : "„{actor}“  kustutas „{addressbook}“ aadressiraamatu",
    "You deleted address book {addressbook}" : "Sa kustutasid aadressiraamatu „{addressbook}“",
    "{actor} updated address book {addressbook}" : "{actor} uuendasaadressiraamatut „{addressbook}“",
    "You updated address book {addressbook}" : "Sa uuendasid aadressiraamatut „{addressbook}“",
    "{actor} shared address book {addressbook} with you" : "{actor} jagas „{addressbook}“ aadressiraamatut sinuga",
    "You shared address book {addressbook} with {user}" : "Sa jagasid „{addressbook}“ aadressiraamatut kasutajaga „{user}“",
    "{actor} shared address book {addressbook} with {user}" : "{actor} jagas „{addressbook}“ aadressiraamatut kasutajaga „{user}“",
    "{actor} unshared address book {addressbook} from you" : "{actor} lõpetas „{addressbook}“ aadressiraamatu jagamise sinult",
    "You unshared address book {addressbook} from {user}" : "Sina lõpetasid „{addressbook}“ aadressiraamatu jagamise kasutajalt {user}",
    "{actor} unshared address book {addressbook} from {user}" : "{actor} lõpetas „{addressbook}“ aadressiraamatu kasutajalt {user}",
    "{actor} unshared address book {addressbook} from themselves" : "{actor} lõpetas „{addressbook}“ aadressiraamatu jagamise iseendalt",
    "You shared address book {addressbook} with group {group}" : "Sina jagasid „{addressbook}“ aadressiraamatut grupiga {group}",
    "{actor} shared address book {addressbook} with group {group}" : "{actor} jagas „{addressbook}“ aadressiraamatut grupiga {group}",
    "You unshared address book {addressbook} from group {group}" : "Sina lõpetasid „{addressbook}“ aadressiraamatu jagamise grupiga {group}",
    "{actor} unshared address book {addressbook} from group {group}" : "{actor} lõpetas „{addressbook}“ aadressiraamatu jagamise grupiga {group}",
    "{actor} created contact {card} in address book {addressbook}" : "{actor} lisas „{card}“ kontakti „{addressbook}“ aadressiraamatusse",
    "You created contact {card} in address book {addressbook}" : "Sina lisasid „{card}“ kontakti „{addressbook}“ aadressiraamatusse",
    "{actor} deleted contact {card} from address book {addressbook}" : "{actor} kustutas „{card}“ kontakti „{addressbook}“ aadressiraamatus",
    "You deleted contact {card} from address book {addressbook}" : "Sa kustutasid „{card}“ kontakti „{addressbook}“ aadressiraamatus",
    "{actor} updated contact {card} in address book {addressbook}" : "{actor} uuendas „{card}“ kontakti „{addressbook}“ aadressiraamatus",
    "You updated contact {card} in address book {addressbook}" : "Sa uuendasid „{card}“ kontakti „{addressbook}“ aadressiraamatus",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "<strong>Kontakti</strong> või <strong>aadressiraamatut</strong> muudeti",
    "System address book disabled" : "Süsteemne aadressiraamat pole kasutusel",
    "The system contacts address book has been automatically disabled during upgrade. This means that the address book will no longer be available to users in the contacts app or other clients. The system contacts address book was disabled because the amount of contacts in the address book exceeded the maximum recommended number of contacts. This limit is set to prevent performance issues. You can re-enable the system address book with the following command {command}" : "Süsteemne aadressiraamat on uuenduse ajal automaatselt kasutuselt eemaldatud. See tähendab, et antud aadressiraamat pole enam kasutajatele saadav ei kontaktirakenduses ega muudes klientides. Süsteemne aadressiraamat on kasutuselt eemaldatud, kuna seal sisaldus enam kontakte, kui lubatud ülempiir võimaldab. Selline ülempiir on määratud jõudluskaalutluste alusel. Järgneva käsuga saad süsteemse aadressiraamatu uuesti kasutusele võtta: {command}",
    "Accounts" : "Kasutajakontod",
    "System address book which holds all accounts" : "Süsteemne aadressiraamat, kus leiduvad kõik kasutajakontod",
    "File is not updatable: %1$s" : "Fail pole uuendatav: %1$s",
    "Failed to get storage for file" : "Failile ei õnnestunud eraldada andmeruumi",
    "Could not write to final file, canceled by hook" : "Lõppfaili kirjutamine ei õnnestunud, selle katkestas programmi haak",
    "Could not write file contents" : "Ei õnnestunud kirjutada faili sisu",
    "_%n byte_::_%n bytes_" : ["%n bait","%n baiti"],
    "Error while copying file to target location (copied: %1$s, expected filesize: %2$s)" : "Viga faili kopeerimisel sihtkausta (kopeerisin %1$s, aga suuruseks eeldasin %2$s)",
    "Expected filesize of %1$s but read (from Nextcloud client) and wrote (to Nextcloud storage) %2$s. Could either be a network problem on the sending side or a problem writing to the storage on the server side." : "Eeldasin faili suuruseks %1$s, aga lugesin (Nextcloudi kliendilt) ja kirjutasin (Nextcloudi andmeruumi) %2$s. Tegemist võib olla võrguühenduse veaga saatja poolel või andmeruumi kirjutamise veaga serveri  poolel.",
    "Could not rename part file to final file, canceled by hook" : "Osalise faili nime muutmine lõplikuks nimeks ei õnnestunud, selle katkestas programmi haak",
    "Could not rename part file to final file" : "Osalise faili nime muutmine lõplikuks nimeks ei õnnestunud",
    "Failed to check file size: %1$s" : "Faili suuruse kontrollimine ei õnnestunud: %1$s",
    "Could not open file: %1$s (%2$d), file does seem to exist" : "„%1$s“ (%2$d) faili avamine ei õnnestunud, aga tundub, et ta on olemas",
    "Could not open file: %1$s (%2$d), file doesn't seem to exist" : "„%1$s“ (%2$d) faili avamine ei õnnestunud, tundub, et teda pole olemas",
    "Failed to get size for : %1$s" : "Suuruse tuvastamine ei õnnestunud: %1$s",
    "Encryption not ready: %1$s" : "Krüptimine pole veel kasutatav: %1$s",
    "Failed to open file: %1$s" : "Faili avamine ei õnnestunud: %1$s",
    "Failed to unlink: %1$s" : "Lingi eemaldamine ei õnnestunud: %1$s",
    "Failed to write file contents: %1$s" : "Faili sisu salvestamine ei õnnestunud: %1$s",
    "File not found: %1$s" : "Faili ei leidu: %1$s",
    "Insufficient space" : "Pole piisavalt andmeruumi",
    "Invalid target path" : "Vigane sihtasukoht",
    "System is in maintenance mode." : "Server on hooldusrežiimis.",
    "Upgrade needed" : "Uuendus on vajalik",
    "Delegate:" : "Volitatu:",
    "%1$s created \"%2$s\" on your behalf" : "%1$s lisas sinu nimel „%2$s“ kirje",
    "%1$s created \"%2$s\" on your calendar \"%3$s\"" : "%1$s lisas sinu „%3$s“ kalendrisse „%2$s“ kirje",
    "%1$s updated \"%2$s\" on your behalf" : "%1$s muutis sinu nimel „%2$s“ kirjet",
    "%1$s updated \"%2$s\" on your calendar \"%3$s\"" : "%1$s muutis sinu „%3$s“ kalendris „%2$s“ kirjet",
    "%1$s deleted \"%2$s\" on your behalf" : "%1$s kustutas sinu nimel „%2$s“ kirje",
    "%1$s permanently deleted \"%2$s\" from your calendar \"%3$s\"" : "%1$s kustutas sinu „%3$s“ kalendrist lõplikult „%2$s“ kirje",
    "%1$s moved \"%2$s\" to the trash on your behalf" : "%1$s viskas sinu nimel „%2$s“ kirje prügikasti",
    "%1$s moved \"%2$s\" to the trash on your calendar \"%3$s\"" : "%1$s viskas sinu „%3$s“ kalendrist „%2$s“ kirje prügikasti",
    "%1$s restored \"%2$s\" on your behalf" : "%1$s taastas sinu nimel „%2$s“ kirje",
    "%1$s restored \"%2$s\" on your calendar \"%3$s\"" : "%1$s taastas sinu „%3$s“ kalendris „%2$s“ kirje",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Selleks, et sinu %s toimiks iOS-is/macOS-is CalDAV-i ja CardDAV-iga  peab https olema seadistatud.",
    "Configures a CalDAV account" : "Seadistab CalDAV-i kasutajakonto",
    "Configures a CardDAV account" : "Seadistab CardDAV-i kasutajakonto",
    "Events" : "Sündmused",
    "Untitled task" : "Ilma nimeta pealkiri",
    "Completed on %s" : "Lõpetatud %s",
    "Due on %s by %s" : "Tähtaeg: %s, täitjaks %s",
    "Due on %s" : "Tähtaeg: %s",
    "This is an example contact" : "See on näidiskontakt",
    "Welcome to Nextcloud Calendar!\n\nThis is a sample event - explore the flexibility of planning with Nextcloud Calendar by making any edits you want!\n\nWith Nextcloud Calendar, you can:\n- Create, edit, and manage events effortlessly.\n- Create multiple calendars and share them with teammates, friends, or family.\n- Check availability and display your busy times to others.\n- Seamlessly integrate with apps and devices via CalDAV.\n- Customize your experience: schedule recurring events, adjust notifications and other settings." : "Tere tulemast Nextcloudi Kalendrisse!\n\nSee näidissündmus võimaldab sul tutvuda Nextcloudi Kalendri paindlikkusega oma aja plaanimisel - proovi teha igasuguseid muudatusi!\n\nNextcloudi Kalendriga saad sa:\n- vaevata luua, muuta ja hallata sündmusi,\n- koostada mitmeid kalendreid ning neid jagada tiimikaaslaste, sõprade ja perega,\n- kontrollida teiste vabu aega ja enda omi näidata teistele,\n- kasutada sujuvat CalDAV-i põhist lõimingut teiste rakenduste ja seadmetega,\n- kohendada kõike oma vajadustele: ajastades korduvaid sündmusi ning sättida teavitusi ja muid seadistusi.",
    "Example event - open me!" : "Näidissündmus - klõpsi mind!",
    "System Address Book" : "Süsteemiülene aadressiraamat",
    "The system address book contains contact information for all users in your instance." : "Süsteemiüleses aadressiraamatus leiduvad kõikide selle serveri kasutajate kontaktandmed.",
    "Enable System Address Book" : "Kasuta süsteemiülest aadressiraamatut",
    "DAV system address book" : "DAV-i süsteemiülene aadressiraamat",
    "No outstanding DAV system address book sync." : "DAV-i süsteemiülese aadressiraamatu sünkroonimist pole ootel või toimunud.",
    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "Kuna selles serveris on üle 1000 kasutaja, siis DAV-i süsteemiülese aadressiraamatu sünkroonimist pole veel toimunud. Aga võis ka juhtuda viga. Palun käivita ta käsurealt ise käsuga „occ dav:sync-system-addressbook“.",
    "DAV system address book size" : "DAV-i süsteemiülese aadressiraamatu suurus",
    "The system address book is disabled" : "Süsteemiülene aadressiraamat pole kasutusel",
    "The system address book is enabled, but contains more than the configured limit of %d contacts" : "Süsteemiülene aadressiraamat on kasutusel, kuid seal on andmeid rohkem, kui seadistatud %d kontakti ülempiir lubab",
    "The system address book is enabled and contains less than the configured limit of %d contacts" : "Süsteemiülene aadressiraamat on kasutusel ning seal on andmeid vähem, kui seadistatud %d kontakti ülempiir lubab",
    "WebDAV endpoint" : "WebDAV-i teenuse otspunkt",
    "Could not check that your web server is properly set up to allow file synchronization over WebDAV. Please check manually." : "Ei õnnestunud kontrollida, kas sinu veebiserver on korrektselt seadistatud ja võimaldab kasutada failide sünkroniseerimist WebDAV-i vahendusel. Palun kontrolli seda käsitsi.",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Sinu veebiserver pole veel failide sünkroniseerimiseks vajalikult seadistatud, kuna WebDAV liides paistab olevat katki.",
    "Your web server is properly set up to allow file synchronization over WebDAV." : "Sinu veebiserver on korrektselt seadistatud ja võimaldab kasutada failide sünkroniseerimist WebDAV-i vahendusel.",
    "Calendars including events, details and attendees" : "Kalendrid, sealhulgas sündmused, üksikasjad ja osalejad",
    "Migrated calendar (%1$s)" : "Ümberkolitud kalender (%1$s)",
    "Contacts and groups" : "Kontaktid ja grupid",
    "WebDAV" : "WebDAV",
    "Absence saved" : "Äraoleku teave on salvestatud",
    "Failed to save your absence settings" : "Sinu äraoleku seadistuste salvestamine ei õnnestunud",
    "Absence cleared" : "Äraolek on eemaldatud",
    "Failed to clear your absence settings" : "Sinu äraoleku seadistuste eemaldamine ei õnnestunud",
    "First day" : "Esimene päev",
    "Last day (inclusive)" : "Viimane päev (kaasaarvatud)",
    "Out of office replacement (optional)" : "Asendaja äraoleku ajaks (valikuline)",
    "Name of the replacement" : "Asendaja nimi",
    "Short absence status" : "Äraoleku lühinimi",
    "Long absence Message" : "Äraoleku pikk sõnum",
    "Save" : "Salvesta",
    "Disable absence" : "Lülita äraolek välja",
    "Failed to load availability" : "Saadavuse laadimine ei õnnestunud",
    "Saved availability" : "Saadavus on salvestatud",
    "Failed to save availability" : "Saadavuse salvestamine ei õnnestunud",
    "to" : "saaja",
    "Delete slot" : "Kustuta ajavahemik",
    "No working hours set" : "Tööajad on sisestamata",
    "Add slot" : "Lisa ajavahemik",
    "Weekdays" : "Nädalapäevad",
    "Pick a start time for {dayName}" : "Vali algusaeg: {dayName}",
    "Pick a end time for {dayName}" : "Vali lõpuaeg: {dayName}",
    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Kõikide teavituste summutamiseks määra automaatselt kasutajale olek „Ära sega“ nendele aegadele, kus ta vaba ei ole.",
    "Cancel" : "Tühista",
    "Import" : "Impordi",
    "Error while saving settings" : "Viga seadistuste salvestamisel",
    "Contact reset successfully" : "Kontakti lähtestamine õnnestus",
    "Error while resetting contact" : "Viga kontakti lähtestamisel",
    "Contact imported successfully" : "Kontakti importimine õnnestus",
    "Error while importing contact" : "Viga kontakti importimisel",
    "Import contact" : "Impordi kontakt",
    "Reset to default" : "Taasta vaikeseadistused",
    "Import contacts" : "Impordi kontaktid",
    "Importing a new .vcf file will delete the existing default contact and replace it with the new one. Do you want to continue?" : "Uue .vcf faili importimisel olemasolev vaikimisi kontakt kustutatakse ja asendatakse uuega. Kas sa soovid jätkata?",
    "Failed to save example event creation setting" : "Näidissündmuse loomise seadistuste salvestamine ei õnnestunud",
    "Failed to upload the example event" : "Näidissündmuse üleslaadimine ei õnnestunud",
    "Custom example event was saved successfully" : "Kohandatud näidissündmuse salvestamine õnnestus",
    "Failed to delete the custom example event" : "Kohandatud näidissündmuse kustutamine ei õnnestunud",
    "Custom example event was deleted successfully" : "Kohandatud näidissündmuse kustutamine õnnestus",
    "Import calendar event" : "Impordi kalendrisündmus",
    "Uploading a new event will overwrite the existing one." : "Uue sündmuse üleslaadimisel asendatakse olemasolevad.",
    "Upload event" : "Laadi sündmus üles",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Palun paigalda ka {calendarappstoreopen}Kalendrirakendus{linkclose} või {calendardocopen}lisa sünkroniseerimine oma töölaule ja nutiseadmesse ↗{linkclose}.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Palun kontrolli, et {emailopen}e-posti server{linkclose} on seadistatud korrektselt.",
    "Calendar server" : "Kalendriserver",
    "Send invitations to attendees" : "Saada osalejatele kutsed",
    "Automatically generate a birthday calendar" : "Koosta sünnipäevade kalender automaatselt",
    "Birthday calendars will be generated by a background job." : "Sünnipäevade kalender luuakse automaatselt taustateenuse poolt.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Seega pole need andmed kohe saadaval, vaid ilmuvad mingi aja pärast.",
    "Send notifications for events" : "Saada sündmuste teavitusi",
    "Notifications are sent via background jobs, so these must occur often enough." : "Teavitused saadetakse taustateenuste poolt. See eeldab, et vastavaid skripte käivitatakse piisavalt tihti.",
    "Send reminder notifications to calendar sharees as well" : "Saada meeldetuletused ka neile, kes ürituse on lisanud oma kalendrisse",
    "Reminders are always sent to organizers and attendees." : "Meeldetuletused on alati saadetud korraldajatele ja osalejatele.",
    "Enable notifications for events via push" : "Võta kasutusele tõuketeenustepõhised teavitused",
    "Example content" : "Sisunäidis",
    "Example content serves to showcase the features of Nextcloud. Default content is shipped with Nextcloud, and can be replaced by custom content." : "Sisunäidis annab ülevaate Nexctcloudi võimalustest. Vaikimisi sisu tuleb Nexctcloudi paigaldusega kaasa ja seda saad alati oma sisuga asendada.",
    "Availability" : "Saadavus",
    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Kui seadistad oma tööajad, siis teised saavad kohtumise broneerimisel arvestada sellega, millal sind kohal pole.",
    "Absence" : "Äraolek",
    "Configure your next absence period." : "Seadista järgmise äraoleku ajavahemik.",
    "There was an error updating your attendance status." : "Sinu osalemise oleku muutmisel tekkis viga.",
    "Please contact the organizer directly." : "Palun võta ühendust korraldajaga otse.",
    "Are you accepting the invitation?" : "Kas sa nõustud kutsega?",
    "Tentative" : "Esialgne",
    "Your attendance was updated successfully." : "Sinu osalemise oleku muutmine õnnestus.",
    "No results." : "Vasteid ei leitud.",
    "Start typing." : "Alusta kirjutamist."
},
"nplurals=2; plural=(n != 1);");
