OC.L10N.register(
    "files_external",
    {
    "You are not logged in" : "Du är inte inloggad",
    "Permission denied" : "Åtkomst nekad",
    "Storage with ID \"%d\" not found" : "Lagringsutrymme med ID \"%d\" hittades inte",
    "Forbidden to manage local mounts" : "Förbjudet att hantera lokala monteringar",
    "Invalid backend or authentication mechanism class" : "Ogiltig klass för lagringsbackend eller autentiseringsmekanism",
    "Invalid mount point" : "Ogiltig monteringspunkt",
    "Objectstore forbidden" : "Objektlagring är förbjuden",
    "Invalid storage backend \"%s\"" : "Ogiltig lagringsbackend ”%s”",
    "Not permitted to use backend \"%s\"" : "Det är inte tillåtet att använda lagringsbackend ”%s”",
    "Not permitted to use authentication mechanism \"%s\"" : "Det är inte tillåtet att använda autentiseringsmekanismen ”%s”",
    "Unsatisfied backend parameters" : "Parametrarna för lagringsbackend är inte uppfyllda",
    "Unsatisfied authentication mechanism parameters" : "Parametrarna för autentiseringsmekanismen är inte uppfyllda",
    "Insufficient data: %s" : "Otillräckliga data: %s",
    "Storage with ID \"%d\" is not editable by non-admins" : "Lagring med ID \"%d\" kan inte redigeras av icke-administratörer",
    "Static credentials" : "Statiska inloggningsuppgifter",
    "Access key ID" : "Åtkomstnyckel-ID",
    "Secret access key" : "Hemlig åtkomstnyckel",
    "Builtin" : "Inbyggt",
    "None" : "Ingen",
    "OpenStack v2" : "OpenStack v2",
    "Login" : "Logga in",
    "Password" : "Lösenord",
    "Tenant name" : "Klientorganisationsnamn",
    "Identity endpoint URL" : "Webbadress till identitetsslutpunkt",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "Domän",
    "Rackspace" : "Rackspace",
    "API key" : "API-nyckel",
    "Global credentials" : "Globala autentiseringsuppgifter",
    "Log-in credentials, save in database" : "Inloggningsuppgifter sparade i databasen",
    "Login and password" : "Inloggning och lösenord",
    "Log-in credentials, save in session" : "Inloggningsuppgifter, spara i sessionen",
    "Global credentials, manually entered" : "Globala uppgifter, manuellt inmatade",
    "Manually entered, store in database" : "Manuellt inmatad, lagra i databas",
    "RSA public key" : "Publik RSA-nyckel",
    "Public key" : "Publik nyckel",
    "RSA private key" : "Privat RSA-nyckel",
    "Private key" : "Privat nyckel",
    "Kerberos default realm, defaults to \"WORKGROUP\"" : "Kerberos-standardriket är som standard ”WORKGROUP”",
    "Kerberos ticket Apache mode" : "Apache-läge för Kerberos-biljett",
    "Kerberos ticket" : "Kerberos-biljett",
    "S3-Compatible Object Storage" : "S3-kompatibel objektlagring",
    "Bucket" : "Bucket",
    "Hostname" : "Värdnamn",
    "Port" : "Port",
    "Proxy" : "Proxy",
    "Region" : "Region",
    "Storage Class" : "Lagringsklass",
    "Use HTTPS" : "Använd HTTPS",
    "Use Path Style (https://example.com/bucket)" : "Använd sökvägsstil (https://example.com/bucket)",
    "Use Legacy S3 signing (v2)" : "Använd äldre S3-signering (v2)",
    "Enable multipart copy" : "Aktivera flerdelad kopiering",
    "Enable Direct Downloads (presigned URLs)" : "Aktivera direktnedladdningar (förauktoriserade URL:er)",
    "SSE-C encryption key" : "SSE-C krypteringsnyckel",
    "WebDAV" : "WebDAV",
    "URL" : "Webbadress",
    "Remote subfolder" : "Fjärrundermapp",
    "Secure https://" : "Säker https://",
    "FTP/FTPS" : "FTP/FTPS",
    "Host" : "Värd",
    "Secure ftps://" : "Säker ftps://",
    "Local (server storage)" : "Lokal (serverlagring)",
    "Location" : "Plats",
    "Nextcloud (WebDAV)" : "Nextcloud (WebDAV)",
    "SFTP (SSH file transfer)" : "SFTP (SSH-filöverföring)",
    "Root" : "Rot",
    "SFTP with public key authentication" : "SFTP med autentisering via offentlig nyckel",
    "SMB/CIFS (Windows network share)" : "SMB/CIFS (Windows-nätverksresurs)",
    "Share" : "Resurs",
    "Show hidden files" : "Visa dolda filer",
    "Case sensitive file system" : "Skiftlägeskänsligt filsystem",
    "Disabling it will allow to use a case insensitive file system, but comes with a performance penalty" : "Inaktivering gör det möjligt att använda ett skiftlägesokänsligt filsystem, men det kommer att påverka prestandan",
    "Verify ACL access when listing files" : "Verifiera ACL-åtkomst vid fillistning",
    "Check the ACL's of each file or folder inside a directory to filter out items where the account has no read permissions, comes with a performance penalty" : "Kontrollera ACL:en för varje fil och mapp i en katalog för att filtrera bort objekt som kontot saknar läsbehörighet till. Detta försämrar prestandan.",
    "Timeout" : "Timeout",
    "SMB/CIFS using Nextcloud login" : "SMB/CIFS med Nextcloud-inloggning",
    "Login as share" : "Logga in som delning",
    "OpenStack Swift Object Storage" : "OpenStack Swift objektlagring",
    "Service name" : "Namn på tjänst",
    "Request timeout (seconds)" : "Tidsgräns för begäran (sekunder)",
    "External storage" : "Extern lagring",
    "External storage support" : "Stöd för extern lagring",
    "Adds basic external storage support" : "Lägger till grundläggande stöd för extern lagring",
    "This application enables administrators to configure connections to external storage providers, such as FTP servers, S3 or SWIFT object stores, other Nextcloud servers, WebDAV servers, and more. Administration can choose which types of storage to enable and can mount these storage locations for an account, a group, or the entire system. Users will see a new folder appear in their root Nextcloud directory, which they can access and use like any other Nextcloud folder. External storage also allows people to share files stored in these external locations. In these cases, the credentials for the owner of the file are used when the recipient requests the file from external storage, thereby ensuring that the recipient can access the shared file.\n\nExternal storage can be configured using the GUI or at the command line. This second option provides the administration with more flexibility for configuring bulk external storage mounts and setting mount priorities. More information is available in the external storage GUI documentation and the external storage Configuration File documentation." : "Den här appen gör det möjligt för administratörer att konfigurera anslutningar till externa lagringsleverantörer, exempelvis FTP-servrar, S3- eller SWIFT-objektlagring, andra Nextcloud-servrar och WebDAV-servrar. Administratören kan välja vilka lagringstyper som ska aktiveras och montera lagringsplatserna för ett konto, en grupp eller hela systemet. Användarna ser en ny mapp i rotkatalogen i Nextcloud och kan använda den som vilken annan Nextcloud-mapp som helst. Filer i externa lagringsutrymmen kan också delas. När mottagaren begär en sådan fil används filägarens autentiseringsuppgifter för åtkomst till det externa lagringsutrymmet, vilket säkerställer att mottagaren kan komma åt den delade filen.\n\nExtern lagring kan konfigureras i det grafiska gränssnittet eller på kommandoraden. Kommandoraden ger administratören större flexibilitet vid masskonfiguration av externa monteringar och inställning av monteringsprioritet. Mer information finns i dokumentationen om det grafiska gränssnittet för extern lagring och dokumentationen om konfigurationsfilen för extern lagring.",
    "Edit storage" : "Redigera lagring",
    "Add storage" : "Lägg till lagring",
    "Folder name" : "Mappnamn",
    "Authentication" : "Autentisering",
    "Cancel" : "Avbryt",
    "Edit" : "Redigera",
    "Create" : "Skapa",
    "Restrict to" : "Begränsa till",
    "Storage configuration" : "Lagringskonfiguration",
    "Never" : "Aldrig",
    "Once every direct access" : "En gång vid varje direktåtkomst",
    "Always" : "Alltid",
    "Mount options" : "Monteringsalternativ",
    "Check filesystem changes" : "Kontrollera ändringar i filsystemet",
    "Read only" : "Skrivskyddad",
    "Enable previews" : "Aktivera förhandsgranskningar",
    "Enable sharing" : "Aktivera delning",
    "Enable encryption" : "Aktivera kryptering",
    "Compatibility with Mac NFD encoding (slow)" : "Kompatibilitet med Mac NFD-kodning (långsam)",
    "External storages" : "Externa lagringsutrymmen",
    "Status" : "Status",
    "Restricted to" : "Begränsad till",
    "Actions" : "Åtgärder",
    "Checking …" : "Kontrollerar …",
    "Recheck status" : "Kontrollera status igen",
    "Delete" : "Ta bort",
    "System provided storage" : "Systemtillhandahållet lagringsutrymme",
    "Saved" : "Sparad",
    "Error while saving" : "Fel vid sparning",
    "Saved allowed backends" : "Tillåtna lagringsbackendtyper har sparats",
    "Failed to save allowed backends" : "Det gick inte att spara tillåtna lagringsbackendtyper",
    "Advanced options for external storage mounts" : "Avancerade alternativ för extern lagring",
    "Allow people to mount external storage" : "Tillåt användare att montera extern lagring",
    "External storage backends people are allowed to mount" : "Lagringsbackendtyper som användare får montera",
    "Error generating key pair" : "Fel vid generering av nyckelpar",
    "Key size" : "Nyckelstorlek",
    "Generate keys" : "Generera nycklar",
    "Confirm" : "Bekräfta",
    "Storage credentials" : "Autentiseringsuppgifter för lagringen",
    "To access the storage, you need to provide the authentication credentials." : "För att komma åt lagringen måste du ange autentiseringsuppgifterna.",
    "Enter the storage login" : "Ange inloggning för lagringen",
    "Enter the storage password" : "Ange lösenord för lagringen",
    "External storage enables you to mount external storage services and devices as secondary Nextcloud storage devices." : "Med extern lagring kan du montera externa lagringstjänster och enheter som sekundära lagringsenheter i Nextcloud.",
    "You may also allow people to mount their own external storage services." : "Du kan också tillåta att användare monterar sina egna externa lagringstjänster.",
    "The cURL support in PHP is not enabled or installed." : "Stöd för cURL i PHP är inte aktiverat eller installerat.",
    "The FTP support in PHP is not enabled or installed." : "Stöd för FTP i PHP är inte aktiverat eller installerat.",
    "{module} is not installed." : "{module} är inte installerad.",
    "Dependant backends" : "Beroende lagringsbackendtyper",
    "No external storage configured or you do not have the permission to configure them" : "Ingen extern lagringsenhet är konfigurerad, eller så har du inte behörighet att konfigurera den.",
    "Add external storage" : "Lägg till extern lagring",
    "Global credentials saved" : "Globala autentiseringsuppgifter har sparats",
    "Could not save global credentials" : "Det gick inte att spara de globala autentiseringsuppgifterna",
    "Global credentials can be used to authenticate with multiple external storages that have the same credentials." : "Globala autentiseringsuppgifter kan användas för flera externa lagringsutrymmen som har samma inloggningsuppgifter.",
    "Saving …" : "Sparar …",
    "Save" : "Spara",
    "Unable to update this external storage config. {statusMessage}" : "Det gick inte att uppdatera konfigurationen för det här externa lagringsutrymmet. {statusMessage}",
    "New configuration successfully saved" : "Ny konfiguration har sparats",
    "Enter missing credentials" : "Ange saknade inloggningsuppgifter",
    "Credentials successfully set" : "Autentiseringsuppgifterna har angetts",
    "Error while setting credentials: {error}" : "Fel vid inställning av autentiseringsuppgifter: {error}",
    "Checking storage …" : "Kontrollerar lagring …",
    "There was an error with this external storage." : "Ett fel uppstod med det här externa lagringsutrymmet.",
    "We were unable to check the external storage {basename}" : "Det gick inte att kontrollera det externa lagringsutrymmet {basename}",
    "Examine this faulty external storage configuration" : "Undersök denna felaktiga externa lagringskonfiguration",
    "Open in Files" : "Öppna i Filer",
    "External mount error" : "Fel vid extern montering",
    "There was an error with this external storage. Do you want to review this mount point config in the settings page?" : "Ett fel uppstod med det här externa lagringsutrymmet. Vill du granska monteringspunktens konfiguration på inställningssidan?",
    "Open settings" : "Öppna inställningar",
    "Ignore" : "Ignorera",
    "List of external storage." : "Lista över externa lagringsutrymmen.",
    "There is no external storage configured. You can configure them in your Personal settings." : "Inga externa lagringsutrymmen har konfigurerats. Du kan konfigurera dem i dina personliga inställningar.",
    "There is no external storage configured and you don't have the permission to configure them." : "Inga externa lagringsutrymmen har konfigurerats och du har inte behörighet att konfigurera dem.",
    "No external storage" : "Ingen extern lagring",
    "Storage type" : "Lagringstyp",
    "Unknown" : "Okänd",
    "Scope" : "Omfattning",
    "Personal" : "Privat",
    "System" : "System",
    "Connected" : "Ansluten",
    "Error" : "Fel",
    "Indeterminate" : "Obestämd",
    "Incomplete configuration" : "Ofullständig konfiguration",
    "Unauthorized" : "Obehörig",
    "Network error" : "Nätverksfel",
    "Grant access" : "Bevilja åtkomst",
    "Error configuring OAuth2" : "Det gick inte att konfigurera OAuth2",
    "%s" : "%s",
    "Access key" : "Åtkomstnyckel",
    "Secret key" : "Hemlig nyckel",
    "OAuth2" : "OAuth2",
    "Client ID" : "Klient-ID",
    "Client secret" : "Klienthemlighet",
    "S3 Storage" : "S3-lagring",
    "Enable SSL" : "Aktivera SSL",
    "Enable Path Style" : "Aktivera sökvägsstil",
    "Legacy (v2) authentication" : "Äldre autentisering (v2)",
    "FTP" : "FTP",
    "Local" : "Lokal",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "SFTP with secret key login" : "SFTP-inloggning med hemlig nyckel",
    "SMB/CIFS" : "SMB/CIFS",
    "SMB/CIFS using OC login" : "SMB/CIFS med OC-inloggning",
    "OpenStack Object Storage" : "OpenStack-objektlagring",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "cURL-stödet i PHP är inte aktiverat eller installerat. Det går därför inte att montera %s. Be systemadministratören att installera stödet.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "FTP-stöd i PHP är inte aktiverat eller har inte installerats. Montering av %s är inte möjlig. Be din systemadministratör om installation.",
    "\"%1$s\" is not installed. Mounting of %2$s is not possible. Please ask your system administrator to install it." : "\"%1$s\" är inte installerad. Montering av %2$s är inte möjlig. Be din systemadministratör att installera den.",
    "Checking storage …" : "Kontrollerar lagring …",
    "Type to select account or group." : "Skriv för att välja konto eller grupp.",
    "(Group)" : "(Grupp)",
    "Check for changes" : "Sök efter ändringar",
    "Disconnect" : "Koppla från",
    "Unknown backend: {backendName}" : "Okänd backend: {backendName}",
    "Admin defined" : "Definierad av administratören",
    "Automatic status checking is disabled due to the large number of configured storages, click to check status" : "Automatisk statuskontroll är inaktiverad på grund av det stora antalet konfigurerade lagringsutrymmen. Klicka för att kontrollera status.",
    "Are you sure you want to disconnect this external storage?" : "Vill du koppla från det här externa lagringsutrymmet?",
    "It will make the storage unavailable in {instanceName} and will lead to a deletion of these files and folders on any sync client that is currently connected but will not delete any files and folders on the external storage itself." : "Detta gör lagringen otillgänglig i {instanceName} och leder till att filer och mappar tas bort på alla synkroniseringsklienter som för närvarande är anslutna, men det raderar inte några filer eller mappar på den externa lagringen.",
    "Delete storage?" : "Ta bort lagring?",
    "Click to recheck the configuration" : "Klicka för att kontrollera inställningarna igen",
    "Saving …" : "Sparar …",
    "Failed to save global credentials" : "Det gick inte att spara de globala autentiseringsuppgifterna",
    "Failed to save global credentials: {message}" : "Det gick inte att spara de globala autentiseringsuppgifterna: {message}",
    "No external storage configured or you don't have the permission to configure them" : "Inga externa lagringsutrymmen har konfigurerats eller så har du inte behörighet att konfigurera dem",
    "Open documentation" : "Öppna dokumentationen",
    "External storage enables you to mount external storage services and devices as secondary Nextcloud storage devices. You may also allow people to mount their own external storage services." : "Med extern lagring kan du montera externa lagringstjänster och enheter som sekundära lagringsenheter i Nextcloud. Du kan även tillåta användare att montera egna externa lagringstjänster.",
    "Configuration" : "Konfiguration",
    "Available for" : "Tillgänglig för",
    "All people" : "Alla användare",
    "Advanced settings" : "Avancerade inställningar",
    "Use presigned S3 url" : "Använd en försignerad S3-webbadress"
},
"nplurals=2; plural=(n != 1);");
