OC.L10N.register(
    "dav",
    {
    "Calendar" : "Kalender",
    "Tasks" : "Uppgifter",
    "Personal" : "Privat",
    "{actor} created calendar {calendar}" : "{actor} skapade kalendern {calendar}",
    "You created calendar {calendar}" : "Du skapade kalendern {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} tog bort kalendern {calendar}",
    "You deleted calendar {calendar}" : "Du tog bort kalendern {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} uppdaterade kalendern {calendar}",
    "You updated calendar {calendar}" : "Du uppdaterade kalendern {calendar}",
    "{actor} restored calendar {calendar}" : "{actor} återställde kalendern {calendar}",
    "You restored calendar {calendar}" : "Du återställde kalendern {calendar}",
    "You shared calendar {calendar} as public link" : "Du delade kalender {calendar} som offentlig länk",
    "You removed public link for calendar {calendar}" : "Du tog bort offentlig länk för kalender {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} delade kalender {calendar} med dig",
    "You shared calendar {calendar} with {user}" : "Du delade kalender {calendar} med {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} delade kalender {calendar} med {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} slutade dela kalender {calendar} med dig",
    "You unshared calendar {calendar} from {user}" : "Du slutade dela kalender {calendar} med {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} slutade dela kalender {calendar} med {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} slutade dela kalender {calendar} med sig själv",
    "You shared calendar {calendar} with group {group}" : "Du delade kalendern {calendar} med gruppen {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} delade kalendern {calendar} med gruppen {group}",
    "You unshared calendar {calendar} from group {group}" : "Du slutade dela kalendern {calendar} med gruppen {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} slutade dela kalendern {calendar} med gruppen {group}",
    "Untitled event" : "Namnlös händelse",
    "{actor} created event {event} in calendar {calendar}" : "{actor} skapade händelsen {event} i kalendern {calendar}",
    "You created event {event} in calendar {calendar}" : "Du skapade händelsen {event} i kalendern {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} tog bort händelsen {event} från kalendern {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Du tog bort händelsen {event} från kalendern {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} uppdaterade händelsen {event} i kalendern {calendar}",
    "You updated event {event} in calendar {calendar}" : "Du uppdaterade händelsen {event} i kalendern {calendar}",
    "{actor} moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "{actor} flyttade händelsen {event} från kalendern {sourceCalendar} till kalendern {targetCalendar}",
    "You moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "Du flyttade händelsen {event} från kalendern {sourceCalendar} till kalendern {targetCalendar}",
    "{actor} restored event {event} of calendar {calendar}" : "{actor} återställde händelsen {event} i kalendern {calendar}",
    "You restored event {event} of calendar {calendar}" : "Du återställde händelsen {event} i kalendern {calendar}",
    "Busy" : "Upptagen",
    "{actor} created to-do {todo} in list {calendar}" : "{actor} skapade uppgiften {todo} i listan {calendar}",
    "You created to-do {todo} in list {calendar}" : "Du skapade uppgiften {todo} i listan {calendar}",
    "{actor} deleted to-do {todo} from list {calendar}" : "{actor} tog bort uppgiften {todo} från listan {calendar}",
    "You deleted to-do {todo} from list {calendar}" : "Du tog bort uppgiften {todo} från listan {calendar}",
    "{actor} updated to-do {todo} in list {calendar}" : "{actor} uppdaterade uppgiften {todo} i listan {calendar}",
    "You updated to-do {todo} in list {calendar}" : "Du uppdaterade uppgiften {todo} i listan {calendar}",
    "{actor} solved to-do {todo} in list {calendar}" : "{actor} slutförde uppgiften {todo} i listan {calendar}",
    "You solved to-do {todo} in list {calendar}" : "Du slutförde uppgiften {todo} i listan {calendar}",
    "{actor} reopened to-do {todo} in list {calendar}" : "{actor} öppnade uppgiften {todo} igen i listan {calendar}",
    "You reopened to-do {todo} in list {calendar}" : "Du öppnade uppgiften {todo} igen i listan {calendar}",
    "{actor} moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "{actor} flyttade uppgift {todo} från lista {sourceCalendar} till lista {targetCalendar}",
    "You moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "Du flyttade uppgift {todo} från lista {sourceCalendar} till lista {targetCalendar}",
    "Calendar, contacts and tasks" : "Kalender, kontakter och uppgifter",
    "A <strong>calendar</strong> was modified" : "En <strong>kalender</strong> ändrades",
    "A calendar <strong>event</strong> was modified" : "En <strong>kalenderhändelse</strong> ändrades",
    "A calendar <strong>to-do</strong> was modified" : "En <strong>kalenderuppgift</strong> ändrades",
    "Contact birthdays" : "Födelsedagar",
    "Death of %s" : "Dödsdag för %s",
    "Accept" : "Acceptera",
    "Decline" : "Avböj",
    "Untitled calendar" : "Namnlös kalender",
    "Calendar:" : "Kalender:",
    "Date:" : "Datum:",
    "Where:" : "Var:",
    "Description:" : "Beskrivning:",
    "_%n year_::_%n years_" : ["%n år","%n år"],
    "_%n month_::_%n months_" : ["%n månad","%n månader"],
    "_%n day_::_%n days_" : ["%n dag","%n dagar"],
    "_%n hour_::_%n hours_" : ["%n timme","%n timmar"],
    "_%n minute_::_%n minutes_" : ["%n minut","%n minuter"],
    "%s (in %s)" : "%s (på %s)",
    "%s (%s ago)" : "%s (%s sedan)",
    "Calendar: %s" : "Kalender: %s",
    "Date: %s" : "Datum: %s",
    "Description: %s" : "Beskrivning: %s",
    "Where: %s" : "Var: %s",
    "%1$s via %2$s" : "%1$s via %2$s",
    "In the past on %1$s for the entire day" : "Tidigare den %1$s hela dagen",
    "_In %n minute on %1$s for the entire day_::_In %n minutes on %1$s for the entire day_" : ["Om %n minut den %1$s hela dagen","Om %n minuter den %1$s hela dagen"],
    "_In %n hour on %1$s for the entire day_::_In %n hours on %1$s for the entire day_" : ["Om %n timme den %1$s hela dagen","Om %n timmar den %1$s hela dagen"],
    "_In %n day on %1$s for the entire day_::_In %n days on %1$s for the entire day_" : ["Om %n dag den %1$s hela dagen","Om %n dagar den %1$s hela dagen"],
    "_In %n week on %1$s for the entire day_::_In %n weeks on %1$s for the entire day_" : ["Om %n vecka den %1$s hela dagen","Om %n veckor den %1$s hela dagen"],
    "_In %n month on %1$s for the entire day_::_In %n months on %1$s for the entire day_" : ["Om %n månad den %1$s hela dagen","Om %n månader den %1$s hela dagen"],
    "_In %n year on %1$s for the entire day_::_In %n years on %1$s for the entire day_" : ["Om %n år den %1$s hela dagen","Om %n år den %1$s hela dagen"],
    "In the past on %1$s between %2$s - %3$s" : "Tidigare den %1$s mellan %2$s - %3$s",
    "_In %n minute on %1$s between %2$s - %3$s_::_In %n minutes on %1$s between %2$s - %3$s_" : ["Om %n minut den %1$s mellan %2$s - %3$s","Om %n minuter den %1$s mellan %2$s - %3$s"],
    "_In %n hour on %1$s between %2$s - %3$s_::_In %n hours on %1$s between %2$s - %3$s_" : ["Om %n timme den %1$s mellan %2$s - %3$s","Om %n timmar den %1$s mellan %2$s - %3$s"],
    "_In %n day on %1$s between %2$s - %3$s_::_In %n days on %1$s between %2$s - %3$s_" : ["Om %n dag den %1$s mellan %2$s - %3$s","Om %n dagar den %1$s mellan %2$s - %3$s"],
    "_In %n week on %1$s between %2$s - %3$s_::_In %n weeks on %1$s between %2$s - %3$s_" : ["Om %n vecka den %1$s mellan %2$s - %3$s","Om %n veckor den %1$s mellan %2$s - %3$s"],
    "_In %n month on %1$s between %2$s - %3$s_::_In %n months on %1$s between %2$s - %3$s_" : ["Om %n månad den %1$s mellan %2$s - %3$s","Om %n månader den %1$s mellan %2$s - %3$s"],
    "_In %n year on %1$s between %2$s - %3$s_::_In %n years on %1$s between %2$s - %3$s_" : ["Om %n år den %1$s mellan %2$s - %3$s","Om %n år den %1$s mellan %2$s - %3$s"],
    "Could not generate when statement" : "Det gick inte att generera tidsbeskrivningen",
    "Every Day for the entire day" : "Varje dag hela dagen",
    "Every Day for the entire day until %1$s" : "Varje dag hela dagen tills den %1$s",
    "Every Day between %1$s - %2$s" : "Varje dag mellan %1$s - %2$s",
    "Every Day between %1$s - %2$s until %3$s" : "Varje dag mellan %1$s - %2$s tills den %3$s",
    "Every %1$d Days for the entire day" : "Varje %1$d dagar, hela dagen",
    "Every %1$d Days for the entire day until %2$s" : "Varje %1$d dagar hela dagen tills den %2$s",
    "Every %1$d Days between %2$s - %3$s" : "Varje %1$d dagar mellan %2$s - %3$s",
    "Every %1$d Days between %2$s - %3$s until %4$s" : "Varje %1$d dagar mellan %2$s - %3$s tills den %4$s",
    "Could not generate event recurrence statement" : "Det gick inte att generera beskrivningen av händelsens upprepning",
    "Every Week on %1$s for the entire day" : "Varje vecka på %1$s, hela dagen",
    "Every Week on %1$s for the entire day until %2$s" : "Varje vecka på %1$s hela dagen tills den %2$s",
    "Every Week on %1$s between %2$s - %3$s" : "Varje vecka på %1$s mellan %2$s - %3$s",
    "Every Week on %1$s between %2$s - %3$s until %4$s" : "Varje vecka på %1$s mellan %2$s - %3$s till den %4$s",
    "Every %1$d Weeks on %2$s for the entire day" : "Varje %1$d vecka på %2$s hela dagen",
    "Every %1$d Weeks on %2$s for the entire day until %3$s" : "Varje %1$d vecka på %2$s för hela dagen till %3$s",
    "Every %1$d Weeks on %2$s between %3$s - %4$s" : "Varje %1$d vecka på %2$s mellan %3$s - %4$s",
    "Every %1$d Weeks on %2$s between %3$s - %4$s until %5$s" : "Varje %1$d vecka på %2$s mellan %3$s - %4$s till %5$s",
    "Every Month on the %1$s for the entire day" : "Varje månad på den %1$s hela dagen",
    "Every Month on the %1$s for the entire day until %2$s" : "Varje månad på den %1$s hela dagen till %2$s",
    "Every Month on the %1$s between %2$s - %3$s" : "Varje månad på den %1$s mellan %2$s - %3$s",
    "Every Month on the %1$s between %2$s - %3$s until %4$s" : "Varje månad på den %1$s mellan %2$s - %3$s till %4$s",
    "Every %1$d Months on the %2$s for the entire day" : "Varje %1$d månad på den %2$s hela dagen",
    "Every %1$d Months on the %2$s for the entire day until %3$s" : "Varje %1$d månad på den %2$s hela dagen till %3$s",
    "Every %1$d Months on the %2$s between %3$s - %4$s" : "Varje %1$d månad på den %2$s mellan %3$s - %4$s",
    "Every %1$d Months on the %2$s between %3$s - %4$s until %5$s" : "Varje %1$d månad på den %2$s mellan %3$s - %4$s till %5$s",
    "Every Year in %1$s on the %2$s for the entire day" : "Varje år %1$s på den %2$s hela dagen",
    "Every Year in %1$s on the %2$s for the entire day until %3$s" : "Varje år i %1$s på den %2$s hela dagen till %3$s",
    "Every Year in %1$s on the %2$s between %3$s - %4$s" : "Varje år i %1$s på den %2$s mellan %3$s - %4$s",
    "Every Year in %1$s on the %2$s between %3$s - %4$s until %5$s" : "Varje år i %1$s på den %2$s mellan %3$s - %4$s till %5$s",
    "Every %1$d Years in %2$s on the %3$s for the entire day" : "Vart %1$d år i %2$s på den %3$s hela dagen",
    "Every %1$d Years in %2$s on the %3$s for the entire day until %4$s" : "Vart %1$d år i %2$s på den %3$s hela dagen till %4$s",
    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s" : "Vart %1$d år i %2$s på den %3$s mellan %4$s - %5$s",
    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s until %6$s" : "Vart %1$d år i %2$s på den %3$s mellan %4$s - %5$s till %6$s",
    "On specific dates for the entire day until %1$s" : "På särskilda datum hela dagen till och med %1$s",
    "On specific dates between %1$s - %2$s until %3$s" : "På specifika datum mellan %1$s - %2$s tills %3$s",
    "In the past on %1$s" : "Tidigare den %1$s",
    "_In %n minute on %1$s_::_In %n minutes on %1$s_" : ["Om %n minut den %1$s","Om %n minuter den %1$s"],
    "_In %n hour on %1$s_::_In %n hours on %1$s_" : ["Om %n timme den %1$s","Om %n timmar den %1$s"],
    "_In %n day on %1$s_::_In %n days on %1$s_" : ["Om %n dag den %1$s","Om %n dagar den %1$s"],
    "_In %n week on %1$s_::_In %n weeks on %1$s_" : ["Om %n vecka den %1$s","Om %n veckor den %1$s"],
    "_In %n month on %1$s_::_In %n months on %1$s_" : ["Om %n månad den %1$s","Om %n månader den %1$s"],
    "_In %n year on %1$s_::_In %n years on %1$s_" : ["Om %n år den %1$s","Om %n år den %1$s"],
    "In the past on %1$s then on %2$s" : "Tidigare den %1$s och sedan den %2$s",
    "_In %n minute on %1$s then on %2$s_::_In %n minutes on %1$s then on %2$s_" : ["Om %n minut den %1$s och sedan den %2$s","Om %n minuter den %1$s och sedan den %2$s"],
    "_In %n hour on %1$s then on %2$s_::_In %n hours on %1$s then on %2$s_" : ["Om %n timme den %1$s och sedan den %2$s","Om %n timmar den %1$s och sedan den %2$s"],
    "_In %n day on %1$s then on %2$s_::_In %n days on %1$s then on %2$s_" : ["Om %n dag den %1$s och sedan den %2$s","Om %n dagar den %1$s och sedan den %2$s"],
    "_In %n week on %1$s then on %2$s_::_In %n weeks on %1$s then on %2$s_" : ["Om %n vecka den %1$s och sedan den %2$s","Om %n veckor den %1$s och sedan den %2$s"],
    "_In %n month on %1$s then on %2$s_::_In %n months on %1$s then on %2$s_" : ["Om %n månad den %1$s och sedan den %2$s","Om %n månader den %1$s och sedan den %2$s"],
    "_In %n year on %1$s then on %2$s_::_In %n years on %1$s then on %2$s_" : ["Om %n år den %1$s och sedan den %2$s","Om %n år den %1$s och sedan den %2$s"],
    "In the past on %1$s then on %2$s and %3$s" : "Tidigare den %1$s sedan den %2$s och %3$s",
    "_In %n minute on %1$s then on %2$s and %3$s_::_In %n minutes on %1$s then on %2$s and %3$s_" : ["Om %n minut den %1$s sedan den %2$s och %3$s","Om %n minuter den %1$s sedan den %2$s och %3$s"],
    "_In %n hour on %1$s then on %2$s and %3$s_::_In %n hours on %1$s then on %2$s and %3$s_" : ["Om %n timme den %1$s sedan den %2$s och %3$s","Om %n timmar den %1$s sedan den %2$s och %3$s"],
    "_In %n day on %1$s then on %2$s and %3$s_::_In %n days on %1$s then on %2$s and %3$s_" : ["Om %n dagar den %1$s sedan den %2$s och %3$s","Om %n dagar den %1$s sedan den %2$s och %3$s"],
    "_In %n week on %1$s then on %2$s and %3$s_::_In %n weeks on %1$s then on %2$s and %3$s_" : ["Om %n vecka den %1$s sedan den %2$s och %3$s","Om %n veckor den %1$s sedan den %2$s och %3$s"],
    "_In %n month on %1$s then on %2$s and %3$s_::_In %n months on %1$s then on %2$s and %3$s_" : ["Om %n månad den %1$s, sedan den %2$s och %3$s","Om %n månader den %1$s, sedan den %2$s och %3$s"],
    "_In %n year on %1$s then on %2$s and %3$s_::_In %n years on %1$s then on %2$s and %3$s_" : ["Om %n år den %1$s sedan den %2$s och %3$s","Om %n år den %1$s sedan den %2$s och %3$s"],
    "Could not generate next recurrence statement" : "Det gick inte att generera beskrivningen av nästa upprepning",
    "Cancelled: %1$s" : "Inställt: %1$s",
    "\"%1$s\" has been canceled" : "\"%1$s\" har ställts in",
    "Re: %1$s" : "Sv: %1$s",
    "%1$s has accepted your invitation" : "%1$s har accepterat din inbjudan",
    "%1$s has tentatively accepted your invitation" : "%1$s har preliminärt accepterat din inbjudan",
    "%1$s has declined your invitation" : "%1$s har tackat nej till din inbjudan",
    "%1$s has responded to your invitation" : "%1$s har svarat på din inbjudan",
    "Invitation updated: %1$s" : "Inbjudan uppdaterad: %1$s",
    "%1$s updated the event \"%2$s\"" : "%1$s uppdaterade händelsen \"%2$s\"",
    "Invitation: %1$s" : "Inbjudan: %1$s",
    "%1$s would like to invite you to \"%2$s\"" : "%1$s har bjudit in dig till \"%2$s\"",
    "Organizer:" : "Arrangör:",
    "Attendees:" : "Deltagare:",
    "Title:" : "Titel:",
    "When:" : "När:",
    "Location:" : "Plats:",
    "Link:" : "Länk:",
    "Occurring:" : "Förekommer:",
    "More options …" : "Fler alternativ …",
    "More options at %s" : "Fler alternativ på %s",
    "Monday" : "Måndag",
    "Tuesday" : "Tisdag",
    "Wednesday" : "Onsdag",
    "Thursday" : "Torsdag",
    "Friday" : "Fredag",
    "Saturday" : "Lördag",
    "Sunday" : "Söndag",
    "January" : "Januari",
    "February" : "Februari",
    "March" : "Mars",
    "April" : "April",
    "May" : "Maj",
    "June" : "Juni",
    "July" : "Juli",
    "August" : "Augusti",
    "September" : "September",
    "October" : "Oktober",
    "November" : "November",
    "December" : "December",
    "First" : "Första",
    "Second" : "Andra",
    "Third" : "Tredje",
    "Fourth" : "Fjärde",
    "Fifth" : "Femte",
    "Last" : "Sista",
    "Second Last" : "Näst sist",
    "Third Last" : "Tredje sist",
    "Fourth Last" : "Fjärde sist",
    "Fifth Last" : "Femte sista",
    "Contacts" : "Kontakter",
    "{actor} created address book {addressbook}" : "{actor} skapade adressboken {addressbook}",
    "You created address book {addressbook}" : "Du skapade adressboken {addressbook}",
    "{actor} deleted address book {addressbook}" : "{actor} tog bort adressboken {addressbook}",
    "You deleted address book {addressbook}" : "Du tog bort adressboken {addressbook}",
    "{actor} updated address book {addressbook}" : "{actor} uppdaterade adressboken {addressbook}",
    "You updated address book {addressbook}" : "Du uppdaterade adressboken {addressbook}",
    "{actor} shared address book {addressbook} with you" : "{actor} delade adressboken {addressbook} med dig",
    "You shared address book {addressbook} with {user}" : "Du delade adressboken {addressbook} med {user}",
    "{actor} shared address book {addressbook} with {user}" : "{actor} delade adressboken {addressbook} med {user}",
    "{actor} unshared address book {addressbook} from you" : "{actor} slutade dela adressboken {addressbook} med dig",
    "You unshared address book {addressbook} from {user}" : "Du slutade dela adressboken {addressbook} med {user}",
    "{actor} unshared address book {addressbook} from {user}" : "{actor} slutade dela adressboken {addressbook} med {user}",
    "{actor} unshared address book {addressbook} from themselves" : "{actor} slutade dela adressboken {addressbook} med sig själv",
    "You shared address book {addressbook} with group {group}" : "Du delade adressboken {addressbook} med gruppen {group}",
    "{actor} shared address book {addressbook} with group {group}" : "{actor} delade adressboken {addressbook} med gruppen {group}",
    "You unshared address book {addressbook} from group {group}" : "Du slutade dela adressboken {addressbook} med gruppen {group}",
    "{actor} unshared address book {addressbook} from group {group}" : "{actor} slutade dela adressboken {addressbook} med gruppen {group}",
    "{actor} created contact {card} in address book {addressbook}" : "{actor} skapade kontakten {card} i adressboken {addressbook}",
    "You created contact {card} in address book {addressbook}" : "Du skapade kontakten {card} i adressboken {addressbook}",
    "{actor} deleted contact {card} from address book {addressbook}" : "{actor} tog bort kontakten {card} från adressboken {addressbook}",
    "You deleted contact {card} from address book {addressbook}" : "Du tog bort kontakten {card} från adressboken {addressbook}",
    "{actor} updated contact {card} in address book {addressbook}" : "{actor} uppdaterade kontakten {card} i adressboken {addressbook}",
    "You updated contact {card} in address book {addressbook}" : "Du uppdaterade kontakten {card} i adressboken {addressbook}",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "En <strong>kontakt</strong> eller <strong>adressbok</strong> ändrades",
    "System address book disabled" : "Systemadressbok inaktiverad",
    "The system contacts address book has been automatically disabled during upgrade. This means that the address book will no longer be available to users in the contacts app or other clients. The system contacts address book was disabled because the amount of contacts in the address book exceeded the maximum recommended number of contacts. This limit is set to prevent performance issues. You can re-enable the system address book with the following command {command}" : "Systemadressboken har inaktiverats automatiskt under uppgraderingen. Det innebär att adressboken inte längre är tillgänglig i appen Kontakter eller andra klienter. Adressboken inaktiverades eftersom antalet kontakter översteg det rekommenderade maxantalet. Gränsen motverkar prestandaproblem. Du kan aktivera systemadressboken igen med kommandot {command}",
    "Accounts" : "Konton",
    "System address book which holds all accounts" : "Systemadressbok som innehåller alla konton",
    "File is not updatable: %1$s" : "Filen kan inte uppdateras: %1$s",
    "Failed to get storage for file" : "Det gick inte att hämta lagring för filen",
    "Could not write to final file, canceled by hook" : "Det gick inte att skriva till slutfilen; åtgärden avbröts av en hook",
    "Could not write file contents" : "Det gick inte att skriva filinnehållet",
    "_%n byte_::_%n bytes_" : ["%n byte","%n byte"],
    "Error while copying file to target location (copied: %1$s, expected filesize: %2$s)" : "Fel vid kopiering till målplatsen (kopierat: %1$s, förväntad filstorlek: %2$s)",
    "Expected filesize of %1$s but read (from Nextcloud client) and wrote (to Nextcloud storage) %2$s. Could either be a network problem on the sending side or a problem writing to the storage on the server side." : "Den förväntade filstorleken var %1$s, men %2$s lästes från Nextcloud-klienten och skrevs till Nextcloud-lagringen. Det kan bero på ett nätverksproblem på avsändarsidan eller ett skrivfel i serverlagringen.",
    "Could not rename part file to final file, canceled by hook" : "Det gick inte att byta namn på delfilen till slutfilen; åtgärden avbröts av en hook",
    "Could not rename part file to final file" : "Det gick inte att byta namn på delfilen till slutfilen",
    "Failed to check file size: %1$s" : "Det gick inte att kontrollera filstorleken: %1$s",
    "Could not open file: %1$s (%2$d), file does seem to exist" : "Det gick inte att öppna filen: %1$s (%2$d), filen verkar finnas",
    "Could not open file: %1$s (%2$d), file doesn't seem to exist" : "Det gick inte att öppna filen: %1$s (%2$d), filen verkar inte finnas",
    "Failed to get size for : %1$s" : "Det gick inte att hämta storleken för: %1$s",
    "Encryption not ready: %1$s" : "Krypteringen är inte klar: %1$s",
    "Failed to open file: %1$s" : "Det gick inte att öppna filen: %1$s",
    "Failed to unlink: %1$s" : "Det gick inte att ta bort länken: %1$s",
    "Failed to write file contents: %1$s" : "Det gick inte att skriva filinnehållet: %1$s",
    "File not found: %1$s" : "Filen hittades inte: %1$s",
    "Insufficient space" : "Otillräckligt utrymme",
    "Invalid target path" : "Ogiltig målsökväg",
    "System is in maintenance mode." : "Systemet är i underhållsläge.",
    "Upgrade needed" : "Uppgradering krävs",
    "Delegate:" : "Ombud:",
    "%1$s created \"%2$s\" on your behalf" : "%1$s skapade \"%2$s\" för din räkning",
    "%1$s created \"%2$s\" on your calendar \"%3$s\"" : "%1$s skapade \"%2$s\" i din kalender \"%3$s\"",
    "%1$s updated \"%2$s\" on your behalf" : "%1$s uppdaterade \"%2$s\" för din räkning",
    "%1$s updated \"%2$s\" on your calendar \"%3$s\"" : "%1$s uppdaterade \"%2$s\" i din kalender \"%3$s\"",
    "%1$s deleted \"%2$s\" on your behalf" : "%1$s tog bort \"%2$s\" för din räkning",
    "%1$s permanently deleted \"%2$s\" from your calendar \"%3$s\"" : "%1$s tog permanent bort \"%2$s\" från din kalender \"%3$s\"",
    "%1$s moved \"%2$s\" to the trash on your behalf" : "%1$s flyttade \"%2$s\" till papperskorgen för din räkning",
    "%1$s moved \"%2$s\" to the trash on your calendar \"%3$s\"" : "%1$s flyttade \"%2$s\" till papperskorgen i din kalender \"%3$s\"",
    "%1$s restored \"%2$s\" on your behalf" : "%1$s återställde \"%2$s\" för din räkning",
    "%1$s restored \"%2$s\" on your calendar \"%3$s\"" : "%1$s återställde \"%2$s\" i din kalender \"%3$s\"",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Din %s måste konfigureras att använda HTTPS för CalDAV och CardDAV med iOS/macOS.",
    "Configures a CalDAV account" : "Konfigurerar ett CalDAV-konto",
    "Configures a CardDAV account" : "Konfigurerar ett CardDAV-konto",
    "Events" : "Händelser",
    "Untitled task" : "Namnlös uppgift",
    "Completed on %s" : "Slutförd den %s",
    "Due on %s by %s" : "Förfaller den %s kl. %s",
    "Due on %s" : "Förfaller den %s",
    "This is an example contact" : "Detta är en exempelkontakt",
    "Welcome to Nextcloud Calendar!\n\nThis is a sample event - explore the flexibility of planning with Nextcloud Calendar by making any edits you want!\n\nWith Nextcloud Calendar, you can:\n- Create, edit, and manage events effortlessly.\n- Create multiple calendars and share them with teammates, friends, or family.\n- Check availability and display your busy times to others.\n- Seamlessly integrate with apps and devices via CalDAV.\n- Customize your experience: schedule recurring events, adjust notifications and other settings." : "Välkommen till Nextcloud Kalender!\n\nDetta är en exempelhändelse. Utforska den flexibla planeringen i Nextcloud Kalender genom att ändra vad du vill.\n\nMed Nextcloud Kalender kan du:\n- Enkelt skapa, redigera och hantera händelser.\n- Skapa flera kalendrar och dela dem med teammedlemmar, vänner eller familj.\n- Kontrollera tillgänglighet och visa andra när du är upptagen.\n- Integrera smidigt med appar och enheter via CalDAV.\n- Anpassa upplevelsen med återkommande händelser, aviseringar och andra inställningar.",
    "Example event - open me!" : "Exempelhändelse – öppna mig!",
    "System Address Book" : "Systemadressbok",
    "The system address book contains contact information for all users in your instance." : "Systemadressboken innehåller kontaktinformation för alla användare i din instans.",
    "Enable System Address Book" : "Aktivera systemadressboken",
    "DAV system address book" : "DAV-systemets adressbok",
    "No outstanding DAV system address book sync." : "Ingen utestående synkronisering för DAV-systemets adressbok.",
    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "DAV-systemets adressbokssynkronisering har inte körts ännu eftersom din instans har fler än 1000 användare eller för att ett fel uppstod. Kör det manuellt genom att anropa \"occ dav:sync-system-addressbook\".",
    "DAV system address book size" : "Storlek på DAV-systemadressbok",
    "The system address book is disabled" : "Systemadressboken är inaktiverad",
    "The system address book is enabled, but contains more than the configured limit of %d contacts" : "Systemadressboken är aktiverad, men innehåller fler än det konfigurerade gränsvärdet på %d kontakter",
    "The system address book is enabled and contains less than the configured limit of %d contacts" : "Systemadressboken är aktiverad, men innehåller färre än det konfigurerade gränsvärdet på %d kontakter",
    "WebDAV endpoint" : "WebDAV-slutpunkt",
    "Could not check that your web server is properly set up to allow file synchronization over WebDAV. Please check manually." : "Det gick inte att kontrollera att din webbserver är korrekt inställd för att tillåta filsynkronisering över WebDAV. Kontrollera manuellt.",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Din webbserver är ännu inte korrekt inställd för att tillåta filsynkronisering, eftersom WebDAV-gränssnittet verkar vara trasigt.",
    "Your web server is properly set up to allow file synchronization over WebDAV." : "Din webbserver är korrekt inställd för att tillåta filsynkronisering över WebDAV.",
    "Calendars including events, details and attendees" : "Kalendrar inklusive händelser, detaljer och deltagare",
    "Migrated calendar (%1$s)" : "Migrerade kalender (%1$s)",
    "Contacts and groups" : "Kontakter och grupper",
    "WebDAV" : "WebDAV",
    "Absence saved" : "Frånvaro sparad",
    "Failed to save your absence settings" : "Det gick inte att spara dina frånvaroinställningar",
    "Absence cleared" : "Frånvaro rensad",
    "Failed to clear your absence settings" : "Det gick inte att rensa dina frånvaroinställningar",
    "First day" : "Första dagen",
    "Last day (inclusive)" : "Sista dagen (inklusive)",
    "Out of office replacement (optional)" : "Ersättare under frånvaron (valfritt)",
    "Name of the replacement" : "Namn på ersättaren",
    "Short absence status" : "Kort frånvarostatus",
    "Long absence Message" : "Långt frånvaromeddelande",
    "Save" : "Spara",
    "Disable absence" : "Inaktivera frånvaro",
    "Failed to load availability" : "Det gick inte att läsa in tillgängligheten",
    "Saved availability" : "Tillgängligheten har sparats",
    "Failed to save availability" : "Det gick inte att spara tillgängligheten",
    "to" : "till",
    "Delete slot" : "Ta bort tidsintervall",
    "No working hours set" : "Inga arbetstider har angetts",
    "Add slot" : "Lägg till tidsintervall",
    "Weekdays" : "Vardagar",
    "Pick a start time for {dayName}" : "Välj en starttid för {dayName}",
    "Pick a end time for {dayName}" : "Välj en sluttid för {dayName}",
    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Ställ automatiskt in användarstatusen på \"Stör ej\" utanför tillgängliga tider för att stänga av alla aviseringar.",
    "Cancel" : "Avbryt",
    "Import" : "Importera",
    "Error while saving settings" : "Fel vid sparande av inställningar",
    "Contact reset successfully" : "Kontakten har återställts",
    "Error while resetting contact" : "Fel vid återställning av kontakt",
    "Contact imported successfully" : "Kontakten har importerats",
    "Error while importing contact" : "Fel vid import av kontakt",
    "Import contact" : "Importera kontakt",
    "Reset to default" : "Återställ till grundinställningar",
    "Import contacts" : "Importera kontakter",
    "Importing a new .vcf file will delete the existing default contact and replace it with the new one. Do you want to continue?" : "Om du importerar en ny .vcf-fil tas den befintliga standardkontakten bort och ersätts med den nya. Vill du fortsätta?",
    "Failed to save example event creation setting" : "Det gick inte att spara inställningen för att skapa en exempelhändelse",
    "Failed to upload the example event" : "Det gick inte att ladda upp exempelhändelsen",
    "Custom example event was saved successfully" : "Anpassad exempelhändelse sparades",
    "Failed to delete the custom example event" : "Det gick inte att ta bort den anpassade exempelhändelsen",
    "Custom example event was deleted successfully" : "Den anpassade exempelhändelsen har tagits bort",
    "Import calendar event" : "Importera kalenderhändelse",
    "Uploading a new event will overwrite the existing one." : "Om du laddar upp en ny händelse kommer den att skriva över den befintliga.",
    "Upload event" : "Ladda upp händelse",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Installera även {calendarappstoreopen}appen Kalender{linkclose} eller {calendardocopen}anslut datorn och mobilen för synkronisering ↗{linkclose}.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Kontrollera att {emailopen}e-postservern{linkclose} är korrekt konfigurerad.",
    "Calendar server" : "Kalenderserver",
    "Send invitations to attendees" : "Skicka inbjudan till deltagare",
    "Automatically generate a birthday calendar" : "Generera en födelsedagskalender automatiskt",
    "Birthday calendars will be generated by a background job." : "Födelsedagskalendrar skapas av ett bakgrundsjobb.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "De är därför inte tillgängliga direkt efter aktiveringen, men visas efter en stund.",
    "Send notifications for events" : "Skicka aviseringar om händelser",
    "Notifications are sent via background jobs, so these must occur often enough." : "Aviseringar skickas via bakgrundsjobb, som därför måste köras tillräckligt ofta.",
    "Send reminder notifications to calendar sharees as well" : "Skicka även påminnelser till kalenderdeltagare",
    "Reminders are always sent to organizers and attendees." : "Påminnelser skickas alltid till arrangörer och deltagare.",
    "Enable notifications for events via push" : "Aktivera pushaviseringar om händelser",
    "Example content" : "Exempelinnehåll",
    "Example content serves to showcase the features of Nextcloud. Default content is shipped with Nextcloud, and can be replaced by custom content." : "Exempelinnehåll används för att visa upp funktionerna i Nextcloud. Standardinnehåll levereras med Nextcloud och kan ersättas med anpassat innehåll.",
    "Availability" : "Tillgänglighet",
    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Om du konfigurerar dina arbetstider kommer andra att se när du är frånvarande när de bokar ett möte.",
    "Absence" : "Frånvaro",
    "Configure your next absence period." : "Konfigurera din nästa frånvaroperiod.",
    "There was an error updating your attendance status." : "Ett fel uppstod vid uppdatering av din närvarostatus.",
    "Please contact the organizer directly." : "Kontakta arrangören direkt.",
    "Are you accepting the invitation?" : "Accepterar du inbjudan?",
    "Tentative" : "Preliminärt",
    "Your attendance was updated successfully." : "Din närvarostatus har uppdaterats.",
    "No results." : "Inga resultat.",
    "Start typing." : "Börja skriva."
},
"nplurals=2; plural=(n != 1);");
