OC.L10N.register(
    "circles",
    {
    "You created the team {circle}" : "Вы создали команду {circle}",
    "{author} created the team {circle}" : "{author} создал(а) команду {circle}",
    "You deleted {circle}" : "Вы удалили круг «{circle}»",
    "{author} deleted {circle}" : "{author} удалил(а) круг «{circle}»",
    "You made {member} join {circle}" : "Вы присоединили {member} к {circle}",
    "{author} made {member} join {circle}" : "{author} присоединил {member} к {circle}",
    "You added team {member} as member to {circle}" : "Вы добавили команду {member} как участника в {circle}",
    "{author} added team {member} as member to {circle}" : "{author} добавил(а) команду {member} как участника в {circle}",
    "You made {member} leave {circle}" : "Вы исключили {member} из {circle}",
    "{author} made {member} leave {circle}" : "{author} исключил {member} из {circle}",
    "You removed {member} from {circle}" : "Вы удалили пользователя {member} из круга «{circle}»",
    "{author} removed {member} from {circle}" : "{author} удалил {member} из {circle}",
    "You joined {circle}" : "Вы присоединились к «{circle}»",
    "{member} joined {circle}" : "{member} присоединился(ась) к «{circle}»",
    "You accepted the invitation to join {circle}" : "Вы приняли приглашение на присоединение к «{circle}»",
    "{member} accepted the invitation to join {circle}" : "{member} принял(а) приглашение присоединиться к кругу «{circle}»",
    "You added {member} as member to {circle}" : "Вы добавили пользователя {member} в круг «{circle}»",
    "You have been added as member to {circle} by {author}" : "Вы были добавлены в круг «{circle}» пользователем {author}",
    "{member} has been added as member to {circle} by {author}" : "{author} добавил(а) {member} участником в круг «{circle}»",
    "You added {external} to {circle}" : "Вы добавили {external} в круг «{circle}»",
    "{external} has been added to {circle} by {author}" : "{author} добавил(а) {external} в круг «{circle}»",
    "You accepted {member}'s request to join {circle}" : "Вы одобрили запрос пользователя {member} на присоединение к кругу «{circle}»",
    "Your request to join {circle} has been accepted by {author}" : "{author} одобрил(а) ваш запрос на присоединение к кругу «{circle}»",
    "{member}'s request to join {circle} has been accepted by {author}" : "Запрос пользователя {member} на присоединение к кругу «{circle}» был одобрен пользователем {author}",
    "You left {circle}" : "Вы покинули «{circle}»",
    "{member} left {circle}" : "{member} покинул(а) круг «{circle}»",
    "You declined the invitation to join {circle}" : "Вы отклонили приглашение в круг «{circle}»",
    "{member} declined an invitation to join {circle}" : "{member} отклонил(а) приглашение в круг «{circle}»",
    "You cancelled your request to join {circle}" : "Вы отменили свой запрос на присоединение к кругу «{circle}»",
    "{member} cancelled a request to join {circle}" : "{member} отменил запрос на вступление в {circle}",
    "You have been removed from {circle} by {author}" : "{author} удалил вас из круга «{circle}»",
    "{member} has been removed from {circle} by {author}" : "{author} удалил(а) участника {member} из круга «{circle}»",
    "You removed {external} from {circle}" : "Вы удалили {external} из круга «{circle}»",
    "{external} has been removed from {circle} by {author}" : "{author} удалил(а) {external} из круга «{circle}»",
    "You cancelled {member}'s invitation to join {circle}" : "Вы отменили приглашение пользователя {member} в круг «{circle}»",
    "Your invitation to join {circle} has been cancelled by {author}" : "{author} отменил(а) ваше приглашение присоединиться к кругу «{circle}»",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} отменил(а) приглашение пользователя {member} присоединиться к кругу «{circle}»",
    "You dismissed {member}'s request to join {circle}" : "Вы отклонили запрос пользователя {member} на присоединение к кругу «{circle}»",
    "Your request to join {circle} has been dismissed by {author}" : "{author} отклонил(а) ваш запрос на присоединение к кругу «{circle}»",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{author} отклонил(а) запрос пользователя {member} на присоединение к кругу «{circle}»",
    "You invited {member} to join {circle}" : "Вы пригласили пользователя {member} присоединиться к кругу «{circle}»",
    "You have been invited to join {circle} by {author}" : "{author} пригласил(а) вас присоединиться к кругу «{circle}»",
    "{member} has been invited to join {circle} by {author}" : "{author} пригласил(а) пользователя {member} присоединиться к кругу «{circle}»",
    "You changed {member}'s level in {circle} to %1$s" : "Вы изменили уровень участника {member} в круге «{circle}» на %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} изменил(а) ваш уровень в круге «{circle}» на %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} изменил(а) уровень участника {member} в круге «{circle}» на %1$s",
    "You sent a request to join {circle}" : "Вы отправили запрос на присоединение к «{circle}»",
    "{member} sent a request to join {circle}" : "{member} отправил(а) запрос на вступление в «{circle}»",
    "You are the new owner of {circle}" : "Вы стали владельцем «{circle}»",
    "{member} is the new owner of {circle}" : "{member} — новый владелец «{circle}»",
    "Teams" : "Команды",
    "On events happening in a <strong>team</strong> of which you are a member" : "О событиях, происходящих в <strong>команде</strong>, участником которой вы являетесь",
    "Any important event in a <strong>team</strong> you are moderating" : "Любое важное событие в <strong>команде</strong>, которую вы модерируете",
    "On global events happening in any <strong>team</strong>" : "О глобальных событиях, происходящих в любой <strong>команде</strong>",
    "Single" : "Единственный",
    "Personal" : "Личный",
    "System" : "Системный",
    "Visible" : "Видимый",
    "Open" : "Открытый",
    "Invite" : "Приглашение",
    "Join request" : "Запрос на вступление",
    "Friends" : "Друзья",
    "Password protected" : "Защищено паролем",
    "No Owner" : "Нет владельца",
    "Hidden" : "Скрыто",
    "Backend" : "Внутренний",
    "Local" : "Локальный",
    "Root" : "Корневой",
    "Team invite" : "Приглашение команды",
    "Federated" : "Федеративный",
    "Mount point" : "Точка сборки",
    "App" : "Приложение",
    "Nextcloud Account" : "Учётная запись Nextcloud",
    "Nextcloud Group" : "Группа Nextcloud",
    "Email address" : "Адрес электронной почты",
    "Contact" : "Контакт",
    "Team" : "Команда",
    "Nextcloud App" : "Приложение Nextcloud",
    "Teams App" : "Приложение \"Команды\"",
    "Admin Command Line" : "Командная строка администратора",
    "Member" : "Участник",
    "Moderator" : "Модератор",
    "Admin" : "Администратор",
    "Owner" : "Владелец",
    "%s shared »%s« with you." : "%s предоставил(а) вам доступ к «%s».",
    "%s shared »%s« with \"%s\"." : "%s предоставил(а) доступ к «%s» пользователю \"%s\".",
    "%s on %s" : "%s на %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : " %1$s поделился »%2$s« с вами.\nВы уже должны были получить отдельное письмо со ссылкой на доступ к нему.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s поделился »%2$s« с вами. Вы уже должны были получить отдельное письмо со ссылкой для доступа к нему.",
    "Password to access »%1$s« shared to you by %2$s" : "Пароль для доступа к «%1$s», общий доступ к которому предоставлен вам пользователем %2$s",
    "Password to access »%s«" : "Пароль для доступа к «%s»",
    "It is protected with the following password:" : "Доступ защищён следующим паролем: ",
    "%1$s via %2$s" : "%1$s через %2$s",
    "Click the button below to open it." : "Нажмите кнопку ниже, чтобы открыть его.",
    "Open »%s«" : "Открыть «%s»",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s поделился с вами несколькими файлами.\nВы уже должны были получить отдельное письмо со ссылкой для доступа к ним.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s поделился с вами несколькими файлами. Вы уже должны были получить отдельное письмо со ссылкой для доступа к ним.",
    "Password to access files shared to you by %1$s" : "Пароль для доступа к файлам, общий доступ к которому предоставлен вам пользователем %1$s",
    "Password to access files" : "Пароль для доступа к файлам",
    "%s shared multiple files with \"%s\"." : "%s поделился несколькими файлами с \"%s\".",
    "%s shared multiple files with you." : "%s предоставил(а) вам доступ к нескольким файлам.",
    "Boot up" : "Загрузка",
    "Nextcloud Initialization" : "Инициализация Nextcloud",
    "Teams App Initialization" : "Инициализация приложения \"Команды\"",
    "Fresh installation status" : "Статус новой установки",
    "Building Local Database" : "Создание локальной базы данных",
    "Testing Basic Team Creation" : "Проверка базового создания команды",
    "Adding local users and moderators" : "Добавление локальных пользователей и модераторов",
    "Show all teams" : "Показать все команды",
    "Create a new team" : "Создать новую команду",
    "Files" : "Файлы",
    "This feature is not available for personal teams" : "Эта функция недоступна для личных команд",
    "The team is not federated" : "Команда не является федеративной",
    "You cannot join this team" : "Вы не можете вступить в эту команду",
    "This member is not a moderator" : "Это участник — не модератор",
    "Insufficient privileges" : "Недостаточно прав доступа",
    "This member does not exist" : "Этот участник не существует",
    "This member is the owner of the team" : "Этот участник является владельцем команды",
    "Level cannot be changed for this type of member" : "Невозможно изменить уровень участника такого типа",
    "You are already a member of this team" : "Вы уже являетесь участником этой команды",
    "You have been blocked from this team" : "Вы были заблокированы в этой команде",
    "The account is already a member of this team" : "Учётная запись уже является участником этой команды",
    "The account has already been invited into this team" : "Эта учётная запись уже приглашена в эту команду",
    "%s (Team owned by %s)" : "%s (команда, владелец: %s)",
    "You are now a member of the Team \"%2$s\"" : "Теперь вы участник команды \"%2$s\"",
    "You have been invited by %1$s into the Team \"%2$s\"" : "%1$s пригласил(а) вас в команду \"%2$s\"",
    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$s отправил(а) запрос на участие в команде \"%2$s\"",
    "Accept" : "Принять",
    "Refuse" : "Отказаться",
    "Leave the team" : "Покинуть команду",
    "No image file provided" : "Файл изображения не указан",
    "Invalid file provided" : "Указан недопустимый файл",
    "File is too big" : "Файл слишком большой",
    "Invalid image" : "Недопустимое изображение",
    "Unknown filetype" : "Неизвестный тип файла",
    "%s" : "%s",
    "Personal team" : "Личная команда",
    "%s owned by %s" : "%s, владелец: %s",
    "You have no permission to create a new team" : "У вас нет прав для создания новой команды",
    "Insufficient permissions to perform this action" : "Недостаточно разрешений для выполнения этого действия",
    "%s shared a file with \"%s\"." : "%s поделился файлом с \"%s\".",
    "%s shared a file with you." : "%s поделился с вами файлом.",
    "%1$s shared %2$s with %3$s" : "%1$s поделился(ась) %2$s с %3$s",
    "%1$s shared %2$s with \"%3$s\"" : "%1$s поделился(ась) %2$s с \"%3$s\"",
    "Open %s" : "Открыть %s",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s поделился с вами некоторыми материалами.\nВы уже должны были получить отдельное письмо со ссылкой для доступа к нему.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s поделился с вами некоторыми материалами. Вы уже должны были получить отдельное письмо со ссылкой для доступа к нему.",
    "Password to access content shared with you by %1$s" : "Пароль для доступа к содержимому, предоставленному вам %1$s",
    "Password to access content" : "Пароль для доступа к содержимому",
    "Federated Teams" : "Федеративные команды",
    "This item is already shared with this team" : "К этому элементу уже предоставлен общий доступ этой команде",
    "Bring cloud-users closer together." : "Объедините пользователей облачных технологий.",
    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Команды позволяют людям создавать свои группы людей/коллег/друзей.\nЗатем эти группы людей могут быть использованы любым другим приложением для совместного использования.",
    "Unable to update federated teams config" : "Не удалось обновить конфигурацию федеративных команд",
    "Invalid URL format. Please provide a valid URL." : "Недопустимый формат URL. Укажите корректный URL.",
    "Changed frontal cloud URL" : "Изменён фронтальный URL облака",
    "Federation allows you to share teams with other trusted servers and make them discoverable across instances." : "Федерация позволяет делиться командами с другими доверенными серверами и делать их доступными для обнаружения между экземплярами.",
    "Enable federated teams" : "Включить федеративные команды",
    "Frontal URL" : "Фронтальный URL",
    "https://…" : "https://…",
    "The public URL used by other instances to discover and connect to your teams." : "Публичный URL, используемый другими экземплярами для обнаружения ваших команд и подключения к ним.",
    "Unlimited" : "Неограничено",
    "Default quota" : "Квота по умолчанию",
    "Select default quota" : "Квота по умолчанию",
    "Save" : "Save",
    "Reconnect" : "Переподключиться ",
    "Connect" : "Подключиться",
    "New team" : "Новая команда",
    "Search teams" : "Поиск команд",
    "Overview" : "Общие сведения",
    "No teams found" : "Команды не найдены",
    "Try a different search." : "Попробуйте другой запрос поиска.",
    "Create a team to get started." : "Для начала, создайте команду.",
    "Members" : "Участники",
    "_%n resource_::_%n resources_" : ["%n ресурс","%n ресурса","%n ресурсов","%n ресурсов"],
    "Team \"{name}\" created" : "Команда \"{name}\" создана",
    "Could not create the team" : "Не удалось создать команду",
    "Cancel" : "Отмена",
    "Next" : "Далее",
    "Back" : "Назад",
    "Create team" : "Создать команду",
    "Step {current} of {total}" : "Шаг {current} из {total}",
    "Team name" : "Название команды",
    "e.g. Design" : "напр. Дизайн",
    "Search for people to add" : "Поиск людей для добавления",
    "Switch to list view" : "Переключение в режим просмотра списка",
    "Switch to grid view" : "Переключиться на режим просмотра сеткой",
    "Folder" : "Каталог",
    "Team owner" : "Владелец команды",
    "you" : "вы",
    "Manage team" : "Управление командой",
    "Copy link" : "Копировать ссылку",
    "Leave team" : "Покинуть команду",
    "Delete team" : "Удалить команду",
    "An error happened during the config change" : "Не удалось изменить конфигурацию",
    "Confirm enabling federation" : "Подтвердите включение федерации",
    "Enabling this will prevent {circle} from being a member of other teams.\nAre you sure?" : "Включение данного параметра не позволит {circle} стать членом других команд. Вы уверены?",
    "Enable federation" : "Включить федерацию",
    "Copied" : "Скопировано",
    "Could not copy" : "Не удалось скопировать",
    "Create link" : "Создать ссылку",
    "Enforce password protection on files shared to this team" : "Применить защиту паролем к файлам, предоставленным этой команде",
    "Use a unique password for all shares to this team" : "Используйте уникальный пароль для всех общих ресурсов этой команды",
    "Unique password …" : "Уникальный пароль ...",
    "Change unique password" : "Изменение уникального пароля",
    "Failed to save password. Please try again later." : "Не удалось сохранить пароль. Пожалуйста, повторите попытку позже.",
    "Close" : "Закрыть",
    "Choose a team picture" : "Выбор изображения команды",
    "There is no description for this team" : "Для этой команды нет описания",
    "Enter a description for the team" : "Введите описание команды",
    "New folder" : "Новая папка",
    "Folder name" : "Имя папки",
    "Talk conversation" : "Название обсуждения",
    "New Talk conversation" : "Новое обсуждение",
    "Conversation name" : "Название обсуждения",
    "Collective" : "Группа",
    "Calendar" : "Календарь",
    "New calendar" : "Новый календарь",
    "Calendar name" : "Название календаря",
    "Unknown resource type" : "Неизвестный тип ресурса",
    "Team calendar \"{resourceName}\" created and shared with team" : "Создан календарь команды \"{resourceName}\" и предоставлен в общий доступ для членов команды",
    "{resourceType} \"{resourceName}\" created and shared with team" : "{resourceType} \"{resourceName}\" создан и предоставлен в общий доступ для членов команды",
    "A calendar named \"{name}\" already exists. Please choose a different name." : "Календарь с именем \"{name}\" уже существует, выберите другое имя.",
    "Failed to create {resourceType}: {error}" : "Не удалось создать {resourceType}: {error}",
    "Please select a valid png or jpg file" : "Выберите файл в формате .png или .jpg",
    "Error picking team picture" : "Не удалось загрузить изображение команды",
    "Error cropping avatar picture" : "Не удалось обрезать изображение для аватара",
    "An error happened while saving {fields}" : "Произошла ошибка при сохранении {fields}",
    "Description" : "Описание",
    "Upload team picture" : "Загрузить изображение команды",
    "Choose from Nextcloud Files" : "Выбрать из файлов Nextcloud",
    "Delete picture" : "Удалить изображение",
    "Edit" : "Редактировать",
    "Request to join" : "Присоединиться",
    "Create" : "Создать",
    "Show in Calendar" : "Показывать в календаре",
    "Your request to join this team is pending approval" : "Ваша заявка на вступление в эту команду ожидает одобрения",
    "You are not a member of {circle}" : "Вы не являетесь участником круга {circle}",
    "Add" : "Добавить",
    "Edit team picture" : "Редактировать изображение команды",
    "Apply" : "Применить",
    "Remove {type}" : "Удалить {type}",
    "Add to group" : "Добавить в группу",
    "Add members to group" : "Добавить участников в группу",
    "Search {types}" : "Поиск {types}",
    "Add guest" : "Добавить гостя",
    "Loading …" : "Загрузка …",
    "No results" : "Нет результатов",
    "Add {type}" : "Добавить {type} ",
    "Promote as sole owner" : "Повысить до единственного владельца",
    "Promote to {level}" : "Повысить до уровня \"{level}\"",
    "Demote to {level}" : "Понизить до уровня \"{level}\"",
    "Are you sure you want to leave this team? This action cannot be undone." : "Вы уверены, что хотите покинуть эту команду? Это действие нельзя отменить.",
    "Leave team failed." : "Не удалось покинуть команду.",
    "Could not delete the member {displayName}" : "Не удалось удалить участника {displayName}",
    "Could not change the member level to {level}" : "Не удалось изменить уровень участника на \"{level}\"",
    "Could not accept membership request" : "Не удалось принять запрос на участие",
    "Accept membership request" : "Принять запрос на присоединение",
    "Reject membership request" : "Отклонить запрос на присоединение",
    "Manage level" : "Управлять уровнем",
    "Remove member" : "Удалить участника",
    "Pending" : "В очереди",
    "Unable to get the results" : "Не удалось получить результаты запроса",
    "Some members could not be added" : "Не удалось добавить некоторых участников",
    "There was an issue adding members to the team" : "Возникла проблема с добавлением участников в команду",
    "There was an error fetching the member list" : "Не удалось получить список участников",
    "The list of members is only visible to members of this team" : "Список участников виден только членам этой команды",
    "Search among current members" : "Поиск среди текущих участников",
    "Role" : "Роль",
    "Filter by role" : "Фильтр по роли",
    "Loading members list …" : "Загрузка списка участников …",
    "No members found matching your search" : "Не найдено участников по Вашему запросу",
    "You currently have no access to the member list" : "В настоящее время у вас нет доступа к списку участников",
    "Add to {team}" : "Добавить в {team}",
    "Invite members to {team}" : "Пригласить участников в {team}",
    "Your teams and everything shared with them across Nextcloud." : "Ваши команды и всё, чем вы делитесь с ними через Nextcloud.",
    "Could not load teams" : "Не удалось загрузить команды",
    "Something went wrong while loading your teams." : "Что-то пошло не так при попытке загрузки Ваших команд.",
    "Try again" : "Попытаться снова",
    "No teams yet" : "Пока нет команд",
    "Create your first team to start collaborating." : "Создайте свою первую команду, чтобы начать совместную работу.",
    "Create your first team" : "Создайте свою первую команду",
    "Your teams" : "Ваши команды",
    "Loading" : "Загрузка",
    "Go back" : "Назад",
    "Join" : "Присоединиться",
    "Could not load the team" : "Не удалось загрузить команду",
    "Team not found" : "Команда не найдена",
    "This team may have been removed." : "Данная команда, возможно, была удалена.",
    "Failed to load teams" : "Не удалось загрузить команды",
    "Join or create teams to see them here." : "Присоединитесь к командам или создайте новые, чтобы увидеть их здесь.",
    "Loading…" : "Загрузка…",
    "More teams" : "Больше команд",
    "Link copied to the clipboard" : "Ссылка скопирована в буфер обмена",
    "Could not copy link to the clipboard" : "Не удалось скопировать ссылку в буфер обмена",
    "Are you sure you want to leave {team}?" : "Вы уверены, что хотите покинуть {team}?",
    "You left \"{name}\"" : "Вы покинули \"{name}\"",
    "Could not leave the team" : "Не удалось покинуть команду",
    "Are you sure you want to delete {team}? This cannot be undone." : "Вы уверены, что хотите удалить \"{team}\"? Эта операция не может быть отменена.",
    "Team deleted" : "Команда удалена",
    "Could not delete the team" : "Не удалось удалить команду",
    "Join team" : "Присоединиться к команде",
    "You are about to leave {circle}.\nAre you sure?" : "Подтвердите выход из круга \"{circle}\"",
    "Please confirm team leave" : "Пожалуйста, подтвердите выход из команды",
    "Could not leave the team {displayName}" : "Не удалось покинуть команду {displayName}",
    "Unable to join the team" : "Невозможно присоединиться к команде",
    "You are about to delete {circle}.\nAre you sure?" : "Подтвердите удаление круга \"{circle}\"",
    "Please confirm team deletion" : "Пожалуйста, подтвердите удаление команды",
    "Unable to delete the team" : "Невозможно удалить команду",
    "Could not copy link to the clipboard." : "Не удалось скопировать ссылку в буфер обмена",
    "All contacts" : "Все контакты",
    "Not grouped" : "Без группы",
    "Recently contacted" : "Недавние контакты",
    "Organization chart" : "Организационная структура",
    "Contacts settings" : "Параметры контактов",
    "Create your own teams for sharing. Add Nextcloud users, contacts, or anyone via email." : "Создавайте собственные команды для обмена данными. Добавляйте пользователей Nextcloud, контакты или любых других людей по электронной почте.",
    "User" : "Пользователь",
    "Group" : "Группа",
    "Email" : "Электронная почта",
    "Invites" : "Приглашения",
    "Anyone can request membership" : "Любой может подать заявку на вступление",
    "Members need to accept invitation" : "Участники должны принять приглашение",
    "Memberships must be confirmed/accepted by a Moderator (requires \"Anyone can request membership\")" : "Заявки на вступление должны быть подтверждены/одобрены модератором (требуется настройка «Любой может подать заявку на вступление»)",
    "Members can also invite" : "Разрешить приглашать участникам",
    "Membership" : "Членство",
    "Prevent teams from being a member of another team" : "Запретить командам быть членами другой команды",
    "Federation" : "Федерация",
    "Allow federated members" : "Разрешить участие членов федерации",
    "Privacy" : "Конфиденциальность",
    "Visible to everyone" : "Видим для всех",
    "users" : "пользователи",
    "Users" : "Пользователи",
    "groups" : "групп",
    "Groups" : "Группы",
    "federated users" : "федеративные пользователи",
    "Federated users" : "Федеративные пользователи",
    "teams" : "команды",
    "email addresses" : "адреса эл. почты",
    "Email addresses" : "Адреса электронной почты",
    "contacts" : "контакты",
    "Contacts" : "Контакты",
    "An error has occurred in team(s). Check the console for more details." : "Произошла ошибка в команде(ах). Проверьте консоль для получения более подробной информации.",
    "Unable to create team {circleName}" : "Невозможно создать команду {circleName}",
    "Unable to delete team {circleId}" : "Невозможно удалить команду {circleId}",
    "No files in here" : "Здесь нет файлов",
    "No entries found in this folder" : "В этой папке ничего нет",
    "Name" : "Имя",
    "Size" : "Размер",
    "Modified" : "Изменён",
    "Circles App Initialization" : "Инициализация приложения \"Круги\""
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
