OC.L10N.register(
    "files_lock",
    {
    "Desktop client" : "Werkskermkliënt",
    "iOS client" : "iOS-kliënt",
    "Android client" : "Android-kliënt",
    "Unlock file" : "Unlock file",
    "Lock file" : "Lock file"
},
"nplurals=2; plural=(n != 1);");
