OC.L10N.register(
    "circles",
    {
    "Personal" : "Personleg",
    "System" : "System",
    "Password protected" : "Passordverna",
    "Local" : "Lokal",
    "Federated" : "Federated",
    "App" : "Applikasjon",
    "Contact" : "Kontakt",
    "Member" : "Medlem",
    "Moderator" : "Moderator",
    "Admin" : "Administrer",
    "Owner" : "Owner",
    "Open »%s«" : "Opna »%s«",
    "Accept" : "Godta",
    "Invalid file provided" : "Ugyldig fil",
    "File is too big" : "Fila er for stor",
    "Invalid image" : "Ugyldig bilete",
    "Unknown filetype" : "Ukjend filtype",
    "Open %s" : "Opne{filnamn}",
    "Unlimited" : "Ubegrensa",
    "Save" : "Save",
    "Connect" : "Kople til",
    "Overview" : "Oversyn",
    "Members" : "Medlemmar",
    "Cancel" : "Cancel",
    "Back" : "Tilbake",
    "Folder" : "Mappe",
    "Copy link" : "Kopier lenkje",
    "Close" : "Lat att",
    "New folder" : "Ny mappe",
    "Folder name" : "Mappenamn",
    "Conversation name" : "Samtale namn",
    "Calendar" : "Kalendar",
    "New calendar" : "Ny kalender",
    "Description" : "Skildring",
    "Edit" : "Rediger",
    "Create" : "Opprett",
    "Add" : "Legg til",
    "Apply" : "Anvend",
    "Remove member" : "Fjern medlem",
    "Pending" : "Ventar",
    "Role" : "Rolle",
    "Add to {team}" : "Legg til {team}",
    "Loading…" : "Lastar...",
    "User" : "Bruker",
    "Group" : "Gruppe",
    "Email" : "Epost",
    "Privacy" : "Personvern",
    "Users" : "Brukarare",
    "Groups" : "Grupper",
    "No files in here" : "Ingen filer her",
    "No entries found in this folder" : "Ingen oppføringar funne i denne mappa",
    "Name" : "Namn",
    "Size" : "Storleik",
    "Modified" : "Endra"
},
"nplurals=2; plural=(n != 1);");
