OC.L10N.register(
    "serverinfo",
    {
    "System" : "Systema",
    "Unknown" : "Incognite",
    "Monitoring" : "Controlante",
    "Active users" : "Usatores active",
    "Never" : "Nunquam",
    "Current usage" : "Uso actual",
    "Load average" : "Carga medie",
    "Database" : "Base de datos",
    "Type:" : "Typo:",
    "Version:" : "Version:",
    "Size:" : "Dimension:",
    "Details" : "Detalios",
    "Total" : "Total",
    "Authentication" : "Authentication",
    "Hostname" : "Nomine de Hospite",
    "PHP" : "PHP",
    "seconds" : "secundas",
    "Upload max size:" : "Dimension maxime de incarga:",
    "Shares" : "Compartimentos",
    "Users:" : "Usatores:",
    "Warning" : "Aviso",
    "Copied!" : "Copiate!",
    "Not supported!" : "Non supportate!",
    "Press ⌘-C to copy." : "Pulsa ⌘-C pro copiar.",
    "Press Ctrl-C to copy." : "Pulsa Ctrl-C pro copiar.",
    "Files:" : "Files:",
    "External monitoring tool" : "Instrumento de controlo externe",
    "Copy" : "Copiar"
},
"nplurals=2; plural=(n != 1);");
