._material-design-icon_584lD{display:flex;align-self:center;justify-self:center;align-items:center;justify-content:center}._iconToggleSwitch_rwBqv{color:var(--2d1b8583);transition:color var(--animation-quick) ease}._iconToggleSwitch_rwBqv svg{height:auto!important}._iconToggleSwitch_rwBqv circle{cx:var(--78386a55);transition:cx var(--animation-quick) ease}
