OC.L10N.register(
    "office",
    {
    "Office" : "Escritório",
    "Office overview" : "Visão geral do escritório",
    "Office overview app for Nextcloud" : "Aplicativo de visão geral do escritório para Nextcloud",
    "Create new" : "Criar novo",
    "Scroll left" : "Rolar para a esquerda",
    "Scroll right" : "Rolar para a direita",
    "Blank" : "Vazio",
    "Search {category}" : "Pesquisar {category}",
    "Search" : "Pesquisa",
    "Failed to create file" : "Falha ao criar o arquivo",
    "Failed to load files" : "Falha ao carregar os arquivos",
    "No office suite installed" : "Nenhuma suíte de escritório instalada",
    "{count} found in {category}" : "{count} encontrados em {category}",
    "Recent {category}" : "Recentes {category}",
    "Filter files" : "Filtrar arquivos",
    "All" : "Todos",
    "Mine" : "Meus",
    "Shared with me" : "Compartilhados comigo",
    "Switch to grid view" : "Mudar para a visualização em grade",
    "Switch to list view" : "Mudar para a visualização em lista",
    "No {category} found" : "Nenhum {category} encontrado",
    "Switch to \"All\" to see every file you have access to" : "Mude para “Todos” para ver todos os arquivos aos quais você tem acesso",
    "Search all in Files" : "Pesquisar tudo em Arquivos",
    "Show all in Files" : "Mostrar tudo em Arquivos",
    "Create" : "Criar",
    "Filename" : "Nome de arquivo",
    "Documents" : "Documentos",
    "Spreadsheets" : "Planilhas",
    "Presentations" : "Apresentações",
    "Diagrams" : "Diagramas",
    "Filename cannot be empty" : "O nome de arquivo não pode ser vazio",
    "Filename contains invalid characters" : "O nome do arquivo contém caracteres inválidos.",
    "{count} {category} found" : "{count} {category} encontrados"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
