OC.L10N.register(
    "files_lock",
    {
    "File can only be unlocked by the owner of the lock" : "הנעילה יכולה להיות משוחררת ע\"י הבעלים בלבד",
    "Desktop client" : "לקוח לשולחן העבודה",
    "iOS client" : "לקוח iOS",
    "Android client" : "לקוח Android",
    "Temporary files lock" : "נעילת קבצים זמנית",
    "Temporary lock your files" : "לנעול את הקבצים שלך באופן זמני",
    "Allow your users to temporary lock their files to avoid conflicts while working on shared files." : "מאפשר למשתמשים שלך לנעול את הקבצים שלהם כדי למנוע סתירות בעת עבודה על קבצים משותפים.",
    "Unlock file" : "שחרור קובץ",
    "Lock file" : "נעילת קובץ"
},
"nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
