OC.L10N.register(
    "logreader",
    {
    "Logging" : "Zapisivanje",
    "Errors in the log" : "Pogreške u zapisima",
    "Failed to get an iterator for log entries: %s" : "Neuspjelo dohvaćanje iteratora za zapise u dnevniku: %s",
    "No errors in the logs since %s" : "Nema pogrešaka u zapisima od %s",
    "_%n error in the logs since %s_::_%n errors in the logs since %s_" : ["%n pogreška u zapisima od %s","%n pogrešaka u zapisima od %s","%n pogrešaka u zapisima od %s"],
    "_%n warning in the logs since %s_::_%n warnings in the logs since %s_" : ["%n upozorenje u zapisima od %s","%n upozorenja u zapisima od %s","%n upozorenja u zapisima od %s"],
    "Log Reader" : "Čitač zapisa",
    "A log reader for Nextcloud" : "Čitač zapisa za Nextcloud",
    "Log reader for Nextcloud" : "Čitač zapisa za Nextcloud",
    "If you feel this is an error, please verify {setting} in your {config} and check the Nextcloud Administration Manual." : "Ako smatrate da je ovo pogreška, provjerite {setting} u vašem {config} i pogledajte priručnik za administratore za Nextcloud.",
    "Log reader" : "Preglednik zapisa",
    "Open log reader settings" : "Otvori postavke preglednika zapisa",
    "Log reader settings" : "Postavke preglednika zapisa",
    "Currently the log file {file} is shown" : "Trenutačno je prikazana {file} datoteka zapisa",
    "Show server log" : "Prikaži zapise poslužitelja",
    "Live view is disabled" : "Prikaz uživo je onemogućen",
    "No log file" : "Nema datoteke zapisa",
    "File-based logging must be enabled to access logs from the Web UI." : "Zapisivanje u datoteku mora biti omogućeno kako bi se zapisima moglo pristupiti putem web-sučelja.",
    "Log entry successfully copied" : "Zapis iz dnevnika uspješno kopiran",
    "Level" : "Razina",
    "App" : "Aplikacija",
    "No app in context" : "Nema aplikacije u kontekstu",
    "Time" : "Vrijeme",
    "Copy raw entry" : "Kopiraj neobrađeni zapis",
    "Copy formatted entry" : "Kopiraj oblikovani zapis",
    "Hide exception details" : "Sakrij detalje iznimke",
    "View exception details" : "Prikaži detalje iznimke",
    "Raw log entry" : "Neobrađeni zapis",
    "Search log entries" : "Pretraži zapise dnevnika",
    "Caused by {exception}" : "Uzrokovano s {exception}",
    "Line {line}" : "Redak {line}",
    "Filter log levels" : "Filtriraj razine zapisa",
    "Set log level" : "Postavi razinu zapisa",
    "Time format" : "Format vremena",
    "Live view" : "Pregled uživo",
    "Download/Upload logs" : "Preuzmi / prenesi zapise",
    "Ctrl" : "Ctrl",
    "Could not parse local log file" : "Nije moguće obraditi lokalnu datoteku zapisa",
    "You can also show log entries copied from your clipboard by pasting them on the log view using: {keyboardShortcut}" : "Zapise iz dnevnika kopirane u međuspremnik možete prikazati i tako da ih zalijepite u prikaz zapisa pomoću: {keyboardShortcut}",
    "Download logs" : "Preuzmi zapise",
    "Show local log file" : "Prikaži lokalnu datoteku zapisa",
    "Upload local log file to be displayed" : "Prenesi lokalnu datoteku zapisa za prikaz",
    "Time format used for displaying the timestamp" : "Format vremena koji se koristi za prikaz vremenske oznake",
    "(Local log files only support the \"raw\" time format)" : "(Lokalne datoteke zapisa podržavaju samo „neobrađeni” format vremena)",
    "Could not change date time format." : "Nije moguće promijeniti format datuma i vremena.",
    "Raw data" : "Neobrađeni podaci",
    "Local time" : "Lokalno vrijeme",
    "UTC time" : "UTC vrijeme",
    "Relative" : "Relativno",
    "Could not change live view setting." : "Nije moguće promijeniti postavku prikaza uživo.",
    "Polling is disabled because server is not configured to log to file" : "Dohvaćanje u intervalima onemogućeno je jer poslužitelj nije konfiguriran za zapisivanje u datoteku",
    "Polling (live view)" : "Dohvaćanje u intervalima (prikaz uživo)",
    "Could not set logging levels to show" : "Nije moguće postaviti razine zapisivanja za prikaz",
    "Filter logging levels" : "Filtriraj razine zapisivanja",
    "Could not set logging level" : "Nije moguće postaviti razinu zapisivanja",
    "Set backend loglevel" : "Postavi razinu zapisivanja pozadinskog sustava",
    "Application" : "Aplikacija",
    "Message" : "Poruka",
    "Log entry actions" : "Radnje zapisa u dnevniku",
    "Loading older log entries" : "Učitavanje starijih zapisa dnevnika",
    "No older log entries available" : "Nema dostupnih starijih zapisa dnevnika",
    "Collapse row" : "Sažmi redak",
    "Expand row" : "Proširi redak",
    "Show details" : "Prikaži detalje",
    "Debug" : "Otklanjanje pogrešaka",
    "Info" : "Informacije",
    "Warning" : "Upozorenje",
    "Error" : "Pogreška",
    "Fatal" : "Fatalno",
    "Could not load log entries" : "Nije moguće učitati zapise dnevnika",
    "Clipboard" : "Međuspremnik",
    "Could not parse clipboard content" : "Nije moguće obraditi sadržaj međuspremnika",
    "Could not fetch new log entries (server unavailable)" : "Nije moguće dohvatiti nove zapise dnevnika (poslužitelj nedostupan)",
    "Could not fetch new entries" : "Nije moguće dohvatiti nove zapise",
    "Could not copy to clipboard, please copy manually:" : "Nije moguće kopirati u međuspremnik, kopirajte ručno:",
    "\tfrom {address} by {user} at {time}\n" : "\tsa {address} od {user} u {time}\n"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
