OC.L10N.register(
    "office",
    {
    "Office" : "ຫ້ອງການ",
    "Create new" : "ສ້າງໃຫມ່",
    "Blank" : "Blank",
    "Search" : "ຄົ້ນຫາ",
    "All" : "ທັງໝົດ",
    "Shared with me" : "Shared with me",
    "Switch to grid view" : "ປ່ຽນເປັນມຸມມອງແບບຕາຂ່າຍ",
    "Switch to list view" : "ປ່ຽນເປັນມຸມມອງລາຍການ",
    "Create" : "ສ້າງ",
    "Filename" : "ຊື່ຟາຍ",
    "Documents" : "ເອກະສານ",
    "Spreadsheets" : "Spreadsheets",
    "Presentations" : "Presentations",
    "Filename cannot be empty" : "ຊື່ຟາຍ ບໍ່ສາມາດເປົ່າວ່າງໄດ້"
},
"nplurals=1; plural=0;");
