OC.L10N.register(
    "suspicious_login",
    {
    "New login location detected" : "Aptiktas prisijungimas iš naujos vietos",
    "More info about the suspicious IP address available on %s" : "Daugiau informacijos apie įtartiną IP adresą rasite %s",
    "A new login into your account was detected. The IP address %s was classified as suspicious by an AI model. If this was you, you can ignore this message, as the AI model did not take any automated actions. Otherwise, you should change your password." : "Aptiktas naujas prisijungimas prie jūsų paskyros. Dirbtinio intelekto modelis IP adresą %s klasifikavo kaip įtartiną. Jei tai buvote jūs, galite ignoruoti šį pranešimą, nes dirbtinio intelekto modelis neatliko jokių automatinių veiksmų. Priešingu atveju turėtumėte pakeisti slaptažodį.",
    "Open %s ↗" : "Atverti %s ↗",
    "Suspicious Login" : "Įtartinas prisijungimas",
    "New login detected" : "Aptiktas naujas prisijungimas",
    "Detect and warn about suspicious IPs logging into Nextcloud\n\t" : "Aptikti ir įspėti apie įtartinus, prie „Nextcloud“ prisijungiančius, IP adresus\n\t",
    "A new login into your account was detected. The IP address %s was classified as suspicious. If this was you, you can ignore this message. Otherwise you should change your password." : "Buvo aptiktas naujas prisijungimas prie jūsų paskyros. IP adresas %s buvo klasifikuotas kaip įtartinas. Jeigu tai buvote jūs, galite nepaisyti šio pranešimo. Priešingu atveju, turėtumėte pasikeisti slaptažodį."
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
