OC.L10N.register(
    "profile",
    {
    "View profile" : "View profile",
    "Profile picker" : "Profile picker",
    "Profile" : "Profile",
    "This application provides the profile" : "This application provides the profile",
    "Provides a customizable user profile interface." : "Provides a customisable user profile interface.",
    "Searching …" : "Searching …",
    "Not found" : "Not found",
    "Search for a user profile" : "Search for a user profile",
    "Search for a user profile. Start typing" : "Search for a user profile. Start typing",
    "Insert selected user profile link" : "Insert selected user profile link",
    "Insert" : "Insert",
    "You have not added any info yet" : "You have not added any info yet",
    "{user} has not added any info yet" : "{user} has not added any info yet",
    "Error opening the user status modal, try hard refreshing the page" : "Error opening the user status modal, try hard refreshing the page",
    "Edit profile" : "Edit profile",
    "The headline and about sections will show up here" : "The headline and about sections will show up here",
    "Profile not found" : "Profile not found",
    "The profile does not exist or is unavailable." : "The profile does not exist or is unavailable.",
    "Back to %s" : "Back to %s",
    "Provides a customisable user profile interface." : "Provides a customisable user profile interface.",
    "Edit Profile" : "Edit Profile",
    "The profile does not exist." : "The profile does not exist."
},
"nplurals=2; plural=(n != 1);");
