OC.L10N.register(
    "oauth2",
    {
    "Your client is not authorized to connect. Please inform the administrator of your client." : "Klienten har inte behörighet att ansluta. Informera klientens administratör.",
    "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path" : "URL:en för omdirigering måste vara fullständig, till exempel https://yourdomain.com/path",
    "OAuth 2.0" : "OAuth 2.0",
    "Allows OAuth2 compatible authentication from other web applications." : "Tillåter OAuth 2.0-kompatibel autentisering från andra webbappar.",
    "The OAuth2 app allows administrators to configure the built-in authentication workflow to also allow OAuth2 compatible authentication from other web applications." : "Med OAuth 2.0-appen kan administratörer konfigurera det inbyggda autentiseringsflödet så att även OAuth 2.0-kompatibel autentisering från andra webbappar tillåts.",
    "Secret key" : "Hemlig nyckel",
    "Delete" : "Ta bort",
    "An unknown error occurred." : "Ett okänt fel uppstod.",
    "OAuth 2.0 clients" : "OAuth 2.0-klienter",
    "OAuth 2.0 allows external services to request access to {instanceName}." : "OAuth 2.0 tillåter externa tjänster att begära åtkomst till {instanceName}.",
    "Name" : "Namn",
    "Redirection URI" : "Omdirigerings-URI",
    "Client identifier" : "Klientidentifierare",
    "Delete client" : "Ta bort klient",
    "Make sure you store the secret key, it cannot be recovered." : "Spara den hemliga nyckeln. Den kan inte återskapas.",
    "Add client" : "Lägg till klient",
    "Add" : "Lägg till",
    "Client Identifier" : "Klientidentifierare",
    "Show client secret" : "Visa klienthemlighet",
    "Hide client secret" : "Dölj klienthemlighet"
},
"nplurals=2; plural=(n != 1);");
