OC.L10N.register(
    "suspicious_login",
    {
    "New login location detected" : "Nouvel emplacement de connexion détecté",
    "More info about the suspicious IP address available on %s" : "Plus d'informations sur l'adresse IP suspecte sont disponibles sur %s",
    "A new login into your account was detected. The IP address %s was classified as suspicious by an AI model. If this was you, you can ignore this message, as the AI model did not take any automated actions. Otherwise, you should change your password." : "Une nouvelle connexion à votre compte a été détectée. L'adresse IP %s a été considérée comme suspecte par un modèle IA. S'il s'agissait de vous, vous pouvez ignorer ce message, car le modèle IA n'a pris aucune mesure automatique. Sinon, vous devriez changer votre mot de passe.",
    "Open %s ↗" : "Ouvrir %s ↗",
    "Suspicious Login" : "Connexion suspecte",
    "New login detected" : "Nouvelle connexion détectée",
    "Detect and warn about suspicious IPs logging into Nextcloud\n\t" : "Détecte et avertit des IPs suspectes se connectant à Nextcloud",
    "A new login into your account was detected. The IP address %s was classified as suspicious. If this was you, you can ignore this message. Otherwise you should change your password." : "Une nouvelle connexion à votre compte a été détectée. L'adresse IP %s a été considérée comme suspecte. S'il s'agissait de vous, vous pouvez ignorer ce message. Sinon, vous devriez changer votre mot de passe."
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
