OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "Pridėtas į patikimų serverių sąrašą",
    "No server found with ID: %s" : "Nerasta jokio serverio, kurio ID: %s",
    "Could not remove server" : "Nepavyko pašalinti serverio",
    "Server is already in the list of trusted servers." : "Serveris jau yra patikimų serverių sąraše.",
    "No server to federate with found" : "Nerasta jokio serverio, su kuriuo jungtis į federaciją",
    "Could not add server" : "Nepavyko pridėti serverio",
    "Trusted servers" : "Patikimi serveriai",
    "Federation" : "Federacija",
    "Federation allows you to connect with other trusted servers to exchange the account directory." : "Federacija leidžia prisijungti prie kitų patikimų serverių, kad būtų galima keistis paskyros katalogu.",
    "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing." : "Federacija leidžia prisijungti prie kitų patikimų serverių, kad būtų galima keistis paskyros katalogu.",
    "Could not add trusted server. Please try again later." : "Nepavyko pridėti patikimo serverio. Bandykite dar kartą vėliau.",
    "Add trusted server" : "Pridėti patikimą serverį",
    "Server url" : "Serverio url",
    "Add" : "Pridėti",
    "Server ok" : "Serveris tvarkoje",
    "User list was exchanged at least once successfully with the remote server." : "Vartotojų sąrašas buvo bent kartą sėkmingai pakeistas su nuotoliniu serveriu.",
    "Server pending" : "Laukiama serverio",
    "Waiting for shared secret or initial user list exchange." : "Laukiama bendrinamo slapto rakto arba pradinio vartotojų sąrašo pasikeitimo.",
    "Server access revoked" : "Prieiga prie serverio atšaukta",
    "Server failure" : "Serverio gedimas",
    "Connection to the remote server failed or the remote server is misconfigured." : "Ryšys su nuotoliniu serveriu nepavyko arba nuotolinis serveris yra neteisingai sukonfigūruotas.",
    "Failed to delete trusted server. Please try again later." : "Nepavyko pašalinti patikimo serverio. Bandykite dar kartą vėliau.",
    "Delete" : "Ištrinti",
    "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "Federacija leidžia prisijungti prie kitų patikimų serverių, kad būtų galima keistis paskyrų katalogu. Pavyzdžiui, tai bus naudojama automatiškai užpildyti išorines paskyras, skirtas federaciniam bendrinimui. Norint sukurti federuotą bendrinimą, nebūtina pridėti serverio kaip patikimo serverio.",
    "Each server must validate the other. This process may require a few cron cycles." : "Kiekvienas serveris turi patvirtinti kitą. Šiam procesui gali prireikti kelių „cron“ ciklų.",
    "External documentation for Federated Cloud Sharing" : "Išorinė dokumentacija apie federacinį debesies bendrinimą",
    "+ Add trusted server" : "+ Pridėti patikimą serverį",
    "Trusted server" : "Patikimas serveris"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
