OC.L10N.register(
    "provisioning_api",
    {
    "Logged in account must be an administrator or have authorization to edit this setting." : "يجب أن يكون الحساب الداخل مسؤول نظام أو لديه الصلاحية لتعديل هذا الإعداد.",
    "Could not create non-existing user ID" : "يتعذّر إنشاء مُعرِّف ID لمستخدِم غير موجود",
    "User already exists" : "أنت موجودٌ مُسبقاً",
    "Group %1$s does not exist" : "المجموعة %1$s غير موجودة",
    "Insufficient privileges for group %1$s" : "أذونات غير كافية للمجموعة %1$s",
    "No group specified (required for sub-admins)" : "لم يتم تحديد أي مجموعة (مطلوبة للمديرين الفرعيين)",
    "Sub-admin group does not exist" : "مجموعة المديرين الفرعيين غير موجودة",
    "Cannot create sub-admins for admin group" : "تعذّر إنشاء مديرين فرعيين لمجموعة المديرين",
    "No permissions to promote sub-admins" : "أذونات غير كافية لترقية المديرين الفرعيين",
    "Invalid password value" : "قيمة غير صحيحة لكلمة المرور",
    "An email address is required, to send a password link to the user." : "عنوان الإيميل مطلوب لإرسال رابط كلمة المرور للمستخدِم",
    "Required email address was not provided" : "عنوان الإيميل المطلوب لم يتم توفيره",
    "Invalid email address" : "عنوان الإيميل غير صحيح",
    "Invalid language" : "لغة غير صالحة",
    "Invalid quota value: %1$s" : "قيمة غير صحيحة للحصة: %1$s",
    "Invalid quota value. %1$s is exceeding the maximum quota" : "قيمة غير صحيحة للحصة. %1$s تزيد عن الحد الأقصى للحصة",
    "Unlimited quota is forbidden on this instance" : "الحصة غير المحدودة غير مسموح بها على هذا الخادوم",
    "Setting the password is not supported by the users backend" : "تعيين كلمة المرور غير مدعوم من قِبَل الواجهة الخلفية للمستخدمين.",
    "Invalid locale" : "اختيار الدولة أو المنطقة غير صحيح",
    "Invalid first day of week" : "اليوم الأول من الأسبوع غير صحيح",
    "Cannot remove yourself from the admin group" : "لا يمكنك إزالة نفسك من قائمة المديرين",
    "Cannot remove yourself from this group as you are a sub-admin" : "لا يمكنك إزالة نفسك من هذه المجموعة باعتبارك مدير فرعي فيها",
    "Not viable to remove user from the last group you are sub-admin of" : "لا يمكن إزالة المستخدم من آخر مجموعة أنت مدير فرعي لها",
    "User does not exist" : "المستخدِم غير موجود",
    "Group does not exist" : "المجموعة غير موجودة",
    "User is not a sub-admin of this group" : "المستخدِم ليس مدير فرعي على هذه المجموعة",
    "Email address not available" : "عنوان الإيميل غير متاح",
    "Sending email failed" : "تعذّر إرسال الإيميل",
    "Email confirmation" : "تأكيد الإيميل",
    "To enable the email address %s please click the button below." : "لتمكين عنوان الإيميل %s، إضغط الزر أدناه رجاءً.",
    "Confirm" : "تأكيد",
    "Email was already removed from account and cannot be confirmed anymore." : " البريد الإلكتروني سبق حذفه من الحساب و لا يمكن تأكيده بعد الآن.",
    "Could not verify mail because the token is expired." : "لا يمكن التحقّق من الإيميل بسبب انتهاء صلاحية الأَمارة token.",
    "Could not verify mail because the token is invalid." : "لا يمكن التحقّق من الإيميل بسبب أن الأَمارة token غير صحيحة.",
    "An unexpected error occurred. Please contact your admin." : "حدث خطأ غير متوقع. اتصل بالمدير رجاءً.",
    "Email confirmation successful" : "تمّ توكيد الإيميل بنجاح",
    "Provisioning API" : "توفير واجهة برمجة التطبيقات API",
    "This application enables a set of APIs that external systems can use to manage accounts, groups and apps." : "يتيح هذا التطبيق مجموعة من واجهات برمجة التطبيقات التي يمكن للأنظمة الخارجية استخدامها لإدارة الحسابات والمجموعات والتطبيقات.",
    "This application enables a set of APIs that external systems can use to create, edit, delete and query account\n\t\tattributes, query, set and remove groups, set quota and query total storage used in Nextcloud. Group admin accounts\n\t\tcan also query Nextcloud and perform the same functions as an admin for groups they manage. The API also enables\n\t\tan admin to query for active Nextcloud applications, application info, and to enable or disable an app remotely.\n\t\tOnce the app is enabled, HTTP requests can be used via a Basic Auth header to perform any of the functions\n\t\tlisted above. More information is available in the Provisioning API documentation, including example calls\n\t\tand server responses." : "يتيح هذا التطبيق مجموعة من واجهات برمجة التطبيقات التي يمكن للأنظمة الخارجية استخدامها لإنشاء الحساب وتحريره وحذفه والاستعلام عنه\n\t\tالخصائص، و الاستعلامات، و تعيين المجموعات و إزالتها، و تعيين الحصص، و الاستعلام عن إجمالي مساحة التخزين المستخدمة في نكست كلاود. حسابات مشرف المجموعة \n\t\t يمكنه أيضًا الاستعلام عن نكست كلاود و تنفيذ نفس الوظائف كمشرف للمجموعات التي يديرونها. تتيح واجهة برمجة التطبيقات API أيضاً \n\t\tمشرف للاستعلام عن تطبيقات نكست كلاود النشطة، و معلومات التطبيق، و تمكين التطبيق أو تعطيله عن بُعد. \n\t\tبمجرد تمكين التطبيق، يمكن استخدام طلبات HTTP عبر رأس المصادقة الأساسية لتنفيذ أي من الوظائف \n\t\t المذكورة أعلاه. \nللمزيد من المعلومات، أنظُر توثيق Provisioning API، بما في ذلك أمثلة على الاستدعاءات \n\t\t واستجابات الخادوم."
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
