OC.L10N.register(
    "admin_audit",
    {
    "Auditing / Logging" : "Pengauditan/Pencatatan",
    "Provides logging abilities for Nextcloud such as logging file accesses or otherwise sensitive actions." : "Menyediakan kemampuan pencatatan untuk Nextcloud, misalnya pencatatan akses file atau tindakan sensitif lainnya."
},
"nplurals=1; plural=0;");
