OC.L10N.register(
    "office",
    {
    "Office" : "المكتب",
    "Office overview" : "نظرة عامة على البرنامج المكتبي",
    "Office overview app for Nextcloud" : "نظرة عامة على تطبيق Office لـ Nextcloud",
    "Create new" : "إنشاء جديد",
    "Scroll left" : "تحريك لليسار",
    "Scroll right" : "تحريك لليمين",
    "Blank" : "فارغ",
    "Search {category}" : "بحث {category}",
    "Search" : "بحث",
    "Failed to create file" : "فشل في إنشاء الملف",
    "Failed to load files" : "تعذّر تحميل الملفات",
    "No office suite installed" : "لا يوجد حزمة برامج مكتبية مثبتة",
    "{count} found in {category}" : "{count} تم ايجادة في {category}",
    "Recent {category}" : "آخر {category}",
    "Filter files" : "تصفية الملفات",
    "All" : "الكل",
    "Mine" : "ملكي",
    "Shared with me" : "تمّت مُشاركته معي",
    "Switch to grid view" : "تبديل إلى العرض الشبكي",
    "Switch to list view" : "التبديل إلى عرض القائمة",
    "No {category} found" : "لم يتم العثور على أي{category}",
    "Switch to \"All\" to see every file you have access to" : "انتقل إلى \"الكل\" لعرض جميع الملفات التي يمكنك الوصول إليها",
    "Search all in Files" : "ابحث في جميع الملفات",
    "Show all in Files" : "عرض الكل في الملفات",
    "Create" : "إنشاء",
    "Filename" : "اسم الملف",
    "Documents" : "المستندات",
    "Spreadsheets" : "الجداول الالكترونية",
    "Presentations" : "العروض",
    "Diagrams" : "الأشكال",
    "Filename cannot be empty" : "لا يجوز أن يُترك اسم الملف فارغًا",
    "Filename contains invalid characters" : "اسم الملف يحتوي على أحرف غير صالحة",
    "{count} {category} found" : "{count}{category} وجد"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
