OC.L10N.register(
    "appstore",
    {
    "Apps" : "ແອັບພລິເຄຊັນ",
    "App name" : "App name",
    "Version" : "ເວີຊັນ",
    "Groups" : "ກຸ່ມ",
    "Actions" : "ການດຳເນີນການ",
    "Show details" : "ສະແດງລາຍລະອຽດ",
    "Grid view" : "ເບິ່ງຕາຕະລາງ",
    "Cancel" : "ຍົກເລີກ",
    "Learn more" : "ຮຽນຮູ້ເພີ່ມເຕີມ",
    "Daemon" : "Daemon",
    "Deploy Daemon" : "Daemon ການຕິດຕັ້ງ",
    "Type" : "ປະເພດ",
    "Name" : "ຊື່",
    "Display Name" : "ຊື່ທີ່ສະແດງ",
    "GPUs support" : "ຮອງຮັບ GPUs",
    "Compute device" : "ອຸປະກອນຄຳນວນ",
    "Advanced deploy options" : "Advanced deploy options",
    "Edit ExApp deploy options before installation" : "Edit ExApp deploy options before installation",
    "Configured ExApp deploy options. Can be set only during installation" : "Configured ExApp deploy options. Can be set only during installation",
    "Environment variables" : "Environment variables",
    "ExApp container environment variables" : "ExApp container environment variables",
    "No environment variables defined" : "No environment variables defined",
    "Mounts" : "Mounts",
    "Define host folder mounts to bind to the ExApp container" : "Define host folder mounts to bind to the ExApp container",
    "Must exist on the Deploy daemon host prior to installing the ExApp" : "Must exist on the Deploy daemon host prior to installing the ExApp",
    "Host path" : "Host path",
    "Container path" : "Container path",
    "Read-only" : "Read-only",
    "Remove mount" : "Remove mount",
    "New mount" : "New mount",
    "Enter path to host folder" : "Enter path to host folder",
    "Enter path to container folder" : "Enter path to container folder",
    "Toggle read-only mode" : "Toggle read-only mode",
    "Confirm adding new mount" : "Confirm adding new mount",
    "Confirm" : "ຢືນຢັນ",
    "Cancel adding mount" : "Cancel adding mount",
    "Add mount" : "Add mount",
    "ExApp container mounts" : "ExApp container mounts",
    "No mounts defined" : "No mounts defined",
    "Description" : "ລາຍລະອຽດ",
    "View in store" : "ເບິ່ງໃນຮ້ານຄ້າ",
    "Visit website" : "ເຂົ້າຊົມເວັບໄຊ",
    "Usage documentation" : "Usage documentation",
    "Admin documentation" : "ເອກະສານສຳລັບຜູ້ເບິ່ງແຍງລະບົບ",
    "Developer documentation" : "ເອກະສານສຳລັບນັກພັດທະນາ",
    "Details" : "ລາຍລະອຽດ",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "ບໍ່ສາມາດຕິດຕັ້ງແອັບນີ້ໄດ້ ເພາະວ່າ dependencies ຕໍ່ໄປນີ້ຍັງບໍ່ຄົບຖ້ວນ:",
    "Latest updated" : "Latest updated",
    "Author" : "ຜູ້ຂຽນ",
    "Categories" : "ໝວດໝູ່",
    "Resources" : "ຊັບພະຍາກອນ",
    "Changelog" : "ລາຍການປ່ຽນແປງ",
    "Supported" : "ຮອງຮັບ",
    "Featured" : "ແນະນຳ",
    "This app is supported via your current Nextcloud subscription." : "ແອັບນີ້ໄດ້ຮັບການສະໜັບສະໜູນຜ່ານການສະໝັກສະມາຊິກ Nextcloud ປັດຈຸບັນຂອງທ່ານ.",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "ແອັບທີ່ແນະນຳຖືກພັດທະນາໂດຍ ແລະ ພາຍໃນຊຸມຊົນ. ມັນສະເໜີຟັງຊັນຫຼັກ ແລະ ພ້ອມສຳລັບການໃຊ້ງານຈິງ.",
    "Community rating: {score}/5" : "Community rating: {score}/5",
    "Choose Deploy Daemon for {appName}" : "Choose Deploy Daemon for {appName}",
    "No Deploy daemons configured" : "ບໍ່ມີ Daemon ການຕິດຕັ້ງທີ່ຖືກຕັ້ງຄ່າ",
    "Register a custom one or setup from available templates" : "ລົງທະບຽນໂຕໃໝ່ ຫຼື ຕັ້ງຄ່າຈາກແມ່ແບບທີ່ມີຢູ່",
    "Manage Deploy daemons" : "Manage Deploy daemons",
    "Registered Deploy daemons list" : "ລາຍຊື່ Daemon ການຕິດຕັ້ງທີ່ລົງທະບຽນແລ້ວ",
    "Default" : "ຄ່າເລີ່ມຕົ້ນ",
    "Carousel" : "Carousel",
    "Previous slide" : "Previous slide",
    "Next slide" : "Next slide",
    "Choose slide to display" : "Choose slide to display",
    "{index} of {total}" : "{index} of {total}",
    "Limit to groups" : "Limit to groups",
    "Save" : "ບັນທຶກ",
    "Update all" : "ອັບເດດທັງໝົດ",
    "Loading app list" : "Loading app list",
    "Search everywhere" : "ຄົ້ນຫາທຸກບ່ອນ",
    "Download and enable all" : "Download and enable all",
    "Could not load app discover section" : "Could not load app discover section",
    "Could not render element" : "Could not render element",
    "Nothing to show" : "Nothing to show",
    "Could not load section content from app store." : "Could not load section content from app store.",
    "Loading" : "ກຳລັງໂຫຼດ",
    "Fetching the latest news…" : "Fetching the latest news…",
    "Loading categories" : "Loading categories",
    "Version {version}, {license}-licensed" : "Version {version}, {license}-licensed",
    "Version {version}" : "ເວີຊັນ {version}",
    "Disable" : "ປິດໃຊ້ງານ",
    "Enable" : "ເປີດໃຊ້ງານ",
    "Download and enable" : "Download and enable",
    "Rate the app" : "Rate the app",
    "Report a bug" : "ລາຍງານບັກ",
    "Remove" : "ລຶບອອກ",
    "Update to {version}" : "ອັບເດດເປັນ {version}",
    "Discover" : "Discover",
    "Your apps" : "ແອັບຂອງທ່ານ",
    "Active apps" : "ແອັບທີ່ເປີດໃຊ້ຢູ່",
    "Disabled apps" : "ແອັບທີ່ປິດໃຊ້ຢູ່",
    "Updates" : "ອັບເດດ",
    "App bundles" : "App bundles",
    "Featured apps" : "ແອັບທີ່ແນະນຳ",
    "Supported apps" : "ແອັບທີ່ຮອງຮັບ",
    "An error occurred during the request. Unable to proceed." : "ເກີດຂໍ້ຜິດພາດໃນລະຫວ່າງການຮ້ອງຂໍ. ບໍ່ສາມາດດຳເນີນການຕໍ່ໄດ້."
},
"nplurals=1; plural=0;");
