OC.L10N.register(
    "serverinfo",
    {
    "System" : "Sistem",
    "Unknown" : "Neznano",
    "Monitoring" : "Sistemska dejavnost",
    "Monitoring app with useful server information" : "Program za spremljanje delovanja sistema z različnimi podrobnostmi obremenitve strežnika",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Omogoča prikaz različnih podrobnosti strežnika, kot so obremenitev CPE, zasedenost pomnilnika in prostora, števila uporabnikov in drugo.",
    "Active users" : "Dejavni uporabniki",
    "Last hour" : "Zadnja ura",
    "Webcron" : "Webcron",
    "Background jobs" : "Opravila v ozadju",
    "Mode" : "Način",
    "Never" : "nikoli",
    "Load" : "Obremenitev",
    "CPU info not available" : "Podatki CPE niso na voljo",
    "Current usage" : "Trenutna zasedenost",
    "Load average" : "Povprečna obremenitev",
    "Database" : "Podatkovna zbirka",
    "Type:" : "Vrsta:",
    "Version:" : "Različica:",
    "Size:" : "Velikost:",
    "Used" : "Zasedeno",
    "Available" : "Na voljo",
    "Disk" : "Disk",
    "Files" : "Datoteke",
    "Storages" : "Shrambe",
    "Mount:" : "Priklopna točka:",
    "Filesystem:" : "Datotečni sistem:",
    "Available:" : "Na voljo:",
    "Used:" : "V uporabi:",
    "Status" : "Stanje",
    "Started" : "Začeto",
    "Duration" : "Trajanje",
    "Job" : "Zaposlitev",
    "When" : "Ko je",
    "Details" : "Podrobnosti",
    "Failed" : "Opravilo je spodletelo!",
    "Running" : "V teku",
    "Memory" : "Pomnilnik",
    "RAM info not available" : "Podatki RAM niso na voljo",
    "Total" : "Skupaj",
    "Configuration" : "Nastavitve",
    "Output in JSON" : "Odvod v zapisu JSON",
    "Skip server update" : "Preskoči posodobitev strežnika",
    "Authentication" : "Overitev",
    "Network" : "Omrežje",
    "Hostname" : "Ime gostitelja",
    "Gateway" : "Prehod",
    "DNS" : "Domensko ime DNS",
    "Status:" : "Stanje:",
    "Speed:" : "Hitrost:",
    "Duplex:" : "Dupleks:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "PHP extensions" : "Razširitve PHP",
    "Unable to list extensions" : "Ni mogoče izpisati seznama razširitev",
    "PHP" : "Okolje PHP",
    "Memory limit:" : "Omejitev pomnilnika:",
    "Max execution time:" : "Največji čas izvajanja:",
    "seconds" : "sekunde",
    "Upload max size:" : "Omejitev velikosti pošiljanja:",
    "OPcache Revalidate Frequency:" : "Frekvenca overjanja OPcache:",
    "Show phpinfo" : "Pokaži odvod ukaza phpinfo",
    "CPU" : "CPE",
    "Shares" : "Souporaba",
    "Users:" : "Uporabniki:",
    "Groups:" : "Skupine:",
    "Links:" : "Povezave:",
    "Emails:" : "Elektronski naslovi:",
    "Federated sent:" : "Poslano zveznemu oblaku:",
    "Federated received:" : "Prejeto zveznemu oblaku:",
    "Talk conversations:" : "Pogovori Talk:",
    "Average" : "Povprečje",
    "Warning" : "Opozorilo",
    "Operating System:" : "Operacijski sistem:",
    "CPU:" : "CPE:",
    "Server time:" : "Čas strežnika:",
    "Uptime:" : "Čas delovanja:",
    "Temperature" : "Temperatura",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Skupaj: {memTotalBytes}/Trenutna uporaba: {memUsageBytes}",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "Izmenjevalni prostor SWAP: Skupaj: {swapTotalBytes}/Trenutna uporaba: {swapUsageBytes}",
    "SWAP info not available" : "Podatki izmenjevalnega prostora niso na voljo",
    "Copied!" : "Kopirano!",
    "Not supported!" : "Ni podprto!",
    "Press ⌘-C to copy." : "Pritisnite ⌘-C za kopiranje.",
    "Press Ctrl-C to copy." : "Pritisnite Ctrl-C za kopiranje.",
    "Memory:" : "Pomnilnik:",
    "Files:" : "Datoteke:",
    "Storages:" : "Shrambe:",
    "Free Space:" : "Prostor:",
    "Hostname:" : "Ime gostitelja:",
    "Gateway:" : "Prehod:",
    "Extensions:" : "Razširitve:",
    "External monitoring tool" : "Zunanje orodje za nadzor",
    "Use this end point to connect an external monitoring tool:" : "Priklopna točka za povezavo zunanjega orodja za nadzor:",
    "Copy" : "Kopiraj",
    "Skip apps section (including apps section will send an external request to the app store)" : "Preskoči razdelek programov (vključitev razdelka pošlje zunanji zahtevek trgovini s programi).",
    "To use an access token, please generate one then set it using the following command:" : "Za uporabo žetona za dostop, ga je treba najprej ustvariti in nato nastaviti z ukazom:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Pri poizvedovanju po zgornjem naslovu URL je treba žeton nato prenesti z glavo »NC-Token«.",
    "DNS:" : "DNS:"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
