OC.L10N.register(
    "office",
    {
    "Office" : "Kontorirakendus",
    "Office overview" : "Kontorirakenduse ülevaade",
    "Office overview app for Nextcloud" : "Nextcloudi kontorirakenduse ülevaade",
    "Create new" : "Loo uus",
    "Scroll left" : "Keri vasakule",
    "Scroll right" : "Keri paremale",
    "Blank" : "Tühi",
    "Search {category}" : "Otsi „{category}“ kategooriat",
    "Search" : "Otsi",
    "Failed to create file" : "Faili loomine ei õnnestunud",
    "Failed to load files" : "Failide laadimine ei õnnestu",
    "No office suite installed" : "Ühtegi kontoritarkvarapaketti pole valitud",
    "{count} found in {category}" : "{count} leidus „{category}“ kategoorias",
    "Recent {category}" : "Hiljutine kategooria: „{category}“",
    "Filter files" : "Filtreeri faile",
    "All" : "Kõik",
    "Mine" : "Minu omad",
    "Shared with me" : "Jagatud minuga",
    "Switch to grid view" : "Kasuta ruudustikuvaadet",
    "Switch to list view" : "Kasuta loendivaadet",
    "No {category} found" : "Ühtegi „{category}“ kategooriat ei leidu",
    "Switch to \"All\" to see every file you have access to" : "Vali „Kõik“ ja näed kõiki faile, millele sul on ligipääs",
    "Search all in Files" : "Otsi neid kõiki failirakendusest",
    "Show all in Files" : "Näita neid kõiki failirakenduses",
    "Create" : "Lisa",
    "Filename" : "Failinimi",
    "Documents" : "Dokumendid",
    "Spreadsheets" : "Arvutustabelid",
    "Presentations" : "Esitlused",
    "Diagrams" : "Joonised ja diagrammid",
    "Filename cannot be empty" : "Failinimi ei tohi olla tühi",
    "Filename contains invalid characters" : "Failinimes leidub keelatud tähemärke",
    "{count} {category} found" : "Leidus {count} „{category}“ kategooria"
},
"nplurals=2; plural=(n != 1);");
