OC.L10N.register(
    "app_api",
    {
    "Daemon config not found" : "Конфігурацію демона не знайдено",
    "Error starting install of ExApp" : "Помилка під час встановлення ExApp",
    "ExApp failed to register, check the NC logs" : "ExApp не вдалося зареєструвати, перевірте журнали ЧПК",
    "ExApp not found, failed to get status" : "ExApp не знайдено, не вдалося отримати статус",
    "Error adding Docker registry" : "Помилка додавання реєстру Docker",
    "Error removing Docker registry" : "Помилка видалення реєстру Docker",
    "This app is not installed from the AppStore. No extra information available. Only enable/disable and remove actions are allowed." : "Ця програма не встановлюється з AppStore. Додаткова інформація відсутня. Дозволено лише вмикати/вимикати та видаляти.",
    "Could not perform installation of ExApp" : "Не вдалося виконати інсталяцію ExApp",
    "Failed to enable ExApp" : "Не вдалося увімкнути ExApp",
    "Failed to disable ExApp" : "Не вдалося вимкнути ExApp",
    "Could not update ExApp" : "Не вдалося оновити ExApp",
    "Error starting update of ExApp" : "Помилка запуску оновлення ExApp",
    "Could not perform update of ExApp" : "Не вдалося виконати оновлення ExApp",
    "ExApp not found, failed to get logs" : "ExApp не знайдено, не вдалося отримати журнали",
    "Failed to get container logs. Note: Downloading Docker container works only for containers with the json-file or journald logging driver. Error: %s" : "Не вдалося отримати журнали контейнера. Примітка: Завантаження контейнера Docker працює тільки для контейнерів із драйвером журналювання json-file або journald. Помилка: %s",
    "ExApp not found, failed to get deploy options" : "ExApp не знайдено, не вдалося отримати параметри розгортання",
    "AppAPI authentication failed" : "Не вдалося пройти автентифікацію AppAPI",
    "AppAPI ExApp notifier" : "Сповіщувач AppAPI ExApp",
    "AppAPI" : "AppAPI",
    "AI Integration Team" : "Команда з інтеграції штучного інтелекту",
    "ExApps Settings" : "Налаштування ExApps",
    "AppAPI deploy daemon" : "Демон розгортання AppAPI",
    "AppAPI default deploy daemon is not set. Please register a default deploy daemon in the settings to install External Apps (Ex-Apps)." : "Стандартний демон розгортання AppAPI не встановлено. Будь ласка, зареєструйте стандартний демон розгортання в налаштуваннях, щоб встановити зовнішні програми (Ex-Apps).",
    "AppAPI default deploy daemon \"%s\" is not accessible. Please check the daemon configuration." : "Демон розгортання AppAPI за замовчуванням \"%s\" недоступний. Будь ласка, перевірте конфігурацію демона.",
    "Nextcloud AppAPI" : "Nextcloud AppAPI",
    "External Apps management" : "Керування зовнішніми програмами",
    "Admin options saved" : "Параметри адміністратора збережено",
    "Failed to save admin options" : "Не вдалося зберегти параметри адміністрування",
    "The AppAPI Project is an exciting initiative that aims to revolutionize the way applications are developed for Nextcloud through the use of docker containers. Allowing for greater programming language choice and allowing computationally expensive tasks to be offloaded to a different server." : "Проєкт AppAPI — це цікава ініціатива, яка має на меті революціонізувати спосіб розробки додатків для Nextcloud за допомогою контейнерів Docker. Це розширює вибір мов програмування та дозволяє переносити обчислювально ресурсоємні завдання на інший сервер.",
    "ExApp init timeout (minutes)" : "Тайм-аут ініціалізації ExApp (хвилини)",
    "ExApp initialization process timeout after which AppAPI will mark it as failed" : "Таймаут процесу ініціалізації ExApp, після якого AppAPI позначить його як невдалий",
    "ExApp init timeout" : "Тайм-аут ініціалізації ExApp",
    "ExApp container restart policy" : "Політика перезапуску контейнера ExApp",
    "Cancel" : "Скасувати",
    "Delete" : "Вилучати",
    "Password confirmation failed" : "Не вдалося підтвердити пароль",
    "Default" : "Типово",
    "Set as default" : "Встановлено за замовчуванням",
    "Test deploy" : "Тестове розгортання",
    "Docker registries" : "Реєстри докерів",
    "Edit" : "Редагувати",
    "Daemon connection successful" : "Підключення демона виконано успішно",
    "Unlimited" : "Необмежено",
    "{size} GiB" : "{size} GiB",
    "{size} MiB" : "{size} MiB",
    "Default daemon. ExApps will be installed on it" : "Демон за замовчуванням. На ньому будуть встановлені ExApps",
    "ExApps installed" : "Встановлено ExApps",
    "Name" : "Назва",
    "Protocol" : "Протокол",
    "Host" : "Хост",
    "ExApp direct communication (FRP disabled)" : "Прямий зв'язок з ExApp (FRP вимкнено)",
    "Deploy options" : "Варіанти розгортання",
    "Docker network" : "Докерна мережа",
    "Nextcloud URL" : "URL-адреса наступної хмари",
    "HaProxy password" : "Пароль HaProxy",
    "Memory limit" : "Ліміт пам'яті",
    "CPU limit" : "Обмеження процесора",
    "Additional options" : "Додаткові опції",
    "Check connection" : "Перевірте з'єднання",
    "Registered Deploy daemons list" : "Список зареєстрованих демонів розгортання",
    "Register ExApp in Nextcloud" : "Зареєструйте ExApp у Nextcloud",
    "Check if the ExApp is registered in Nextcloud before deployment" : "Перед розгортанням перевірте, чи зареєстровано ExApp у Nextcloud",
    "Image pull" : "Витягування зображення",
    "Check if the image is successfully pulled" : "Перевірте, чи успішно витягнуто зображення",
    "Container started" : "Контейнер запущено",
    "Check if the image successfully pulled and container is created and started" : "Перевірте, чи успішно витягнуто образ, створено та запущено контейнер",
    "Heartbeat" : "Серцебиття",
    "Check for the heartbeat is finished and healthy" : "Перевірте, чи серцебиття закінчилося і є здоровим",
    "Init step" : "Початковий крок",
    "Wait for initialization step to finish" : "Дочекайтеся завершення кроку ініціалізації",
    "Enabled" : "Увімкнено",
    "Check if ExApp successfully handled the enabled event and registered all stuff properly" : "Перевірте, чи успішно ExApp обробив увімкнену подію та зареєстрував усе належним чином",
    "Only if ExApp container is preset" : "Тільки якщо попередньо встановлено контейнер ExApp",
    "Deploy test passed successfully!" : "Тест на розгортання успішно пройдено!",
    "Deploy test failed at step \"{step}\"" : "Не вдалося виконати тест розгортання на кроці \"{step}\"",
    "More information" : "Докладно",
    "Download ExApp logs" : "Звантажити журнали ExApp",
    "Please enter a registry domain" : "Будь ласка, введіть домен в реєстрі",
    "This registry mapping already exists" : "Таке відображення реєстру вже існує",
    "Docker registry mapping added" : "Додано відображення реєстру докерів",
    "Error adding Docker registry mapping" : "Помилка додавання зіставлення реєстру Docker",
    "Docker registry mapping removed" : "Видалено відображення реєстру докерів",
    "Error removing Docker registry mapping" : "Помилка видалення зіставлення реєстру Docker",
    "Override Docker registries" : "Перевизначення реєстрів Docker",
    "This is useful if you want to use a custom Docker registry, for example, to use a private Docker registry, or to use a different Docker registry for testing." : "Це корисно, якщо ви хочете використовувати власний реєстр Docker, наприклад, для використання приватного реєстру Docker або для використання іншого реєстру Docker для тестування.",
    "Image pull will be skipped" : "Підтягування зображень буде пропущено",
    "Remove" : "Вилучити",
    "Add registry override mapping" : "Додати відображення заміщення реєстру",
    "From" : "Від",
    "registry URL (e.g. ghcr.io)" : "URL-адресу реєстру (наприклад, ghcr.io)",
    "To" : "Кому",
    "registry URL (e.g. docker.io)" : "URL-адресу реєстру (наприклад, docker.io)",
    "Add" : "Додати",
    "The secret key for the HaRP container communication (HP_SHARED_KEY)." : "Секретний ключ для зв'язку з контейнером HaRP (HP_SHARED_KEY).",
    "AppAPI Docker Socket Proxy authentication password" : "Пароль автентифікації AppAPI Docker Socket Proxy",
    "DaemonConfig successfully registered" : "DaemonConfig успішно зареєстровано",
    "Failed to register DaemonConfig. Check the logs" : "Не вдалося зареєструвати DaemonConfig. Перевірте логи",
    "DaemonConfig successfully updated" : "DaemonConfig успішно оновлено",
    "Failed to update DaemonConfig. Check the logs" : "Не вдалося оновити DaemonConfig. Перевірте логи",
    "Failed to connect to Daemon. Check the logs" : "Не вдалося підключитися до Daemon. Перевір журнали.",
    "Failed to check connection to Daemon. Check the logs" : "Не вдалося перевірити з'єднання з Daemon. Перевірте журнали.",
    "Daemon configuration template" : "Шаблон конфігурації демона",
    "Daemon registration form" : "Реєстраційна форма Daemon",
    "Display name" : "Ім'я для показу",
    "Deployment method" : "Спосіб розгортання",
    "HaRP host" : "HaRP хост",
    "Daemon host" : "Носій демона",
    "HaRP shared key" : "Спільний ключ HaRP",
    "Enable HaRP" : "Увімкнути HaRP",
    "FRP server address" : "Адреса сервера FRP",
    "Docker socket proxy port" : "Проксі-порт докерного сокета",
    "Disable FRP" : "Вимкнути FRP",
    "Docker network for ex-app deployment must be defined" : "Необхідно визначити докерну мережу для розгортання ex-app",
    "Compute device" : "Обчислити пристрій",
    "Memory limit (in MiB)" : "Ліміт пам'яті (в Мбайт)",
    "Must be a positive integer" : "Повинно бути натуральним числом",
    "CPU limit as decimal value" : "Обмеження процесора як десяткове значення",
    "Must be a positive number" : "Повинно бути додатнім числом",
    "Add additional option" : "Додати додаткову опцію",
    "Option key (unique)" : "Ключ опції (унікальний)",
    "Option key (unique, e.g. my_key)" : "Ключ опції (унікальний, наприклад, my_key)",
    "Option key is required" : "Потрібен ключ опції",
    "Option value" : "Значення опції",
    "Option value is required" : "Значення опції обов'язкове",
    "Confirm" : "Підтвердити",
    "Save" : "Зберегти",
    "Register" : "Зареєструватися",
    "External Apps" : "Зовнішні застосунки",
    "### Boost your Nextcloud with AppAPI and its specially designed applications.\n\n\nThe AppAPI is a project within the Nextcloud ecosystem designed to streamline and enhance the process of\napplication development, deployment, and management.\n\nIt introduces a new methodology that allows developers to create\napplications using a variety of programming languages, not limited to PHP, which was traditionally used in Nextcloud development.\n\n### Bundled App\n\n**Starting with Nextcloud 30.0.1, this application is included in the default Nextcloud package.**\n\n### Support\n\nWe appreciate any support for this project:\n\n- ⭐ Star our work on GitHub\n- ❗ Create an Issue or feature request\n- 💁 Resolve an Issue and create a Pull Request\n- 🧑‍💻 Develop your own application using AppAPI\n\nWe are genuinely excited about the future of the AppAPI project and its potential to transform\nthe way applications are developed and experienced within Nextcloud.\n\nAs we embark on this journey, we warmly invite you - developers, thinkers, creators, and visionaries -\nto join us in shaping a more versatile, stable, and secure app landscape.\n\n*Your insights, suggestions, and contributions are invaluable to us.*" : "### Покращуйте Nextcloud за допомогою AppAPI та спеціально розроблених додатків.\n\n\nAppAPI — це проект в екосистемі Nextcloud, призначений для оптимізації та вдосконалення процесу\nрозробки, розгортання та управління додатками.\n\nВін запроваджує нову методологію, яка дозволяє розробникам створювати\nдодатки з використанням різних мов програмування, не обмежуючись PHP, який традиційно використовувався в розробці Nextcloud.\n\n### Вбудована програма\n\n**Починаючи з Nextcloud 30.0.1, ця програма входить до стандартного пакету Nextcloud.**\n\n### Підтримка\n\nМи вдячні за будь-яку підтримку цього проєкту:\n\n- ⭐ Поставте зірку нашій роботі на GitHub\n- ❗ Створіть проблему або запит на функцію\n- 💁 Вирішіть проблему та створіть запит на витяг\n- 🧑‍💻 Розробіть власний додаток за допомогою AppAPI\n\nМи щиро радіємо майбутньому проекту AppAPI та його потенціалу змінити\nспосіб розробки та використання додатків у Nextcloud.\n\nПочинаючи цю подорож, ми щиро запрошуємо вас — розробників, мислителів, творців та візіонерів —\nприєднатися до нас у формуванні більш універсального, стабільного та безпечного середовища для додатків.\n\n*Ваші думки, пропозиції та внески є для нас безцінними.*",
    "The AppAPI Project is an exciting initiative that aims to revolutionize the way applications are developed for Nextcloud." : "Проект AppAPI - це захоплююча ініціатива, яка має на меті революціонізувати спосіб розробки додатків для Nextcloud.",
    "Deploy Daemons" : "Розгортання демонів",
    "Deploy Daemon (DaemonConfig) is an ExApps orchestration daemon." : "Демон розгортання (DaemonConfig) - це демон оркестрування ExApps.",
    "Deploy Daemons. Deploy Daemon (DaemonConfig) is an ExApps orchestration daemon." : "Розгортання демонів. Deploy Daemon (DaemonConfig) - це демон оркестрування ExApps.",
    "Default Deploy Daemon is not accessible. Please verify its configuration" : "Демон розгортання за замовчуванням недоступний. Будь ласка, перевірте його конфігурацію",
    "Specify container restart policy, e.g. 'always' to ensure ExApp running after daemon server reboot" : "Вкажіть політику перезапуску контейнера, наприклад, \"завжди\", щоб забезпечити роботу ExApp після перезавантаження сервера демона",
    "This settings changes are reflected only for newly created containers" : "Ці зміни налаштувань відображаються тільки для новостворених контейнерів",
    "{license}-licensed" : "Ліцензія: {license}",
    "Update to {version}" : "Оновити до {version}",
    "Delete data on remove" : "Видалення даних при видаленні",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Цей застосунок не має обмежень щодо мінімальної версії Nextcloud. В майбутньому це може викликати певні помилки.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Для цього застосунку не визначено найвищу версію Nextcloud. Це може викликати помилку в майбутньому.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Цей застосунок не буде встановлено, оскільки такі залежності неможливо виконати:",
    "View in store" : "Переглянути у крамниці застосунків",
    "Visit website" : "Перейти на вебсайт",
    "Report a bug" : "Повідомити про помилку",
    "User documentation" : "Користувацька документація",
    "Admin documentation" : "Документація адміністратора",
    "Developer documentation" : "Документація для розробника",
    "This app is not registered in AppStore. No extra information available. Only enable/disable and remove actions are allowed." : "Ця програма не зареєстрована в AppStore. Додаткова інформація відсутня. Дозволено лише вмикати/вимикати та видаляти дії.",
    "This app is supported via your current Nextcloud subscription." : "Підтримка застосунку через вашу поточну передплату Nextcloud.",
    "Supported" : "Підтримано",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Функціональні застосунки розробляються спільнотою. Вони пропонують основну функціональність і готові до використання у продуктовому середовищі.",
    "Featured" : "Функціональні",
    "Update to {update}" : "Оновити до {update}",
    "All ExApps are up-to-date." : "Всі ExApps оновлені.",
    "Default Deploy daemon is not accessible" : "За замовчуванням демон розгортання недоступний",
    "Icon" : "Значок",
    "Version" : "Версія",
    "Daemon" : "Демон",
    "Level" : "Рівень",
    "Actions" : "Дії",
    "Results from other categories" : "Результати з інших категорій",
    "No apps found" : "Не знайдено жодної програми",
    "_%n ExApp has an update available_::_%n apps have an update available_" : ["%n ExApp має оновлення","%n додатків мають оновлення","%n додатків мають оновлення","%n додатків мають оновлення"],
    "_Update_::_Update all_" : ["Оновити","Оновити все","Оновити все","Оновити все"],
    "Deploy Daemon" : "Розгортання демона",
    "Type" : "Тип",
    "Display Name" : "Назва для показу",
    "GPUs support" : "Підтримка GPU",
    "Are you sure you want delete Deploy Daemon" : "Ви впевнені, що хочете видалити Демон розгортання",
    "All ExApps on this daemon will be removed" : "Усі ExApps на цьому демоні буде видалено",
    "All ExApps installed on this daemon will be removed" : "Всі ExApps, встановлені на цьому демоні, буде видалено",
    "\"manual-install\" Deploy Daemon cannot be set as default" : "\"manual-install\" Демон розгортання не може бути встановлений за замовчуванням",
    "Failed to save admin options. Check the logs" : "Не вдалося зберегти параметри адміністрування. Перевірте логи",
    "Deploy daemon config details" : "Деталі конфігурації демона для розгортання",
    "Manual install daemon usually used for development. It cannot be set as default daemon." : "Демон ручного встановлення, який зазвичай використовується для розробки. Він не може бути встановлений як демон за замовчуванням.",
    "Deploy config" : "Розгортання конфігурації",
    "Verify connection" : "Перевірте з'єднання",
    "No Deploy daemons configured" : "Не налаштовано демонів розгортання",
    "Register a custom one or setup from available templates" : "Зареєструвати власний або налаштувати з доступних шаблонів",
    "Register Daemon" : "Зареєструвати демона",
    "AppAPI will try to install small skeleton ExApp to verify Daemon configured correctly and deployment steps are passing." : "AppAPI спробує встановити невеликий скелет ExApp, щоб переконатися, що демон налаштовано правильно і кроки розгортання пройдено.",
    "The following Deploy test checks must be passed to succeed:" : "Для успішного розгортання необхідно пройти наступні перевірки тесту розгортання:",
    "More info" : "Більше інформації",
    "Remove test ExApp" : "Видалити тестовий ExApp",
    "Start Deploy test" : "Почніть тест на розгортання",
    "Stop Deploy test" : "Тест на зупинку розгортання",
    "ExApp is unregistered and container is removed on \"Stop deploy test\"" : "ExApp скасовано, а контейнер видалено на \"Зупинити тест розгортання\"",
    "Hostname to access ExApps" : "Ім'я хоста для доступу до ExApps",
    "Hostname or path to access Docker daemon (e.g. nextcloud-appapi-dsp:2375, /var/run/docker.sock)" : "Ім'я хоста або шлях до демона Docker (наприклад, nextcloud-appapi-dsp:2375, /var/run/docker.sock)",
    "Daemon with this name already exists" : "Демон з таким ім'ям вже існує",
    "Password must be at least 12 characters long" : "Пароль повинен мати довжину не менше 12 символів",
    "With https enabled network is set to host" : "З увімкненим https мережа налаштована на хост",
    "Changes would be applied only for newly installed ExApps. For existing ExApps, Docker containers should be recreated." : "Зміни будуть застосовані лише до нових встановлених ExApps. Для існуючих ExApps слід перестворити контейнери Docker.",
    "URL should start with http:// or https://" : "URL-адреса повинна починатися з http:// або https://",
    "For HTTPS daemon, Nextcloud URL should be HTTPS" : "Для HTTPS-демона URL-адреса Nextcloud має бути HTTPS",
    "All available GPU devices on daemon host will be requested to be enabled in ExApp containers by Docker." : "Docker попросить увімкнути всі доступні графічні пристрої на хості демона у контейнерах ExApp.",
    "Edit Deploy Daemon" : "Редагування демона розгортання",
    "Register Deploy Daemon" : "Реєстрація Розгортання демона",
    "Select daemon configuration template" : "Виберіть шаблон конфігурації демона",
    "Unique Deploy Daemon Name" : "Унікальне ім'я демона розгортання",
    "Select daemon deploy method" : "Вибір методу розгортання демона",
    "Set daemon as default" : "Встановити демона за замовчуванням",
    "Set as default daemon" : "Встановлюється як демон за замовчуванням",
    "Enable https" : "Увімкнути https",
    "Show deploy config" : "Показати конфігурацію розгортання",
    "Hide deploy config" : "Приховати конфігурацію розгортання",
    "Network" : "Мережа",
    "Docker network name" : "Ім'я докерної мережі",
    "Additional option" : "Додаткова опція",
    "by {author}\n{license}" : "Автор: {author}\n{license}",
    "Your apps" : "Ваші застосунки",
    "Documentation" : "Документація",
    "Details" : "Деталі",
    "Changelog" : "Зміни",
    "Active apps" : "Активні застосунки",
    "Disabled apps" : "Неактивні застосунки",
    "Updates" : "Оновлення",
    "Featured apps" : "Функціональне",
    "Supported apps" : "Застосунки, що підтримуються",
    "manual-install apps cannot be updated" : "програми, встановлені вручну, не можуть бути оновлені",
    "{progress}% Deploying" : "{progress}% Розгортання",
    "{progress}% Initializing" : "{progress}% Ініціалізація",
    "Healthchecking" : "Перевірка здоров'я",
    "Deploy and Enable" : "Розгортання та активація",
    "Enable" : "Увімкнути",
    "Disable" : "Вимкнути",
    "Allow untested app" : "Дозволити непротестовані застосунки",
    "Default Deploy daemon is not accessible. Please verify configuration" : "За замовчуванням демон розгортання недоступний. Будь ласка, перевірте конфігурацію",
    "The app will be downloaded from the App Store and deployed on default Deploy Daemon" : "Додаток буде завантажено з App Store і розгорнуто за допомогою демона розгортання за замовчуванням",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Відсутня інформація щодо підтримки цього застосунку вашою версією Nextcloud. Ви зможете встановити цей застосунок, проте він може працювати не так, як ви очікуєте.",
    "Your ExApps" : "Ваші колишні програми",
    "An error occurred during the request. Unable to proceed." : "Під час запиту сталася помилка. Неможливо продовжити.",
    "The app has been enabled but needs to be updated." : "Додаток увімкнено, але його потрібно оновити.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Помилка: цей застосунок неможливо увімкнути, оскільки він робить сервер нестабільним",
    "### Boost your Nextcloud with AppAPI and its specially designed applications.\n\n\nThe AppAPI is a project within the Nextcloud ecosystem designed to streamline and enhance the process of\napplication development, deployment, and management.\n\nIt introduces a new methodology that allows developers to create\napplications using a variety of programming languages, not limited to PHP, which was traditionally used in Nextcloud development.\n\n\n### List of applications that require AppAPI:\n\n- [talk_bot_ai_example](https://github.com/cloud-py-api/talk_bot_ai_example)\n- [upscaler_example](https://github.com/cloud-py-api/upscaler_example)\n- [image_to_text_example](https://github.com/cloud-py-api/file_to_text_example)\n- [ai_image_generator_bot](https://github.com/cloud-py-api/ai_image_generator_bot)\n- [SummarAI](https://github.com/nextcloud/sumupbot)\n\n_If you wish to develop an application, we will gladly help and assist you._\n\n### Support\n\nWe appreciate any support for this project:\n\n- ⭐ Star our work on GitHub\n- ❗ Create an Issue or feature request\n- 💁 Resolve an Issue and create a Pull Request\n- 🧑‍💻 Develop your own application using AppAPI\n\nWe are genuinely excited about the future of the AppAPI project and its potential to transform\nthe way applications are developed and experienced within Nextcloud.\n\nAs we embark on this journey, we warmly invite you - developers, thinkers, creators, and visionaries -\nto join us in shaping a more versatile, stable, and secure app landscape.\n\n*Your insights, suggestions, and contributions are invaluable to us.*" : "### Покращуйте Nextcloud за допомогою AppAPI та спеціально розроблених додатків.\n\n\nAppAPI — це проект в екосистемі Nextcloud, призначений для оптимізації та вдосконалення процесу\nрозробки, розгортання та управління додатками.\n\nВін запроваджує нову методологію, яка дозволяє розробникам створювати\nдодатки з використанням різних мов програмування, не обмежуючись PHP, який традиційно використовувався в розробці Nextcloud.\n\n\n### Список додатків, які вимагають AppAPI:\n\n- [talk_bot_ai_example](https://github.com/cloud-py-api/talk_bot_ai_example)\n- [upscaler_example](https://github.com/cloud-py-api/upscaler_example)\n- [image_to_text_example](https://github.com/cloud-py-api/file_to_text_example)\n- [ai_image_generator_bot](https://github.com/cloud-py-api/ai_image_generator_bot)\n- [SummarAI](https://github.com/nextcloud/sumupbot)\n\n_Якщо ви бажаєте розробити додаток, ми з радістю допоможемо вам._\n\n### Підтримка\n\nМи вдячні за будь-яку підтримку цього проєкту:\n\n- ⭐ Поставте зірку нашій роботі на GitHub\n- ❗ Створіть проблему або запит на функцію\n- 💁 Вирішіть проблему та створіть запит на витяг\n- 🧑‍💻 Розробіть власний додаток за допомогою AppAPI\n\nМи щиро радіємо майбутньому проекту AppAPI та його потенціалу змінити\nспосіб розробки та використання додатків у Nextcloud.\n\nПочинаючи цю подорож, ми щиро запрошуємо вас — розробників, мислителів, творців та візіонерів —\nприєднатися до нас у формуванні більш універсального, стабільного та безпечного середовища для додатків.\n\n*Ваші думки, пропозиції та внески є для нас безцінними.*"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
