OC.L10N.register(
    "app_api",
    {
    "Cancel" : "Скасаваць",
    "Delete" : "Выдаліць",
    "Default" : "Прадвызначаныя",
    "Edit" : "Рэдагаваць",
    "Name" : "Назва",
    "Host" : "Хост",
    "Nextcloud URL" : "URL-адрас NextCloud",
    "Enabled" : "Уключаны",
    "More information" : "Больш інфармацыі",
    "Remove" : "Выдаліць",
    "From" : "Ад",
    "To" : "Да",
    "Add" : "Дадаць",
    "Display name" : "Імя для паказу",
    "Enable HTTPS" : "Уключыць HTTPS",
    "Confirm" : "Пацвердзіць",
    "Save" : "Захаваць",
    "Update to {version}" : "Абнавіць да {version}",
    "Delete data on remove" : "Ачысціць даныя пры выдаленні",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Гэтай праграме не прызначана мінімальная версія Nextcloud. У будучыні гэта будзе памылкай.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Гэтай праграме не прызначана максімальная версія Nextcloud. У будучыні гэта будзе памылкай.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Гэта праграма не можа быць усталявана, бо не выкананы наступныя залежнасці:",
    "Visit website" : "Наведаць вэб-сайт",
    "Report a bug" : "Паведаміць пра памылку",
    "Update to {update}" : "Абнавіць да {update}",
    "Icon" : "Значок",
    "Version" : "Версія",
    "Level" : "Узровень",
    "Actions" : "Дзеянні",
    "Results from other categories" : "Вынікі з іншых катэгорый",
    "_Update_::_Update all_" : ["Абнавіць","Абнавіць усе","Абнавіць усе","Абнавіць усе"],
    "Type" : "Тып",
    "Display Name" : "Імя для паказу",
    "Your apps" : "Вашы праграмы",
    "Documentation" : "Дакументацыя",
    "Details" : "Падрабязнасці",
    "Active apps" : "Актыўныя праграмы",
    "Disabled apps" : "Адключаныя праграмы",
    "Updates" : "Абнаўленні",
    "Featured apps" : "Папулярныя праграмы",
    "Supported apps" : "Праграмы, якія падтрымліваюцца",
    "Enable" : "Уключыць",
    "Disable" : "Адключыць",
    "Allow untested app" : "Дазволіць неправераную праграму",
    "An error occurred during the request. Unable to proceed." : "Падчас запыту адбылася памылка. Не ўдалося працягнуць.",
    "The app has been enabled but needs to be updated." : "Праграма ўключана, але патрабуе абнаўлення."
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
