OC.L10N.register(
    "circles",
    {
    "Personal" : "Personal",
    "System" : "Systema",
    "Visible" : "Visibile",
    "Password protected" : "Protegite per contrasigno",
    "Hidden" : "Occultate",
    "Local" : "Local",
    "Root" : "Root",
    "Federated" : "Federated",
    "Owner" : "Owner",
    "Accept" : "Acceptar",
    "File is too big" : "File es troppo grande",
    "Invalid image" : "Imagine invalide",
    "Unknown filetype" : "Typo de file incognite",
    "%s" : "%s",
    "Unlimited" : "Ilimitate",
    "Default quota" : "Quota predefinite",
    "Save" : "Save",
    "Connect" : "Connecter se",
    "Members" : "Membros",
    "Cancel" : "Cancel",
    "Next" : "Proxime",
    "Folder" : "Dossier",
    "you" : "Tu",
    "Copy link" : "Copiar ligamine",
    "Close" : "Clauder",
    "New folder" : "Nove dossier",
    "Folder name" : "Nomine de dossier",
    "Calendar" : "Calendario",
    "New calendar" : "Nove calendario",
    "Description" : "Description",
    "Edit" : "Modificar",
    "Apply" : "Applicar",
    "Pending" : "Pendente",
    "Go back" : "Retornar",
    "Loading…" : "Cargante...",
    "User" : "User",
    "Group" : "Gruppo",
    "Federation" : "Federation",
    "Users" : "Usatores",
    "Groups" : "Gruppos",
    "No files in here" : "Nulle files ci",
    "No entries found in this folder" : "Nulle entratas trovate in iste dossier",
    "Name" : "Nomine",
    "Size" : "Dimension",
    "Modified" : "Modificate"
},
"nplurals=2; plural=(n != 1);");
