OC.L10N.register(
    "circles",
    {
    "You deleted {circle}" : "Borraste el círculo {circle}",
    "{author} deleted {circle}" : "{author} borró {circle}",
    "You removed {member} from {circle}" : "Eliminaste a {member} de {circle}",
    "You joined {circle}" : "Te uniste a {circle}",
    "{member} joined {circle}" : "{member} se unió a {circle}",
    "You accepted the invitation to join {circle}" : "Aceptaste la invitación para unirte a {cirlce}",
    "{member} accepted the invitation to join {circle}" : "{member} aceptó la inivtación para unirse a {circle}",
    "You added {member} as member to {circle}" : "Agregaste a {member} como miembro de {circle}",
    "You have been added as member to {circle} by {author}" : "Has sido agregado como miembro de {circle} por {author}",
    "{member} has been added as member to {circle} by {author}" : "{member} ha sido agregado como un miembro de {circle} por {author}",
    "You added {external} to {circle}" : "Agregaste a {external} a {circle}",
    "{external} has been added to {circle} by {author}" : "{external} ha sido agregado a {circle} por {author}",
    "You accepted {member}'s request to join {circle}" : "Aceptaste la solicitud de {member} para unirse a {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Tu solicitud para unirte a {circle} ha sido aceptada por {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "La solicitud de {member} para unirse  a {circle} ha sido aceptada por {author}",
    "You left {circle}" : "Dejaste el {circle}",
    "{member} left {circle}" : "{member} dejó {circle}",
    "You declined the invitation to join {circle}" : "Declinaste la invitacion a unirte a {circle}",
    "{member} declined an invitation to join {circle}" : "{member} declinó la invitación para unirse a {cricle}",
    "You cancelled your request to join {circle}" : "Cancelaste tu solicitud para unirte a {cricle}",
    "You have been removed from {circle} by {author}" : "Has sido eliminado de {circle} por {author}",
    "{member} has been removed from {circle} by {author}" : "{member} ha sido eliminado de {circle} por {author}",
    "You removed {external} from {circle}" : "Eliminaste a {external} de {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} ha sido eliminado de {circle} por {autor}",
    "You cancelled {member}'s invitation to join {circle}" : "Cancelaste la invitación de {member} para unirse a {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "Tu invitación para unirte a {circle} ha sido cancelada por {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} canceló la invitación de {member} para unirse a {crcle}",
    "You dismissed {member}'s request to join {circle}" : "Descartaste la solicitud de {member} para unirse a {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "Tu solicitud para unirte a {circle} fue descartada por {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "La solicitud de {member} para unirse a {circle} ha sido descartada por {author}",
    "You invited {member} to join {circle}" : "Invitaste a {member} a unirse a {circle}",
    "You have been invited to join {circle} by {author}" : "{author} te ha invitado a unirte a {circle}",
    "{member} has been invited to join {circle} by {author}" : "{member} fue invitado a unirse a {circle} por {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Cambiaste el nivel de {member} en el círculo a %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} cambió tu nivel en {circle} a %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} cambió el nivel de {member} en {circle}  a %1$s",
    "You sent a request to join {circle}" : "Enviaste una solicitud para unirte a {circle}",
    "{member} sent a request to join {circle}" : "{member} envió una solicitud para unirse a {circle}",
    "You are the new owner of {circle}" : "Eres el nuevo dueño de {circle}",
    "{member} is the new owner of {circle}" : "{member} es el nuevo dueño de {circle}",
    "Single" : "Individual",
    "Personal" : "Personal",
    "System" : "Sistema",
    "Visible" : "Visible",
    "Open" : "Abrir",
    "Invite" : "Invitar",
    "Friends" : "Amigos",
    "Password protected" : "Protegido con contraseña",
    "No Owner" : "Sin propietario",
    "Hidden" : "Oculto",
    "Backend" : "Backend",
    "Local" : "Local",
    "Root" : "Raíz",
    "Federated" : "Federado",
    "Mount point" : "Punto de montaje",
    "App" : "Aplicación",
    "Nextcloud Account" : "Cuenta de Nextcloud",
    "Nextcloud Group" : "Grupo de Nextcloud",
    "Email address" : "Dirección de correo electrónico",
    "Contact" : "Contacto",
    "Nextcloud App" : "Aplicación de Nextcloud",
    "Member" : "Miembro",
    "Moderator" : "Moderador",
    "Admin" : "Administrador",
    "Owner" : "Dueño",
    "%s shared »%s« with you." : "%s compartió »%s« contigo.",
    "%s shared »%s« with \"%s\"." : "%s compartió «%s» contigo.",
    "%s on %s" : "%s en %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s compartió «%2$s» contigo.\n      Deberías haber recibido un correo electrónico por separado con un enlace para acceder a él.\n      ",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%s compartió »%s« contigo. Deberías haber recibido un correo electrónico por separado con un enlace para acceder a él.",
    "Password to access »%1$s« shared to you by %2$s" : "Contraseña para acceder a »%1$s« compartida contigo por %2$s",
    "Password to access »%s«" : "Contraseña para acceder  »%s«",
    "It is protected with the following password:" : "Está protegido con la siguiente contraseña:",
    "%1$s via %2$s" : "%1$s a través de %2$s",
    "Click the button below to open it." : "Haz click en el botón para abrirlo.",
    "Open »%s«" : "Abrir »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s compartió varios archivos contigo.\n      Deberías haber recibido un correo electrónico por separado con un enlace para acceder a ellos.\n      ",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s compartió varios archivos contigo. Deberías haber recibido un correo electrónico por separado con un enlace para acceder a ellos.",
    "Password to access files shared to you by %1$s" : "Contraseña para acceder a los archivos compartidos contigo por %1$s",
    "Password to access files" : "Contraseña para acceder a los archivos",
    "%s shared multiple files with \"%s\"." : "%s compartió varios archivos con \"%s\".",
    "%s shared multiple files with you." : "%s compartió varios archivos contigo.",
    "Boot up" : "Inicio",
    "Nextcloud Initialization" : "Inicialización de Nextcloud",
    "Fresh installation status" : "Estado de instalación nueva",
    "Building Local Database" : "Creando la base de datos local",
    "Adding local users and moderators" : "Agregando usuarios locales y moderadores",
    "Files" : "Archivo",
    "This member is not a moderator" : "Este miembro no es un moderador",
    "Insufficient privileges" : "Privilegios insuficientes",
    "This member does not exist" : "Este miembro no existe",
    "Level cannot be changed for this type of member" : "El nivel no puede ser cambiado para este tipo de miembro",
    "Accept" : "Aceptar",
    "Refuse" : "Rechazar",
    "No image file provided" : "No se proporcionó un archivo de imagen",
    "Invalid file provided" : "Archivo proporcionado inválido",
    "File is too big" : "El archivo es demasiado grande.",
    "Invalid image" : "Imagen inválida",
    "Unknown filetype" : "Tipo de archivo desconocido",
    "%s" : "%s",
    "%s owned by %s" : "%s propiedad de %s",
    "%s shared a file with \"%s\"." : "%s compartió un archivo con \"%s\".",
    "%s shared a file with you." : "%s compartió un archivo contigo.",
    "Open %s" : "Abrir %s",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s compartió contenido contigo.\n      Deberías haber recibido un correo electrónico por separado con un enlace para acceder a él.\n      ",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s compartió contenido contigo. Deberías haber recibido un correo electrónico por separado con un enlace para acceder a él.",
    "Password to access content shared with you by %1$s" : "Contraseña para acceder al contenido compartido contigo por %1$s",
    "Password to access content" : "Contraseña para acceder al contenido",
    "Bring cloud-users closer together." : "Acerca a los usuarios de la nube.",
    "https://…" : "https://…",
    "Unlimited" : "Ilimitado",
    "Default quota" : "Cuota predeterminada",
    "Select default quota" : "Seleccionar cuota predeterminada",
    "Save" : "Save",
    "Reconnect" : "Reconectar",
    "Connect" : "Conectar",
    "Overview" : "Generalidades",
    "Members" : "Miembros",
    "Cancel" : "Cancel",
    "Back" : "Regresar",
    "Team name" : "Nombre del equipo",
    "Switch to list view" : "Cambiar a vista de lista",
    "Folder" : "Carpeta",
    "you" : "tú",
    "Copy link" : "Copiar liga",
    "Copied" : "Copiado",
    "Create link" : "Crear enlace",
    "Close" : "Cerrar",
    "New folder" : "Carpeta nueva",
    "Folder name" : "Nombre de la carpeta",
    "Talk conversation" : "Conversación de Talk",
    "Conversation name" : "Nombre de la conversación",
    "Calendar" : "Calendario",
    "New calendar" : "Nuevo calendario",
    "Please select a valid png or jpg file" : "Selecciona un archivo válido PNG o JPG",
    "Description" : "Descripción",
    "Edit" : "Editar",
    "Create" : "Crear",
    "Show in Calendar" : "Mostrar en el calendario",
    "Add" : "Agregar",
    "Apply" : "Aplicar",
    "Remove {type}" : "Eliminar {type}",
    "Search {types}" : "Buscar {types}",
    "No results" : "No hay resultados",
    "Add {type}" : "Añadir {type}",
    "Pending" : "Pendiente",
    "Role" : "Rol",
    "Add to {team}" : "Agregar a {team}",
    "Try again" : "Reintentar",
    "Loading" : "Cargando",
    "Go back" : "Regresar",
    "Join" : "Unirse",
    "Loading…" : "Cargando",
    "Recently contacted" : "Recientemente contactado",
    "User" : "Usuario",
    "Group" : "Grupo",
    "Federation" : "Federación",
    "Users" : "Usuarios",
    "groups" : "grupos",
    "Groups" : "Grupos",
    "Email addresses" : "Correos electrónicos",
    "No files in here" : "No hay archivos aquí",
    "No entries found in this folder" : "No se encontraron elementos en esta carpeta",
    "Name" : "Nombre",
    "Size" : "Tamaño",
    "Modified" : "Modificado",
    "Circles App Initialization" : "Inicialización de la aplicación Círculos"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
