OC.L10N.register(
    "provisioning_api",
    {
    "Logged in account must be an administrator or have authorization to edit this setting." : "登录的账号必须是管理员或有权编辑此设置。",
    "Could not create non-existing user ID" : "无法创建不存在的用户 ID",
    "User already exists" : "用户已存在",
    "Group %1$s does not exist" : "组 %1$s 不存在",
    "Insufficient privileges for group %1$s" : "组 %1$s 的权限不足",
    "No group specified (required for sub-admins)" : "未指定组（子管理员需要）",
    "Sub-admin group does not exist" : "子管理员组不存在",
    "Cannot create sub-admins for admin group" : "无法为管理员组创建子管理员",
    "No permissions to promote sub-admins" : "没有提升子管理员的权限",
    "Invalid password value" : "密码值无效",
    "An email address is required, to send a password link to the user." : "需要电子邮件地址，以将密码链接发送给用户。",
    "Required email address was not provided" : "未提供所需的电子邮件地址",
    "User creation failed" : "用户创建失败",
    "Cannot change display name for this user" : "无法更改此用户的显示名称",
    "Invalid email address" : "无效电子邮箱地址",
    "Language change is not allowed on this instance" : "此实例不允许更改语言",
    "Invalid language" : "语言无效",
    "Insufficient permissions to change quota" : "权限不足，无法更改配额",
    "Insufficient permissions to change groups" : "权限不足，无法更改组",
    "Group %s does not exist" : "组 %s 不存在",
    "Insufficient permissions to change sub-admin groups" : "权限不足，无法更改子管理员组",
    "Insufficient permissions to change manager" : "权限不足，无法更改管理者",
    "Invalid quota value: %1$s" : "配额值无效：%1$s",
    "Invalid quota value. %1$s is exceeding the maximum quota" : "配额值无效。%1$s 超过了最大配额",
    "Unlimited quota is forbidden on this instance" : "此实例上禁止无限配额",
    "Setting the password is not supported by the users backend" : "用户后端不支持设置密码",
    "Invalid locale" : "区域设置无效",
    "Invalid timezone" : "时区无效",
    "Invalid first day of week" : "一周的第一天无效",
    "Cannot remove yourself from the admin group" : "无法将自己从管理员组中移除",
    "Cannot remove yourself from this group as you are a sub-admin" : "无法将自己从此组中移除，因为您是子管理员",
    "Not viable to remove user from the last group you are sub-admin of" : "无法从您作为子管理员的最后一个组中移除用户",
    "User does not exist" : "用户不存在",
    "Group does not exist" : "组不存在",
    "User is not a sub-admin of this group" : "用户不是此组的子管理员",
    "Email address not available" : "电子邮件地址不可用",
    "Sending email failed" : "发送电子邮件失败",
    "Logged in account is not mail address owner" : "登录账号并非邮件地址所有者",
    "Email confirmation" : "电子邮件确认",
    "To enable the email address %s please click the button below." : "要启用电子邮件地址 %s 请点击下方按钮。",
    "Confirm" : "确认",
    "Email was already removed from account and cannot be confirmed anymore." : "电子邮件已从帐户中删除，无法再确认。",
    "Could not verify mail because the token is expired." : "无法验证邮件，因为令牌已过期",
    "Could not verify mail because the token is invalid." : "无法验证邮件，因为令牌无效",
    "An unexpected error occurred. Please contact your admin." : "发生意外错误。请联系系统管理员",
    "Email confirmation successful" : "电子邮件确认成功",
    "Provisioning API" : "供应 API",
    "This application enables a set of APIs that external systems can use to manage accounts, groups and apps." : "此应用程序启用了一组 API，外部系统可以使用这些 API 来管理账号、组和应用。",
    "This application enables a set of APIs that external systems can use to create, edit, delete and query account\n\t\tattributes, query, set and remove groups, set quota and query total storage used in Nextcloud. Group admin accounts\n\t\tcan also query Nextcloud and perform the same functions as an admin for groups they manage. The API also enables\n\t\tan admin to query for active Nextcloud applications, application info, and to enable or disable an app remotely.\n\t\tOnce the app is enabled, HTTP requests can be used via a Basic Auth header to perform any of the functions\n\t\tlisted above. More information is available in the Provisioning API documentation, including example calls\n\t\tand server responses." : "此应用程序启用了一组 API，外部系统可以使用这些 API 创建、编辑、删除和查询账号\n\t\t属性，查询、设置和移除组，设置配额和查询 Nextcloud 中使用的总存储量。组管理员账号\n\t\t还可以查询 Nextcloud，并为其管理的组执行与管理员相同的功能。API 还允许\n\t\t管理员查询活动的 Nextcloud 应用程序、应用程序信息，并远程启用或禁用应用程序。\n\t\t启用了应用程序后，可以通过基本身份验证标头使用 HTTP 请求来执行\n\t\t上方列出的任何功能。更多信息，可在供应 API 文档中获得，包括示例调用\n\t\t和服务器响应。"
},
"nplurals=1; plural=0;");
