import{t as s}from"./preload-helper-B5suVMXI.chunk.mjs";import{z as i,i as a}from"./index-jVniDJU4.chunk.mjs";import{e,n}from"./icons-Du8Q1knx.chunk.mjs";const r={name:"HeaderNavigation",components:{ArrowLeft:e,NcButton:a,NcLoadingIcon:i},inheritAttrs:!1,props:{loading:{type:Boolean,default:!1},path:{type:String,default:"/"},title:{type:String,required:!0},rootTitle:{type:String,default:s("photos","Photos")}},computed:{isRoot(){return this.path==="/"},name(){return this.isRoot?this.rootTitle:this.title}},methods:{folderUp(){this.$router.push(this.$route.path.split("/").slice(0,-1).join("/"))},refresh(){this.$emit("refresh")},t:s}};var l=function(){var t=this,o=t._self._c;return o("div",{staticClass:"photos-navigation",class:{"photos-navigation--root":t.isRoot},attrs:{role:"toolbar"}},[t.isRoot?t._e():o("NcButton",{staticClass:"photos-navigation__back",attrs:{"aria-label":t.t("photos","Go back"),variant:"tertiary"},on:{click:t.folderUp},scopedSlots:t._u([{key:"icon",fn:function(){return[o("ArrowLeft",{attrs:{size:20}})]},proxy:!0}],null,!1,1821202730)}),o("div",{staticClass:"photos-navigation__title"},[o("h1",{staticClass:"photos-navigation__title__main",on:{click:t.refresh}},[t._v(" "+t._s(t.name)+" ")]),o("div",{staticClass:"photos-navigation__title__sub"}),t._t("subtitle")],2),o("div",{staticClass:"photos-navigation__content"},[t.$slots.default?o("div",{staticClass:"photos-navigation__content__left"},[t._t("default")],2):t._e(),o("NcLoadingIcon",{directives:[{name:"show",rawName:"v-show",value:t.loading,expression:"loading"}],staticClass:"photos-navigation__loader"}),o("div",{staticClass:"photos-navigation__content__right"},[t._t("right")],2)],1)],1)},c=[],h=n(r,l,c,!1,null,"dee91203");const u=h.exports;export{u as H};
//# sourceMappingURL=HeaderNavigation-BZeSRu1V.chunk.mjs.map
