OC.L10N.register(
    "settings",
    {
    "{actor} added you to group {group}" : "{actor} bætti þér við hópinn {group}",
    "You added {user} to group {group}" : "Þú bættir {user} við hópinn {group}",
    "{actor} added {user} to group {group}" : "{actor} bætti {user} við hópinn {group}",
    "An administrator added you to group {group}" : "Stjórnandi bætti þér við hópinn {group}",
    "An administrator added {user} to group {group}" : "Stjórnandi bætti {user} við hópinn {group}",
    "{actor} removed you from group {group}" : "{actor} fjarlægði þig úr hópnum {group}",
    "You removed {user} from group {group}" : "Þú fjarlægðir {user} úr hópnum {group}",
    "{actor} removed {user} from group {group}" : "{actor} fjarlægði {user} úr hópnum {group}",
    "An administrator removed you from group {group}" : "Stjórnandi fjarlægði þig úr hópnum {group}",
    "An administrator removed {user} from group {group}" : "Stjórnandi fjarlægði {user} úr hópnum {group}",
    "Your <strong>group memberships</strong> were modified" : "<strong>Hópaheimildum</strong> þínum var breytt",
    "{actor} changed your password" : "{actor} breytti lykilorðinu þínu",
    "You changed your password" : "Þú breyttir lykilorðinu þínu",
    "Your password was reset by an administrator" : "Kerfisstjóri breytti lykilorðinu þínu",
    "Your password was reset" : "Lykilorðið þitt hefur verið endursett",
    "{actor} changed your email address" : "{actor} breytti tölvupóstfanginu þínu",
    "You changed your email address" : "Þú breyttir tölvupóstfanginu þínu",
    "Your email address was changed by an administrator" : "Kerfisstjóri breytti tölvupóstfanginu þínu",
    "You created an app password for a session named \"{token}\"" : "Þú bjóst til forritslykilorð fyrir setu sem kallast \"{token}\"",
    "An administrator created an app password for a session named \"{token}\"" : "Stjórnandi bjó til forritslykilorð fyrir setu sem kallast \"{token}\"",
    "You deleted app password \"{token}\"" : "Þú eyddir forritslykilorðinu \"{token}\"",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Þú endurnefndir forritslykilorðið \"{token}\" sem \"{newToken}\"",
    "You granted filesystem access to app password \"{token}\"" : "Þú veittir forritslykilorðinu \"{token}\" aðgang að skráakerfinu",
    "You revoked filesystem access from app password \"{token}\"" : "Þú afturkallaðir aðgang að skráakerfinu á forritslykilorðinu \"{token}\"",
    "Security" : "Öryggi",
    "You successfully logged in using two-factor authentication (%1$s)" : "Þér tókst að skrá þig inn með tveggja-þrepa auðkenningu (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Innskráning með tveggja-þrepa auðkenningu mistókst (%1$s)",
    "Remote wipe was started on %1$s" : "Fjartengd útþurrkun var hafin á %1$s",
    "Remote wipe has finished on %1$s" : "Fjartengdri útþurrkun er lokið á %1$s",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Breyting hefur orðið á <strong>lykilorði</strong> eða <strong>tölvupóstfangi</strong> þínu",
    "Wrong password" : "Rangt lykilorð",
    "Unable to change personal password" : "Ekki tókst að breyta persónulegu lykilorði",
    "Saved" : "Vistað",
    "No Login supplied" : "Ekkert innskráningarnafn gefið",
    "Unable to change password" : "Ekki tókst að breyta lykilorði",
    "Unable to change password. Password too long." : "Ekki tókst að breyta lykilorði. Lykilorðið er of langt.",
    "Authentication error" : "Villa við auðkenningu",
    "Please provide an admin recovery password; otherwise, all account data will be lost." : "Settu inn endurheimtulykilorð kerfisstjóra, annars munu öll gögn aðgangsins tapast.",
    "Wrong admin recovery password. Please check the password and try again." : "Rangt endurheimtulykilorð kerfisstjóra, athugaðu lykilorðið og reyndu aftur.",
    "Backend does not support password change, but the encryption of the account key was updated." : "Bakendi styður ekki breytingu á lykilorði, en það tókst að uppfæra dulritunarlykil aðgangsins.",
    "Administrator documentation" : "Hjálparskjöl stjórnanda",
    "User documentation" : "Hjálparskjöl notenda",
    "Nextcloud help overview" : "Efnisyfirlit Nextcloud-hjálpar",
    "Invalid SMTP password." : "Ógilt SMTP-lykilorð",
    "Email setting test" : "Prófa tölvupóststillingar",
    "Well done, %s!" : "Vel gert, %s!",
    "If you received this email, the email configuration seems to be correct." : "Fyrst að þú fékkst þennan tölvupóst, þá lítur út fyrir að tölvupóstuppsetningin sé í lagi.",
    "Email could not be sent. Check your mail server log" : "Ekki var hægt að senda póst. Skoðaðu annál póstþjónsins",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Vandamál kom upp við að senda tölvupóst. Farðu yfir stillingarnar þínar. (Villa: %s)",
    "You need to set your account email before being able to send test emails. Go to %s for that." : "Þú verður að gefa upp tölvupóstfang aðgangsins þíns svo að þú getir sent prófunarpósta. Farðu á %s til þess.",
    "Recently active" : "Nýlega virkir",
    "Disabled accounts" : "Óvirkir aðgangar",
    "Settings" : "Stillingar",
    "Invalid account" : "Ógildur aðgangur",
    "Invalid mail address" : "Ógilt tölvupóstfang",
    "Settings saved" : "Stillingar vistaðar",
    "Unable to change full name" : "Get ekki breytt fullu nafni",
    "Unable to change email address" : "Get ekki breytt tölvupóstfangi",
    "Unable to set invalid phone number" : "Get ekki sett ógilt símanúmer",
    "Unable to set invalid website" : "Get ekki sett ógilt vefsvæði",
    "Some account data was invalid" : "Sum gögn aðgangsins voru ógild",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Til að sannprófa Twitter-aðganginn þinn, sendu þá eftirfarandi tíst á Twitter (gakktu úr skugga um að skeytinu sé ekki skipt í línur):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Til að sannprófa vefsvæðið þitt, vistaðu eftirfarandi efni á vefrótinni þinni (web-root) á '.well-known/CloudIdVerificationCode.txt' (gakktu úr skugga um að allur textinn sé í einni línu):",
    "%1$s changed your password on %2$s." : "%1$s breytti lykilorðinu þínu á %2$s.",
    "Your password on %s was changed." : "Lykilorðinu þínu á %s hefur verið breytt.",
    "Your password on %s was reset by an administrator." : "Kerfisstjóri breytti lykilorðinu þínu á %s.",
    "Your password on %s was reset." : "Lykilorðinu þínu á %s hefur verið breytt.",
    "Password for %1$s changed on %2$s" : "Lykilorð fyrir %1$s breyttist %2$s",
    "Password changed for %s" : "Lykilorð breyttist fyrir %s",
    "If you did not request this, please contact an administrator." : "Ef þú baðst ekki um þetta, hafðu þá samband við kerfisstjóra.",
    "Your email address on %s was changed." : "Tölvupóstfanginu þínu á %s var breytt.",
    "Your email address on %s was changed by an administrator." : "Kerfisstjóri breytti tölvupóstfanginu þínu á %s.",
    "Email address for %1$s changed on %2$s" : "Lykilorð fyrir %1$s breyttist þann %2$s",
    "Email address changed for %s" : "Tölvupóstfang breyttist fyrir %s",
    "The new email address is %s" : "Nýja tölvupóstfangið er %s",
    "Appearance and accessibility" : "Útlit og aðgengi",
    "Personal settings" : "Persónulegar stillingar",
    "Administration settings" : "Stillingar stjórnunar",
    "Accounts" : "Notandaaðgangar",
    "Help & privacy" : "Aðstoð og gagnaleynd",
    "Your %s account was created" : "%s notandaaðgangurinn þinn var búinn til",
    "Welcome aboard" : "Velkomin um borð",
    "Welcome aboard %s" : "Velkomin um borð %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Velkomin(n) í %s aðganginn þinn; þú getur bætt við, varið og deilt gögnunum þínum.",
    "Your Login is: %s" : "Innskráningarnafnið þitt er: %s",
    "Set your password" : "Stilltu lykilorðið þitt",
    "Go to %s" : "Farðu í %s",
    "Install Client" : "Setja upp biðlaraforrit",
    "Personal" : "Einka",
    "Administration" : "Stjórnun",
    "Users" : "Notendur",
    "Additional settings" : "Valfrjálsar stillingar",
    "Assistant" : "Meðhjálpari",
    "Administration privileges" : "Kerfisstjórnunarheimildir",
    "Groupware" : "Hópvinnukerfi",
    "Office" : "Skrifstofa",
    "Overview" : "Yfirlit",
    "Basic settings" : "Grunnstillingar",
    "Sharing" : "Deiling",
    "Availability" : "Aðgengileiki",
    "Calendar" : "Dagatal",
    "Personal info" : "Persónulegar upplýsingar",
    "Mobile & desktop" : "Farsímar og borðtölvur",
    "Artificial Intelligence" : "Gervigreind",
    "Email server" : "Póstþjónn",
    "Mail Providers" : "Þjónustuveitur",
    "Send emails using" : "Senda tölvupósta með",
    "User's email account" : "Tölvupóstaðgangi notanda",
    "System email account" : "Tölvupóstaðgangi kerfisins",
    "Security & setup checks" : "Prófanir á öryggi og uppsetningu",
    "Background jobs" : "Verk í bakgrunni",
    "Unlimited" : "ótakmörkuðu",
    "Verifying" : "Sannreyni",
    "Verifying …" : "Sannreyni …",
    "Verify" : "Sannreyna",
    "Allowed admin IP ranges" : "Leyfð svið IP-vistfanga stjórnenda",
    "Admin IP filtering is correctly configured." : "Síun IP-vistfanga stjórnenda er rétt stillt.",
    "App directories owner" : "Eigandi forritamappa",
    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:\n%s" : "Sumar forritamöppur eru í eigu annarra notenda en möppurnar á vefþjóninum. Þetta getur komið upp ef forritin hafa verið sett upp handvirkt. Athugaðu með heimildir á eftirfarandi forritamöppum:\n%s",
    "App directories have the correct owner \"%s\"" : "Forritamöppur eru með rétta eigandann \"%s\"",
    "Your remote address could not be determined." : "Ekki var hægt að ákvarða fjartengda vistfangið þitt.",
    "Code integrity" : "Áreiðanleiki kóða",
    "No altered files" : "Engar breyttar skrár",
    "Cron errors" : "Cron-villur",
    "Cron last run" : "Síðasta cron-keyrsla",
    "Data directory protected" : "Gagnamappa varin",
    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Gagnamappan og skrárnar þínar eru líklega aðgengilegar öllum af internetinu vegna þess að .htaccess skrá er ekki virk. Við mælum eindregið með að þú stillir vefþjóninn þinn á þann hátt að gagnamappa er ekki lengur aðgengileg eða þú færir gagnamöppu út fyrir skjalarót vefþjóns.",
    "Database missing columns" : "Gagnagrunn vantar dálka",
    "Missing optional column \"%s\" in table \"%s\"." : "Vantar valkvæða dálkinn \"%s\" í töflunni \"%s\".",
    "Database missing indices" : "Gagnagrunn vantar vísa",
    "\"%s\" in table \"%s\"" : "\"%s\" í töflu \"%s\"",
    "Database missing primary keys" : "Gagnagrunn vantar aðallykla",
    "Missing primary key on table \"%s\"." : "Vantar aðallykilinn í töflunni \"%s\".",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "Gagnagrunninn vantar nokkra aðallykla (primary keys). Vegna þess að það að bæta aðallyklum við stórar töflur getur tekið töluverðan tíma, þá var þeim ekki bætt við sjálfvirkt. Með því að keyra \"occ db:add-missing-primary-keys\" væri hægt að bæta inn þessum aðallyklum sem vantar, á meðan kerfið er í gangi. Um leið og búið er að bæta inn þessum aðallyklum, munu fyrirspurnir í þessar töflur verða miklu hraðvirkari.",
    "Debug mode" : "Villuleitarhamur",
    "Debug mode is disabled." : "Villuleitarhamur er óvirkur.",
    "Default phone region" : "Sjálfgefið svæði símaþjónustu",
    "Email test" : "Prófa tölvupóststillingar",
    "Email test was successfully sent" : "Það tókst að senda tölvupóstprófun",
    "The database is used for transactional file locking. To enhance performance, please configure memcache, if available." : "Gagnagrunnurinn er notaður fyrir færslulæsingu skráa. Til að auka afköst ættirðu að setja upp skyndiminni (með memcache) ef það er tiltækt.",
    "The reverse proxy header configuration is incorrect. This is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud." : "Uppsetning gagnstæðs milliþjónshauss (reverse proxy header) er röng. Þetta er öryggisvandamál og getur leyft árásaraðilum að dulbúa IP-vistfang þeirra sem sýnilegt fyrir Nextcloud.",
    "Your IP address was resolved as %s" : "IP-vistfangið þitt var leyst sem %s",
    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud." : "Uppsetning gagnstæðs milliþjónshauss (reverse proxy header) er röng, eða að þú ert að tengjast Nextcloud frá treystum milliþjóni. Ef ekki, þá er þetta er öryggisvandamál og getur leyft árásaraðilum að dulbúa IP-vistfang þeirra sem sýnilegt fyrir Nextcloud.",
    "Internet connectivity" : "Tenging við internet",
    "Internet connectivity is disabled in configuration file." : "Tenging við internet er gerð óvirk í stillingaskrá.",
    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Þessi þjónn er ekki með virka internettengingu: ekki náðis tenging við fjölmarga endapunkta. Þetta þýðir að sumir eiginleikar eins og að virkja ytri gagnageymslu, tilkynningar um uppfærslur eða uppsetningu á forritum þriðja aðila, mun ekki virka. Fjartengdur aðgangur að skrám og sending tilkynninga í tölvupósti virka líklega ekki heldur. Við leggjum til að internettenging sé virkjuð fyrir þennan vefþjón ef þú vilt hafa alla eiginleika tiltæka.",
    "Old server-side-encryption" : "Eldri gerð dulritunar á þjóni",
    "Disabled" : "Óvirkt",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "Eldri gerð dulritunar á þjóni er virk. Við mælum með því að hún sé gerð óvirk.",
    "Memcache" : "Memcache",
    "No memory cache has been configured. To enhance performance, please configure a memcache, if available." : "Ekkert skyndiminni (cache) hefur verið stillt Til að auka afköst ættirðu að setja upp skyndiminni (með memcache) ef það er tiltækt.",
    "Configured" : "Stillt",
    "MySQL row format" : "Snið MySQL-raða",
    "You are not using MySQL" : "Þú ert ekki að nota MySQL",
    "PHP default charset" : "Sjálfgefin stafatafla PHP",
    "PHP configuration option \"default_charset\" should be UTF-8" : "PHP-stillingarofinn \"default_charset\" ætti að vera UTF-8",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "PHP-fallið \"set_time_limit\" er ekki tiltækt. Þetta gæti valdið því að skriftur stöðvist í miðri keyrslu og skemmi uppsetninguna þína. Við mælumst til þess að þetta fall sé gert virkt.",
    "Freetype" : "Freetype",
    "Supported" : "Stutt",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "PHP-uppsetningin er ekki með stuðning við Free Type. Þetta mun valda því að notendamyndir og stillingaviðmót virki ekki.",
    "PHP getenv" : "PHP getenv",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "Það lítur út eins og að PHP sé ekki rétt sett upp varðandi fyrirspurnir um umhverfisbreytur. Prófun með getenv(\"PATH\") skilar auðu svari.",
    "PHP memory limit" : "Minnismörk PHP",
    "PHP modules" : "PHP-einingar",
    "This instance is missing some required PHP modules. It is required to install them: %s." : "Í þetta kerfistilvik vantar ýmsar nauðsynlegar PHP-einingar. Mælt er eindregið með að setja þær upp: %s.",
    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "PHP Opcache er ekki hlaðið inn. Fyrir betri afköst mælum við með að því sé hlaðið inn í PHP-uppsetninguna þína.",
    "PHP version" : "PHP-útgáfa",
    "You are currently running PHP %s." : "Þú ert núna að keyra PHP %s.",
    "Push service" : "Ýtiþjónusta",
    "Valid enterprise license" : "Gilt notkunarleyfi fyrirtækis",
    "Free push service" : "Ókeypis ýtiþjónusta",
    "Random generator" : "Slembigjafi",
    "No suitable source for randomness found by PHP which is highly discouraged for security reasons." : "Enginn hentugur gagnagjafi fyrir handahófsreikning fannst fyrir PHP, sem er mjög óráðlegt af öryggisástæðum.",
    "Secure" : "Öruggt",
    "Configuration file access rights" : "Aðgangsheimildir að stillingaskrá",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Skrifvarða stillingaskráin hefur verið virkjuð. Þetta kemur í veg fyrir að hægt sé að sýsla með sumar stillingar í gegnum vefviðmótið. Að auki þarf þessi skrá að vera skrifanleg við hverja uppfærslu.",
    "Nextcloud configuration file is writable" : "Stillingaskrá Nextcloud er ritanleg",
    "HTTP headers" : "HTTP-hausar",
    "Database version" : "Útgáfa gagnagrunns",
    "Unknown database platform" : "Óþekkt gagnagrunnskerfi",
    "Architecture" : "Tölvuhögun",
    "64-bit" : "64-bita",
    "Temporary space available" : "Bráðabirgðapláss tiltækt",
    "- %.1f GiB available in %s (PHP temporary directory)" : "- %.1f GiB tiltæk í %s (PHP-bráðabirgðamöppu)",
    "- %.1f GiB available in %s (Nextcloud temporary directory)" : "- %.1f GiB tiltæk í %s (Nextcloud-bráðabirgðamöppu)",
    "Temporary directory is correctly configured:\n%s" : "Bráðabirgðamappa er rétt stillt:\n%s",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Gagnagrunnurinn keyrir ekki með \"READ COMMITTED\" færsluaðgreiningarstiginu. Þetta getur valdið vandamálum þegar margar aðgerðir eru keyrðar í einu.",
    ".well-known URLs" : ".well-known slóðir",
    "Font file loading" : "Innhleðsla leturskrár",
    "Profile information" : "Persónuupplýsingar",
    "Nextcloud settings" : "Stillingar Nextcloud",
    "AI tasks can be implemented by different apps. Here you can set which app should be used for which task." : "AI-gervigreind verka getur verið framkvæmd af mismunandi forritum. Hér geturðu stillt hvaða forrit ætti að nota fyrir hvaða verk.",
    "Enable" : "Virkja",
    "Machine translation can be implemented by different apps. Here you can define the precedence of the machine translation apps you have installed at the moment." : "Vélþýðingar geta verið framkvæmdar af mismunandi forritum. Hér geturðu skilgreint forgangsröðun þeirra vélþýðingarforrita sem eru uppsett í augnablikinu.",
    "Image generation can be implemented by different apps. Here you can set which app should be used." : "Gerð mynda getur verið framkvæmd af mismunandi forritum. Hér geturðu stillt hvaða forrit ætti að nota.",
    "Text processing tasks can be implemented by different apps. Here you can set which app should be used for which task." : "Textavinnsla verka getur verið framkvæmd af mismunandi forritum. Hér geturðu stillt hvaða forrit ætti að nota fyrir hvaða verk.",
    "Task:" : "Verk:",
    "Unable to modify setting" : "Ekki gekk að breyta stillingu",
    "None" : "Ekkert",
    "Changed disclaimer text" : "Breyttur texti fyrirvara",
    "Deleted disclaimer text" : "Eyddi texta fyrirvara",
    "Could not set disclaimer text" : "Gat ekki stillt texta fyrirvara",
    "Allow apps to use the Share API" : "Leyfa forritum að nota Share API",
    "Allow resharing" : "Leyfa endurdeilingu",
    "Allow sharing with groups" : "Leyfa deilingu með hópum",
    "Restrict users to only share with users in their groups" : "Takmarka notendur við að deila með notendum í þeirra eigin hópum",
    "Allow users to share via link and emails" : "Leyfa notendum að deila með tenglum og tölvupósti",
    "Allow public uploads" : "Leyfa opinberar innsendingar",
    "Always ask for a password" : "Alltaf biðja um lykilorð",
    "Enforce password protection" : "Krefjast verndunar með aðgangsorði",
    "Exclude groups from password requirements" : "Undanskilja hópa frá kröfum um lykilorð",
    "Exclude groups from creating link shares" : "Undanskilja hópa frá því að búa til sameignartengla",
    "Shares with guessable tokens may be accessed easily" : "Aðgangur er greiður að sameignum með teikn sem auðvelt er að giska á",
    "Limit sharing based on groups" : "Takmarka deilingu út frá hópum",
    "Allow sharing for everyone (default)" : "Leyfa deilingu fyrir alla (sjálfgefið)",
    "Groups allowed to share" : "Hópar með heimild til að deila",
    "Groups excluded from sharing" : "Hópar undanskildir frá því að deila",
    "Enforce expiration date" : "Krefjast dagsetningar á gildistíma",
    "Default expiration time of new shares in days" : "Sjálfgefinn gildistími fyrir nýjar sameignir í dögum",
    "Expire shares after x days" : "Sameignir renna út eftir x daga",
    "Set default expiration date for shares to other servers" : "Setja sjálfgefinn gildistíma fyrir sameignir til annarra netþjóna",
    "Enforce expiration date for remote shares" : "Krefjast dagsetningar á gildistíma fjartengdra sameigna",
    "Default expiration time of remote shares in days" : "Sjálfgefinn gildistími fyrir fjartengdar sameignir í dögum",
    "Expire remote shares after x days" : "Fjartengdar sameignir renna út eftir x daga",
    "Set default expiration date for shares via link or mail" : "Setja sjálfgefinn gildistíma fyrir sameignir sem deilt er með tengli eða tölvupósti",
    "Default expiration time of shares in days" : "Sjálfgefinn gildistími fyrir sameignir í dögum",
    "Privacy settings for sharing" : "Stillingar á friðhelgi deilingar",
    "Allow account name autocompletion in share dialog and allow access to the system address book" : "Leyfa sjálfklárun notandanafns í deilingarglugga og heimila aðgang að nafnaskrá kerfisins",
    "Restrict account name autocompletion and system address book access to users within the same groups" : "Takmarka sjálfklárun á heiti notendaaðganga og aðgang að kerfisnafnaskrá við notendur innan sömu hópa",
    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Birta fyrirvara á opinberu innsendingasíðunni (birtist einungis þegar listi yfir skrár er falinn)",
    "Disclaimer text" : "Texti fyrirvara",
    "This text will be shown on the public link upload page when the file list is hidden." : "Þessi texti birtist á opinberu upphleðslusíðunni þegar listi yfir skrár er falinn.",
    "Default share permissions" : "Sjálfgefnar aðgangsheimildir fyrir deilingu",
    "Two-Factor Authentication" : "Tveggja-þrepa auðkenning",
    "Two-factor authentication can be enforced for all accounts and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Hægt er að þvinga fram tveggja-þrepa auðkenningu fyrir alla notendaaðganga og/eða tiltekna hópa. Ef þeir eru ekki með tveggja-þrepa auðkenningarþjónustu uppsetta, munu þeir ekki geta skráð sig inn á kerfið.",
    "Enforce two-factor authentication" : "Þvinga fram tveggja-þrepa auðkenningu",
    "Limit to groups" : "Takmarka við hópa",
    "Enforcement of two-factor authentication can be set for certain groups only." : "Hægt er að þvinga fram tveggja-þátta auðkenningu fyrir einungis ákveðna hópa.",
    "Two-factor authentication is enforced for all members of the following groups." : "Tveggja-þrepa auðkenning er þvinguð fram fyrir alla meðlimi eftirfarandi hópa.",
    "Enforced groups" : "Þvingaðir hópar",
    "Two-factor authentication is not enforced for members of the following groups." : "Tveggja-þrepa auðkenning er ekki þvinguð fram fyrir meðlimi eftirfarandi hópa.",
    "Excluded groups" : "Útilokaðir hópar",
    "When groups are selected/excluded, they use the following logic to determine if an account has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If an account is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Þegar hópar eru valdir/útilokaðir, styðjast þeir við eftirfarandi röksemdafærslu til að ákvarða hvort notandaaðgangur sé með þvingaða/virka tveggja-þrepa auðkenningu: tveggja-þrepa auðkenning er virk fyrir alla nema meðlimi útilokaðra hópa. Ef hópar eru valdir, er tveggja-þrepa auðkenning virk fyrir alla meðlimi þessara hópa. Ef notandi er bæði í völdum og í útilokuðum hópum, ræður valið og því er tveggja-þrepa auðkenning virk.",
    "Save changes" : "Vista breytingar",
    "Failed to create group" : "Mistókst að búa til hóp",
    "Groups" : "Hópar",
    "Creating group…" : "Bý til hóp …",
    "Create group" : "Búa til hóp",
    "Group name" : "Heiti hóps",
    "Please enter a valid group name" : "Settu inn gilt nafn á hópi",
    "Loading groups…" : "Hleð inn hópum…",
    "Google Chrome for Android" : "Google Chrome fyrir Android",
    "{productName} iOS app" : "{productName} iOS-forrit",
    "{productName} Android app" : "{productName} Android-forrit",
    "{productName} Talk for iOS" : "{productName} Talk fyrir iOS",
    "{productName} Talk for Android" : "{productName} Talk fyrir Android",
    "Sync client" : "Samstilla biðlara",
    "This session" : "Þessa setu",
    "{client} - {version} ({system})" : "{client} - {version} ({system})",
    "{client} - {version}" : "{client} - {version}",
    "Confirm wipe" : "Staðfesta útþurrkun",
    "Do you really want to wipe your data from this device?" : "Viltu í alvörunni hreinsa gögnin þín af þessu tæki?",
    "Wipe device" : "Þurrka út af tæki",
    "Cancel" : "Hætta við",
    "Device name" : "Heiti tækis",
    "Cancel renaming" : "Hætta við að endurnefna",
    "Save new name" : "Vista nýtt nafn",
    "Marked for remote wipe" : "Merkt fyrir fjartengda útþurrkun",
    "Device settings" : "Stillingar tækis",
    "Allow filesystem access" : "Leyfa aðgang að skráakerfi",
    "Rename" : "Endurnefna",
    "Revoke" : "Afturkalla",
    "Revoking this token might prevent the wiping of your device if it has not started the wipe yet." : "Afturköllun á þessu teikni gæti komið í veg fyrir útþurrkun af tækinu nema ef útþurrkunin sé þegar byrjuð.",
    "Device" : "Tæki",
    "Last activity" : "Síðasta virkni",
    "Actions" : "Aðgerðir",
    "Devices & sessions" : "Tæki og setur",
    "Web, desktop and mobile clients currently logged in to your account." : "Veftól, tölvur og símar sem núna eru skráð inn á aðganginn þinn.",
    "Error while creating device token" : "Villa við að búa til teikn fyrir tækið",
    "App name" : "Heiti forrits",
    "Create new app password" : "Búa til nýtt lykilorð forrits",
    "App password copied!" : "Lykilorð forrits afritað!",
    "Copy app password" : "Afrita lykilorð forrits",
    "Login name copied!" : "Notandanafn innskráningar afritað!",
    "Copy login name" : "Afrita notandanafn innskráningar",
    "Could not copy app password. Please copy it manually." : "Tókst ekki að afrita lykilorð forritsins. Afritaðu það handvirkt.",
    "Could not copy login name. Please copy it manually." : "Tókst ekki að afrita innskráningarnafnið. Afritaðu það handvirkt.",
    "New app password" : "Nýtt lykilorð forrits",
    "Login" : "Innskráning",
    "Password" : "Lykilorð",
    "Show QR code for mobile apps" : "Birta QR-kóða fyrir snjallsímaforrit",
    "Use system cron service to call the cron.php file every 5 minutes." : "Nota cron-þjónustu kerfisins til að kalla á cron.php skrána á 5 mínútna fresti.",
    "The cron.php needs to be executed by the system account \"{user}\"." : "cron.php verður að vera keyrt af kerfisnotandanum \"{user}\".",
    "The PHP POSIX extension is required. See {linkstart}PHP documentation{linkend} for more details." : "Nauðsynlegt er að hafa PHP-POSIX-viðaukann. Skoðaðu {linkstart}PHP-hjálparskjölin{linkend} fyrir nánari útlistun.",
    "Unable to update background job mode" : "Tókst ekki að uppfæra ham bakgrunnsverks",
    "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information." : "Til að þjónninn virki sem skyldi, er mikilvægt að stilla bakgrunnsverk rétt. Mælt er með því að nota 'cron' kerfisins. Skoðaðu hjálparskjölin til að sjá ítarlegar upplýsingar.",
    "Last job execution ran {time}. Something seems wrong." : "Síðasta verk var keyrt {time}. Eitthvað er ekki eins og það á að sér að vera.",
    "Last job ran {relativeTime}." : "Síðasta verk var keyrt {relativeTime}.",
    "Background job did not run yet!" : "Bakgrunnsverk hefur ekki ennþá verið keyrt!",
    "AJAX" : "AJAX",
    "Execute one task with each page loaded. Use case: Single account instance." : "Framkvæma eitt verk með hverri innhlaðinni síðu. Dæmi um notkun: Tilvik fyrir einn notandaaðgang.",
    "Webcron" : "Webcron",
    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 accounts depending on the usage)." : "cron.php er skráð á webcron-þjónustu til að kalla á cron.php á 5 mínútna fresti yfir HTTP. Dæmi um notkun: Mjög lítil tilvik (1–5 notendaaðgangar eða eftir notkun).",
    "Cron (Recommended)" : "Cron (mælt með þessu)",
    "Unable to update profile default setting" : "Tókst ekki að uppfæra sjálfgefna stillingu notandasniðs",
    "Profile" : "Notandasnið",
    "Enable or disable profile by default for new accounts." : "Virkja eða gera notandasnið óvirkt sjálfgefið fyrir nýja notendaaðganga.",
    "Password confirmation is required" : "Þörf á staðfestingu lykilorðs",
    "Failed to save setting" : "Mistókst að vista stillingu",
    "Unable to update server side encryption config" : " Get ekki uppfært uppsetningu fyrir dulritun á þjóni",
    "Server-side encryption" : "Dulritun á þjóni",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Dulritun á vefþjóni (server-side encryption) gerir kleift að dulrita skrár sem sendar eru inn á þennan þjón. Sá eiginleiki er ekki án áhrifa á afköst kerfisins, þannig að slíkt ætti ekki að virkja nema að vel yfirlögðu máli.",
    "Enable server-side encryption" : "Virkja dulritun á þjóni",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Engin dulritunareining hlaðin inn, virkjaðu dulritunareiningu í valmynd forritsins.",
    "Select default encryption module:" : "Veldu sjálfgefna dulritunareiningu:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}" : "Þú verður að yfirfæra dulritunarlyklana þína úr gömlu dulrituninni (ownCloud <= 8.0) yfir í þá nýju. Virkjaðu \"Sjálfgefin dulritunareining\" og keyrðu {command}",
    "Enable encryption" : "Virkja dulritun",
    "Please read carefully before activating server-side encryption:" : "Lestu eftirfarandi gaumgæfilega áður en þú virkjar dulritun á þjóni:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Þegar dulritun er virkjuð, munu frá þeim tímapunkti allar skrár sem sendar eru inn á þjóninn verða dulritaðar inni á honum. Einungis mun verða hægt að afvirkja dulritun síðar, ef virka dulritunareiningin styður þá aðgerð, og ef allar forsendur (t.d. að setja endurheimtulykil) eru uppfylltar.",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Dulritun ein og sér tryggir ekki öryggi kerfisins. Endilega skoðaðu hjálparskjölin um hvernig dulritunarforritið virkar, og dæmi um hvaða uppsetningar eru studdar.",
    "Be aware that encryption always increases the file size." : "Hafðu í huga að dulritun eykur alltaf skráastærð.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Það er góður siður að taka regluleg öryggisafrit af gögnunum þínum; ef um dulrituð gögn er að ræða, gakktu úr skugga um að einnig sé tekið öryggisafrit af dulritunarlyklum ásamt gögnunum.",
    "This is the final warning: Do you really want to enable encryption?" : "Þetta er lokaaðvörun: Viltu örugglega virkja dulritun?",
    "Please confirm the group removal" : "Staðfestu fjarlægingu hópsins",
    "Confirm" : "Staðfesta",
    "Submit" : "Senda inn",
    "Rename group" : "Endurnefna hóp",
    "Current password" : "Núverandi lykilorð",
    "New password" : "Nýtt lykilorð",
    "Choose your profile picture" : "Veldu auðkennismynd fyrir þig",
    "Please select a valid png or jpg file" : "Veldu gilda PNG eða JPG-skrá",
    "Error setting profile picture" : "Villa kom upp við að setja auðkennismyndina",
    "Error cropping profile picture" : "Villa kom upp við að skera utan af auðkennismyndinni",
    "Error saving profile picture" : "Villa kom upp við að vista auðkennismyndina",
    "Error removing profile picture" : "Villa kom upp við að fjarlægja auðkennismyndina",
    "Your profile picture" : "Auðkennismyndin þín",
    "Upload profile picture" : "Senda inn auðkennismynd",
    "Choose profile picture from Files" : "Veldu sem auðkennismynd úr skrám",
    "Remove profile picture" : "Fjarlægja auðkennismynd",
    "The file must be a PNG or JPG" : "Skráin verður að vera PNG eða JPG",
    "Picture provided by original account" : "Mynd frá upprunalegum aðgangi",
    "Set as profile picture" : "Setja sem auðkennismynd",
    "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "Athugaðu að það getur tekið allt að 24 klukkustundir fyrir auðkennismyndina þína að uppfærast allsstaðar.",
    "Your biography. Markdown is supported." : "Æviágrip þitt. Stuðningur er við Markdown-snið.",
    "Unable to update date of birth" : "Tókst ekki að uppfæra fæðingardag",
    "Enter your date of birth" : "Settu inn fæðingardaginn þinn",
    "You are using {s}{usage}{/s}" : "Þú ert að nota {s}{usage}{/s}",
    "You are using {s}{usage}{/s} of {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})" : "Þú ert að nota {s}{usage}{/s} af {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})",
    "Details" : "Nánar",
    "You are a member of the following groups:" : "Þú ert meðlimur eftirfarandi hópa:",
    "Your full name" : "Fullt nafn þitt",
    "Unable to update primary email address" : "Get ekki uppfært aðaltölvupóstfang",
    "Unable to delete additional email address" : "Get ekki eytt aukatölvupóstfangi",
    "No email address set" : "Ekkert tölvupóstfang sett",
    "Email options" : "Tölvupóststillingar",
    "Options for additional email address {index}" : "Valkostir fyrir aukalegt tölvupóstfang {index}",
    "Remove primary email" : "Fjarlægja aðaltölvupóstfang",
    "Delete email" : "Eyða tölvupósti",
    "This address is not confirmed" : "Þetta tölvupóstfang er ekki staðfest",
    "Unset as primary email" : "Aftengja sem aðaltölvupóstfang",
    "Set as primary email" : "Gera að aðaltölvupóstfangi",
    "Additional email address {index}" : "Aukalegt tölvupóstfang {index}",
    "Unable to delete primary email address" : "Get ekki eytt aðaltölvupóstfangi",
    "Unable to add additional email address" : "Get ekki bætt við aukatölvupóstfangi",
    "Unable to update additional email address" : "Get ekki uppfært aukatölvupóstfang",
    "Primary email for password reset and notifications" : "Aðallykilorð fyrir tilkynningar og endurstillingu lykilorðs",
    "Your handle" : "Auðkennið þitt",
    "Derived from your locale ({weekDayName})" : "Ákvarðað af staðfærslu kerfisins ({weekDayName})",
    "Unable to update first day of week" : "Mistókst að uppfæra fyrsta dag viku",
    "Day to use as the first day of week" : "Dagurinn sem á að nota sem fyrsta dag vikunnar",
    "Your headline" : "Fyrirsögnin þín",
    "No language set" : "Ekkert tungumál skilgreint",
    "Unable to update language" : "Tókst ekki að uppfæra tungumál",
    "Languages" : "Tungumál",
    "Help translate" : "Hjálpa við þýðingu",
    "No locale set" : "Engin staðfærsla tilgreind",
    "Unable to update locale" : "Tókst ekki að uppfæra staðfærslu",
    "Locales" : "Staðfærslur",
    "Week starts on {firstDayOfWeek}" : "Vika byrjar á {firstDayOfWeek}",
    "Your city" : "Borg/sveitarfélag",
    "Your organisation" : "Fyrirtækið þitt",
    "Your phone number" : "Símanúmerið þitt",
    "Edit your Profile visibility" : "Breyta sýnileika notandasniðsins þíns",
    "Unable to update profile enabled state" : "Tókst ekki að uppfæra virka stöðu notandasniðs",
    "Enable profile" : "Virkja notandasnið",
    "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "Sú stilling sem meira er takmarkandi, annað hvort sýnileiki eða dreifing, fær meira vægi í notandasniðinu þínu. Til dæmis ef sýnileiki er stilltur á \"Birta öllum\" og dreifing er stillt á \"Einka\", þá hefur \"Einka\" meira vægi.",
    "Unable to update visibility of {displayId}" : "Tókst ekki að uppfæra sýnileika á {displayId}",
    "she/her" : "hún",
    "he/him" : "hann",
    "they/them" : "hán/þau",
    "Your role" : "Hlutverk þitt",
    "Timezone" : "Tímabelti",
    "Your X (formerly Twitter) handle" : "X (fyrrum Twitter) notandanafnið þitt",
    "Your website" : "Vefsvæðið þitt",
    "Invalid value" : "Ógilt gildi",
    "Unable to update {property}" : "Tókst ekki að uppfæra {property}",
    "No {property} set" : "Ekkert {property} sett",
    "Change scope level of {property}, current scope is {scope}" : "Breyta dreifingarstigi á {property}, fyrirliggjandi svið er {scope}",
    "Unable to update federation scope of the primary {property}" : "Tókst ekki að uppfæra skýjasambandsdreifingu á aðal {property}",
    "Unable to update federation scope of additional {property}" : "Tókst ekki að uppfæra skýjasambandsdreifingu á aukalegu {property}",
    "Add additional email" : "Bæta við aukatölvupóstfangi",
    "Add" : "Bæta við",
    "Create" : "Búa til",
    "Change" : "Breyta",
    "Delete" : "Eyða",
    "Reshare" : "Endurdeila",
    "School" : "Skóli",
    "Default" : "Sjálfgefið",
    "Default language" : "Sjálfgefið tungumál",
    "Common languages" : "Algeng tungumál",
    "Other languages" : "Önnur tungumál",
    "Password change is disabled because the master key is disabled" : "Lykilorðabreyting er óvirk vegna þess að aðallykill er óvirkur",
    "No accounts" : "Engir aðgangar",
    "List of accounts. This list is not fully rendered for performance reasons. The accounts will be rendered as you navigate through the list." : "Listi yfir notendaaðganga. Til að halda sem bestum afköstum er þessi listi ekki myndgerður að fullu. Notendaaðgangar munu birtast eftir því sem farið er í gegnum listann.",
    "Account name" : "Heiti notandaaðgangs",
    "Account updated" : "Aðgangur uppfærður",
    "Edit account" : "Breyta notandaaðgangi",
    "Saving …" : "Vista …",
    "Save" : "Vista",
    "Account name will be autogenerated" : "Heiti notandaaðgangs verður útbúið sjálfvirkt",
    "Account name (required)" : "Heiti notandaaðgangs (krafist)",
    "Password (required)" : "Lykilorð (nauðsynlegt)",
    "Email (required)" : "Tölvupóstfang (nauðsynlegt)",
    "Email" : "Netfang",
    "New account" : "Nýr aðgangur",
    "Add new account" : "Bæta við nýjum aðgangi",
    "Display name" : "Birtingarnafn",
    "Either password or email is required" : "Annað hvort lykilorð eða tölvupóstfang eru nauðsynleg",
    "Member of the following groups (required)" : "Meðlimur eftirfarandi hópa (nauðsynlegt)",
    "Member of the following groups" : "Meðlimur eftirfarandi hópa",
    "Set account groups" : "Setja hópa notandaaðgangs",
    "Admin of the following groups" : "Stjórnandi eftirfarandi hópa",
    "Language" : "Tungumál",
    "Set default language" : "Settu sjálfgefið tungumál",
    "Manager" : "Stjórnandi",
    "Quota" : "Kvóti",
    "Set account quota" : "Settu kvóta notandaaðgangs",
    "Total rows summary" : "Samantek á fjölda raða",
    "Scroll to load more rows" : "Skrunaðu til að hlaða inn fleiri röðum",
    "Avatar" : "Auðkennismynd",
    "Group admin for" : "Hópstjóri fyrir",
    "Account backend" : "Bakendi notandaaðganga",
    "Storage location" : "Staðsetning gagnageymslu",
    "First login" : "Fyrsta innskráning",
    "Last login" : "Síðasta innskráning",
    "Account actions" : "Aðgerðir fyrir aðgang",
    "Unknown" : "Óþekkt",
    "Never" : "Aldrei",
    "{size} used" : "{size} notað",
    "Delete account" : "Eyða notandaaðgangi",
    "Disable account" : "Gera notandaaðgang óvirkan",
    "Enable account" : "Virkja notandaaðgang",
    "Resend welcome email" : "Endursenda kveðjupóst",
    "Remote wipe of devices" : "Fjartengd útþurrkun af tækjum",
    "Wipe {userid}'s devices" : "Þurrka út af tækjum {userid}",
    "Wiped {userid}'s devices" : "Þurrkaði út af tækjum {userid}",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "Eyða að fullu notandaaðgangnum {userid}, þar með talið öllum persónulegum skrám viðkomandi, forritsgögnum, o.s.frv.",
    "Account deletion" : "Eyðing á aðgangi",
    "Delete {userid}'s account" : "Eyða notandaaðgangi {userid}",
    "Welcome mail sent!" : "Kveðjupóstur sendur!",
    "Toggle account actions menu" : "Víxla af/á valmynd fyrir aðgerðir notandaaðgangs",
    "Edit" : "Breyta",
    "Account management settings" : "Stillingar umsýslu notandaaðgangs",
    "Visibility" : "Sýnileiki",
    "Show language" : "Birta tungumál",
    "Show account backend" : "Birta bakenda notandaaðgangs",
    "Show storage path" : "Birta slóð á gagnageymslu",
    "Show first login" : "Birta fyrstu innskráningu",
    "Show last login" : "Birta síðustu innskráningu",
    "Sorting" : "Röðun",
    "Group list sorting" : "Röðun lista yfir hópa",
    "By member count" : "Eftir fjölda meðlima",
    "By name" : "Eftir nafni",
    "Send email" : "Senda tölvupóst",
    "Send welcome email to new accounts" : "Senda tölvupóst sem býður nýja notendur velkomna",
    "Defaults" : "Sjálfgefin gildi",
    "Default quota" : "Sjálfgefinn kvóti",
    "Select default quota" : "Setja sjálfgefinn kvóta",
    "Search" : "Search",
    "Help" : "Hjálp",
    "Show those shortcuts" : "Sýna þessa flýtilykla",
    "Server error while trying to complete WebAuthn device registration" : "Villa á þjóni við að ljúka skráningu WebAuthn-tækis",
    "Passwordless authentication requires a secure connection." : "Lykilorðalaus auðkenning krefst öruggrar tengingar.",
    "Add WebAuthn device" : "Bæta við WebAuthn-tæki",
    "Please authorize your WebAuthn device." : "Auðkenndu WebAuthn-tækið þitt.",
    "Unnamed device" : "Nafnlaust tæki",
    "Passwordless Authentication" : "Lykilorðalaus auðkenning",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "Settu aðganginn þinn upp fyrir lykilorðalausa auðkenningu byggða á FIDO2-staðlinum.",
    "No devices configured." : "Engin tæki skilgreind.",
    "The following devices are configured for your account:" : "Eftirfarandi tæki eru uppsett fyrir notandaaðganginn þinn:",
    "Your browser does not support WebAuthn." : "Vafrinn þinn styður ekki WebAuthn.",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Það er mikilvægt að setja þennan vefþjón upp þannig að hann getir sent tölvupóst, eins og fyrir endurstillingu lykilorða og útsendingu tilkynninga.",
    "Send mode" : "Sendihamur",
    "Encryption" : "Dulritun",
    "Sendmail mode" : "Sendmail-hamur",
    "Disable certificate verification (insecure)" : "Gera sannvottun skilríkja óvirka (óöruggt)",
    "From address" : "Frá vistfangi",
    "Domain" : "Lén",
    "Server address" : "Vistfang þjóns",
    "Host" : "Þjónn",
    "Port" : "Gátt",
    "Authentication" : "Auðkenning",
    "Authentication required" : "Auðkenningar krafist",
    "Saving…" : "Vista…",
    "Save settings" : "Vista stillingar",
    "Security & setup warnings" : "Öryggi og aðvaranir vegna uppsetningar",
    "Try again" : "Reyndu aftur",
    "All checks passed." : "Stóðst allar prófanir.",
    "There are some errors regarding your setup." : "Það komu upp villur varðandi uppsetninguna þína.",
    "There are some warnings regarding your setup." : "Það komu upp viðvaranir varðandi uppsetninguna þína.",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Sem stjórnandi geturðu fínstillt hegðun við deilingu. Endilega kíktu á hjálparskjölin til að sjá ítarlegri upplýsingar.",
    "You need to enable the File sharing App." : "Þú verður að virkja skráardeilingarforritið.",
    "Apply" : "Virkja",
    "All accounts" : "Allir aðgangar",
    "Admins" : "Kerfisstjórar",
    "Account group: {group}" : "Hópur notendaaðganga: {group}",
    "Account management" : "Umsýsla notandaaðgangs",
    "Location" : "Staðsetning",
    "Profile picture" : "Einkennismynd",
    "About" : "Um hugbúnaðinn",
    "Date of birth" : "Fæðingardagur",
    "Full name" : "Fullt nafn",
    "Additional email" : "Aukatölvupóstfang",
    "Fediverse (e.g. Mastodon)" : "Skýjasamband - Fediverse (t.d. Mastodon)",
    "Headline" : "Fyrirsögn",
    "Organisation" : "Stofnun/Félag/Fyrirtæki",
    "Phone number" : "Símanúmer",
    "Pronouns" : "Fornöfn",
    "Role" : "Role",
    "X (formerly Twitter)" : "X (fyrrum Twitter)",
    "Bluesky" : "Bluesky",
    "Website" : "Vefsvæði",
    "Profile visibility" : "Sýnileiki notandasniðs",
    "Locale" : "Staðfærsla",
    "First day of week" : "Fyrsti dagur viku",
    "Private" : "Einka",
    "Only visible to people matched via phone number integration through Talk on mobile" : "Einungis sýnilegt fólki sem samsvarar samþættum símanúmerum í gegnum Talk-forritið á farsímum",
    "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Er ekki tiltækt þar sem þessi eiginleiki er nauðsynlegur fyrir kjarnavirkni á borð við skráadeilingu og boð í dagatölum",
    "Local" : "Staðvært",
    "Only visible to people on this instance and guests" : "Einungis sýnilegt staðværum notendum og gestum",
    "Federated" : "Deilt milli þjóna (skýjasambandssameign)",
    "Only synchronize to trusted servers" : "Aðeins samstilla við treysta þjóna",
    "Not available as federation has been disabled for your account, contact your system administration if you have any questions" : "Er ekki tiltækt þar sem skýjasamband (federation) hefur verið gert óvirkt fyrir aðganginn þinn, hafðu samband við kerfisstjórann þinn ef þú ert með einhverjar spurningar",
    "Published" : "Útgefið",
    "Synchronize to trusted servers and the global and public address book" : "Samstilla við treysta þjóna og víðværar og opinberar vistfangaskrár",
    "Not available as publishing account specific data to the lookup server is not allowed, contact your system administration if you have any questions" : "Er ekki tiltækt þar sem ekki er leyfilegt að miðla sértækum gögnum notenda yfir á uppflettingaþjóninn, hafðu samband við kerfisstjórann þinn ef þú ert með einhverjar spurningar",
    "Your apps" : "Forritin þín",
    "Active apps" : "Virk forrit",
    "Disabled apps" : "Óvirk forrit",
    "Updates" : "Uppfærslur",
    "App bundles" : "Forritavöndlar",
    "Featured apps" : "Forrit efst á baugi",
    "Supported apps" : "Studd forrit",
    "Show to everyone" : "Birta öllum",
    "Show to logged in accounts only" : "Birta einungis hjá innskráðum notendaaðgöngum",
    "Hide" : "Fela",
    "Error while wiping the device with the token" : "Villa við að hreinsa tækið með teikninu",
    "Error while updating device token name" : "Villa við að uppfæra nafn fyrir teikn tækisins",
    "Error while updating device token scope" : "Villa við að uppfæra gildissvið fyrir teikn tækisins",
    "An error occurred during the request. Unable to proceed." : "Villa kom upp við beiðnina. Get ekki haldið áfram.",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Það komu of margar beiðnir frá netkerfinu þínu. Reyndu aftur eða hafðu samband við kerfisstjóra ef þetta er ekki rétt.",
    "Error" : "Villa",
    "Account documentation" : "Hjálparskjöl fyrir notendaaðganga",
    "Administration documentation" : "Hjálparskjöl fyrir stjórnendur",
    "Documentation" : "Hjálparskjöl",
    "Forum" : "Vefspjall",
    "General documentation" : "Almenn hjálparskjöl",
    "Legal notice" : "Lagaleg atriði",
    "Privacy policy" : "Meðferð persónulegra gagna",
    "Version" : "Útgáfa",
    "Reasons to use Nextcloud in your organization" : "Ástæður til að nota Nextcloud á vinnustaðnum þínum",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Þróað af {communityopen}Nextcloud samfélaginu{linkclose}, {githubopen}grunnkóðinn{linkclose} er gefinn út með {licenseopen}AGPL{linkclose} notkunarleyfinu.",
    "Like our Facebook page" : "Líkaðu við Facebook-síðuna okkar",
    "Follow us on Mastodon" : "Fylgstu með okkur á Mastodon",
    "Check out our blog" : "Kíktu á bloggið okkar",
    "Subscribe to our newsletter" : "Gerstu áskrifandi að fréttabréfinu okkar",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Þessi samfélagsútgáfa Nextcloud kemur ekki með neinni opinberri aðstoð og rauntímatilkynningar eru ekki til taks.",
    "Open documentation" : "Opna hjálparskjöl",
    "Use a second factor besides your password to increase security for your account." : "Notaðu annað þrep til viðbótar lykilorðinu þínu til að auka öryggi notandaaðgangsins þíns.",
    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Ef þú notaðir utanaðkomandi forrit til að tengjast við Nextcloud, skaltu ganga úr skugga um að þú útbúir lykilorð fyrir hvert slíkt forrit áður en þú virkjar 2FA tveggja-þrepa auðkenningu.",
    "Very weak password" : "Mjög veikt lykilorð",
    "Weak password" : "Veikt lykilorð",
    "So-so password" : "Svo-svo lykilorð",
    "Good password" : "Gott lykilorð",
    "Strong password" : "Sterkt lykilorð",
    "Group list is empty" : "Listi yfir hópa er tómur",
    "Unable to retrieve the group list" : "Tókst ekki að ná í lista yfir hópinn",
    "Could not remove app." : "Gat ekki fjarlægt forrit.",
    "Could not update app." : "Gat ekki uppfært forrit.",
    "Apps" : "Forrit",
    "Machine translation" : "Vélræn þýðing",
    "Image generation" : "Gerð mynda",
    "Text processing" : "Textavinnsla",
    "Exclude some groups from sharing" : "Undanskilja suma hópa frá því að deila",
    "Limit sharing to some groups" : "Takmarka deilingu við suma hópa",
    "Show details for {appName} app" : "Birta ítarlegri upplýsingar fyrir {appName} forritið",
    "Update to {update}" : "Uppfæra í {update}",
    "Remove" : "Fjarlægja",
    "Featured" : "Í deiglunni",
    "This app is supported via your current Nextcloud subscription." : "Þetta forrit er stutt í gegnum fyrirliggjandi Nextcloud-áskrift þína.",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Forrit í deiglunni eru þróuð af og innan samfélagsins. Þau bjóða upp á ýmsa kjarnaeiginleika og eru tilbúin til notkunar í raunvinnslu.",
    "Community rating: {score}/5" : "Einkunnir frá samfélaginu: {score}/5",
    "Disable all" : "Gera allt óvirkt",
    "Download and enable all" : "Sækja og virkja allt",
    "All apps are up-to-date." : "Öll forrit eru af nýjustu útgáfu.",
    "Icon" : "Táknmynd",
    "Name" : "Heiti",
    "Level" : "Stig",
    "Results from other categories" : "Niðurstöður úr öðrum flokkum",
    "No apps found for your version" : "Engin forrit fundust fyrir útgáfuna þína",
    "_%n app has an update available_::_%n apps have an update available_" : ["%n forrit er með tiltæka uppfærslu","%n forrit eru með tiltæka uppfærslu"],
    "_Update_::_Update all_" : ["Uppfæra","Uppfæra allt"],
    "Nothing to show" : "Ekkert til að sýna",
    "Loading" : "Hleð inn",
    "Fetching the latest news…" : "Sæki nýjustu fréttir…",
    "Carousel" : "Hringekja",
    "Previous slide" : "Fyrri skyggna",
    "Next slide" : "Næsta skyggna",
    "Choose slide to display" : "Veldu skyggnu til að birta",
    "{index} of {total}" : "{index} af {total}",
    "Daemon" : "Púki",
    "Deploy Daemon" : "Setja bakgrunnsþjónustu (daemon) í gang",
    "Type" : "Tegund",
    "Display Name" : "Birtingarnafn",
    "GPUs support" : "Stuðningur við GPUs-skjáörgjörva",
    "Compute device" : "Reiknitæki",
    "Learn more" : "Læra meira",
    "Environment variables" : "Umhverfisbreytur",
    "No environment variables defined" : "Engar umhverfisbreytur skilgreindar",
    "Mounts" : "Tengipunktar",
    "Host path" : "Slóð á hýsivél",
    "Container path" : "Slóð á gagnagám",
    "Read-only" : "Skrifvarið",
    "Remove mount" : "Fjarlægja tengipunkt",
    "New mount" : "Nýr tengipunktur",
    "Enter path to host folder" : "Settu inn slóð á hýsilvélarmöppu",
    "Enter path to container folder" : "Settu inn slóð á gagnagámsmöppu",
    "Toggle read-only mode" : "Víxla lesham/skrifham af/á",
    "Confirm adding new mount" : "Staðfestu viðbætingu tengipunkts",
    "Cancel adding mount" : "Hætta við að bæta inn tengipunkti",
    "Add mount" : "Bæta við tengipunkti",
    "No mounts defined" : "Engir tengipunktar skilgreindir",
    "Description" : "Lýsing",
    "View in store" : "Skoða í hugbúnaðarsafni",
    "Visit website" : "Heimsækja vefsvæðið",
    "Usage documentation" : "Leiðbeiningar um notkun",
    "Admin documentation" : "Hjálparskjöl kerfisstjóra",
    "Developer documentation" : "Skjölun fyrir þróunaraðila",
    "All" : "Allt",
    "Limit app usage to groups" : "Takmarka notkun forrits við tiltekna hópa",
    "No results" : "Engar niðurstöður",
    "Update to {version}" : "Uppfæra í {version}",
    "Delete data on remove" : "Eyða gögnum við fjarlægingu",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Ekki var hægt að setja upp forritið þar sem eftirfarandi kerfiskröfur eru ekki uppfylltar:",
    "Latest updated" : "Síðast uppfært",
    "Author" : "Höfundur",
    "Categories" : "Flokkar",
    "Resources" : "Tilföng",
    "Interact" : "Gagnvirkni",
    "Report a bug" : "Tilkynna um villu",
    "Request feature" : "Stinga upp á eiginleikum",
    "Ask questions or discuss" : "Spyrja spurninga eða ræða málin",
    "Rate the app" : "Gefðu forritinu einkunn",
    "Rate" : "Gefa einkunn",
    "Changelog" : "Breytingaskrá",
    "Loading accounts …" : "Hleð inn notendaaðgöngum...",
    "Set line manager" : "Settu línustjórnanda",
    "Set account as admin for …" : "Setja notandaaðganginn sem stjórnanda fyrir …",
    "Password or insufficient permissions message" : "Skilaboð um lykilorð eða ekki nægar heimildir",
    "Display name was successfully changed" : "Það tókst að breyta birtingarnafninu",
    "Password was successfully changed" : "Það tókst að breyta lykilorðinu",
    "Email was successfully changed" : "Það tókst að breyta tölvupóstfanginu",
    "Loading account …" : "Hleð inn notandaaðgangi …",
    "Change display name" : "Breyta birtingarnafni",
    "Set new password" : "Stilla nýtt lykilorð",
    "You do not have permissions to see the details of this account" : "Þú hefur ekki réttindi til að skoða ítarupplýsingar um þennan notandaaðgang",
    "Set new email address" : "Stilla nýtt tölvupóstfang",
    "Add account to group" : "Bæta notandaaðgangi í hóp",
    "Set account as admin for" : "Setja notandaaðganginn sem stjórnanda fyrir",
    "Select account quota" : "Veldu kvóta notandaaðgangs",
    "Set the language" : "Settu tungumálið",
    "Done" : "Lokið",
    "Adding your device …" : "Bæti við tækinu þínu …",
    "App Store" : "Forritasafn",
    "Loading app list" : "Hleð inn forritalista",
    "Loading categories" : "Hleð inn flokkum",
    "Version {version}, {license}-licensed" : "Útgáfa {version}, {license}-notkunarleyfi",
    "Version {version}" : "Útgáfa {version}",
    "Sending…" : "Sendi...",
    "Email sent" : "Tölvupóstur sendur",
    "{progress}% Deploying …" : "{progress}% Sett í gang …",
    "{progress}% Initializing …" : "{progress}% Frumstilling …",
    "Health checking" : "Ástandsskoðun",
    "Download and enable" : "Sækja og virkja",
    "Disable" : "Gera óvirkt",
    "Allow untested app" : "Leyfa óprófuð forrit",
    "The app will be downloaded from the App Store" : "Forritið verður sótt úr forritabúðinni",
    "Error: This app cannot be enabled because it makes the server unstable" : "Villa: Ekki er hægt að virkja þetta forrit því það gerir þjóninn óstöðugan",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Forritið hefur verið virkjað, en það þarf að uppfæra það. Þú verður áframsendur á uppfærslusíðuna eftir 5 sekúndur.",
    "None/STARTTLS" : "Ekkert/STARTTLS",
    "SSL" : "SSL",
    "Credentials" : "Auðkenni",
    "SMTP Login" : "SMTP-innskráning",
    "SMTP Password" : "SMTP-lykilorð",
    "Test and verify email settings" : "Prófa og staðfesta tölvupóststillingar"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
