<?php
// This file is auto-generated. Do not edit!
return array('measurementSystem'=>array('001'=>'metric','GB'=>'UK','LR'=>'US','MM'=>'UK','US'=>'US'),'measurementSystem-category-temperature'=>array('BS'=>'US','BZ'=>'US','KY'=>'US','LR'=>'metric','MM'=>'metric','PR'=>'US','PW'=>'US'),'paperSize'=>array('001'=>'A4','BZ'=>'US-Letter','CA'=>'US-Letter','CL'=>'US-Letter','CO'=>'US-Letter','CR'=>'US-Letter','GT'=>'US-Letter','MX'=>'US-Letter','NI'=>'US-Letter','PA'=>'US-Letter','PH'=>'US-Letter','PR'=>'US-Letter','SV'=>'US-Letter','US'=>'US-Letter','VE'=>'US-Letter'));
