OC.L10N.register(
    "circles",
    {
    "Personal" : "ផ្ទាល់​ខ្លួន",
    "Password protected" : "បាន​ការ​ពារ​ដោយ​ពាក្យ​សម្ងាត់",
    "Federated" : "Federated",
    "Admin" : "អ្នក​គ្រប់​គ្រង",
    "Owner" : "Owner",
    "Invalid image" : "រូបភាព​មិន​ត្រឹម​ត្រូវ",
    "Unknown filetype" : "មិន​ស្គាល់​ប្រភេទ​ឯកសារ",
    "Open %s" : "បើក %s",
    "Unlimited" : "មិន​កំណត់",
    "Save" : "Save",
    "Connect" : "ភ្ជាប់",
    "Cancel" : "Cancel",
    "Folder" : "ថត",
    "you" : "អ្នក​",
    "Copy link" : "ចម្លងតំណ",
    "Close" : "បិទ",
    "New folder" : "ថត​ថ្មី",
    "Folder name" : "ឈ្មោះ​ថត",
    "Calendar" : "ប្រតិទិន",
    "New calendar" : "ប្រតិទិន​ថ្មី",
    "Description" : "ការ​អធិប្បាយ",
    "Edit" : "កែប្រែ",
    "Add" : "បន្ថែម",
    "Apply" : "អនុវត្ត",
    "Pending" : "កំពុង​រង់ចាំ",
    "User" : "User",
    "Email" : "អ៊ីមែល",
    "Users" : "អ្នកប្រើ",
    "Groups" : "ក្រុ",
    "Name" : "ឈ្មោះ",
    "Size" : "ទំហំ",
    "Modified" : "បាន​កែ​ប្រែ"
},
"nplurals=1; plural=0;");
