<?php
/**
 * SPDX-FileCopyrightText: 2016 Nextcloud GmbH and Nextcloud contributors
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */
return array (
  'xkzwnuxkdn9a8kcykuitbkg1g' => true,
  'ejxjzgbgunaz9z6j6exbniqga' => true,
  'gfifvtldtltdghjcnjkfgjxrf' => true,
  'pedrocagatinhodanet140594' => true,
  'l7dg980a43rijfcnr3puk5faj' => true,
  'jesperkroghnielsen@msncom' => true,
  'awesome3215sucksnachoness' => true,
  'mbnxmylxp7gxqv7hmi9gsoriz' => true,
  '30398351harrypotteralways' => true,
  '17f8kvl219rsva6ue4hhmbock' => true,
  'ypaandrey310119945ypa10-2' => true,
  'youwillneverguessthis1103' => true,
  'yourenotgettingmypassword' => true,
  'ybrjkfqtdutymtdbx25102009' => true,
  'yankeesriseupinthemorning' => true,
  'yankeessensualthunder2003' => true,
  'xxxxxxxxxxxxxxxxxxxxxxxxx' => true,
  'xatuna.chorgolashvili1995' => true,
  'wlong123greenbeltmarriott' => true,
  'wiskes1212131306150311221' => true,
  'windows.nt.setup.hardware' => true,
  'windows.apps.winsock.mail' => true,
  'williamadilgadzhimuradov1' => true,
  'whatthebrown123bambang456' => true,
  'whateverredckinaelizaveta' => true,
  'welcomeseekinga10lapdance' => true,
  'welcomeneed2killemall4fun' => true,
  'watchyougotgorddownie1973' => true,
  'wdoxx8xdlrxateeccszdmxtec' => true,
  'vvvvvvvvvvvvvvvffffffffff' => true,
  'vjcrdfcktpfvytdthbnbnjxrf' => true,
  'victorrusakoff89233974373' => true,
  'victoria_victosha08091980' => true,
  'victoreviniciusamoreterno' => true,
  'ventura89514432805ventura' => true,
  'venitia|clubinterdit.com|' => true,
  'vdsafgsafgsrgrsgagfasdgdf' => true,
  'vbybufycnfkrthdbnz4227514' => true,
  'valerka111213141516171819' => true,
  'valeriyahappyness17031996' => true,
  'vadimlokeridoker1995vadim' => true,
  'vadim123guzel123slavik123' => true,
  'v953i340k80u58s85y951alik' => true,
  'utyfgena20099889612022521' => true,
  'umushevarishromisunariani' => true,
  'trustno1gareth_gibson1987' => true,
  'trustno1flirty_brunette42' => true,
  'trimonoceta04248391123456' => true,
  'tina.feofilaktova21021995' => true,
  'tiggerhandsomematthew9008' => true,
  'tigersoneandonlygeorgette' => true,
  'tigersautocarrozzeria2000' => true,
  'thunderstampel.anastasiya' => true,
  'thundermarcelomagalhaes18' => true,
  'thunderknowshow2lickalady' => true,
  'thomasreallynoavailable94' => true,
  'thomasprohibitprohibition' => true,
  'thomasbouncebackability92' => true,
  'thieuvochongkhongsongduoc' => true,
  'thietlaptaikhoanchung1805' => true,
  'theinsightandthecatharsis' => true,
  'thaystrigueiromissperfect' => true,
  'thamaragenepool3336290188' => true,
  'thalytaedfisicaprofcarmen' => true,
  'thalisonolindadimas200900' => true,
  'tezinhaschorncristina1812' => true,
  'terciliovailatineto161193' => true,
  'teamocomonuncaameininguem' => true,
  'tazzzz@blackberrybrittany' => true,
  'taylorjgklsjklg.jgklsjklg' => true,
  'tastymushroomlop123456hjk' => true,
  'tanya123456789tanyaa19981' => true,
  'tainanunesbittencourt2208' => true,
  't6dlniahehjsktr60vp8rb50e' => true,
  't2338497r1981chirchik1981' => true,
  'svetlankazadorozhnaya1997' => true,
  'sveta160890yagodkamalinka' => true,
  'sveta13041961kola15111948' => true,
  'supermansweetdaddycoconut' => true,
  'supermansekxybabydoll_805' => true,
  'supermanmahatmasamatman10' => true,
  'supermanlordkipanidze1988' => true,
  'supeouafaazachnelson72005' => true,
  'sunshinetoddanthonydirect' => true,
  'sunshinetissemerenforce93' => true,
  'sunshineout_doors_girl_23' => true,
  'sunshineizobritatelpioner' => true,
  'sunshine5555sss44gdff4533' => true,
  'studentkasvobodaischastie' => true,
  'steelershorny_guy_swinger' => true,
  'steelersfabrice.coupliere' => true,
  'steelersdj_serezha_milano' => true,
  'starwarssweetsandra_jewel' => true,
  'starwarssupremecommander1' => true,
  'starwarssixtys_batman_fan' => true,
  'starwarsnelsonbatista1970' => true,
  'starwarsbrunettesweetie06' => true,
  'stacividservielectronicjr' => true,
  'ssssshbruno_carmorrison12' => true,
  'sparkysolidbrassfasteners' => true,
  'somerandomgu-seafoodrocks' => true,
  'soccershenitte_cortes2009' => true,
  'sobanahdii_hackijudylhook' => true,
  'slipknotnewmetalistheband' => true,
  'slayerzabliceva.margarita' => true,
  'slayerthisgirlisthebestmy' => true,
  'slayermarcosmith.prestige' => true,
  'simo060-707-5121yutrew123' => true,
  'shilov.nikolayka528046rus' => true,
  'shark239010050510darkwolf' => true,
  'shadowtaleofpirates_death' => true,
  'shadowkillian_petra_and_z' => true,
  'shadow_pyhsch0c0path_for_' => true,
  'seumundosedistancioudomeu' => true,
  'service=jbossbeandeployer' => true,
  'serebraikova20018svetlana' => true,
  'sdwjhg06110627loveyoumuch' => true,
  'scout1shivstryptheworld77' => true,
  'scorpio38minutesremaining' => true,
  'scootertu_hombre19_soy_yo' => true,
  'scootersimo-bouge-mekouar' => true,
  'schistoysovestyunasvobodu' => true,
  'sayanglashos_y_bobblohoyd' => true,
  'savagethebattlefornewerth' => true,
  'satxhvtpr5f2unbqzfa793mw1' => true,
  'sasha09584041950950859160' => true,
  'sanojdanicorscarecare2148' => true,
  'saichenko1997ivan1997ivan' => true,
  'sahinjalemilaneagqizsevir' => true,
  'russianproduction13031996' => true,
  'rulmigenskarlnsmagikat200' => true,
  'romkaomgups20diatit170792' => true,
  'robertthomas.harrison.pps' => true,
  'robertgamertechenthusiast' => true,
  'rileyseftonspatty_c21omeg' => true,
  'rfnmrfghbywtcrfctrcbgtrcb' => true,
  'rfcf13frfkjvff12345678900' => true,
  'rfcbvwtdfjktujdyf25032009' => true,
  'rdfcygvygygfvytgfytgfyufg' => true,
  'rctybzfktrcfylhjdyf240993' => true,
  'rangersyourbabygirl4eva06' => true,
  'rakitinmikhailalekseevich' => true,
  'rachelpesano_futaenokiwam' => true,
  'rbkcunap2l6dnbizwqwyh4e0y' => true,
  'qwazka310888svetapartnova' => true,
  'quicklydarknessapproaches' => true,
  'qqqwwweeerrr111222333444q' => true,
  'qpwoeirutnhishellyeng_270' => true,
  'qjiuhbnvo35gk9rl0kttxuy12' => true,
  'qazwsxmarvelouz_creations' => true,
  'qazwsxgilandkarendeguzman' => true,
  'pussychocolatelolliipop31' => true,
  'ptqd4yyrgdgdgbc4p4w9gv3r7' => true,
  'protxdalinersuresh_babu78' => true,
  'princesspeter_stormare_jr' => true,
  'princesspau_duro_da_bahia' => true,
  'princesseric.stratton1978' => true,
  'princesscesar-rodriguinho' => true,
  'phoenixsexytheresaconnors' => true,
  'phidqueswidahosinglespeed' => true,
  'phattrienkinhtelatrongtam' => true,
  'pepperricardo_santiago.10' => true,
  'pepperraffaelemasciarelli' => true,
  'pepperdeshazer.franciscus' => true,
  'passyernakov_neonilc1983y' => true,
  'passworspecial_world_2002' => true,
  'passworsebas_martinez1983' => true,
  'passworkevin.featherstone' => true,
  'password1zjpa7fll_p3qp5y4' => true,
  'password1searchforinformy' => true,
  'password1receva_valentina' => true,
  'password1pianist-musikant' => true,
  'password1mugancev_dmitrii' => true,
  'password1jolucocru_10_877' => true,
  'password1johnnyrebofdixie' => true,
  'password1jamespaulkssssss' => true,
  'password1jafferson-olaria' => true,
  'password1doublebirdstrike' => true,
  'password1copita_77_carito' => true,
  'password1kellyeshortiichg' => true,
  'passworbasiliothestraycat' => true,
  'passsweet_gawga_peach2004' => true,
  'oroxiefrederick_ohlweiler' => true,
  'oliveirabinadeloirdejesus' => true,
  'njrbpqld0bjcgv7vofovjq0o4' => true,
  'nickoedelavega09262340724' => true,
  'ncc1701ssttaanniissllaavv' => true,
  'ncc1701janfiska_kser0781e' => true,
  'natella.ivanovski05021991' => true,
  'natalyavybornyhsherbakova' => true,
  'natalya.kaydalovaakulenko' => true,
  'nandochetiincueacamminand' => true,
  'nagabandfanshiboom_sexy28' => true,
  'mustangpallaoromarioluigi' => true,
  'mustangcharlie_white_0101' => true,
  'mustangbkazimir.alie0185t' => true,
  'mustanggabrielmielesdxonj' => true,
  'monstrdarmaedvkontakte123' => true,
  'monkeyrabota.4.rasskazova' => true,
  'monkeyokaroli-ipyato0289r' => true,
  'monkeymustapaevavalentina' => true,
  'mkxxfffv2fjbwbilliec71351' => true,
  'minhasenhavocenaodescobre' => true,
  'michellepettitt-thetigers' => true,
  'michelleoazariyt_roj0188f' => true,
  'michellenewyorkislanders1' => true,
  'michellehellomotoman12345' => true,
  'michelleeuropeangoldfish3' => true,
  'michaelwonufriy.hbez0884i' => true,
  'michaelklezkaya_perekopka' => true,
  'michaelgelia.vsevolodovna' => true,
  'michaelfrangarinhafofinha' => true,
  'merlinyjjkyuhkhlrukoirdyu' => true,
  'merlinsweety_angel_alinka' => true,
  'merlinjdandtruthforchrist' => true,
  'merlinheadwitchhunter2000' => true,
  'mercedesmrlawrencetureaud' => true,
  'mazaev.aleksandr.19671967' => true,
  'maverickxgfxghfxghxfgf4xf' => true,
  'maverickfdtyfuygftyftyfty' => true,
  'matthewroiceannecancional' => true,
  'matthewdjangelsinthefield' => true,
  'matthewdarmabazarovahanda' => true,
  'matheussilvaalves99017262' => true,
  'matheusmartorelli78921266' => true,
  'mastermattberkeylovesweed' => true,
  'master_dark_magician_girl' => true,
  'martinkris.ofitserova2011' => true,
  'marseilleayun_khairunnisa' => true,
  'marlon2692119713942499770' => true,
  'marina.shekacheva18091986' => true,
  'marina.medianceva20051988' => true,
  'marciarosadebritooliveira' => true,
  'manuela|clubinterdit.com|' => true,
  'lovesporn@hungarianhoneys' => true,
  'londongazzleyoctavaespada' => true,
  'london_demon_mistress2905' => true,
  'libsumosisomera_christian' => true,
  'lhavbdfvhtbvjhnbvjhrvbhje' => true,
  'letmeinspring_branch_baby' => true,
  'letmeinsharmashraddha1989' => true,
  'lero4ka15121994belo4ka333' => true,
  'leonshirleelephantdiaries' => true,
  'lbvf12092000bpapasasa1970' => true,
  'lakerslistrichka-ljudmila' => true,
  'lsdfc.13151762$of.2191742' => true,
  'ktjyfhljlfdbyxb1123581321' => true,
  'kristina2909mekristina123' => true,
  'killerhjivenko_alev1984ya' => true,
  'kfgreckfnsi28082010ytndjz' => true,
  'kestrelsniper_loccoz_tres' => true,
  'kennethyopwmonaghan846019' => true,
  'katyaglinkova201507qwerty' => true,
  'katielinascimento94015969' => true,
  'katena.katya.love10051996' => true,
  'karecandykislnorris13_199' => true,
  'kain791345183571479134652' => true,
  'k.ksrkmjksrcbysqfkrjujksr' => true,
  'jxcvx06719ghghdsseiu0ls3j' => true,
  'justinthe_one_true_phyber' => true,
  'justinsummersolstice_1122' => true,
  'justinleonardodavinchi000' => true,
  'joshuala_caspa_del_diablo' => true,
  'jordanfranzelejhonsorillo' => true,
  'jordanbarranquerocristina' => true,
  'jessicadanielparaelmundo3' => true,
  'jessicacanadascowiglr2723' => true,
  'jenniferturbaev_baxytzhan' => true,
  'jenniferisidor.eva_1989ja' => true,
  'jefersonhiifabyamoreterno' => true,
  'jacksonqsilvesy_per1982li' => true,
  'jacksoncalini4encko-lilia' => true,
  'jacksonjonahvandenbussche' => true,
  'isaev_zhenyok_na_prichale' => true,
  'iridaceaerhjrecpjkjnbcnbq' => true,
  'ird_newsletter_subscriber' => true,
  'internetzh.begimova_olimp' => true,
  'internetthreejproductions' => true,
  'internetnagarjuna.bodduna' => true,
  'insightpangya_yulgung_007' => true,
  'iloveyouskuzovatovdmitrii' => true,
  'iloveyoupereplesnin.sasha' => true,
  'iloveyoumaryono_laymena76' => true,
  'iloveyoujamesbond17061984' => true,
  'iloveyoudrop_dead_sexy_09' => true,
  'ilovetechnosomuch02061993' => true,
  'ifyouareathudofherbaceous' => true,
  'ibelongtoyoujesusiloveyou' => true,
  'iamwhocybeslurpeedecastro' => true,
  'hwhhwlfchrimuel%3asexy4me' => true,
  'harleychocolatedickaholic' => true,
  'harleyangeloxcka.galusina' => true,
  'hammerbersain_rincon_anza' => true,
  'hamhoev9267547888temerlan' => true,
  'h9r8thhnh8rtbhtj95igb9ith' => true,
  'guitarmister.mishanya2011' => true,
  'guitardroggina-emelianova' => true,
  'grafchokolakyla1123581321' => true,
  'gnusmas12345just123456789' => true,
  'gjktyxer1rbhf2dfkthmtdyf3' => true,
  'gingerdaprpprdddddddddoll' => true,
  'ghtcnegktybtndjtujdhtvtyb' => true,
  'ghbdtnbrartemrfrltkf12345' => true,
  'ggv2pvw6w5d74igztsszwoyai' => true,
  'georgeabrahammartinez2008' => true,
  'generaln667stylkawesdxcvb' => true,
  'galichka1992matchenko1991' => true,
  'fyfcnfcbzyfcntymrf7536074' => true,
  'fuckmeviajeroafricano1957' => true,
  'fuckmestefan.ohrhallinger' => true,
  'fuckmeslowhands4ugiftdlvr' => true,
  'fuckmejburtsov.rozi1980zf' => true,
  'freedomflamezandstarz2001' => true,
  'freedombirthday77yadhtrib' => true,
  'footballtmstis-tkovr0289w' => true,
  'footballletyourheart_sing' => true,
  'footballlbukav_adawd1989u' => true,
  'footballasd10_asd10_asd10' => true,
  'footballanyelo_rodrigo-90' => true,
  'fffffffffffffffffffffffff' => true,
  'ferrarismpaulo_19_alvaran' => true,
  'ferraribakulaunimatrix001' => true,
  'ferforemaalessandro_datti' => true,
  'fedorrambosuperpupersuper' => true,
  'evilrubberduckyofdarkness' => true,
  'euamominhavo0144184010205' => true,
  'euamominhaestrela04121991' => true,
  'esteorkutfuehackeadojajaj' => true,
  'elmejormichristianaldwins' => true,
  'ekaterina.pirsova11121986' => true,
  'eiantiflagkistormcrow1971' => true,
  'ed923ejuf3f342i34f3fwrfwf' => true,
  'dyu324udiy23udyuyd3483248' => true,
  'dsxcfvuyfdrdcufutfytfytdf' => true,
  'drfghttggv54343fddr4r4fdf' => true,
  'dragonwinds-of-plague-dtw' => true,
  'dieoverscorpio_is_my_star' => true,
  'diangellanicolewilliamson' => true,
  'diamondmisecreto_deamortu' => true,
  'diamondeternally_missed_2' => true,
  'diamondaliev.magamed.2001' => true,
  'diamondsandra_south_bitch' => true,
  'dfinjythflj666dfinjythflj' => true,
  'deua02|jeunebaiseuse.com|' => true,
  'desktops.comstarmtknobuch' => true,
  'demkinpro15975356loko1996' => true,
  'delmyidentisasonofabitch1' => true,
  'deidara_aka_tsukuri220596' => true,
  'dbnfkbqdbrnjhjdbx32224ljv' => true,
  'dashkadashkadashkaaaaaaaa' => true,
  'danielqforop-sonyaw1985ek' => true,
  'danieljd_martyfranich2424' => true,
  'danieldababygurluwishuhad' => true,
  'dallasyassine.bouchataoui' => true,
  'cowboysali.moshtaghi.fard' => true,
  'cowboysklodijan_maqellara' => true,
  'corvettesameer_sameerjain' => true,
  'correcthorsebatterystaple' => true,
  'computerrachanabhardwaj11' => true,
  'computermegafuckinghacker' => true,
  'claneya1mcdaniellemasucci' => true,
  'christopherstraussabuel04' => true,
  'chrisblnv.nefyodorova2010' => true,
  'chofrenchyvigatwickmanvan' => true,
  'chickenhotshotdanielmoore' => true,
  'chicag060-707-5121jobe123' => true,
  'chelseayamasheva_evgeniya' => true,
  'cheesedarthridiculous2000' => true,
  'checpiperboyhasanhajhasan' => true,
  'charliehet.speelsetuintje' => true,
  'charliegallowiljackwright' => true,
  'charliel0rddimwitflathead' => true,
  'cbyrkbyfkbrb1234508773210' => true,
  'capellanjssevenfold_narzi' => true,
  'brightonx-766026brightonx' => true,
  'bradleychrimuel%3asexy4me' => true,
  'bqb7t3c4ff393qdrf3w4gbrq3' => true,
  'boroveshkin.ratak27041983' => true,
  'boboxxdanielle_lvz_jamesx' => true,
  'blackrose-promopass013110' => true,
  'bigdogxlomon.galyam.1984s' => true,
  'bigdoguonufriyb.sok0883pq' => true,
  'bigdogundone_online_radio' => true,
  'bigdogtyler_derden_fc1910' => true,
  'bigdognata_kuznecova_1983' => true,
  'batmanf417d853dcd911a3fcc' => true,
  'baseballsivuyise.ndzendze' => true,
  'baseballluzdosdesesperado' => true,
  'baseballloccitanebelgorod' => true,
  'baseballlysander_demaiter' => true,
  'baseball02.osincevaoksana' => true,
  'baronerossosofim123456789' => true,
  'banditdreamcollection1903' => true,
  'azulamareloverdesenhadela' => true,
  'assholegermansrifacruells' => true,
  'arsenalsophisticated_jell' => true,
  'arsenalcarlos_johncena_14' => true,
  'armandynamite_3rd_offense' => true,
  'apuillterrybronfanatic102' => true,
  'apaixonadoporthaina130594' => true,
  'aondequerqueeuvatelevocmg' => true,
  'anthonyykjukkhkjhghjhgjhg' => true,
  'anthonyying_yang_in_chaos' => true,
  'anthonytarina_anatolyevna' => true,
  'anthonyftballplaya4life13' => true,
  'anthonyannelies.debrauwer' => true,
  'angelsidnsevengirlz_onebo' => true,
  'andrealetmegetthistraight' => true,
  'anaeditebarbosadeoliveira' => true,
  'anacosta19bueno98715sahm3' => true,
  'amandazvnzavizion14081990' => true,
  'amandasummer_97_hernandez' => true,
  'amandanicole.jukeboxjunky' => true,
  'allisternative_butterfly8' => true,
  'albina.dzhanybekova221189' => true,
  'accessybezboro_kircu1981f' => true,
  'abkiod52adelthemunchkin77' => true,
  'abc123perfectstranger_313' => true,
  'abc123kiwiscottishgirl123' => true,
  'abc123itolma_valerys1985t' => true,
  'abc123theeternalspectator' => true,
  'aaaaaapriscilarezende_pva' => true,
  'aaaaaapatricia.aguiar1992' => true,
  'aaaaaaaaaaaaaaaaaaaaaaaax' => true,
  '_blue_jean_blue_sky_billy' => true,
  'z1u2qi5i024tx555z443xg2pb' => true,
  'xg0tazucgol3xmubwp7kepp8c' => true,
  'viveriveniversumvivusvici' => true,
  'vthsimbal1905198888915091' => true,
  'vale27764491998241155bbbb' => true,
  'ukfujkmtdybrbnfdbrnjhjdbx' => true,
  'tri1407povesti8919ovitali' => true,
  'thebestpasswordintheworld' => true,
  'tashaseliktashakosha10327' => true,
  'tkqns85zbyx3gjfpwmmw8mgqh' => true,
  'tecisafokingsexybeastz0rz' => true,
  'tcdjyfsozcvzddh9wuhhiukjw' => true,
  'sofiaalexandrovna0826bars' => true,
  'shiggs33-0.ww2cfkyyzjs-di' => true,
  'sn888ez939in595ka2012love' => true,
  'rafaelmuratbakiev18910309' => true,
  'qazwsxedcrfvtgbyhnujmikol' => true,
  'oriihq2sdjwmdpz4c9q45fwjr' => true,
  'nafi19912919oksanenok2912' => true,
  'loejfy7trwfyk6byjrqnjzsja' => true,
  'lltnrz4ngfdetbqmeivtmle5c' => true,
  'kishlar89220603713nikolay' => true,
  'hidj4at4t6n45mnhchooltrf2' => true,
  'gazelles.comtorp615cit236' => true,
  'game149pipec123aemadonna2' => true,
  'fx3v8gualfcik5pomcexstfhf' => true,
  'excite_egingerprincess711' => true,
  'ed1tdao67xjlznk2uxcot8mes' => true,
  'dtkbrjktgyfz729fktrcfylhf' => true,
  'datinggold-goldmember1301' => true,
  'cgfvths_gbljhfcs1986gbplf' => true,
  'certifiedplantmaintensupv' => true,
  'cyygur3h0rp3buz6mensa9ahf' => true,
  'bdfyjdbxkthfcnhexrjdbujhb' => true,
  'bwkp7y1naxm4lfkktneol9270' => true,
  'bhosxznicmedina3436216321' => true,
  '??n???n?00727n???n???n???' => true,
  '9qe6ghewiabugmqay05bmcpb1' => true,
  '971106xxxkzcegthpkjqutybq' => true,
  '933502779stevelvetmclasky' => true,
  '9202lbjh3730gbdj0203yjrbz' => true,
  '89513115915angelishksuper' => true,
  '89508031047elyaplotnikova' => true,
  '8927090246089374240484vrn' => true,
  '89248914199207052009chiga' => true,
  '89228477321z89228849446zz' => true,
  '89213225114vad89213224814' => true,
  '89045752923628611andreyka' => true,
  '890255818578rfnzifdjxrbyf' => true,
  '8888888888888888888888888' => true,
  '873961020320xtzthaisricci' => true,
  '8731.3852.3852.2008-06-29' => true,
  '8433bleachedgrounderz7644' => true,
  '81534976105338730124vinte' => true,
  '80978531048tanja231019930' => true,
  '7xdiwkri1hrnj9ebzfyppg9hy' => true,
  '789456123njilldestroysjac' => true,
  '7745654746457565456745lll' => true,
  '73856214431valekguitarist' => true,
  '6kqz0dgx2yrmawnro4gjw63aq' => true,
  '6936220974371267kondratiy' => true,
  '654321sulotera_12_phanget' => true,
  '654321blink18244444342003' => true,
  '5ojpu6ibmsheffieldbrother' => true,
  '5friendslittlelittlegreen' => true,
  '593766759840336961758yana' => true,
  '5900539403david10.11.1995' => true,
  '581326035berkytljynrbkkvb' => true,
  '538873sitibombshellbullie' => true,
  '537fc9eecf3e56d7cdrewboye' => true,
  '528162f528162f89043287202' => true,
  '525721xalittle_princess96' => true,
  '509465b66cf4d3fascarphase' => true,
  '4rsyx10calalexandrewsloan' => true,
  '4815162342o815108lostjk89' => true,
  '45c24c18$0$43037$4fafbaef' => true,
  '43f8e57c$0$28052$2c56edd9' => true,
  '425ac4a7$0$10822$afc38c87' => true,
  '41433244545corlolkarvadol' => true,
  '410n9pa55wordy0ucantqu3ss' => true,
  '4071981tatiana_makrushina' => true,
  '3yy6q9pudgaltimothy300858' => true,
  '3f338fa2$0$27026$626a54ce' => true,
  '3f07ca18$0$17913$a3f2974a' => true,
  '3mc3tch6564464iyh64t6liu3' => true,
  '3957035290975016041252947' => true,
  '347007cvbnrtyuehefutyn007' => true,
  '33xtj1sbf7matchsuhsbatch7' => true,
  '3304595601rhfcbdfzltdeirf' => true,
  '28sytxgzrnx1szz_annalogue' => true,
  '28081996fabianacampanelli' => true,
  '258749602587496025874960z' => true,
  '2568.4194.3694.2009-04-29' => true,
  '20367678631729doctorkuzia' => true,
  '1gna38cqf361muktfd1c18aes' => true,
  '19rvp8ramsanoos_kulvine6e' => true,
  '19991206kristina258445254' => true,
  '199219931994199519961997.' => true,
  '1987styrrey9374superseven' => true,
  '198719891992jonasbrothers' => true,
  '18771877nimarcianita_2506' => true,
  '18067114atsushia.kitamura' => true,
  '178612682lasasylady_harve' => true,
  '1717253velverfgityjzxvtym' => true,
  '1369sasylidukeofallhaitia' => true,
  '123valerusik456anahkin789' => true,
  '123vzurbtrhjirbbuheirb456' => true,
  '123456789vadimka123456789' => true,
  '123456789987654321147luba' => true,
  '123456789123456789yufgbn7' => true,
  '123456789101112131415olga' => true,
  '123321123321qweewqqweeewq' => true,
  '122333444455555666666mena' => true,
  '121212owusuappiah.stephen' => true,
  '121212noyabrina.devyatova' => true,
  '121212mastermind27_daitol' => true,
  '1212121666susann.weinhold' => true,
  '11schyangel1jolil_mohamme' => true,
  '111cergei333gornostaev555' => true,
  '111527251grt101625lolfate' => true,
  '11111006sdetal123lebed123' => true,
  '111019380906194004061970p' => true,
  '11081992kolomiez_olexandr' => true,
  '10201215141312vika1112111' => true,
  '10091992rusnachuk10091992' => true,
  '09099068patricia_11_03_96' => true,
  '079739988zaq1xsw2cde3vfr4' => true,
  '*****lyashenko190493*****' => true,
  '#minal@9921370887@ganvir#' => true,
);