OC.L10N.register(
    "oauth2",
    {
    "Your client is not authorized to connect. Please inform the administrator of your client." : "İstemcinizin bağlanma izni yok. Lütfen BT yöneticinize istemciniz ile ilgili bilgi verin.",
    "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path" : "Yönlendirme adresi https://sitem.com/yol gibi tam bir adres olmalıdır",
    "OAuth 2.0" : "OAuth 2.0",
    "Allows OAuth2 compatible authentication from other web applications." : "Diğer site uygulamaları için OAuth2 uyumlu kimlik doğrulaması sağlar.",
    "The OAuth2 app allows administrators to configure the built-in authentication workflow to also allow OAuth2 compatible authentication from other web applications." : "OAuth2 uygulaması, BT yöneticilerinin iç kimlik doğrulama iş akışını yapılandırabilmesini ve diğer site uygulamaları için OAuth2 uyumlu kimlik doğrulaması kullanılabilmesini sağlar.",
    "Secret key" : "Gizli anahtar",
    "Delete" : "Sil",
    "An unknown error occurred." : "Bilinmeyen bir sorun çıktı.",
    "OAuth 2.0 clients" : "OAuth 2.0 istemcileri",
    "OAuth 2.0 allows external services to request access to {instanceName}." : "OAuth 2.0 dış hizmetlerin {instanceName} için erişim isteğinde bulunmasını sağlar.",
    "Name" : "Ad",
    "Redirection URI" : "Yönlendirme adresi",
    "Client identifier" : "İstemci belirteci",
    "Delete client" : "İstemciyi sil",
    "Make sure you store the secret key, it cannot be recovered." : "Yeniden öğrenilemeyeceği için gizli anahtarı kaydettiğinizden emin olun.",
    "Add client" : "İstemci ekle",
    "Add" : "Ekle",
    "Client Identifier" : "İstemci belirteci",
    "Show client secret" : "İstemci parolasını görüntüle",
    "Hide client secret" : "İstemci parolasını gizle"
},
"nplurals=2; plural=(n > 1);");
