OC.L10N.register(
    "files",
    {
    "Added to favorites" : "Додано зірочку",
    "Removed from favorites" : "Вилучено зірочку",
    "You added {file} to your favorites" : "Ви додали зірочку для {file}",
    "You removed {file} from your favorites" : "Ви прибрали зірочку для {file}",
    "Favorites" : "Із зірочкою",
    "File changes" : "Зміни у файлах",
    "Created by {user}" : "Створено користувачем {user}",
    "Changed by {user}" : "Змінено користувачем {user}",
    "Deleted by {user}" : "Вилучено користувачем {user}",
    "Restored by {user}" : "Відновлено користувачем {user}",
    "Renamed by {user}" : "Перейменовано користувачем {user}",
    "Moved by {user}" : "Переміщено користувачем {user}",
    "\"remote account\"" : "\"віддалений обліковий запис\"",
    "You created {file}" : "Ви створили {file}",
    "You created an encrypted file in {file}" : "Ви створили зашифрований файл у {file}",
    "{user} created {file}" : "{user} створив(-ла) файл {file}",
    "{user} created an encrypted file in {file}" : "{user} створив(-ла) зашифрований файл у {file}",
    "{file} was created in a public folder" : "Файл {file} створено у публічному каталозі",
    "You changed {file}" : "Ви змінили файл {file}",
    "You changed an encrypted file in {file}" : "Ви змінили зашифрований файл у {file}",
    "{user} changed {file}" : "{user} змінив(-ла) файл {file}",
    "{user} changed an encrypted file in {file}" : "{user} змінив(-ла) зашифрований файл {file}",
    "You deleted {file}" : "Ви вилучили {file}",
    "You deleted an encrypted file in {file}" : "Ви вилучити зашифрований файл у {file}",
    "{user} deleted {file}" : "{user} вилучив(-ла) {file}",
    "{user} deleted an encrypted file in {file}" : "{user} вилучив зашифрований файл у {file}",
    "You restored {file}" : "Ви відновили {file}",
    "{user} restored {file}" : "{user} відновив(-ла) {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Ви перейменували файл {oldfile} (прихований) на {newfile} (прихований)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Ви перейменували файл {oldfile} (прихований) на {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Ви перейменували файл {oldfile} на {newfile} (прихований)",
    "You renamed {oldfile} to {newfile}" : "Ви перейменували файл {oldfile} на {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} перейменував {oldfile} (прихований) у {newfile} (прихований)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} перейменував {oldfile} (прихований) у {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} перейменував {oldfile} у {newfile} (прихований)",
    "{user} renamed {oldfile} to {newfile}" : "{user} перейменував(-ла) {oldfile} у {newfile}",
    "You moved {oldfile} to {newfile}" : "Ви перемістили {oldfile} до {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} перемістив(-ла) {oldfile} до {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Файл було додано або вилучено з ваших документів <strong>із зірочкою</strong>",
    "Files" : "Файли",
    "A file or folder has been <strong>changed</strong>" : "Файл або каталог було <strong> змінено </strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "Файл або каталог із зірочкою було <strong>змінено</strong>",
    "Failed to authorize" : "Не вдалося авторизуватися",
    "Invalid folder path" : "Недійсний шлях до каталогу",
    "Folder not found" : "Каталог не знайдено",
    "The file cannot be found" : "Цей файл неможливо знайти",
    "The destination path does not exist: %1$s" : "Шлях призначення відсутній: %1$s",
    "You do not have permission to create a file at the specified location" : "У вас відсутні права на створення файлу у визначеному розташуванні",
    "The file could not be converted." : "Файл неможливо конвертувати",
    "Could not get relative path to converted file" : "Не вдалося отримати відносний шлях до сконвертованого файлу",
    "Limit must be a positive integer." : "Ліміт має бути позитивним числом.",
    "The replacement character may only be a single character." : "Символ заміни може містити тільки один знак.",
    "Filename sanitization already started." : "Санація імен файлів вже розпочалася.",
    "No filename sanitization in progress." : "Санація імен файлів не виконується.",
    "Favorite files" : "Файли із зірочкою",
    "No favorites" : "Немає улюблених",
    "More favorites" : "Ще файли із зірочкою",
    "No read permission on file." : "Відсутні права на читання файлу.",
    "Accept" : "Прийняти",
    "Reject" : "Відхилити",
    "Incoming ownership transfer from {user}" : "Запит від користувача {user} на передавання прав власника",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Прийняти {path}?\n\nУвага: Процес передавання після прийняття запиту може тривати до 1 години.",
    "Ownership transfer denied" : "Перенесення прав власності відхилено",
    "Your ownership transfer of {path} was denied by {user}." : "Перенесення прав на ваші дані {path} відхилено користувачем {user}.",
    "Ownership transfer failed" : "Не вдалося передати право власності",
    "Your ownership transfer of {path} to {user} failed." : "Не вдалося перадати ваші права власника на {path} користувачеві {user}.",
    "The ownership transfer of {path} from {user} failed." : "Не вдалося передати права власника на {path} від користувача {user}.",
    "Ownership transfer done" : "Право власності передано",
    "Your ownership transfer of {path} to {user} has completed." : "Ваші права власника на {path} успішно передано користувачеві {user}.",
    "The ownership transfer of {path} from {user} has completed." : "Завершено передавання права власника на {path} від користувача {user}.",
    "in %s" : "в %s",
    "Transferred from %1$s on %2$s" : "Перенесено від %1$s до %2$s",
    "Create files" : "Створювати файли",
    "Delete files" : "Вилучити файли",
    "Download files" : "Звантажувати файли",
    "When disabled, the option to download will be hidden" : "Якщо вимкнено, параметр для звантаження файлів буде приховано",
    "View files" : "Переглядати файли",
    "Edit files" : "Редагувати файли",
    "Show files in grid view" : "Подання файлів сіткою",
    "File" : "Файл",
    "File Management" : "Керування файлами",
    "Home" : "Домівка",
    "Target folder does not exist any more" : "Каталог призначення більше не дійсний",
    "Reload current directory" : "Перезавантажити поточний каталог",
    "Go to the \"{dir}\" directory" : "Перейти до каталогу \"{dir}\"",
    "Current directory path" : "Шлях до поточного каталогу",
    "Share" : "Поширити",
    "Reload content" : "Перезавантажити вміст",
    "Your have used your space quota and cannot upload files anymore" : "Ви вже використали квоту на місце та не можете завантажувати файли",
    "You do not have permission to upload or create files here." : "У вас відсутній дозвіл завантажувати або створювати тут файли.",
    "Drag and drop files here to upload" : "Перетягніть файли сюди для завантаження",
    "Favorite" : "Додати зірочку",
    "Back" : "Назад",
    "Toggle selection for file \"{displayName}\"" : "Перемкнути вибір для файлу \"{displayName}\"",
    "Toggle selection for folder \"{displayName}\"" : "Перемкнути вибір для каталогу \"{displayName}\"",
    "File is loading" : "Завантаження файлу",
    "Folder is loading" : "Завантаження каталогу",
    "Filename" : "Ім'я файлу",
    "Folder name" : "Назва каталогу",
    "{displayName} (unavailable)" : "{displayName} (недоступно)",
    "Another entry with the same name already exists." : "Інший запис з таким же ім'ям вже присутній",
    "Invalid filename." : "Недійсне ім'я файлу.",
    "Rename file" : "Перейменувати файл",
    "Recently created" : "Нещодавно створено",
    "Folder" : "Каталог",
    "Unknown file type" : "Невідомий тип файлу",
    "{ext} image" : "{ext} зображення",
    "{ext} video" : "{ext} відео",
    "{ext} audio" : "{ext} аудіо",
    "{ext} text" : "{ext} текст",
    "Pending" : "Очікування",
    "Unknown date" : "Невідома дата",
    "Active filters" : "Активні фільтри",
    "Remove filter" : "Вилучити фільтр",
    "Today" : "Сьогодні",
    "Last 7 days" : "За останні 7 днів",
    "Last 30 days" : "За останні 30 днів",
    "This year ({year})" : "Цього року ({year})",
    "Last year ({year})" : "Минулого року ({year})",
    "Custom range" : "Власний діяпазон",
    "Custom date range" : "Власний вибір проміжку",
    "Search everywhere" : "Шукати всюди",
    "Documents" : "Документи",
    "Spreadsheets" : "Електронні таблиці",
    "Presentations" : "Презентації",
    "PDFs" : "Файли PDF",
    "Folders" : "Каталоги",
    "Audio" : "Аудіо",
    "Images" : "Зображення",
    "Videos" : "Відео",
    "Filters" : "Фільтри",
    "Back to filters" : "Повернутися до фільтрів",
    "Appearance" : "Вигляд",
    "Show hidden files" : "Показувати приховані файли",
    "Show file type column" : "Показувати стовпець з типом файлу",
    "Show file extensions" : "Показувати розширення файлів",
    "Crop image previews" : "Попередній перегляд перед кадруванням",
    "General" : "Загальне",
    "Sort favorites first" : "Спочатку показувати із зірочкою",
    "Sort folders before files" : "Показувати каталоги перед файлами",
    "Enable folder tree view" : "Увімкнути показ дерева каталогів",
    "Default view" : "Типовий вигляд",
    "All files" : "Усі файли",
    "Personal files" : "Мої документи",
    "Additional settings" : "Додатково",
    "Actions" : "Дії",
    "File actions" : "Дії з файлами",
    "Selection" : "Вибір",
    "Select all files" : "Вибрати всі файли",
    "Deselect all" : "Зняти всі мітки",
    "Select or deselect" : "Вибрати або скасувати вибір",
    "Select a range" : "Виберіть діапазон",
    "Navigation" : "Навігація",
    "Go to parent folder" : "Перейти до батьківського каталогу",
    "Go to file above" : "Перейти до файлу вище",
    "Go to file below" : "Перейти до файлу нижче",
    "Go left in grid" : "Перейти ліворуч у сітці",
    "Go right in grid" : "Перейти праворуч у сітці",
    "View" : "Подання",
    "Toggle grid view" : "Перемкнути подання сіткою",
    "Show those shortcuts" : "Показувати ці скорочення",
    "Warnings" : "Застереження",
    "Warn before changing a file extension" : "Попереджати перед зміною розширення файлу",
    "Warn before deleting a file" : "Попереджати перед вилученням файлу",
    "WebDAV URL" : "URL-адреса WebDAV",
    "Create an app password" : "Створити пароль застосунку",
    "Required for WebDAV authentication because Two-Factor Authentication is enabled for this account." : "Вимагається для автентифікації WebDAV, оскільки увімкнено двофакторну автентифікацію для цього облікового запису.",
    "How to access files using WebDAV" : "Як отримати доступ до файлів за допомогою WebDAV",
    "Total rows summary" : "Загалом рядків",
    "Toggle selection for all files and folders" : "Перемкнути вибір для всіх файлів та каталогів",
    "Name" : "Ім'я",
    "File type" : "Тип файлу",
    "Size" : "Розмір",
    "Modified" : "Змінено",
    "{displayName}: failed on some elements" : "{displayName}: не вдалося виконати деякі елементи",
    "{displayName}: done" : "{displayName}: готово",
    "{displayName}: failed" : "{displayName}: не вдалося",
    "(selected)" : "(вибрано)",
    "List of files and folders." : "Список файлів та каталогів",
    "You have used your space quota and cannot upload files anymore." : "Ви вже використали ліміт сховища та більше не зможете завантажувати файли.",
    "Column headers with buttons are sortable." : "Назви стовпців з кнопками можна впорядковувати",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Список не подається повністю з міркувань обчислювальних потужностей. Файли показуватимуться під час прокручування списку.",
    "File not found" : "Файл не знайдено",
    "_{count} selected_::_{count} selected_" : ["Вибрано {count}","Вибрано {count}","Вибрано {count} ","Вибрано {count} "],
    "Views" : "Подання",
    "Search everywhere …" : "Шукайте скрізь ...",
    "Search here …" : "Швидкий фільтр ...",
    "Search scope options" : "Визначити місце пошуку",
    "Search here" : "Швидкий пошук",
    "Owner" : "Власник",
    "{usedQuotaByte} used" : "{usedQuotaByte} використано",
    "{used} of {quota} used" : "Використано {used} із {quota}",
    "{relative}% used" : "{relative}% використано",
    "Could not refresh storage stats" : "Неможливо оновити статистику сховища",
    "Your storage is full, files can not be updated or synced anymore!" : "Ваше сховище переповнене, файли більше не можуть бути оновлені або синхронізовані!",
    "Storage information" : "Інформація про сховище",
    "Storage quota" : "Квота сховища",
    "New folder" : "Новий каталог",
    "Create new folder" : "Створити новий каталог",
    "This name is already in use." : "Це ім'я вже використовується",
    "Create" : "Створити",
    "Files starting with a dot are hidden by default" : "Файли, що починаються з крапки, типово приховано",
    "Failed to start filename sanitization." : "Не вдалося запустити санітарну обробку імен файлів.",
    "Failed to refresh filename sanitization status." : "Не вдалося оновити статус санітарної обробки імені файлу.",
    "Filename sanitization in progress." : "Триває санітарна обробка імені файлу.",
    "Currently {processedUsers} of {totalUsers} accounts are already processed." : "Наразі вже оброблено {processedUsers} акаунтів з {totalUsers}.",
    "Preparing …" : "Підготовка ...",
    "Refresh" : "Оновити",
    "All files have been santized for Windows filename support." : "Усі файли було сантифіковано для підтримки імен файлів у Windows.",
    "Some files could not be sanitized, please check your logs." : "Деякі файли не вдалося очистити, будь ласка, перевірте свої логи.",
    "Sanitization errors" : "Помилки санітарної обробки",
    "Not sanitized filenames" : "Несанітарні імена файлів",
    "Windows filename support has been enabled." : "Увімкнено сумісність з найменуванням файлів у Windows.",
    "While this blocks users from creating new files with unsupported filenames, existing files are not yet renamed and thus still may break sync on Windows." : "Хоча це забороняє користувачам створювати нові файли з непідтримуваними іменами, наявні файли ще не перейменовано, а отже, вони все ще можуть порушувати синхронізацію у Windows.",
    "You can trigger a rename of files with invalid filenames, this will be done in the background and may take some time." : "Ви можете ініціювати перейменування файлів з неправильними іменами, це буде виконано у фоновому режимі і може зайняти деякий час.",
    "Please note that this may cause high workload on the sync clients." : "Зауважте, що це може спричинити високе навантаження на клієнти синхронізації.",
    "Limit" : "Ліміт",
    "This allows to configure how many users should be processed in one background job run." : "Це дозволяє налаштувати, скільки користувачів має бути оброблено за один запуск фонового завдання.",
    "Sanitize filenames" : "Санація імен файлів",
    "(starting)" : "(початок)",
    "Fill template fields" : "Заповнити поля шаблону",
    "Submitting fields …" : "Поля для заповнення ...",
    "Submit" : "Відправити",
    "Choose a file or folder to transfer" : "Виберіть файл або каталог",
    "Transfer \"{path}\"" : "Передати \"{path}\"",
    "Select file or folder" : "Виберіть файл або каталог",
    "Transfer" : "Передати",
    "Transfer {path} to {userid}" : "Передати {path} користувачеві {userid}",
    "Error while opening file picker for transfer ownership" : "Помилка під час відкриття вибору файлу для передачі права власности",
    "Error while searching for users" : "Помилка під час пошуку користувачів",
    "Ownership transfer request sent" : "Запит на передавання прав власника надіслано",
    "Cannot transfer ownership of a file or folder you do not own" : "Неможливо передати права власності на файл або каталог, якими ви не володієте",
    "Error while sending ownership transfer request" : "Помилка під час надсилання запиту на передачу права власности",
    "Transfer ownership of a file or folder" : "Передавання прав власника на файл або каталог",
    "File or folder to transfer" : "Файл або каталог для передачі",
    "No file or folder selected" : "Файл або каталог не вибрано",
    "New owner" : "Новий власник",
    "You need to select a file or folder to transfer ownership." : "Потрібно вибрати файл або каталог для передачі права власности",
    "You need to select a new owner for the file or folder." : "Потрібно вибрати нового власника для файлу або каталогу",
    "Keep {old}" : "Зберегти {old}",
    "Keep without extension" : "Зберегти без розширення",
    "Use {new}" : "Використовувати {new}",
    "Remove extension" : "Вилучити розширення файлу",
    "Change file extension" : "Змінити розширення файлу",
    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "Заміна розширення файлу з \"{old}\" на \"{new}\" може зробити файл недоступним.",
    "Removing the file extension \"{old}\" may render the file unreadable." : "Вилучення розширення файлу \"{old}\" може зробити файл недоступним.",
    "Adding the file extension \"{new}\" may render the file unreadable." : "Додавання розширення до файлу \"{new}\" може зробити файл недоступним.",
    "Do not show this dialog again." : "Більше не заптувати",
    "Rename file to hidden" : "Перейменувати файл у прихований",
    "Prefixing a filename with a dot may render the file hidden." : "Якщо додати крапку перед ім'ям файлу зробить файл прихованим.",
    "Are you sure you want to rename the file to \"{filename}\"?" : "Дійсно перейменувати файл у \"{filename}\"?",
    "Cancel" : "Скасувати",
    "Rename" : "Перейменувати",
    "Select file or folder to link to" : "Виберіть файл або каталог, до якого потрібно застосувати посилання",
    "Choose {file}" : "Виберіть {file}",
    "Files settings" : "Налаштування",
    "Switch to list view" : "У вигляді списку",
    "Switch to grid view" : "У вигляді сітки",
    "The file could not be found" : "Неможливо знайти файл",
    "Upload was cancelled by user" : "Завантаження скасовано користувачем",
    "Not enough free space" : "Недостатньо вільного місця",
    "Operation is blocked by access control" : "Операцію заблоковано через контроль доступу",
    "Error during upload: {message}" : "Помилка під час завантаження: {message}",
    "Error during upload, status code {status}" : "Помилка під час завантаження, код стану {status}",
    "Unknown error during upload" : "Невідома помилка під час завантаження",
    "File list is reloading" : "Список файлів перезавантажується",
    "Loading current folder" : "Отримання поточного каталогу",
    "Retry" : "Ще раз",
    "No files in here" : "Тут немає файлів",
    "Upload some content or sync with your devices!" : "Завантажте вміст або синхронізуйтеся з вашими пристроями!",
    "Go back" : "Повернутися назад",
    "Loading …" : "Завантаження …",
    "Your files" : "Ваші файли",
    "Open in files" : "Відкрити у файлах",
    "File cannot be accessed" : "Неможливо отримати доступ до файлу",
    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Не вдалося знайти файл або у вас відсутній дозвіл на перегляд файлу. Попросіть поділитися цим файлом.",
    "No search results for “{query}”" : "Відсутні результати для \"{query}\"",
    "Search for files" : "Шукати файли",
    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Дозволити обмежувати імена файлів для забезпечення сумісності з різними клієнтами. Типово всі імена файлів, які  відповідають моделі POSIX (напр., Linux, macOS), дозволені.",
    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Після увімкнення сумісности імен файлів з системою Windows наявні файли неможливо буде змінити, але власники зможуть перейменувати ці файли на нові з дійсними іменами.",
    "Failed to toggle Windows filename support" : "Не вдалося перемкнути підтримку файлів для Windows",
    "Files compatibility" : "Сумісність файлів",
    "Enforce Windows compatibility" : "Увімкнути сумісність із Windows",
    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Це унеможливить використання імен файлів, які не сумісні з системами Windows, напр., використанння зарезервованих імен або спеціальних символів. Зауважте, що це не обмежить сумісність за регістром символів.",
    "Blank" : "Порожньо",
    "Unable to create new file from template" : "Неможливо створити новий файл з шаблону",
    "Pick a template for {name}" : "Вибрати шаблон для {name}",
    "Create a new file with the selected template" : "Створити новий файл на основі вибраного шаблону",
    "Creating file" : "Створення файлу",
    "Save as {displayName}" : "Зберегти як {displayName}",
    "Save as …" : "Зберегти як ...",
    "Converting files …" : "Перетворення файлів ...",
    "Failed to convert files: {message}" : "Не вдалося конвертувати файли: {message}",
    "All files failed to be converted" : "Не вдалося конвертувати жодний файл",
    "One file could not be converted: {message}" : "Неможливо конвертувати один файл: {message}",
    "_%n file could not be converted_::_%n files could not be converted_" : ["%n файл неможливо конвертувати","%n файли неможливо конвертувати","%n файлів неможливо конвертувати","%n файлів неможливо конвертувати"],
    "_%n file converted_::_%n files converted_" : ["%n файл конвертовано","%n файли конвертовано","%n файлів конвертовано","%n файлів конвертовано"],
    "Files converted" : "Файли конвертовано",
    "Failed to convert files" : "Не вдалося конвертувати файли",
    "Converting file …" : "Конвертування файлу ...",
    "File successfully converted" : "Файл успішно конвертовано",
    "Failed to convert file: {message}" : "Не вдалося конвертувати файл: {message}",
    "Failed to convert file" : "Не вдалося конвертувати файл",
    "Delete" : "Вилучити",
    "Leave this share" : "Вийти зі спільного доступу",
    "Leave these shares" : "Вийти зі спільного доступу",
    "Disconnect storage" : "Від’єднати сховище",
    "Disconnect storages" : "Від'єднати сховища",
    "Delete permanently" : "Вилучити назавжди",
    "Delete and unshare" : "Вилучити та прибрати спільний доступ",
    "Delete file" : "Вилучити файл",
    "Delete folder" : "Вилучити каталог",
    "Delete folders" : "Вилучити каталоги",
    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Ви намагаєтеся назавжли вилучити {count} ресурс","Ви намагаєтеся назавжли вилучити {count} ресурси","Ви намагаєтеся назавжли вилучити {count} ресурсів","Ви намагаєтеся назавжли вилучити {count} ресурсів"],
    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Ви намагаєтеся вилучити {count} ресурс","Ви намагаєтеся вилучити {count} ресурси","Ви намагаєтеся  вилучити {count} ресурсів","Ви намагаєтеся вилучити {count} ресурсів"],
    "Confirm deletion" : "Підтвердіть вилучення",
    "Download" : "Звантажити",
    "The requested file is not available." : "Запитаний файл відсутній.",
    "The requested files are not available." : "Запитані файли відсутні.",
    "Add to favorites" : "Додати зірочку",
    "Remove from favorites" : "Прибрати зірочку",
    "Add or remove favorite" : "Додати або видалити з улюблених",
    "Move" : "Перемістити",
    "Copy" : "Копіювати",
    "Move or copy" : "Перемістити або копіювати",
    "Destination is not a folder" : "Місце призначення не є каталогом",
    "This file/folder is already in that directory" : "Такий файл чи каталог вже присутні в цьому каталозі",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "Неможливо перемістити файл чи каталог до самого себе або у цей саме підкаталог",
    "A file or folder with that name already exists in this folder" : "Файл чи каталог з таким ім'ям вже присутній в цьому каталозі",
    "The files are locked" : "Файли заблоковано",
    "The file does not exist anymore" : "Цей файл більше недоступний",
    "Moving \"{source}\" to \"{destination}\" …" : "Переміщення \"{source}\" на \"{destination}\" ...",
    "_Moving %n file to \"{destination}\" …_::_Moving %n files to \"{destination}\" …_" : ["Переміщення %n файлу до \"{destination}\" ...","Переміщення %n файлів до \"{destination}\" ...","Переміщення %n файлів до \"{destination}\" ...","Переміщення %n файлів до \"{destination}\" ..."],
    "Copying \"{source}\" to \"{destination}\" …" : "Копіювання \"{source}\" в \"{destination}\" ...",
    "_Copying %n file to \"{destination}\" …_::_Copying %n files to \"{destination}\" …_" : ["Копіювання %n файлу до \"{destination}\" ...","Копіювання %n файлів до \"{destination}\" ...","Копіювання %n файлів до \"{destination}\" ...","Копіювання %n файлів до \"{destination}\" ..."],
    "Choose destination" : "Виберіть каталог призначення",
    "Copy to {target}" : "Копіювати до {target}",
    "Move to {target}" : "Перемістити до {target}",
    "Move or copy operation failed" : "Не вдалося скопіювати або перемістити",
    "Open folder" : "Відкрити каталог",
    "Open folder {displayName}" : "Відкрити каталог {displayName}",
    "Open in Files" : "Відкрити у Файлах",
    "Open locally" : "Відкрити локально",
    "Failed to redirect to client" : "Не вдалося перенаправити на клієнта",
    "Open file locally" : "Відкрити файл локально",
    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Тепер файл можна відкрити на вашому пристрої. Якщо він не відкривається, перевірте, що у вас встановлено настільний клієнт синхронізації.",
    "Retry and close" : "Спробувати ще раз",
    "Open online" : "Відкрити віддалено",
    "Details" : "Докладно",
    "Open the details sidebar" : "Відкрити бічну панель з деталями",
    "Unfavorite" : "Прибрати зірочку",
    "View in folder" : "Переглянути у каталозі",
    "Type" : "Тип",
    "Created new folder \"{name}\"" : "Створив(-ла) новий каталог \"{name}\"",
    "Unable to initialize the templates directory" : "Неможливо встановити каталог з шаблонами",
    "Create templates folder" : "Створити каталог для шаблонів",
    "Templates" : "Шаблони",
    "New template folder" : "Новий каталог шаблонів",
    "In folder" : "У каталозі",
    "Pick folder to search in" : "Вибрати каталог для пошуку",
    "Search in all files" : "Пошук у всіх файлах",
    "Search in folder: {folder}" : "Шукати у каталозі: {folder}",
    "One of the dropped files could not be processed" : "Один із завантажених файлів не вдалося обробити",
    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Ваш бравзер не підтримує Filesystem API. Каталоги не буде завантажено",
    "No files to upload" : "Відсутні файли для завантаження",
    "Unable to create the directory {directory}" : "Неможливо створити каталог {directory}",
    "Some files could not be uploaded" : "Не вдалося завантажити окремі файли",
    "Files uploaded successfully" : "Файли успішно завантажено",
    "No files to process" : "Відсутні файли для обробки",
    "Files copied successfully" : "Файли успішно скопійовано",
    "Files moved successfully" : "Файли успішно переміщено",
    "Some files could not be copied" : "Неможливо скопіювати окремі файли",
    "Some files could not be moved" : "Окремі файли неможливо перемістити",
    "Conflicts resolution skipped" : "Пропущено розв'язання конфліктів",
    "Upload cancelled" : "Завантаження скасовано",
    "Could not rename \"{oldName}\", it does not exist any more" : "Не вдалося перейментувати \"{oldName}\", оскільки він вже відсутній",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Ім'я \"{newName}\" вже використовується у каталозі \"{dir}\". Виберіть інше ім'я.",
    "Could not rename \"{oldName}\"" : "Не вдалося перейменувати \"{oldName}\"",
    "This operation is forbidden" : "Операцію заборонено",
    "This folder is unavailable, please try again later or contact the administration" : "Цей каталог недоступний, спробуйте пізніше або зверніться до адміністратора.",
    "Storage is temporarily not available" : "Сховище тимчасово недоступне",
    "Unexpected error: {error}" : "Неочікувана помилка: {error}",
    "Unknown error" : "Невідома помилка",
    "_%n file_::_%n files_" : ["%n файл","%n файли","%n файлів","%n файлів"],
    "_%n folder_::_%n folders_" : ["%n каталог ","%n каталоги ","%n каталогів ","%n каталогів"],
    "_%n hidden_::_%n hidden_" : ["%n приховано","%n приховано","%n приховано","%n приховано"],
    "Folder name must not be empty." : "Ім'я каталогу не може бути порожнє",
    "Filename must not be empty." : "Імена файлів не мають бути порожні.",
    "\"{char}\" is not allowed inside a folder name." : "\"{char}\" не дозволено всередині імени каталогу.",
    "\"{char}\" is not allowed inside a filename." : "Символ \"{char}\" не дозволено у імені файлу.",
    "\"{segment}\" is a reserved name and not allowed for folder names." : "\"{segment}\" є зарезервованим ім'ям і не дозволено і імені каталогу.",
    "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" є зарезервованим ім'ям і не дозволяється у іменах файлів.",
    "\"{extension}\" is not an allowed filetype." : "\"{extension}\" не є дозволеним типом файлів.",
    "Folder names must not end with \"{extension}\"." : "Ім'я каталогу не може закінчуватися на \"{extension}\".",
    "Filenames must not end with \"{extension}\"." : "Імена файлів не мають закінчуватися на \"{extension}\".",
    "Invalid folder name." : "Недійсне ім'я каталогу.",
    "List of favorite files and folders." : "Список файлів та каталогів із зірочкою.",
    "No favorites yet" : "Відсутні файли чи каталоги, позначені зірочкою",
    "Files and folders you mark as favorite will show up here" : "Файли та каталоги із зірочкою з’являться тут",
    "List of your files and folders." : "Список ваших файлів та каталогів.",
    "Folder tree" : "Дерево каталогів",
    "List of your files and folders that are not shared." : "Перелік ваших файлів та каталогів, які не є у спільному доступі.",
    "No personal files found" : "Мої документи не знайдено",
    "Files that are not shared will show up here." : "Тут показуватимуться файли, які не є у спільному доступі.",
    "Recent" : "Останні",
    "List of recently modified files and folders." : "Список нещодавно змінених файлів та каталогів.",
    "No recently modified files" : "Відсутні файли, які було нещодавно змінено",
    "Files and folders you recently modified will show up here." : "Тут показуватимуться файли та каталоги, які було нещодавно змінено.",
    "Search" : "Пошук",
    "Search results within your files." : "Шукати результати серед ваших файлів.",
    "This node is unavailable" : "Цей вузол не доступний",
    "Renamed \"{oldName}\" to \"{newName}\"" : "Перейменовано \"{oldName}\" на \"{newName}\"",
    "Clear filter" : "Очистити фільтр",
    "Open file sidebar" : "Відкрити бічну панель файлів",
    "Search everywhere …" : "Шукати всюди ...",
    "Search here …" : "Швидкий пошук …",
    "Preparing …" : "Підготовка ...",
    "Submitting fields …" : "Надсилання полів ...",
    "Invalid path selected" : "Вибрано неправильний шлях",
    "Choose file or folder to transfer" : "Виберіть файл або каталог",
    "Change" : "Змінити",
    "Shared by link" : "Доступ за посиланням",
    "Shared" : "Спільне",
    "You" : "Ви",
    "Shared multiple times with different people" : "Поділилися кілька разів з різними людьми",
    "Unable to change the favorite state of the file" : "Неможливо змінити статус вподобаного файлу",
    "Error while loading the file data" : "Помилка під час отримання даних щодо файлу",
    "Tags" : "Мітки",
    "Save as …" : "Зберегти як ...",
    "Converting files …" : "Конвертування файлів ...",
    "Converting file …" : "Конвертування файлу ...",
    "No entries found in this folder" : "В цьому каталозі нічого не знайдено",
    "Select all" : "Вибрати все",
    "Upload too large" : "Файл занадто великий",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Файли, які ви намагаєтеся завантажити, перевищують максимально дозволений розмір завантаження файлів на сервер."
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
