OC.L10N.register(
    "suspicious_login",
    {
    "New login location detected" : "Зарегистрировано новое местоположение при входе в учётную запись",
    "More info about the suspicious IP address available on %s" : "Более подробная информация о подозрительном IP-адресе доступна на сайте %s",
    "Suspicious Login" : "Подозрительный вход",
    "New login detected" : "Зарегистрирован новый вход",
    "Detect and warn about suspicious IPs logging into Nextcloud\n\t" : "Регистрировать и предупреждать о входах в Nextcloud с подозрительных IP-адресов\n\t",
    "A new login into your account was detected. The IP address %s was classified as suspicious. If this was you, you can ignore this message. Otherwise you should change your password." : "Зарегистрирован новый вход в ваш аккаунт. IP-адрес %s считается подозрительным. Если это были вы, то можете проигнорировать это сообщение. Иначе, вам лучше сменить пароль."
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
