OC.L10N.register(
    "bruteforcesettings",
    {
    "Brute-force settings" : "Nustatymai susiję su aklosios jėgos atakomis",
    "Whitelist IPs" : "\"Baltas\" IP sąrašas",
    "Brute-force protection is meant to protect Nextcloud servers from attempts to\nguess account passwords in various ways. Besides the obvious \"*let's try a big\nlist of commonly used passwords*\" attack, it also makes it harder to use\nslightly more sophisticated attacks via the reset password form or trying to\nfind app password tokens.\n\nIf triggered, brute-force protection makes requests coming from an IP on a\nbrute-force protected controller with the same API slower for a 24 hour period.\n\nWith this app, the admin can exempt an IP address or range from this\nprotection which can be useful for testing purposes or when there are false\npositives due to a lot of accounts on one IP address." : "Apsauga nuo aklos jėgos atakų skirta apsaugoti „Nextcloud“ serverius nuo bandymų\nįspėti paskyrų slaptažodžius įvairiais būdais. Be akivaizdžios atakos tipo „*pabandykime didelį\ndažniausiai naudojamų slaptažodžių sąrašą*“, ji taip pat apsunkina\nšiek tiek sudėtingesnių atakų vykdymą per slaptažodžio atkūrimo formą arba bandymus\nsurasti programų slaptažodžių žymenis.\n\nJei suveikia, apsauga nuo aklosios jėgos atakų 24 valandų laikotarpiui sulėtina užklausas,\nateinančias iš IP adreso, esančio nuo aklosios jėgos atakų apsaugotame valdiklyje su tuo pačiu API.\n\nNaudodamas šią programėlę, administratorius gali atskirti IP adresą ar adresų rėžius nuo šios\napsaugos, kas gali būti naudinga testavimo tikslais arba kai atsiranda klaidingų\nteigiamų rezultatų dėl daugybės paskyrų viename IP adrese.",
    "The comment cannot exceed {max} characters." : "Komentaras negali viršyti {max} simbolių.",
    "Leave an internal comment explaining why this IP address is allowed, for example its location, so the entry can be removed when it is no longer needed." : "Palikite vidinį komentarą, paaiškinantį, kodėl šis IP adresas leidžiamas, pavyzdžiui, jo vietą, kad įrašą būtų galima pašalinti, kai jo nebereikės.",
    "Your current IP address is detected as \"{remoteAddress}\". This address is currently throttled. Current delay: {delay} ms." : "Jūsų dabartinis IP adresas aptiktas kaip „{remoteAddress}“. Šis adresas šiuo metu yra ribojamas. Dabartinis vėlavimas: {delay} ms.",
    "Your current IP address is detected as \"{remoteAddress}\". This address bypasses brute-force protection." : "Jūsų dabartinis IP adresas aptiktas kaip „{remoteAddress}“. Šis adresas apeina aklosios jėgos atakų apsaugą.",
    "Your current IP address is detected as \"{remoteAddress}\". This address is not currently throttled." : "Jūsų dabartinis IP adresas aptiktas kaip „{remoteAddress}“. Šis adresas šiuo metu nėra ribojamas.",
    "Failed to add the IP address to the allow list." : "Nepavyko įtraukti IP adreso į leidžiamųjų sąrašą.",
    "Failed to save the rate limit setting." : "Nepavyko išsaugoti dažnio ribos nustatymo.",
    "Failed to update the allow list entry." : "Nepavyko atnaujinti leidžiamųjų sąrašo įrašo.",
    "Brute-force allow list" : "Aklosios jėgos atakų leidžiamųjų sąrašas",
    "To exclude IP ranges from the brute-force protection specify them below. Note that any allowed IP can perform authentication attempts without any throttling. For security reasons, it is recommended to list as few remote addresses as possible or ideally even none at all." : "Norėdami neįtraukti IP adresų rėžius į aklosios jėgos atakų apsaugą, nurodykite juos žemiau. Atminkite, kad bet kuris leidžiamas IP adresas gali atlikti autentifikavimo bandymus be jokio apribojimo. Saugumo sumetimais rekomenduojama nurodyti kuo mažiau nuotolinių adresų arba, idealiu atveju, iš viso nenurodyti.",
    "Bypass rate limiting for allowed IPs" : "Leidžiamų IP adresų srauto ribojimo apeinimas",
    "Add new IP address" : "Pridėti naują IP adresą",
    "IP address" : "IP adresas",
    "Mask" : "IP kaukė",
    "Comment" : "Komentaras",
    "Add" : "Pridėti",
    "Edit comment for {subnet}" : "Redaguoti komentarą skirtą {subnet}",
    "Save" : "Įrašyti",
    "Delete entry for {subnet}" : "Ištrinti įrašą skirtą {subnet}",
    "Comment cannot exceed {max} characters." : "Komentaras negali viršyti {max} simbolių.",
    "Leave an internal comment, why this IP is allowed, e.g. the  location, so it can be revoked, when it is no longer needed." : "Palikite vidinį komentarą, kodėl šis IP adresas leidžiamas, pvz., vietą, kad jį būtų galima atšaukti, kai jo nebereikės.",
    "Your remote address was identified as \"{remoteAddress}\" and is throttled at the moment by {delay}ms." : "Jūsų nuotolinis adresas buvo identifikuotas kaip „{remoteAddress}“ ir šiuo metu yra ribojamas {delay} ms.",
    "Your remote address was identified as \"{remoteAddress}\" and is bypassing brute-force protection." : "Jūsų nuotolinis adresas buvo identifikuotas kaip „{remoteAddress}“ ir apeina aklosios jėgos atakos apsaugą.",
    "Your remote address was identified as \"{remoteAddress}\" and is not actively throttled at the moment." : "Jūsų nuotolinis adresas buvo identifikuotas kaip „{remoteAddress}“ ir šiuo metu nėra aktyviai ribojamas.",
    "There was an error adding the IP to the allow list." : "Įtraukiant IP adresą į leidžiamųjų sąrašą įvyko klaida.",
    "There was an error updating the allow list entry." : "Atnaujinant leidžiamųjų sąrašo įrašą įvyko klaida."
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
