OC.L10N.register(
    "nextcloud_announcements",
    {
    "Nextcloud announcements" : "اعلان‌های نکست‌کلود",
    "Nextcloud announcement" : "اعلان نکست‌کلود",
    "Read more" : "بیشتر بخوانید",
    "Disable announcements" : "غیرفعال‌سازی اعلان‌ها",
    "(These announcements are only shown to administrators)" : "(این اعلان‌ها فقط به مدیران نمایش داده می‌شوند)",
    "Nextcloud announcements brings the latest news of Nextcloud into your notifications" : "اعلان‌های نکست‌کلود آخرین اخبار نکست‌کلود را به اعلان‌های شما می‌آورد"
},
"nplurals=2; plural=(n > 1);");
