OC.L10N.register(
    "office",
    {
    "Office" : "Office",
    "Office overview" : "Office Übersicht",
    "Office overview app for Nextcloud" : "Office Übersichts-App für Nextcloud",
    "Create new" : "Neu erstellen",
    "Scroll left" : "Nach kinks scrollen",
    "Scroll right" : "Nach rechts scrollen",
    "Blank" : "Leer",
    "Search {category}" : "Suche {category}",
    "Search" : "Suche",
    "Failed to create file" : "Datei konnte nicht erstellt werden",
    "Failed to load files" : "Dateien konnten nicht geladen werden",
    "No office suite installed" : "Es ist keine Office-Suite installiert",
    "{count} found in {category}" : "{count} gefunden in {category}",
    "Recent {category}" : "Neueste {category}",
    "Filter files" : "Dateien filtern",
    "All" : "Alle",
    "Mine" : "Meine",
    "Shared with me" : "Mit mir geteilt",
    "Switch to grid view" : "Zur Kachelansicht wechseln",
    "Switch to list view" : "Zur Listenansicht wechseln",
    "No {category} found" : "Kein {category} gefunden",
    "Switch to \"All\" to see every file you have access to" : "Wechseln zu \"Alle“, um alle Dateien anzuzeigen, auf die die Sie Zugriff haben.",
    "Search all in Files" : "In allen Dateien suchen",
    "Show all in Files" : "Alle Dateien anzeigen",
    "Create" : "Erstellen",
    "Filename" : "Dateiname",
    "Documents" : "Dokumente",
    "Spreadsheets" : "Tabellenkalkulationen",
    "Presentations" : "Präsentationen",
    "Diagrams" : "Diagramme",
    "Filename cannot be empty" : "Dateiname darf nicht leer sein",
    "Filename contains invalid characters" : "Dateiname enthält ungültige Zeichen",
    "{count} {category} found" : "{count} {category} gefunden"
},
"nplurals=2; plural=(n != 1);");
