<?php

/**
 * SPDX-FileCopyrightText: 2021 Nextcloud GmbH and Nextcloud contributors
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */

\OCP\Util::addScript('settings', 'vue-settings-admin-delegation', 'core');
?>

<div id="admin-right-sub-granting">
</div>
