<?php

declare (strict_types=1);
namespace OCA\Notifications\Vendor\SpomkyLabs\Pki\CryptoTypes\AlgorithmIdentifier\Feature;

/**
 * Algorithm identifier for hash functions.
 */
interface HashAlgorithmIdentifier extends AlgorithmIdentifierType
{
}