OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Privacidad",
    "-" : "-",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "El centro de privacidad muestra dónde están almacenados sus datos y quién puede acceder a ellos, dado que los haya compartido o porque son administradores.",
    "Error loading additional administrator." : "Error al cargar el administrador adicional.",
    "Error adding new administrator." : "Error al añadir un nuevo administrador.",
    "Error deleting new administrator." : "Error al eliminar un nuevo administrador.",
    "Administrators" : "Administradores",
    "Remove external {propertyName} admin" : "Remover al administrador externo de {propertyName}",
    "Add external admin" : "Añadir un administrador externo",
    "Cancel" : "Cancelar",
    "Add" : "Guardar",
    "Name of external admin" : "Nombre del administrador externo",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key. It means that administrators can access your files, but not read their content." : "Su almacenamiento personal está cifrado usando {linkopen}cifrado del lado del servidor ↗{linkclose} con una llave maestra. Esto significa que los administradores tienen acceso a sus archivos, pero no pueden leer su contenido.",
    "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key based on their configuration." : "Sus archivos en almacenamientos externos pueden estar cifrados usando el {linkopen}cifrado del lado del servidor ↗{linkclose} con una llave maestra basada en la configuración.",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual user key. It means that administrators can access your files, but not read their content." : "Su almacenamiento personal está cifrado usando {linkopen}cifrado del lado del servidor ↗{linkclose} con una llave individual de usuario. Esto significa que los administradores tienen acceso a sus archivos, pero no pueden leer su contenido.",
    "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual key based on their configuration." : "Sus archivos en almacenamientos externos pueden estar cifrados usando el {linkopen}cifrado del lado del servidor ↗{linkclose} con una llave individual de usuario, basado en la configuración.",
    "Additionally, this server is protected with full-disk-encryption." : "Adicionalmente, este servidor está protegido con cifrado de disco completo.",
    "This server is protected with full-disk-encryption." : "Este servidor está protegido con cifrado de disco completo.",
    "Your files are not protected by encryption." : "Sus archivos no están protegidos mediante cifrado.",
    "Error saving new state of full-disk-encryption" : "Error al guardar el nuevo estado de cifrado de disco completo",
    "Encryption" : "Encripción",
    "Edit encryption" : "Editar cifrado",
    "Edit" : "Editar",
    "This server is using full-disk-encryption." : "Este servidor utiliza cifrado de disco completo.",
    "Privacy policy" : "Política de privacidad",
    "Read the privacy policy ↗" : "Leer la política de privacidad ↗",
    "Error loading information about shares." : "Error al cargar la información sobre los recursos compartidos.",
    "People you've shared with" : "Personas con las que lo ha compartido",
    "You do not have any shares with individual users." : "No tiene ningún recurso compartido con usuarios individuales.",
    "Your {serverName} account" : "Su cuenta de {serverName}",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Sus datos representan quién es y pueden ser fácilmente abusados. En Nextcloud creemos que tiene derecho a decidir qué sucede con sus datos. ¡Nextcloud protege sus derechos según lo definido en el Manifiesto de Datos del Usuario!",
    "Who has access to your data?" : "¿Quién tiene acceso a sus datos?",
    "Error saving new location of the server" : "Error al guardar la nueva ubicación del servidor",
    "Where is your data?" : "¿Dónde están sus datos?",
    "Your data is located in:" : "Sus datos se encuentran en:",
    "An admin has not selected the location of the server yet." : "Un administrador aún no ha seleccionado la ubicación del servidor.",
    "Change data location" : "Cambiar la ubicación de los datos",
    "Region" : "Región",
    "Please select a region" : "Por favor, seleccione una región",
    "User Data Manifesto 2.0" : "Manifiesto de datos del usuario 2.0",
    "Defining basic rights for people to control their own data in the internet age." : "Definiendo derechos básicos para que las personas controlen sus propios datos en la era del internet.",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Los datos cargados explícita y voluntariamente por un usuario deben estar bajo el control final del usuario. Los usuarios deben poder decidir a quién otorgar acceso a sus datos, y con qué permisos y licencias se otorga dicho acceso.",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Cuando los datos se cargan a un proveedor de servicios específico, los usuarios deben ser informados sobre dónde ese proveedor almacena los datos, durante cuánto tiempo, bajo qué jurisdicción opera el proveedor y qué leyes aplican.",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Los usuarios siempre deberían poder extraer sus datos del servicio en cualquier momento sin experimentar ningún bloqueo del vendedor. Los estándares abiertos para formatos y protocolos son necesarios para garantizar esto.",
    "Learn more ↗" : "Más información ↗",
    "Somaliland" : "Somalilandia",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "Emiratos Árabes Unidos",
    "Afghanistan" : "Afganistán",
    "Antigua and Barbuda" : "Antigua y Barbuda",
    "Anguilla" : "Anguila",
    "Albania" : "Albania",
    "Armenia" : "Armenia",
    "Angola" : "Angola",
    "Antarctica" : "Antártida",
    "Argentina" : "Argentina",
    "American Samoa" : "Samoa Americana",
    "Austria" : "Austria",
    "Australia" : "Australia",
    "Aruba" : "Aruba",
    "Åland Islands" : "Islas Åland",
    "Azerbaijan" : "Azerbaiyán",
    "Bosnia and Herzegovina" : "Bosnia y Herzegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Bélgica",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgaria",
    "Bahrain" : "Baréin",
    "Burundi" : "Burundi",
    "Benin" : "Benín",
    "Saint Barthélemy" : "San Bartolomé",
    "Bermuda" : "Bermudas",
    "Brunei" : "Brunei",
    "Bolivia" : "Bolivia",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, San Eustaquio y Saba",
    "Brazil" : "Brasil",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Bután",
    "Bouvet Island" : "Isla Bouvet",
    "Botswana" : "Botsuana",
    "Belarus" : "Bielorrusia",
    "Belize" : "Belice",
    "Canada" : "Canadá",
    "Cocos (Keeling) Islands" : "Islas Cocos (Keeling)",
    "Democratic Republic of the Congo" : "República Democrática del Congo",
    "Central African Republic" : "República Centroafricana",
    "Congo" : "Congo",
    "Switzerland" : "Suiza",
    "Cote d'Ivoire" : "Costa de Marfil",
    "Cook Islands" : "Islas Cook",
    "Chile" : "Chile",
    "Cameroon" : "Camerún",
    "China" : "China",
    "Colombia" : "Colombia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Cuba",
    "Cabo Verde" : "Cabo Verde",
    "Curaçao" : "Curazao",
    "Christmas Island" : "Isla de Navidad",
    "Cyprus" : "Chipre",
    "Czech" : "República Checa",
    "Germany" : "Alemania",
    "Djibouti" : "Djibouti",
    "Denmark" : "Dinamarca",
    "Dominican Republic" : "República Dominicana",
    "Algeria" : "Algeria",
    "Ecuador" : "Ecuador",
    "Estonia" : "Estonia",
    "Egypt" : "Egipto",
    "West Sahara" : "Sahara Occidental",
    "Eritrea" : "Eritrea",
    "Spain" : "España",
    "Ethiopia" : "Etiopía",
    "Finland" : "Finlandia",
    "Fiji" : "Fiji",
    "Falkland Islands" : "Islas Malvinas",
    "Micronesia" : "Micronesia",
    "Faroe Islands" : "Islas Faroe",
    "France" : "Francia",
    "Gabon" : "Gabón",
    "United Kingdom" : "Reino Unido",
    "Grenada" : "Granada",
    "Georgia" : "Georgia",
    "French Guiana" : "Guyana Francesa",
    "Guernsey" : "Guernesey",
    "Ghana" : "Ghana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Groenlandia",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Guadeloupe" : "Guadalupe",
    "Equatorial Guinea" : "Guinea Ecuatorial",
    "Greece" : "Grecia",
    "South Georgia and the South Sandwich Islands" : "Islas Georgia del Sur y Sandwich del Sur",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinea-Bissau",
    "Guyana" : "Guyana",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Isla Heard e Islas McDonald",
    "Honduras" : "Honduras",
    "Croatia" : "Croacia",
    "Haiti" : "Haití",
    "Hungary" : "Hungría",
    "Indonesia" : "Indonesia",
    "Ireland" : "Irlanda",
    "Israel" : "Israel",
    "Isle of Man" : "Isla de Man",
    "India" : "India",
    "British Indian Ocean Territory" : "Territorio Británico del Océano Índico",
    "Iraq" : "Irak",
    "Iran" : "Irán",
    "Iceland" : "Islandia",
    "Italy" : "Italia",
    "Jamaica" : "Jamaica",
    "Jordan" : "Jordania",
    "Japan" : "Japón",
    "Kenya" : "Kenia",
    "Kyrgyzstan" : "Kirguistán",
    "Cambodia" : "Camboya",
    "Kiribati" : "Kiribati",
    "Comores" : "Comoras",
    "Saint Kitts and Nevis" : "San Cristóbal y Nieves",
    "North Korea" : "Corea del Norte",
    "South Korea" : "Corea del Sur",
    "Kuwait" : "Kuwait",
    "Cayman Islands" : "Islas Caimán",
    "Kazakhstan" : "Kazajistán",
    "Laos" : "Laos",
    "Lebanon" : "Líbano",
    "Saint Lucia" : "Santa Lucía",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesoto",
    "Lithuania" : "Lituania",
    "Luxembourg" : "Luxemburgo",
    "Latvia" : "Letonia",
    "Libya" : "Libia",
    "Morocco" : "Marruecos",
    "Monaco" : "Mónaco",
    "Moldova" : "Moldavia",
    "Montenegro" : "Montenegro",
    "Saint Martin" : "San Martín",
    "Madagascar" : "Madagascar",
    "Marshall Islands" : "Islas Marshall",
    "Macedonia" : "Macedonia",
    "Mali" : "Malí",
    "Myanmar" : "Birmania",
    "Mongolia" : "Mongolia",
    "Macao" : "Macao",
    "Northern Mariana Islands" : "Islas Marianas del Norte",
    "Mauritania" : "Mauritania",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Mauricio",
    "Maldives" : "Maldivas",
    "Malawi" : "Malawi",
    "Mexico" : "México",
    "Malaysia" : "Malasia",
    "Mozambique" : "Mozambique",
    "Namibia" : "Namibia",
    "New Caledonia" : "Nueva Caledonia",
    "Niger" : "Níger",
    "Norfolk Island" : "Isla Norfolk",
    "Nigeria" : "Nigeria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Países Bajos",
    "Norway" : "Noruega",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Nueva Zelanda",
    "Oman" : "Omán",
    "Panama" : "Panamá",
    "Peru" : "Perú",
    "French Polynesia" : "Polinesia Francesa",
    "Papua New Guinea" : "Papúa Nueva Guinea",
    "Philippines" : "Filipinas",
    "Pakistan" : "Pakistán",
    "Poland" : "Polonia",
    "Saint Pierre and Miquelon" : "San Pedro y Miquelón",
    "Pitcairn" : "Pitcairn",
    "Puerto Rico" : "Puerto Rico",
    "Palestine" : "Palestina",
    "Portugal" : "Portugal",
    "Palau" : "Palau",
    "Paraguay" : "Paraguay",
    "Qatar" : "Catar",
    "Réunion" : "Reunión",
    "Romania" : "Rumanía",
    "Serbia" : "Serbia",
    "Russia" : "Rusia",
    "Rwanda" : "Ruanda",
    "Saudi Arabia" : "Arabia Saudita",
    "Solomon Islands" : "Islas Salomón",
    "Seychelles" : "Seychelles",
    "Sudan" : "Sudán",
    "Sweden" : "Suecia",
    "Singapore" : "Singapur",
    "Saint Helena, Ascension and Tristan da Cunha" : "Santa Elena, Ascensión y Tristán de Acuña",
    "Slovenia" : "Eslovenia",
    "Svalbard and Jan Mayen" : "Svalbard y Jan Mayen",
    "Slovakia" : "Eslovaquia",
    "Sierra Leone" : "Sierra Leona",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "Suriname" : "Surinam",
    "South Sudan" : "Sudán del Sur",
    "Sao Tome and Principe" : "Santo Tomé y Príncipe",
    "El Salvador" : "El Salvador",
    "Sint Maarten" : "San Martín",
    "Syria" : "Siria",
    "Swaziland" : "Suazilandia",
    "Turks and Caicos Islands" : "Islas Turcas y Caicos",
    "Chad" : "Chad",
    "Fr. S. Antarctic Lands" : "P. Tierras del Sur Antártico",
    "Togo" : "Togo",
    "Thailand" : "Tailandia",
    "Tajikistan" : "Tayikistán",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Timor Oriental",
    "Turkmenistan" : "Turkmenistán",
    "Tunisia" : "Túnez",
    "Tonga" : "Tonga",
    "Turkey" : "Turquía",
    "Trinidad and Tobago" : "Trinidad y Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan" : "Taiwán",
    "Tanzania" : "Tanzania",
    "Ukraine" : "Ucrania",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "Islas menores alejadas de los Estados Unidos",
    "United States" : "Estados Unidos",
    "Uruguay" : "Uruguay",
    "Uzbekistan" : "Uzbekistán",
    "Holy See" : "Santa Sede",
    "Saint Vincent and the Grenadines" : "San Vicente y las Granadinas",
    "Venezuela" : "Venezuela",
    "Virgin Islands (British)" : "Islas Vírgenes (británicas)",
    "Virgin Islands (U.S.)" : "Islas Vírgenes (estadounidenses)",
    "Vietnam" : "Vietnam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis y Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Yemen",
    "Mayotte" : "Mayotte",
    "South Africa" : "Sudáfrica",
    "Zambia" : "Zambia",
    "Zimbabwe" : "Zimbabue",
    "Loading administrators …" : "Cargando administradores …",
    "Loading people you've shared with …" : "Cargando personas con las que lo ha compartido …",
    "Control" : "Control",
    "over user data access" : "sobre el acceso a los datos del usuario",
    "Knowledge" : "Conocimiento",
    "of how the data is stored" : "de cómo se almacenan los datos",
    "Freedom" : "Libertad",
    "to choose a platform" : "de elegir una plataforma"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
