<?php

declare(strict_types=1);

/**
 * SPDX-FileCopyrightText: 2021 Nextcloud GmbH and Nextcloud contributors
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */

namespace OCA\Notifications\Controller;

use OCA\Notifications\AppInfo\Application;
use OCA\Notifications\Model\Settings;
use OCA\Notifications\Model\SettingsMapper;
use OCP\AppFramework\Http;
use OCP\AppFramework\Http\Attribute\ApiRoute;
use OCP\AppFramework\Http\Attribute\NoAdminRequired;
use OCP\AppFramework\Http\Attribute\OpenAPI;
use OCP\AppFramework\Http\DataResponse;
use OCP\AppFramework\OCSController;
use OCP\AppFramework\Services\IAppConfig;
use OCP\Config\IUserConfig;
use OCP\IRequest;

class SettingsController extends OCSController {
	public function __construct(
		string $appName,
		IRequest $request,
		protected IAppConfig $appConfig,
		protected IUserConfig $userConfig,
		protected SettingsMapper $settingsMapper,
		protected string $userId,
	) {
		parent::__construct($appName, $request);
	}

	/**
	 * Update personal notification settings
	 *
	 * @param int<0, 4> $batchSetting How often E-mails about missed notifications should be sent (off: 0; hourly: 1; every three hours: 2; daily: 3; weekly: 4)
	 * @psalm-param Settings::EMAIL_SEND_* $batchSetting
	 * @param string $soundNotification Enable sound for notifications ('yes' or 'no')
	 * @param string $soundTalk Enable sound for Talk notifications ('yes' or 'no')
	 * @return DataResponse<Http::STATUS_OK, list<empty>, array{}>
	 *
	 * 200: Personal settings updated
	 */
	#[NoAdminRequired]
	#[OpenAPI]
	#[ApiRoute(verb: 'POST', url: '/api/{apiVersion}/settings', requirements: ['apiVersion' => '(v2)'])]
	public function personal(int $batchSetting, string $soundNotification, string $soundTalk): DataResponse {
		$this->settingsMapper->setBatchSettingForUser($this->settingsMapper->getSettingsByUser($this->userId), $batchSetting);

		$this->userConfig->setValueBool($this->userId, Application::APP_ID, 'sound_notification', $soundNotification === 'yes');
		$this->userConfig->setValueBool($this->userId, Application::APP_ID, 'sound_talk', $soundTalk === 'yes');

		return new DataResponse();
	}

	/**
	 * Update default notification settings for new users
	 *
	 * @param int<0, 4> $batchSetting How often E-mails about missed notifications should be sent (off: 0; hourly: 1; every three hours: 2; daily: 3; weekly: 4)
	 * @psalm-param Settings::EMAIL_SEND_* $batchSetting
	 * @param string $soundNotification Enable sound for notifications ('yes' or 'no')
	 * @param string $soundTalk Enable sound for Talk notifications ('yes' or 'no')
	 * @param string $webpushEnabled Enable web push notifications ('yes' or 'no')
	 * @param string $webpushBrowsersEnabled Enable web push for browsers ('yes' or 'no')
	 * @return DataResponse<Http::STATUS_OK, list<empty>, array{}>
	 *
	 * 200: Admin settings updated
	 */
	#[OpenAPI(scope: OpenAPI::SCOPE_ADMINISTRATION)]
	#[ApiRoute(verb: 'POST', url: '/api/{apiVersion}/settings/admin', requirements: ['apiVersion' => '(v2)'])]
	public function admin(int $batchSetting, string $soundNotification, string $soundTalk, string $webpushEnabled, string $webpushBrowsersEnabled): DataResponse {
		$this->appConfig->setAppValueInt('setting_batchtime', $batchSetting);
		$this->appConfig->setAppValueBool('sound_notification', $soundNotification === 'yes');
		$this->appConfig->setAppValueBool('sound_talk', $soundTalk === 'yes');
		$this->appConfig->setAppValueBool('webpush_enabled', $webpushEnabled === 'yes');
		$this->appConfig->setAppValueBool('webpush_browsers_enabled', $webpushBrowsersEnabled === 'yes');

		return new DataResponse();
	}
}
