OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "Pirmojo paleidimo vediklis",
    "Add your profile information! For example your email is needed to receive notifications." : "Pridėkite savo profilio informaciją! Pavyzdžiui, jūsų el. paštas yra reikalingas, kad gautumėte pranešimus.",
    "Add your profile information! For example your email is needed to receive notifications and reset your password." : "Pridėkite savo profilio informaciją! Pavyzdžiui, jūsų el. paštas yra reikalingas, kad gautumėte pranešimus ir galėtumėte atstatyti slaptažodį.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Papildykite profilį informacija! Pasirinkite paveikslėlį, nurodykite vardą, pavardę, kad lengviau būtumėte atpažinti šioje platformoje.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Papildykite profilį informacija! Nurodykite vardą, pavardę, kad lengviau būtumėte atpažinti šioje platformoje.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Pridėkite savo profilio informaciją! Nustatykite profilio paveikslą, kad lengviau būtumėte atpažinti tarp visų ypatybių.",
    "App recommendation: Calendar" : "Rekomenduojama programėlė: „Kalendorius“",
    "Schedule work & meetings, synced with all your devices." : "Planuokite su visais jūsų įrenginiais sinchronizuotus darbus ir susitikimus.",
    "App recommendation: Contacts" : "Rekomenduojama programėlė: „Kontaktai“",
    "Keep your colleagues and friends in one place without leaking their private info." : "Saugokite savo kolegas bei draugus vienoje vietoje, neatskleisdami jų asmeninės informacjios.",
    "App recommendation: Mail" : "Rekomenduojama programėlė: „Paštas“",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Paprasta el. pašto programėlė, tvarkingai integruota su programėle „Failai“, adresatais ir kalendoriumi.",
    "App recommendation: Tasks" : "Programėlės rekomendacija: Nextcloud „Užduotys“",
    "Sync tasks from various devices with your Nextcloud and edit them online." : "Sinchronizuokite užduotis iš įvairių įrenginių naudodami „Nextcloud“ ir taisykite jas tiesiogiai.",
    "App recommendation: Deck" : "Programėlės rekomendacija: Nextcloud „Darbai“",
    "Kanban style organization for personal planning and team projects." : "Kanban stiliaus organizavimas asmeniniam planavimui ir komandiniams projektams.",
    "App recommendation: Forms" : "Rekomenduojama programėlė: „Anketos“",
    "Simple surveys and questionnaires, self-hosted" : "Paprastos apklausos ir anketos, savarankiškai prižiūrimos",
    "App recommendation: Recognize" : "Rekomenduojama programėlė: „Atpažink“",
    "Smart media tagging for Nextcloud" : "Išmanusis medijos žymėjimas „Nextcloud“",
    "App recommendation: Group folders" : "Rekomenduojama programėlė: \"Grupinės aplankai\"",
    "Admin-configured folders shared by everyone in a group." : "Administratoriaus sukonfigūruoti aplankai, prieinami visiems grupės nariams.",
    "App recommendation: Whiteboard" : "Rekomenduojama programėlė: „Skaitmeninė lenta“",
    "Create and share whiteboards with others and collaborate in real-time." : "Kurkite ir dalinkitės skaitmeninėmis lentelėmis su kitais bei bendradarbiaukite realiuoju laiku.",
    "Connect your calendar" : "Prijunkite savo kalendorių",
    "Connect your contacts" : "Prijunkite savo adresatus",
    "Access files via WebDAV" : "Pasiekite failus per WebDAV",
    "Download macOS/iOS configuration profile" : "Atsisiųsti macOS/iOS konfigūracijos profilį",
    "Desktop client" : "Darbalaukio klientas",
    "Android app on Google Play Store" : "„Android“ programa „Google Play“ parduotuvėje",
    "Android app on F-Droid" : "„Android“ programa „F-Droid“",
    "iOS app" : "iOS programėlė",
    "About & What's new" : "Apie ir Kas naujo",
    "A welcome and introduction wizard for Nextcloud" : "Pasisveikinimo ir pristatymo vedlys, skirtas „Nextcloud“",
    "This application enables a pop-up window when a user first logs into Nextcloud. This window welcomes new users to Nextcloud, and contains links to the standard desktop client, Android app, and the iOS app. The window also shows a link for accessing Nextcloud via WebDAV. At any time, the first run wizard can be opened again via link \"About\" on settings menu.\nThe First run wizard can be customized to meet specific design goals, or to change links and messages. Create an appropriate theme following the Theming documentation, and changes to the look and feel of this Wizard are simple. More information is available in the first run wizard documentation, as well as the theming documentation." : "Ši programa rodo iškylantį langą, kai vartotojas pirmą kartą prisijungia prie „Nextcloud“. Šiame lange naujiems vartotojams pateikiami sveikinimo žodžiai bei nuorodos į standartinę darbalaukio programą, „Android“ programėlę ir „iOS“ programėlę. Lange taip pat rodoma nuoroda, leidžianti prisijungti prie „Nextcloud“ per WebDAV. Pirmąjį paleidimo vedlį bet kuriuo metu galima vėl atidaryti paspaudus nuorodą „Apie“ nustatymų meniu.\nPirmąjį paleidimo vedlį galima pritaikyti pagal konkrečius dizaino tikslus arba pakeisti nuorodas ir pranešimus. Sukurkite tinkamą temą pagal temų kūrimo dokumentaciją, ir šio vedlio išvaizdą bei funkcionalumą bus lengva pakeisti. Daugiau informacijos rasite pirmąjį paleidimo vedlio dokumentacijoje, taip pat temų kūrimo dokumentacijoje.",
    "Download on Apple app store" : "Atsisiųskite iš „Apple App Store“",
    "Download on Google play store" : "Atsisiųskite iš „Google Play“ parduotuvės",
    "Go to previous page" : "Eiti į ankstesnį puslapį",
    "Close" : "Užverti",
    "More about Nextcloud" : "Daugiau apie „Nextcloud“",
    "Explore more apps ↗" : "Ieškokite daugiau programėlių ↗",
    "Extend the functionality of Nextcloud with hundreds of community-developed apps." : "Išplėskite „Nextcloud“ funkcionalumą naudodami šimtus bendruomenės sukurtų programėlių.",
    "Get involved! ↗" : "Prisijunkite! ↗",
    "Be a part of the community that helps build, design, translate and promote Nextcloud!" : "Prisijunk prie bendruomenės, kuri padeda kurti, projektuoti, versti ir populiarinti „Nextcloud“!",
    "Need help? ↗" : "Reikia pagalbos? ↗",
    "Find out more about your Nextcloud setup with the admin, user or developer documentation." : "Daugiau informacijos apie „Nextcloud“ sąranką rasite administratorių, vartotojų arba kūrėjų dokumentacijoje.",
    "For large organisations ↗" : "Didelėms organizacijoms ↗",
    "Get Nextcloud Enterprise for mission critical environments where advanced security and compliance are important." : "Įsigykite „Nextcloud Enterprise“ sprendimą, skirtą ypatingos svarbos aplinkoms, kuriose itin svarbus aukšto lygio saugumas ir atitiktis reikalavimams.",
    "Seamless integration with your devices." : "Sklandi integracija su jūsų įrenginiais.",
    "Sync your files across your devices with the desktop and mobile apps, and connect your calendar and contacts." : "Sinchronizuokite failus visuose savo įrenginiuose naudodami kompiuterio ir mobiliąsias programas bei susiekite kalendorių ir kontaktus.",
    "Desktop app ↗" : "Programėlė kompiuteriui ↗",
    "Download For Windows, Mac OS and Linux." : "Atsisiųskite „Windows“, „Mac OS“ ir „Linux“ versijas.",
    "Calendar and contacts ↗" : "Kalendorius ir kontaktai ↗",
    "Connect your calendar and contacts with your devices." : "Susiekite savo kalendorių ir kontaktus su savo įrenginiais.",
    "Welcome to {cloudName}!" : "Sveiki atvykę į {cloudName}!",
    "Skip" : "Praleisti",
    "This Nextcloud is on version {version}" : "Ši „Nextcloud“ versija yra {version}",
    "A collaboration platform that puts you in control" : "Bendradarbiavimo platforma, suteikianti jums visą kontrolę",
    "Privacy" : "Privatumas",
    "Host your data and files where you decide." : "Saugokite savo duomenis ir failus ten, kur norite.",
    "Productivity" : "Darbo našumas",
    "Collaborate and communicate across any platform." : "Bendradarbiaukite ir bendraukite bet kurioje platformoje.",
    "Interoperability" : "Sąveika",
    "Import and export anything you want with open standards." : "Importuokite ir eksportuokite viską, ko norite, naudodami atvirus standartus.",
    "Community" : "Bendruomenė",
    "Enjoy constant improvements from a thriving open-source community." : "Mėgaukitės nuolatiniais patobulinimais, kuriuos siūlo aktyvi atvirojo kodo bendruomenė.",
    "Nextcloud Hub {version} release" : "„Nextcloud Hub“ {version} išleidimas",
    "Read more about it on the Nextcloud Hub {version} blog" : "Daugiau apie tai skaitykite „Nextcloud Hub“ {version} tinklaraštyje",
    "Find out more on the blog" : "Daugiau informacijos rasite tinklaraštyje",
    "Read the Nextcloud Hub {version} blog" : "Skaitykite „Nextcloud Hub“ {version} tinklaraštį",
    "Share your opinion about Nextcloud Hub {version}" : "Pasidalykite savo nuomone apie „Nextcloud Hub“ {version}",
    "Share via email" : "Dalytis el. paštu",
    "Share on {socialMedia}" : "Dalintis {socialMedia}",
    "New in Nextcloud Hub {version}" : "Naujienos „Nextcloud Hub“ {version}",
    "Connect other apps to {productName}" : "Prijunkite kitas programas prie {productName}",
    "Besides the mobile apps and desktop client you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to {productName}." : "Be mobiliųjų programėlių ir kompiuterio kliento, galite prijungti bet kurią kitą programinę įrangą, kuri palaiko WebDAV/CalDAV/CardDAV protokolus, prie {productName}",
    "Apps to connect to {productName}" : "Programėlės, su kuriomis galima prisijungti prie {productName}",
    "Set up sync clients using an {linkStart}app password{linkEnd}. That way you can make sure you are able to revoke access in case you lose that device." : "Nustatykite sinchronizavimo klientus naudodami {linkStart} programėlės slaptažodį {linkEnd}. Taip užsitikrinsite, kad galėsite atšaukti prieigą, jei prarastumėte tą įrenginį.",
    "Get the apps to sync your files" : "Norėdami sinchronizuoti savo failus, atsisiųskite programėles",
    "{productName} gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "{productName} leidžia jums pasiekti savo failus, kad ir kur būtumėte. Mūsų paprastos naudoti programos kompiuteriams ir mobiliesiems įrenginiams yra prieinamos visose pagrindinėse platformose visiškai nemokamai.",
    "App for syncing" : "Sinchronizavimo programėlė",
    "URL copied" : "URL nukopijuotas",
    "Could not copy the URL, please copy manually" : "Nepavyko nukopijuoti URL adreso, nukopijuokite jį rankiniu būdu",
    "Server address" : "Serverio adresas",
    "Use this link to connect your apps and desktop client to this server:" : "Naudokite šią nuorodą norėdami prijungti savo programėles bei darbalaukio kliento programas prie šio serverio:",
    "Refined design, optimized performance" : "Patobulintas dizainas, optimizuotas našumas",
    "Empowering developers with an open platform" : "Suteikiant kūrėjams galimybes naudotis atvira platforma",
    "Your choice: Nextcloud Office powered by Collabora or Euro-Office" : "Jūsų pasirinkimas: „Nextcloud Office“, teikiama „Collabora“ arba „Euro-Office“",
    "Delegate calendars, meetings and mail boxes for better collaboration" : "Deleguokite kalendorius, susitikimus ir pašto dėžutes, kad bendradarbiavimas būtų geresnis",
    "Gantt charts, dependencies & more in Nextcloud Deck" : "Gantt diagramos, priklausomybės ir kita Nextcloud „Darbai“ sistemoje",
    "More agency: let the Assistant work for you across files, emails, forms, and more" : "Daugiau savarankiškumo: leiskite asistentui dirbti už jus tvarkant failus, el. laiškus, anketas ir kitus dokumentus",
    "Pexip, Matrix, and more updates in integrations" : "„Pexip“, „Matrix“ ir kiti integracijų atnaujinimai",
    "… and many more improvements in all apps!" : "... ir daugybė kitų patobulinimų visose programėlėse!",
    "Experience the brand new Nextcloud Hub!" : "Išbandykite visiškai naują „Nextcloud Hub“!",
    "Get to know the new features of Hub {version}" : "Susipažinkite su naujomis „Hub“ {version} funkcijomis ",
    "Time to own your collaboration: Meet Nextcloud Hub 26 Spring! 🚀" : "Laikas prisiimti atsakomybę už savo bendradarbiavimą: susipažinkite su „Nextcloud Hub“ pavasario 26 d. renginyje! 🚀",
    "What's new?" : "Kas naujo?",
    "Nextcloud on all your devices" : "„Nextcloud“ visuose jūsų įrenginiuose",
    "Nextcloud Hub {version}" : "„Nextcloud Hub“ {version}",
    "Share on social media" : "Bendrinti socialiniuose tinkluose",
    "Get started!" : "Pradėkime!",
    "Global redesign and usability lift" : "Visuotinis dizaino atnaujinimas ir patogumo gerinimas",
    "New Office UI: colors, tabs, bars" : "Nauja „Biuro“ vartotojo sąsaja: spalvos, skirtukai, juostos",
    "Performance and stability boost" : "Našumo ir stabilumo padidinimas",
    "New AI Agency tools unlocked" : "Pristatyti nauji „AI Agency“ įrankiai",
    "Talk threads & live transcription" : "„Pokalbiai“ temos ir tiesioginis transkribavimas",
    "Calendar: date poll for participants" : "Kalendorius: dalyvių apklausa dėl datų",
    "Intuitive file search" : "Intuityvi failų paieška",
    "Teams 2.0 & quick Guest accounts" : "„Teams 2.0“ ir greitai sukuriamos svečių paskyros",
    "Quick presets & many other admin updates" : "Greiti nustatymai ir daugybė kitų administravimo atnaujinimų",
    "Vue3, WebSockets and more OpenAPI for devs" : "„Vue3“, „WebSockets“ ir dar daugiau „OpenAPI“ kūrėjams",
    "… and much more!" : "...  ir dar daugiau!",
    "Nextcloud Hub 25 Autumn – Your digital workspace, ready in no time ⚡" : "„Nextcloud Hub 25 Autumn“ – jūsų skaitmeninė darbo erdvė, paruošta akimirksniu ⚡",
    "Growing sovereignty: new federation features, improved data export and import" : "Didėjantis savarankiškumas: naujos federacijos funkcijos, patobulintas duomenų eksportas ir importas",
    "Nextcloud Talk: live translations, pinned messages, scheduling" : "„Nextcloud Pokalbiai“: vertimai realiuoju laiku, prispausdinti pranešimai, tvarkaraščių sudarymas",
    "Office document comparison" : "Biuro dokumentų palyginimas",
    "Whiteboard: comments, reactions, timers" : "„Skaitmeninė lenta\": komentarai, reakcijos, laikmačiai",
    "Nextcloud Assistant performance upgrade and AI labeling" : "„Nextcloud Asistento“ našumo didinimas ir DI žymėjimas",
    "Powerful E2EE in the web interface" : "Galingas E2EE internetinėje sąsajoje",
    "Speed-up with ADA engine" : "Pagreitinkite veikimą naudodami ADA variklį",
    "Time to own your collaboration: Meet Nextcloud Hub 26 Winter! 🚀" : "Atėjo laikas imtis iniciatyvos bendradarbiaujant: susipažinkite su „Nextcloud Hub 26 Winter“! 🚀"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
