OC.L10N.register(
    "appstore",
    {
    "App store" : "Appbutik",
    "Apps" : "Appar",
    "Nextcloud Appstore" : "Nextcloud-appbutik",
    "App name" : "Appnamn",
    "Version" : "Version",
    "Support level" : "Supportnivå",
    "Groups" : "Grupper",
    "Actions" : "Åtgärder",
    "Show details" : "Visa detaljer",
    "is loading…" : "läses in …",
    "Filter view" : "Filtrera vy",
    "Grid size" : "Rutstorlek",
    "Small grid size" : "Liten rutstorlek",
    "Medium grid size" : "Medelstor rutstorlek",
    "Large grid size" : "Stor rutstorlek",
    "Show incompatible" : "Visa inkompatibla",
    "Grid view" : "Rutnätsvy",
    "Force enable {suite}?" : "Tvinga aktivering av {suite}?",
    "Enabling {suite} requires force enabling the app. This may cause issues with your Nextcloud instance. Are you sure you want to proceed?" : "För att aktivera {suite} måste appen tvångsaktiveras. Det kan orsaka problem med din Nextcloud-instans. Vill du fortsätta?",
    "Force enable" : "Tvångsaktivera",
    "Cancel" : "Avbryt",
    "Office suite switching is managed through the Nextcloud All-in-One interface." : "Byte av kontorssvit hanteras via gränssnittet för Nextcloud All-in-One.",
    "Please use the AIO interface to switch between office suites." : "Använd AIO-gränssnittet för att växla mellan kontorssviter.",
    "Select your preferred office suite." : "Välj den kontorssvit du föredrar.",
    "Please note that installing requires manual server setup." : "Observera att installationen kräver manuell konfiguration av servern.",
    "Disable office suites" : "Inaktivera kontorssviter",
    "installed" : "installerad",
    "Features" : "Funktioner",
    "Learn more" : "Läs mer",
    "Daemon" : "Demon",
    "Deploy Daemon" : "Driftsättningsdemon",
    "Type" : "Typ",
    "Name" : "Namn",
    "Display Name" : "Visningsnamn",
    "GPUs support" : "GPU-stöd",
    "Compute device" : "Beräkningsenhet",
    "Advanced deploy options" : "Avancerade driftsättningsalternativ",
    "Edit ExApp deploy options before installation" : "Redigera ExAppens driftsättningsalternativ före installationen",
    "Configured ExApp deploy options. Can be set only during installation" : "Konfigurerade driftsättningsalternativ för ExAppen. De kan endast anges under installationen",
    "Environment variables" : "Miljövariabler",
    "ExApp container environment variables" : "Miljövariabler för ExApp-containern",
    "No environment variables defined" : "Inga miljövariabler är definierade",
    "Mounts" : "Monteringar",
    "Define host folder mounts to bind to the ExApp container" : "Ange monteringar av värdmappar som ska bindas till ExApp-containern",
    "Must exist on the Deploy daemon host prior to installing the ExApp" : "Måste finnas på driftsättningsdemonens värd innan ExAppen installeras",
    "Host path" : "Värdsökväg",
    "Container path" : "Containersökväg",
    "Read-only" : "Skrivskyddad",
    "Remove mount" : "Ta bort montering",
    "New mount" : "Ny montering",
    "Enter path to host folder" : "Ange sökvägen till värdmappen",
    "Enter path to container folder" : "Ange sökvägen till containermappen",
    "Toggle read-only mode" : "Växla skrivskyddat läge",
    "Confirm adding new mount" : "Bekräfta att den nya monteringen ska läggas till",
    "Confirm" : "Bekräfta",
    "Cancel adding mount" : "Avbryt tillägg av montering",
    "Add mount" : "Lägg till montering",
    "ExApp container mounts" : "Monteringar för ExApp-containern",
    "No mounts defined" : "Inga monteringar har definierats",
    "Description" : "Beskrivning",
    "View in store" : "Visa i appbutiken",
    "Visit website" : "Besök webbplats",
    "Usage documentation" : "Användningsdokumentation",
    "Admin documentation" : "Administratörsdokumentation",
    "Developer documentation" : "Utvecklardokumentation",
    "Details" : "Detaljer",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Den här appen kan inte installeras eftersom följande beroenden inte är uppfyllda:",
    "Missing dependencies" : "Beroenden saknas",
    "This app cannot be limited to groups because it provides functionality that is executed before group membership is determined." : "Den här appen kan inte begränsas till grupper eftersom den tillhandahåller funktioner som körs innan grupptillhörigheten har fastställts.",
    "Limited to groups" : "Begränsad till grupper",
    "Latest updated" : "Senast uppdaterad",
    "Author" : "Författare",
    "Categories" : "Kategorier",
    "Resources" : "Resurser",
    "Documentation resources" : "Dokumentationsresurser",
    "Changelog" : "Ändringslogg",
    "Supported" : "Stöds",
    "Featured" : "Utvalda",
    "This app is supported via your current Nextcloud subscription." : "Den här appen stöds via ditt nuvarande Nextcloud-abonnemang.",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Utvalda appar utvecklas av och inom gemenskapen. De erbjuder central funktionalitet och är klara för produktionsanvändning.",
    "Community rating: {score}/5" : "Betyg: {score}/5",
    "Choose Deploy Daemon for {appName}" : "Välj driftsättningsdemon för {appName}",
    "No Deploy daemons configured" : "Inga driftsättningsdemoner har konfigurerats",
    "Register a custom one or setup from available templates" : "Registrera en anpassad demon eller konfigurera en från de tillgängliga mallarna",
    "Manage Deploy daemons" : "Hantera driftsättningsdemoner",
    "Registered Deploy daemons list" : "Lista över registrerade driftsättningsdemoner",
    "Default" : "Standard",
    "Carousel" : "Karusell",
    "Previous slide" : "Föregående bild",
    "Next slide" : "Nästa bild",
    "Choose slide to display" : "Välj vilken bild som ska visas",
    "{index} of {total}" : "{index} av {total}",
    "Limit to groups" : "Begränsa till grupper",
    "Restrict the usage of {app} to members of the following groups." : "Begränsa användningen av {app} till medlemmar i följande grupper.",
    "Reset limitation" : "Återställ begränsning",
    "Save" : "Spara",
    "Failed to update app {appName}" : "Det gick inte att uppdatera appen {appName}",
    "Update all apps" : "Uppdatera alla appar",
    "Are you sure you want to update all apps?" : "Vill du verkligen uppdatera alla appar?",
    "Update done" : "Uppdateringen är klar",
    "View website" : "Visa webbplats",
    "Update all" : "Uppdatera alla",
    "Loading app list" : "Läser in applistan",
    "No matching apps found" : "Inga matchande appar hittades",
    "Search everywhere" : "Sök överallt",
    "Download and enable all" : "Hämta och aktivera alla",
    "Could not load app discover section" : "Det gick inte att läsa in avsnittet för appupptäckt",
    "Could not render element" : "Det gick inte att återge elementet",
    "Nothing to show" : "Inget att visa",
    "Could not load section content from app store." : "Det gick inte att läsa in avsnittets innehåll från appbutiken.",
    "Loading" : "Läser in",
    "Fetching the latest news…" : "Hämtar de senaste nyheterna …",
    "Update all applications" : "Uppdatera alla program",
    "Appstore categories" : "Kategorier i appbutiken",
    "Search apps…" : "Sök efter appar …",
    "Loading categories" : "Läser in kategorier",
    "Please enter more characters to search." : "Ange fler tecken för att söka.",
    "Search apps" : "Sök efter appar",
    "Version {version}, {license}-licensed" : "Version {version}, {license}-licensierad",
    "Version {version}" : "Version {version}",
    "Disable" : "Inaktivera",
    "Enable" : "Aktivera",
    "Deploy and enable" : "Driftsätt och aktivera",
    "Download and enable" : "Hämta och aktivera",
    "Install and enable" : "Installera och aktivera",
    "Deploy and force enable" : "Driftsätt och tvångsaktivera",
    "Download and force enable" : "Hämta och tvångsaktivera",
    "Install and force enable" : "Installera och tvångsaktivera",
    "Rate the app" : "Betygsätt appen",
    "Report a bug" : "Rapportera ett fel",
    "Ask questions or discuss the app" : "Ställ frågor eller diskutera appen",
    "Visit the website" : "Besök webbplatsen",
    "Remove" : "Ta bort",
    "Update to {version}" : "Uppdatera till {version}",
    "Discover" : "Upptäck",
    "Your apps" : "Dina appar",
    "Active apps" : "Aktiva appar",
    "Disabled apps" : "Inaktiverade appar",
    "Updates" : "Uppdateringar",
    "App bundles" : "App-paket",
    "Featured apps" : "Utvalda appar",
    "Supported apps" : "Appar som stöds",
    "Search results" : "Sökresultat",
    "Powered by Euro-Office" : "Drivs av Euro-Office",
    "Good Nextcloud integration" : "Bra integration med Nextcloud",
    "Open source" : "Öppen källkod",
    "Best performance" : "Bäst prestanda",
    "Limited ODF compatibility" : "Begränsad ODF-kompatibilitet",
    "Best Microsoft compatibility" : "Bäst kompatibilitet med Microsoft",
    "Best Nextcloud integration" : "Bäst integration med Nextcloud",
    "Good performance" : "Bra prestanda",
    "Best security: documents never leave your server" : "Bäst säkerhet: dokumenten lämnar aldrig din server",
    "Best ODF compatibility" : "Bäst ODF-kompatibilitet",
    "Best support for legacy files" : "Bäst stöd för äldre filformat",
    "Could not load app categories. Please try again later." : "Det gick inte att läsa in appkategorierna. Försök igen senare.",
    "Could not load apps list. Please try again later." : "Det gick inte att läsa in applistan. Försök igen senare.",
    "Could not update the app. Please try again later." : "Det gick inte att uppdatera appen. Försök igen senare.",
    "An error occurred during the request. Unable to proceed." : "Ett fel uppstod under begäran. Det gick inte att fortsätta."
},
"nplurals=2; plural=(n != 1);");
