OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Ontbrekende wachtwoord herstelsleutel",
    "Please repeat the recovery key password" : "Herhaal het herstelsleutel wachtwoord",
    "Repeated recovery key password does not match the provided recovery key password" : "Het herhaalde herstelsleutel wachtwoord kwam niet overeen met het eerdere herstelsleutel wachtwoord ",
    "Recovery key successfully enabled" : "Herstelsleutel succesvol ingeschakeld",
    "Could not enable recovery key. Please check your recovery key password!" : "Kon herstelsleutel niet activeren. Controleer het wachtwoord van je herstelsleutel!",
    "Recovery key successfully disabled" : "Herstelsleutel succesvol uitgeschakeld",
    "Could not disable recovery key. Please check your recovery key password!" : "Kon herstelsleutel niet deactiveren. Controleer het wachtwoord van je herstelsleutel!",
    "Please provide the old recovery password" : "Geef het oude herstelwachtwoord op",
    "Please provide a new recovery password" : "Geef een nieuw herstelwachtwoord op",
    "Please repeat the new recovery password" : "Herhaal het nieuwe herstelwachtwoord",
    "Password successfully changed." : "Wachtwoord succesvol gewijzigd.",
    "Could not change the password. Maybe the old password was not correct." : "Kon wachtwoord niet wijzigen. Wellicht oude wachtwoord niet juist ingevoerd.",
    "Recovery Key disabled" : "Herstelsleutel uitgeschakeld",
    "Recovery Key enabled" : "Herstelsleutel ingeschakeld",
    "Could not enable the recovery key, please try again or contact your administrator" : "Kon herstelsleutel niet inschakelen, probeer het opnieuw, of neem contact op met je beheerder",
    "Could not update the private key password." : "Kon het wachtwoord van de privésleutel niet bijwerken.",
    "The old password was not correct, please try again." : "Het oude wachtwoord was onjuist, probeer het opnieuw.",
    "The current log-in password was not correct, please try again." : "Het huidige inlogwachtwoord was niet juist, probeer het opnieuw.",
    "Private key password successfully updated." : "Privésleutel succesvol bijgewerkt.",
    "Invalid private key for encryption app. Please update your private key password in your personal settings to recover access to your encrypted files." : "Ongeldige persoonlijke sleutel voor de versleutelingsapp. Werk de persoonlijke wachtwoordsleutel bij in je persoonlijke instellingen om opnieuw toegang te krijgen tot je versleutelde bestanden.",
    "Encryption App is enabled, but your keys are not initialized. Please log-out and log-in again." : "Versleutelingsapp is ingeschakeld, maar je sleutels werden niet geïnitialiseerd. Log uit en log daarna opnieuw in.",
    "Please enable server side encryption in the admin settings in order to use the encryption module." : "Schakel versleuteling aan de serverzijde in de beheerdersinstellingen in om de versleutelingsmodule te gebruiken.",
    "Encryption app is enabled and ready" : "Versleutelingsapp is ingeschakeld en gereed",
    "Bad Signature" : "Verkeerde handtekening",
    "Missing Signature" : "Missende ondertekening",
    "one-time password for server-side-encryption" : "eenmalig wachtwoord voor versleuteling aan de serverzijde",
    "Encryption password" : "Versleutelingswachtwoord",
    "The administration enabled server-side-encryption. Your files were encrypted using the password <strong>%s</strong>." : "De beheerder heeft versleuteling aan de serverzijde mogelijk gemaakt. Je bestanden zijn gecodeerd met behulp van het wachtwoord <strong>%s</strong>.",
    "The administration enabled server-side-encryption. Your files were encrypted using the password \"%s\"." : "De beheerder heeft versleuteling aan de serverzijde mogelijk gemaakt. Je bestanden zijn gecodeerd met behulp van het wachtwoord \"%s\".",
    "Please login to the web interface, go to the \"Security\" section of your personal settings and update your encryption password by entering this password into the \"Old login password\" field and your current login password." : "Log in op de webinterface, ga naar het gedeelte 'Beveiliging' van je persoonlijke instellingen en update je coderingswachtwoord door dit wachtwoord in te voeren in het veld 'Oud inlogwachtwoord' en je huidige inlogwachtwoord.",
    "Cannot decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Kan dit bestand niet ontcijferen, waarschijnlijk is het een gedeeld bestand, Vraag de eigenaar om het bestand opnieuw met je te delen.",
    "Cannot read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Kan dit bestand niet lezen, waarschijnlijk is het een gedeeld bestand. Vraag de eigenaar om het bestand opnieuw met je te delen.",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "Het inschakelen van deze optie zorgt voor versleutelen van alle bestanden op de hoofdopslag, anders worden alleen bestanden op externe opslag versleuteld",
    "Encrypt the home storage" : "Versleutel de eigen serveropslag",
    "Disable recovery key" : "Deactiveer herstelsleutel",
    "Enable recovery key" : "Activeer herstelsleutel",
    "The recovery key is an additional encryption key used to encrypt files. It is used to recover files from an account if the password is forgotten." : "De herstelsleutel is een extra coderingssleutel die wordt gebruikt om bestanden te versleutelen. Het wordt gebruikt om bestanden van een account te herstellen als het wachtwoord wordt vergeten.",
    "Recovery key password" : "Wachtwoord herstelsleulel",
    "Repeat recovery key password" : "Herhaal wachtwoord herstelsleutel",
    "Old recovery key password" : "Oude wachtwoord herstelsleutel",
    "New recovery key password" : "Nieuwe wachtwoord herstelsleutel",
    "Repeat new recovery key password" : "Herhaal nieuwe wachtwoord herstelsleutel",
    "If you do not remember your old password you can ask your administrator to recover your files." : "Als je je  oude wachtwoord niet meer weet, kun je de beheerder vragen je bestanden te herstellen.",
    "Old log-in password" : "Oude wachtwoord",
    "Current log-in password" : "Huidige wachtwoord",
    "Update" : "Bijwerken",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Het activeren van deze optie maakt het mogelijk om je versleutelde bestanden te benaderen als je wachtwoord kwijt is",
    "Default encryption module" : "Standaard versleutelingsmodule",
    "Encryption app is enabled but your keys are not initialized, please log-out and log-in again" : "Crypto app is ingeschakeld, maar je sleutels werden niet geïnitialiseerd. Log uit en log daarna opnieuw in.",
    "Basic encryption module" : "Basis-versleutelingsmodule",
    "Missing parameters" : "Ontbrekende parameters",
    "Default encryption module for server-side encryption" : "Standaard module voor versleuteling aan de serverzijde",
    "In order to use this encryption module you need to enable server-side encryption in the admin settings. Once enabled this module will encrypt all your files transparently. The encryption is based on AES 256 keys.\nThe module will not touch existing files, only new files will be encrypted after server-side encryption was enabled. It is also not possible to disable the encryption again and switch back to an unencrypted system.\nPlease read the documentation to know all implications before you decide to enable server-side encryption." : "Om deze versleutelingsmodule te kunnen gebruiken, moet je versleuteling aan de serverzijde inschakelen in de beheerdersinstellingen. Eenmaal ingeschakeld zal deze module al je bestanden transparant versleutelen. De versleuteling is gebaseerd op AES 256-sleutels.\nDe module doet niets met bestaande bestanden, alleen nieuwe bestanden worden gecodeerd nadat versleuteling aan de serverzijde is ingeschakeld. Het is ook niet mogelijk om de codering weer  uit te schakelen en terug te schakelen naar een niet-gecodeerd systeem.\nLees de documentatie om alle implicaties te kennen voordat je besluit versleuteling aan de serverzijde in te schakelen.",
    "Change recovery key password:" : "Wijzig wachtwoord herstelsleutel:",
    "Change Password" : "Wijzigen wachtwoord",
    "Your private key password no longer matches your log-in password." : "Het wachtwoord van je privésleutel komt niet meer overeen met je inlogwachtwoord.",
    "Set your old private key password to your current log-in password:" : "Stel het wachtwoord van je oude privésleutel in op je huidige inlogwachtwoord.",
    "Update Private Key Password" : "Bijwerken wachtwoord Privésleutel",
    "Enable password recovery:" : "Activeren wachtwoord herstel:",
    "Enabled" : "Ingeschakeld",
    "Disabled" : "Uitgeschakeld"
},
"nplurals=2; plural=(n != 1);");
