OC.L10N.register(
    "office",
    {
    "Office" : "Oficina",
    "Create new" : "Crear novo",
    "Blank" : "Baleiro",
    "Search {category}" : "Buscar {category}",
    "Search" : "Buscar",
    "Failed to load files" : "Produciuse un fallo ao cargar os ficheiros",
    "All" : "Todo",
    "Shared with me" : "Compartido comigo",
    "Switch to grid view" : "Cambiar á vista de grade",
    "Switch to list view" : "Cambiar á vista de lista",
    "No {category} found" : "Non se atopou {category}",
    "Create" : "Crear",
    "Filename" : "Nome de ficheiro",
    "Documents" : "Documentos",
    "Spreadsheets" : "Follas de cálculo",
    "Presentations" : "Presentacións",
    "Filename cannot be empty" : "O nome de ficheiro non pode estar baleiro"
},
"nplurals=2; plural=(n != 1);");
