OC.L10N.register(
    "files_lock",
    {
    "File is currently locked by %s" : "Datei ist derzeit von %s gesperrt.",
    "File is not locked" : "Datei ist nicht gesperrt",
    "File can only be locked with update permissions." : "Datei kann nur mit Aktualisierungsberechtigungen gesperrt werden.",
    "File can only be unlocked by providing a valid owner lock token" : "Die Datei kann nur mit einem gültigen Eigentümer-Sperr-Token entsperrt werden",
    "File can only be unlocked by the owner of the lock" : "Datei kann nur vom Besitzer der Sperre entsperrt werden",
    "Desktop client" : "Desktop-Client",
    "iOS client" : "iOS-Client",
    "Android client" : "Android-Client",
    "Temporary files lock" : "Dateien temporär sperren",
    "Temporary lock your files" : "Ihre Dateien temporär sperren",
    "Allow your users to temporary lock their files to avoid conflicts while working on shared files." : "Erlaubt es Benutzern eine Datei temporär zu sperren um Konflikte während der Arbeit an geteilten Dateien zu vermeiden.",
    "Manually locked by {user}" : "Manuell gesperrt durch {user}",
    "Locked by editing online in {app}" : "Gesperrt durch Online-Bearbeitung in {app}",
    "Automatically locked by {user}" : "Automatisch gesperrt durch {user}",
    "Unlock file" : "Datei entsperren",
    "Lock file" : "Datei sperren",
    "files_lock" : "files_lock",
    "This file has been locked automatically by a client. Removing the lock may lead to a conflict saving the file." : "Diese Datei wurde automatisch von einem Client gesperrt. Das Entfernen der Sperre kann zu einem Konflikt beim Speichern der Datei führen.",
    "Keep lock" : "Sperre behalten",
    "Force unlock" : "Entsperren erzwingen",
    "Allow your users to temporary lock their files to avoid conflicts while working on shared files.\n\nℹ️ As of Nextcloud 34 this app is bundled with Nextcloud Hub and hence not released through the appstore anymore." : "Ihren Benutzern ermöglichen, ihre Dateien vorübergehend zu sperren, um Konflikte bei der Arbeit an geteilten Dateien zu vermeiden.\n\nℹ️ Ab Nextcloud 34 ist diese App fester Bestandteil von Nextcloud Hub und wird daher nicht mehr über den App Store veröffentlicht."
},
"nplurals=2; plural=(n != 1);");
