OC.L10N.register(
    "files_external",
    {
    "You are not logged in" : "您尚未登入",
    "Permission denied" : "沒有權限",
    "Storage with ID \"%d\" not found" : "沒有找到 ID 為「%d」的儲存空間",
    "Forbidden to manage local mounts" : "禁止管理本機掛載",
    "Invalid backend or authentication mechanism class" : "無效的後端或認證機制類別",
    "Invalid mount point" : "無效的掛載點",
    "Objectstore forbidden" : "物件儲存禁止存取",
    "Invalid storage backend \"%s\"" : "無效的儲存後端「%s」",
    "Not permitted to use backend \"%s\"" : "不允許使用後端「%s」",
    "Not permitted to use authentication mechanism \"%s\"" : "不允許使用認證機制「%s」",
    "Unsatisfied backend parameters" : "無法滿足後端所需的參數條件",
    "Unsatisfied authentication mechanism parameters" : "無法滿足認證機制所需的參數條件",
    "Insufficient data: %s" : "資料不足：%s",
    "Storage with ID \"%d\" is not editable by non-admins" : "非管理員無法編輯 ID 為「%d」的儲存空間",
    "Static credentials" : "靜態憑證",
    "Access key ID" : "存取金鑰 ID",
    "Secret access key" : "祕密存取金鑰",
    "Builtin" : "內建",
    "None" : "無",
    "OpenStack v2" : "OpenStack v2",
    "Login" : "登入",
    "Password" : "密碼",
    "Tenant name" : "租戶名稱",
    "Identity endpoint URL" : "身份識別端點 URL",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "網域",
    "Rackspace" : "Rackspace",
    "API key" : "API 金鑰",
    "Global credentials" : "全域憑證資訊",
    "Log-in credentials, save in database" : "登入憑證，儲存於資料庫",
    "Login and password" : "帳號與密碼",
    "Log-in credentials, save in session" : "登入憑證資訊，儲存於工作階段",
    "Global credentials, manually entered" : "全域憑證，手動輸入",
    "Manually entered, store in database" : "手動輸入，儲存於資料庫",
    "RSA public key" : "RSA 公開金鑰",
    "Public key" : "公開金鑰",
    "RSA private key" : "RSA 私鑰",
    "Private key" : "私鑰",
    "Kerberos default realm, defaults to \"WORKGROUP\"" : "Kerberos 預設領域，預設為「WORKGROUP」",
    "Kerberos ticket Apache mode" : "Kerberos 票證 Apache 模式",
    "Kerberos ticket" : "Kerberos 票證",
    "S3-Compatible Object Storage" : "相容於 S3 的物件儲存",
    "Bucket" : "Bucket",
    "Hostname" : "主機名稱",
    "Port" : "連接埠",
    "Proxy" : "proxy代理",
    "Region" : "地區",
    "Storage Class" : "儲存類別",
    "Use HTTPS" : "使用 HTTPS",
    "Use Path Style (https://example.com/bucket)" : "使用路徑樣式 (https://example.com/bucket)",
    "Use Legacy S3 signing (v2)" : "使用舊版 S3 簽署 (v2)",
    "Enable multipart copy" : "啟用多部份複製",
    "Enable Direct Downloads (presigned URLs)" : "啟用直接下載（預先簽署的 URL）",
    "SSE-C encryption key" : "SSE-C 加密金鑰",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "遠端子資料夾",
    "Secure https://" : "安全 https://",
    "FTP/FTPS" : "FTP/FTPS",
    "Host" : "主機",
    "Secure ftps://" : "安全 ftps://",
    "Local (server storage)" : "本機（伺服器儲存空間）",
    "Location" : "位置",
    "Nextcloud (WebDAV)" : "Nextcloud (WebDAV)",
    "SFTP (SSH file transfer)" : "SFTP（SSH 檔案傳輸）",
    "Root" : "Root",
    "SFTP with public key authentication" : "使用公開金鑰驗證的 SFTP",
    "SMB/CIFS (Windows network share)" : "SMB/CIFS（Windows 網路分享）",
    "Share" : "分享",
    "Show hidden files" : "顯示隱藏檔",
    "Case sensitive file system" : "區分大小寫檔案系統",
    "Disabling it will allow to use a case insensitive file system, but comes with a performance penalty" : "停用其將允許使用不區分大小寫的檔案系統，但會帶來效能損失",
    "Verify ACL access when listing files" : "列出檔案時驗證 ACL 存取權",
    "Check the ACL's of each file or folder inside a directory to filter out items where the account has no read permissions, comes with a performance penalty" : "檢查目錄中每個檔案或資料夾的 ACL，以過濾掉帳號沒有讀取權限的項目，但可能會影響效能",
    "Timeout" : "逾時",
    "SMB/CIFS using Nextcloud login" : "SMB/CIFS 使用 Nextcloud 登入",
    "Login as share" : "以分享身份登入",
    "OpenStack Swift Object Storage" : "OpenStack Swift 物件儲存",
    "Service name" : "服務名稱",
    "Request timeout (seconds)" : "請求逾時（秒）",
    "External storage" : "外部儲存空間",
    "External storage support" : "外部儲存空間支援",
    "Adds basic external storage support" : "新增基本的外部儲存空間支援",
    "This application enables administrators to configure connections to external storage providers, such as FTP servers, S3 or SWIFT object stores, other Nextcloud servers, WebDAV servers, and more. Administration can choose which types of storage to enable and can mount these storage locations for an account, a group, or the entire system. Users will see a new folder appear in their root Nextcloud directory, which they can access and use like any other Nextcloud folder. External storage also allows people to share files stored in these external locations. In these cases, the credentials for the owner of the file are used when the recipient requests the file from external storage, thereby ensuring that the recipient can access the shared file.\n\nExternal storage can be configured using the GUI or at the command line. This second option provides the administration with more flexibility for configuring bulk external storage mounts and setting mount priorities. More information is available in the external storage GUI documentation and the external storage Configuration File documentation." : "此應用程式讓管理員可以設定到外部儲存空間提供者的連線，如 FTP 伺服器、S3 或 SWIFT 物件儲存、其他 Nextcloud 伺服器、WebDAV 伺服器與更多。管理員可以選擇要啟用的儲存空間類型，並可以為使用者、群組或整個系統掛載這些儲存位置。使用者將會在他們的 Nextcloud 根目錄看到一個新的資料夾，他們可以像其他 Nextcloud 資料夾那樣存取並使用該資料夾。外部儲存空間也允許使用者分享儲存在這些外部空間的檔案。在這種情況下，當收件者從外部儲存空間請求檔案時，將使用檔案擁有者的憑證來確保收件者可以存取被分享的檔案。\n\n可以使用圖形使用者介面或命令列設定外部儲存空間。後者提供了管理員更大的彈性，可用於設定大容量儲存空間的掛載並設定掛載屬性。更多資訊可在外部儲存空間圖形化使用者介面的文件與外部儲存空間設定檔文件中檢視。",
    "Edit storage" : "編輯儲存空間",
    "Add storage" : "新增儲存空間",
    "Folder name" : "資料夾名稱",
    "Authentication" : "認證",
    "Cancel" : "取消",
    "Edit" : "編輯",
    "Create" : "建立",
    "Restrict to" : "限制為",
    "Storage configuration" : "儲存空間組態",
    "Never" : "永不",
    "Once every direct access" : "在每次進行存取動作時",
    "Always" : "總是",
    "Mount options" : "掛載選項",
    "Check filesystem changes" : "檢查檔案系統變更",
    "Read only" : "唯讀",
    "Enable previews" : "啟用預覽",
    "Enable sharing" : "啟用分享",
    "Enable encryption" : "啟用加密",
    "Compatibility with Mac NFD encoding (slow)" : "與 Mac NFD 編碼相容（較慢）",
    "External storages" : "外部儲存空間",
    "Status" : "狀態",
    "Restricted to" : "已限制為",
    "Actions" : "動作",
    "Checking …" : "正在檢查……",
    "Recheck status" : "重新檢查狀態",
    "Delete" : "刪除",
    "System provided storage" : "系統提供的儲存空間",
    "Saved" : "已儲存",
    "Error while saving" : "儲存時發生錯誤",
    "Saved allowed backends" : "已儲存允許的後端",
    "Failed to save allowed backends" : "儲存允許的後端失敗",
    "Advanced options for external storage mounts" : "外部儲存空間掛載的進階選項",
    "Allow people to mount external storage" : "允許使用者自行掛載外部儲存空間",
    "External storage backends people are allowed to mount" : "允許使用者掛載的外部儲存空間後端",
    "Error generating key pair" : "生成金鑰對時發生錯誤",
    "Key size" : "金鑰尺寸",
    "Generate keys" : "生成金鑰",
    "Confirm" : "確認",
    "Storage credentials" : "儲存空間憑證",
    "To access the storage, you need to provide the authentication credentials." : "要存取儲存空間，您必須提供驗證憑證。",
    "Enter the storage login" : "輸入儲存空間登入帳號",
    "Enter the storage password" : "輸入儲存空間密碼",
    "External storage enables you to mount external storage services and devices as secondary Nextcloud storage devices." : "外部儲存空間讓您可以掛載外部儲存空間服務與裝置來作為次要的 Nextcloud 儲存裝置。",
    "You may also allow people to mount their own external storage services." : "您亦可允許使用者掛載其自身的外部儲存服務。",
    "The cURL support in PHP is not enabled or installed." : "PHP 的 cURL 支援未啟用或安裝。",
    "The FTP support in PHP is not enabled or installed." : "PHP 的 FTP 支援未啟用或安裝。",
    "{module} is not installed." : "未安裝 {module}。",
    "Dependant backends" : "依賴後端",
    "No external storage configured or you do not have the permission to configure them" : "未設定外部儲存空間組態，或您無權設定",
    "Add external storage" : "新增外部儲存空間",
    "Global credentials saved" : "已儲存全域憑證",
    "Could not save global credentials" : "無法儲存全域憑證",
    "Global credentials can be used to authenticate with multiple external storages that have the same credentials." : "全域憑證可用於認證多個有相同憑證的外部儲存空間。",
    "Saving …" : "正在儲存 …",
    "Save" : "儲存",
    "Unable to update this external storage config. {statusMessage}" : "無法更新此外部儲存空間組態設定。{statusMessage}",
    "New configuration successfully saved" : "已成功儲存新組態設定",
    "Enter missing credentials" : "輸入缺少的憑證",
    "Credentials successfully set" : "已成功設定憑證",
    "Error while setting credentials: {error}" : "設定憑證時發生錯誤：{error}",
    "Checking storage …" : "正在檢查儲存空間 ……",
    "There was an error with this external storage." : "此外部儲存空間發生錯誤。",
    "We were unable to check the external storage {basename}" : "我們無法檢查外部儲存空間 {basename}",
    "Examine this faulty external storage configuration" : "檢查此錯誤的外部儲存空間組態設定",
    "Open in Files" : "以「檔案」開啟",
    "External mount error" : "外部掛載錯誤",
    "There was an error with this external storage. Do you want to review this mount point config in the settings page?" : "此外部儲存空間有錯誤。您想要在設定頁面中檢閱此掛載點的組態設定嗎？",
    "Open settings" : "開啟設定",
    "Ignore" : "忽略",
    "List of external storage." : "外部儲存空間清單。",
    "There is no external storage configured. You can configure them in your Personal settings." : "未設定外部儲存空間組態。您可以在「個人設定」中設定它們。",
    "There is no external storage configured and you don't have the permission to configure them." : "未設定外部儲存空間組態，而且您無權設定。",
    "No external storage" : "無外部儲存空間",
    "Storage type" : "儲存空間類型",
    "Unknown" : "未知",
    "Scope" : "範圍",
    "Personal" : "個人",
    "System" : "系統",
    "Connected" : "已連線",
    "Error" : "錯誤",
    "Indeterminate" : "不確定",
    "Incomplete configuration" : "組態不完整",
    "Unauthorized" : "Unauthorized",
    "Network error" : "網路錯誤",
    "Grant access" : "授予存取權",
    "Error configuring OAuth2" : "設定 OAuth2 時發生錯誤",
    "%s" : "%s",
    "Access key" : "存取金鑰",
    "Secret key" : "私密金鑰",
    "OAuth2" : "OAuth2",
    "Client ID" : "客戶端 ID",
    "Client secret" : "客戶端密碼",
    "S3 Storage" : "S3 儲存空間",
    "Enable SSL" : "啟用 SSL",
    "Enable Path Style" : "啟用路徑樣式",
    "Legacy (v2) authentication" : "舊式認證 (v2)",
    "FTP" : "FTP",
    "Local" : "本站",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "SFTP with secret key login" : "以私密金鑰登入 SFTP",
    "SMB/CIFS" : "SMB/CIFS",
    "SMB/CIFS using OC login" : "使用 OC 登入的 SMB/CIFS",
    "OpenStack Object Storage" : "OpenStack 物件儲存",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "PHP 的 cURL 支援未啟用或安裝。無法掛載 %s。請要求您的系統管理員安裝。",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "PHP 的 FTP 支援未啟用或安裝。無法掛載 %s。請要求您的系統管理員安裝。",
    "\"%1$s\" is not installed. Mounting of %2$s is not possible. Please ask your system administrator to install it." : "「%1$s」未安裝。無法掛載 %2$s。請要求您的系統管理員安裝。",
    "Checking storage …" : "正在檢查儲存空間……",
    "Type to select account or group." : "輸入以選取使用者或群組。",
    "(Group)" : "（群組）",
    "Check for changes" : "檢查變動",
    "Disconnect" : "中斷連結",
    "Unknown backend: {backendName}" : "未知後端：{backendName}",
    "Admin defined" : "管理員自訂",
    "Automatic status checking is disabled due to the large number of configured storages, click to check status" : "因為組態設定的儲存空間數量過多，自動狀態檢查被停用，點擊以檢查狀態",
    "Are you sure you want to disconnect this external storage?" : "您確定要取消連結此外部儲存空間嗎？",
    "It will make the storage unavailable in {instanceName} and will lead to a deletion of these files and folders on any sync client that is currently connected but will not delete any files and folders on the external storage itself." : "這會讓 {instanceName} 無法使用該儲存空間，並將會在目前連線的任何同步客戶端上刪除這些檔案與資料夾，但不會刪除外部儲存空間本身的任何檔案與資料夾。",
    "Delete storage?" : "刪除儲存空間？",
    "Click to recheck the configuration" : "點擊以重新檢查組態設定",
    "Saving …" : "正在儲存…",
    "Failed to save global credentials" : "儲存全域憑證失敗",
    "Failed to save global credentials: {message}" : "儲存全域憑證失敗：{message}",
    "No external storage configured or you don't have the permission to configure them" : "未設定外部儲存空間組態，或您無權設定",
    "Open documentation" : "開啟文件",
    "External storage enables you to mount external storage services and devices as secondary Nextcloud storage devices. You may also allow people to mount their own external storage services." : "外部儲存空間讓您可以掛載外部儲存空間服務與裝置來作為次要的 Nextcloud 儲存裝置。您也可以允許使用者掛載他們自己的儲存服務。",
    "Configuration" : "組態設定",
    "Available for" : "可使用者",
    "All people" : "所有使用者",
    "Advanced settings" : "進階設定",
    "Use presigned S3 url" : "使用預先簽署的 S3 URL"
},
"nplurals=1; plural=0;");
