.photos-navigation[data-v-dee91203]{position:sticky;z-index:20;top:0;display:flex;gap:calc(2 * var(--app-navigation-padding));align-items:center;justify-content:flex-start;width:100%;padding-inline:calc(var(--default-clickable-area) + 2 * var(--app-navigation-padding)) var(--app-navigation-padding);padding-block:var(--app-navigation-padding);background:var(--color-main-background)}.photos-navigation__title[data-v-dee91203]{max-width:45%;display:flex;flex-direction:column}.photos-navigation__title__main[data-v-dee91203]{cursor:pointer;font-weight:700;font-size:20px;line-height:44px}.photos-navigation__title__main[data-v-dee91203],.photos-navigation__title__sub[data-v-dee91203]{overflow:hidden;white-space:nowrap;text-overflow:ellipsis}.photos-navigation__loader[data-v-dee91203]{margin-inline-start:32px}.photos-navigation__content[data-v-dee91203]{display:flex;flex-grow:1;flex-wrap:wrap;gap:16px}.photos-navigation__content__left[data-v-dee91203]{display:flex;flex-grow:1;align-items:center;gap:16px;flex-wrap:wrap}.photos-navigation__content__right[data-v-dee91203]{display:flex;flex-grow:1;align-items:center;justify-content:flex-end;flex-wrap:wrap}
