<?php

declare(strict_types=1);

namespace Webauthn\MetadataService\Denormalizer;

use Webauthn\Denormalizer\ExtensionDescriptorDenormalizer as BaseExtensionDescriptorDenormalizer;

/**
 * @deprecated since 4.9.0 and will be removed in 5.0.0. Use Webauthn\Denormalizer\ExtensionDescriptorDenormalizer instead
 */
final class ExtensionDescriptorDenormalizer extends BaseExtensionDescriptorDenormalizer
{
}
