OC.L10N.register(
    "files_lock",
    {
    "Desktop client" : "Kliant burev",
    "Temporary files lock" : "Restr prennet amzeriel",
    "Temporary lock your files" : "Prennan amzeriel o restroù",
    "Allow your users to temporary lock their files to avoid conflicts while working on shared files." : "Aotreit ho implijourien da brennañ evit ur pennad o restroù evit ampech kudennoù pa labouront war restroù rannet.",
    "Unlock file" : "Dibrennan ar restr",
    "Lock file" : "Prennan ar restr"
},
"nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");
