OC.L10N.register(
    "bruteforcesettings",
    {
    "Brute-force settings" : "Brute-force beállítások",
    "Whitelist IPs" : "IP-címek fehérlistára tétele",
    "Comment" : "Megjegyzés",
    "Add" : "Hozzáadás",
    "Save" : "Mentés",
    "Delete entry for {subnet}" : "{subnet} bejegyzés törlése"
},
"nplurals=2; plural=(n != 1);");
