<?php
// This file is auto-generated. Do not edit!
return array('spellout-numbering-year'=>array('x.x'=>array('rule'=>'=0.0='),'integer'=>array(array('rule'=>'=%spellout-numbering='))),'spellout-numbering'=>array('integer'=>array(array('rule'=>'=%spellout-cardinal-masculine='))),'spellout-cardinal-masculine'=>array('-x'=>array('rule'=>'mínus →→'),'x.x'=>array('rule'=>'←← čiarka →→'),'integer'=>array(0=>array('rule'=>'nula'),1=>array('rule'=>'jeden'),2=>array('rule'=>'dva'),3=>array('rule'=>'tri'),4=>array('rule'=>'štyri'),5=>array('rule'=>'päť'),6=>array('rule'=>'šesť'),7=>array('rule'=>'sedem'),8=>array('rule'=>'osem'),9=>array('rule'=>'deväť'),10=>array('rule'=>'desať'),11=>array('rule'=>'jedenásť'),12=>array('rule'=>'dvanásť'),13=>array('rule'=>'trinásť'),14=>array('rule'=>'štrnásť'),15=>array('rule'=>'pätnásť'),16=>array('rule'=>'šestnásť'),17=>array('rule'=>'sedemnásť'),18=>array('rule'=>'osemnásť'),19=>array('rule'=>'devätnásť'),20=>array('rule'=>'dvadsať[­→→]'),30=>array('rule'=>'tridsať[­→→]'),40=>array('rule'=>'štyridsať[­→→]'),50=>array('rule'=>'←←desiat[­→→]'),100=>array('rule'=>'←%spellout-cardinal-feminine←­sto[ →→]'),1000=>array('rule'=>'←%spellout-cardinal-feminine← tisíc[ →→]'),1000000=>array('rule'=>'←%spellout-cardinal-masculine← $(cardinal,one{milión}few{milióny}other{miliónov})$[ →→]'),1000000000=>array('rule'=>'←%spellout-cardinal-masculine← $(cardinal,one{miliarda}few{miliardy}other{miliardov})$[ →→]'),'1000000000000'=>array('rule'=>'←%spellout-cardinal-masculine← $(cardinal,one{bilión}few{bilióny}other{biliónov})$[ →→]'),'1000000000000000'=>array('rule'=>'←%spellout-cardinal-masculine← $(cardinal,one{biliarda}few{biliardy}other{biliardov})$[ →→]'),'1000000000000000000'=>array('rule'=>'=#,##0='))),'spellout-cardinal-neuter'=>array('-x'=>array('rule'=>'mínus →→'),'x.x'=>array('rule'=>'←← čiarka →→'),'integer'=>array(0=>array('rule'=>'nula'),1=>array('rule'=>'jedno'),2=>array('rule'=>'dve'),3=>array('rule'=>'=%spellout-cardinal-masculine='),20=>array('rule'=>'dvadsať[­→→]'),30=>array('rule'=>'tridsať[­→→]'),40=>array('rule'=>'štyridsať[­→→]'),50=>array('rule'=>'←←desiat[­→→]'),100=>array('rule'=>'←%spellout-cardinal-feminine←­sto[ →→]'),1000=>array('rule'=>'←%spellout-cardinal-feminine← tisíc[ →→]'),1000000=>array('rule'=>'←%spellout-cardinal-masculine← $(cardinal,one{milión}few{milióny}other{miliónov})$[ →→]'),1000000000=>array('rule'=>'←%spellout-cardinal-masculine← $(cardinal,one{miliarda}few{miliardy}other{miliardov})$[ →→]'),'1000000000000'=>array('rule'=>'←%spellout-cardinal-masculine← $(cardinal,one{bilión}few{bilióny}other{biliónov})$[ →→]'),'1000000000000000'=>array('rule'=>'←%spellout-cardinal-masculine← $(cardinal,one{biliarda}few{biliardy}other{biliardov})$[ →→]'),'1000000000000000000'=>array('rule'=>'=#,##0='))),'spellout-cardinal-feminine'=>array('-x'=>array('rule'=>'mínus →→'),'x.x'=>array('rule'=>'←← čiarka →→'),'integer'=>array(0=>array('rule'=>'nula'),1=>array('rule'=>'jedna'),2=>array('rule'=>'dve'),3=>array('rule'=>'=%spellout-cardinal-masculine='),20=>array('rule'=>'dvadsať[­→→]'),30=>array('rule'=>'tridsať[­→→]'),40=>array('rule'=>'štyridsať[­→→]'),50=>array('rule'=>'←←desiat[­→→]'),100=>array('rule'=>'←%spellout-cardinal-feminine←­sto[ →→]'),1000=>array('rule'=>'←%spellout-cardinal-feminine← tisíc[ →→]'),1000000=>array('rule'=>'←%spellout-cardinal-masculine← $(cardinal,one{milión}few{milióny}other{miliónov})$[ →→]'),1000000000=>array('rule'=>'←%spellout-cardinal-masculine← $(cardinal,one{miliarda}few{miliardy}other{miliardov})$[ →→]'),'1000000000000'=>array('rule'=>'←%spellout-cardinal-masculine← $(cardinal,one{bilión}few{bilióny}other{biliónov})$[ →→]'),'1000000000000000'=>array('rule'=>'←%spellout-cardinal-masculine← $(cardinal,one{biliarda}few{biliardy}other{biliardov})$[ →→]'),'1000000000000000000'=>array('rule'=>'=#,##0='))),'spellout-cardinal'=>array('-x'=>array('rule'=>'−→→'),'integer'=>array(array('rule'=>'=#,##0.#='))),'spellout-ordinal'=>array('-x'=>array('rule'=>'−→→'),'integer'=>array(array('rule'=>'=#,##0.#=.'))),'digits-ordinal'=>array('-x'=>array('rule'=>'−→→'),'integer'=>array(array('rule'=>'=#,##0=.'))));
