OC.L10N.register(
    "logreader",
    {
    "Logging" : "Логлох",
    "Errors in the log" : "Лог дахь алдаанууд",
    "Failed to get an iterator for log entries: %s" : "Лог оруулгуудын давталт авч чадсангүй: %s",
    "No errors in the logs since %s" : "%s-аас хойш логд алдаа байхгүй",
    "_%n error in the logs since %s_::_%n errors in the logs since %s_" : ["%s-аас хойш логт %n алдаа","%s-аас хойш логт %n алдаа"],
    "_%n warning in the logs since %s_::_%n warnings in the logs since %s_" : ["%s-аас хойш логт %n анхааруулга","%s-аас хойш логт %n анхааруулга"],
    "Log Reader" : "Лог уншигч",
    "A log reader for Nextcloud" : "Nextcloud-н лог уншигч",
    "Log reader for Nextcloud" : "Nextcloud-н лог уншигч",
    "If you feel this is an error, please verify {setting} in your {config} and check the Nextcloud Administration Manual." : "Хэрэв энэ нь алдаа гэж үзэж байвал {config} доторх {setting}-г шалгаж, Nextcloud Удирдлагын Гарын авлагыг үзнэ үү.",
    "Log reader" : "Лог уншигч",
    "Open log reader settings" : "Лог уншигчийн тохиргоо нээх",
    "Log reader settings" : "Лог уншигчийн тохиргоо",
    "Currently the log file {file} is shown" : "Одоогоор {file} лог файл харагдаж байна",
    "Show server log" : "Серверийн лог харуулах",
    "Live view is disabled" : "Шууд харагдац идэвхгүй",
    "No log file" : "Лог файл байхгүй",
    "File-based logging must be enabled to access logs from the Web UI." : "Вэб UI-аас логд хандахын тулд файлд суурилсан логлох идэвхжсэн байх ёстой.",
    "Log entry successfully copied" : "Лог оруулга амжилттай хуулагдсан",
    "Level" : "түвшин",
    "App" : "Аппликэйшин",
    "No app in context" : "Контекстэд апп байхгүй",
    "Time" : "Цаг",
    "Copy raw entry" : "Түүхий оруулга хуулах",
    "Copy formatted entry" : "Форматлагдсан оруулга хуулах",
    "Hide exception details" : "Алдааны дэлгэрэнгүй нуух",
    "View exception details" : "Алдааны дэлгэрэнгүй харах",
    "Raw log entry" : "Түүхий лог оруулга",
    "Search log entries" : "Лог оруулгууд хайх",
    "Caused by {exception}" : "{exception}-аас болсон",
    "Line {line}" : "{line} мөр",
    "Filter log levels" : "Логийн түвшнүүд шүүх",
    "Set log level" : "Логийн түвшин тохируулах",
    "Time format" : "Цагийн формат",
    "Live view" : "Шууд харагдац",
    "Download/Upload logs" : "Лог татах/Байршуулах",
    "Ctrl" : "Ctrl",
    "Could not parse local log file" : "Локал лог файлыг задлан шинжилж чадсангүй",
    "You can also show log entries copied from your clipboard by pasting them on the log view using: {keyboardShortcut}" : "Та мөн санах ойноос хуулсан лог бичилтүүдийг {keyboardShortcut} товчлуураар лог харагдац дээр буулгаж харуулах боломжтой.",
    "Download logs" : "Лог татах",
    "Show local log file" : "Локал лог файл харуулах",
    "Upload local log file to be displayed" : "Харуулах локал лог файл байршуулах",
    "Time format used for displaying the timestamp" : "Цагийн тэмдэг харуулахад ашигладаг цагийн формат",
    "(Local log files only support the \"raw\" time format)" : "(Локал лог файлууд зөвхөн \"түүхий\" цагийн форматыг дэмждэг)",
    "Could not change date time format." : "Огноо цагийн форматыг өөрчилж чадсангүй.",
    "Raw data" : "Түүхий өгөгдөл",
    "Local time" : "Орон нутгийн цаг",
    "UTC time" : "UTC цаг",
    "Relative" : "Хамаарал",
    "Could not change live view setting." : "Шууд харагдацын тохиргоог өөрчилж чадсангүй.",
    "Polling is disabled because server is not configured to log to file" : "Сервер файлд лог бичихээр тохируулагдаагүй тул санал асуулга идэвхгүй",
    "Polling (live view)" : "Санал асуулга (шууд харагдац)",
    "Could not set logging levels to show" : "Харуулах логийн түвшнүүдийг тохируулж чадсангүй",
    "Filter logging levels" : "Логийн түвшнүүд шүүх",
    "Could not set logging level" : "Логийн түвшинг тохируулж чадсангүй",
    "Set backend loglevel" : "Арын хэсгийн лог түвшин тохируулах",
    "Application" : "Програм",
    "Message" : "Зурвас",
    "Log entry actions" : "Лог оруулгын үйлдлүүд",
    "Loading older log entries" : "Хуучин лог оруулгуудыг ачаалж байна",
    "No older log entries available" : "Хуучин лог оруулга байхгүй",
    "Collapse row" : "Мөр хумих",
    "Expand row" : "Мөр өргөтгөх",
    "Show details" : "Дэлгэрэнгүйг харуулах",
    "Debug" : "Дебаг",
    "Info" : "Info",
    "Warning" : "Warning",
    "Error" : "Алдаа",
    "Fatal" : "Үхлийн",
    "Could not load log entries" : "Лог оруулгуудыг ачаалж чадсангүй",
    "Clipboard" : "Санах ой",
    "Could not parse clipboard content" : "Санах ойн агуулгыг задлан шинжилж чадсангүй",
    "Could not fetch new log entries (server unavailable)" : "Шинэ лог оруулгуудыг татаж чадсангүй (сервер боломжгүй)",
    "Could not fetch new entries" : "Шинэ оруулгуудыг татаж чадсангүй",
    "Could not copy to clipboard, please copy manually:" : "Санах ойд хуулж чадсангүй, гараар хуулна уу:",
    "\tfrom {address} by {user} at {time}\n" : "\t{address} хаягаас {user} хэрэглэгч {time} цагт\n"
},
"nplurals=2; plural=(n != 1);");
