<?php
// This file is auto-generated. Do not edit!
return array('Adlm'=>'adlam','Afak'=>'afaka','Aghb'=>'Aghb','Ahom'=>'Ahom','Hluw'=>'anatolske hieroglyffer','Arab'=>array(''=>'arabisk','variant'=>array('persisk-arabisk')),'Armn'=>'armensk','Armi'=>'armi','Zinh'=>'arvet','Avst'=>'avestansk','Bali'=>'balinesisk','Bamu'=>'bamum','Bass'=>'bassa','Batk'=>'batak','Beng'=>'bengali','Bhks'=>'Bhks','Blis'=>'blissymboler','Bopo'=>'bopomofo','Brah'=>'bramisk','Bugi'=>'buginesisk','Buhd'=>'buhid','Mymr'=>'burmesisk','Cakm'=>'chakma','Cham'=>'cham','Cher'=>'cherokee','Chrs'=>'Chrs','Cirt'=>'cirt','Cpmn'=>'Cpmn','Cprt'=>'cypriotisk','Dsrt'=>'deseret','Deva'=>'devanagari','Diak'=>'Diak','Dogr'=>'Dogr','Dupl'=>'Duploya-stenografi','Egyd'=>'egyptisk demotisk','Egyh'=>'egyptisk hieratisk','Egyp'=>'egyptiske hieroglyffer','Elba'=>'Elba','Elym'=>'Elym','Zsye'=>'emoji','Ethi'=>'etiopisk','Zyyy'=>'fælles','Phnx'=>'fønikisk','Hans'=>array(''=>'forenklet','stand-alone'=>array('forenklet han')),'Narb'=>'gammelt nordarabisk','Geor'=>'georgisk','Geok'=>'georgisk kutsuri','Glag'=>'glagolitisk','Gong'=>'Gong','Gonm'=>'Gonm','Goth'=>'gotisk','Grek'=>'græsk','Gran'=>'grantha','Gujr'=>'gujarati','Guru'=>'gurmukhi','Hani'=>'han','Hanb'=>'han med bopomofo','Hang'=>'hangul','Rohg'=>'hanifi','Hano'=>'hanunoo','Hatr'=>'Hatr','Hebr'=>'hebraisk','Hira'=>'hiragana','Hmnp'=>'Hmnp','Inds'=>'indus','Jamo'=>'jamo','Jpan'=>'japansk','Hrkt'=>'japanske skrifttegn','Java'=>'javanesisk','Jurc'=>'jurchen','Knda'=>'kannada','Cari'=>'kariansk','Kana'=>'katakana','Kawi'=>'Kawi','Kali'=>'kaya li','Khar'=>'kharoshti','Khmr'=>'khmer','Khoj'=>'khojki','Sind'=>'khudawadi','Kits'=>'Kits','Copt'=>'koptisk','Kore'=>'koreansk','Kpel'=>'kpelle','Kthi'=>'kthi','Cyrl'=>'kyrillisk','Cyrs'=>'kyrillisk - oldkirkeslavisk variant','Lana'=>'lanna','Laoo'=>'lao','Latn'=>'latinsk','Latf'=>'latinsk - frakturvariant','Latg'=>'latinsk - gælisk variant','Lepc'=>'lepcha','Limb'=>'limbu','Lina'=>'lineær A','Linb'=>'lineær B','Lisu'=>'lisu','Loma'=>'loma','Lydi'=>'lydisk','Lyci'=>'lykisk','Mahj'=>'Mahj','Maka'=>'Maka','Mlym'=>'malayalam','Mand'=>'mandaisk','Mani'=>'manikæisk','Marc'=>'Marc','Zmth'=>'matematisk notation','Maya'=>'mayahieroglyffer','Medf'=>'Medf','Mtei'=>'meitei-mayek','Mend'=>'mende','Mero'=>'meroitisk','Merc'=>'metroitisk sammenhængende','Modi'=>'Modi','Mong'=>'mongolsk','Moon'=>'moon','Mroo'=>'mroo','Mult'=>'Mult','Nkoo'=>'n’ko','Nbat'=>'nabateisk','Nagm'=>'Nagm','Nkgb'=>'nakhi geba','Nand'=>'Nand','Aran'=>'nastaliq','Newa'=>'Newa','Nshu'=>'nüshu','Ogam'=>'ogham','Olck'=>'ol-chiki','Ital'=>'Olditalisk','Perm'=>'oldpermisk','Xpeo'=>'oldpersisk','Sarb'=>'oldsørarabisk','Hung'=>'oldungarsk','Cans'=>'oprindelige canadiske symboler','Orya'=>'oriya','Orkh'=>'orkhon','Osge'=>'Osge','Osma'=>'osmannisk','Syrn'=>'østsyriakisk','Ougr'=>'Ougr','Hmng'=>'pahawh hmong','Phlv'=>'pahlavi','Palm'=>'palmyrensk','Pauc'=>'Pauc','Phag'=>'phags-pa','Phli'=>'phli','Phlp'=>'phlp','Plrd'=>'pollardtegn','Prti'=>'prti','Brai'=>'punktskrift','Rjng'=>'rejang','Roro'=>'rongo-rongo','Runr'=>'runer','Samr'=>'samaritansk','Sara'=>'sarati','Saur'=>'saurashtra','Shrd'=>'sharada','Shaw'=>'shavisk','Sidd'=>'Sidd','Sinh'=>'singalesisk','Sogd'=>'Sogd','Sogo'=>'Sogo','Sora'=>'sora','Soyo'=>'Soyo','Xsux'=>'sumero-akkadisk cuneiform','Sund'=>'sundanesisk','Sylo'=>'syloti nagri','Zsym'=>'symboler','Visp'=>'synlig tale','Syrc'=>'syrisk','Syre'=>'syrisk - estrangelovariant','Tglg'=>'tagalog','Tagb'=>'tagbanwa','Tale'=>'tai le','Talu'=>'tai lue','Takr'=>'takri','Taml'=>'tamilsk','Tang'=>'tangut','Tavt'=>'tavt','Sgnw'=>'tegnskrift','Telu'=>'telugu','Teng'=>'tengwar','Thaa'=>'thaana','Thai'=>'thailandsk','Tibt'=>'tibetansk','Tfng'=>'tifinagh','Tirh'=>'tirhuta','Tnsa'=>'Tnsa','Toto'=>'Toto','Hant'=>array(''=>'traditionelt','stand-alone'=>array('traditionelt han')),'Zxxx'=>'uden skriftsprog','Ugar'=>'ugaritisk','Zzzz'=>'ukendt skriftsprog','Vaii'=>'vai','Wara'=>'varang kshiti','Syrj'=>'vestsyrisk','Vith'=>'Vith','Wcho'=>'Wcho','Wole'=>'woleai','Yezi'=>'Yezi','Yiii'=>'yi','Zanb'=>'Zanb','Qaag'=>'zawgyi');
