OC.L10N.register(
    "settings",
    {
    "{actor} added you to group {group}" : "{actor} pridėjo jus į grupę {group}",
    "You added {user} to group {group}" : "Jūs pridėjote {user} į grupę {group}",
    "{actor} added {user} to group {group}" : "{actor} pridėjo {user} į grupę {group}",
    "An administrator added you to group {group}" : "Administratorius pridėjo jus į grupę {group}",
    "An administrator added {user} to group {group}" : "Administratorius pridėjo {user} į grupę {group}",
    "{actor} removed you from group {group}" : "{actor} pašalino jus iš grupės {group}",
    "You removed {user} from group {group}" : "Jūs pašalinote {user} iš grupės {group}",
    "{actor} removed {user} from group {group}" : "{actor} pašalino {user} iš grupės {group}",
    "An administrator removed you from group {group}" : "Administratorius pašalino jus iš grupės {group}",
    "An administrator removed {user} from group {group}" : "Administratorius pašalino {user} iš grupės {group}",
    "Your <strong>group memberships</strong> were modified" : "Jūsų <strong>narystės grupėse</strong> buvo modifikuotos",
    "{actor} changed your password" : "{actor} pakeitė jūsų slaptažodį",
    "You changed your password" : "Jūs pakeitėte savo slaptažodį",
    "Your password was reset by an administrator" : "Administratorius atstatė jūsų slaptažodį",
    "Your password was reset" : "Jūsų slaptažodis buvo atstatytas",
    "{actor} changed your email address" : "{actor} pakeitė jūsų el. pašto adresą",
    "You changed your email address" : "Jūs pakeitėte savo el. pašto adresą",
    "Your email address was changed by an administrator" : "Administratorius pakeitė jūsų el. pašto adresą",
    "You created an app password for a session named \"{token}\"" : "Jūs sukūrėte programėlės slaptažodį sesijai, pavadintai „{token}“",
    "An administrator created an app password for a session named \"{token}\"" : "Administratorius sukūrė programos slaptažodį sesijai, pavadintai „{token}“",
    "You deleted app password \"{token}\"" : "Jūs ištrynėte programėlės slaptažodį \"{token}\"",
    "You deleted app password \"{token}\" and cancelled its pending remote wipe" : "Ištrynėte programėlės slaptažodį „{token}“ ir atšaukėte laukiantį nuotolinį valymą",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Jūs pervadinote programėlės slaptažodį \"{token}\" į \"{newToken}\"",
    "You granted filesystem access to app password \"{token}\"" : "Jūs suteikėte failų sistemai prieigą prie programėlės slaptažodžio  „{token}“.",
    "You revoked filesystem access from app password \"{token}\"" : "Jūs atšaukėte  failų sistemos prieigą prie programėlės slaptažodžio „{token}“",
    "Security" : "Saugumas",
    "You successfully logged in using two-factor authentication (%1$s)" : "Jūs sėkmingai prisijungėte, naudodami dviejų faktorių tapatybės nustatymą (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Nepavyko prisijungti, naudojant dviejų faktorių tapatybės nustatymą (%1$s)",
    "Remote wipe was started on %1$s" : "Nuotolinių duomenų ištrynimas buvo pradėtas ties %1$s",
    "Remote wipe has finished on %1$s" : "Nuotolinių duomenų ištrynimas užbaigtas ties %1$s",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Jūsų <strong>slaptažodis</strong> ar <strong>el. paštas</strong> buvo pakeisti",
    "One time login" : "Vienkartinis prisijungimas",
    "QR Code login" : "Prisijungimas naudojant QR kodą",
    "Wrong password" : "Neteisingas slaptažodis",
    "Unable to change personal password" : "Nepavyko pakeisti asmeninio slaptažodžio",
    "Saved" : "Įrašyta",
    "No Login supplied" : "Prisijungimo duomenys nepateikti",
    "Unable to change password" : "Nepavyksta pakeisti slaptažodžio",
    "Unable to change password. Password too long." : "Nepavyko pakeisti slaptažodžio. Slaptažodis per ilgas.",
    "Authentication error" : "Tapatybės nustatymo klaida",
    "Please provide an admin recovery password; otherwise, all account data will be lost." : "Prašome nurodyti administratoriaus atkūrimo slaptažodį; priešingu atveju visi paskyros duomenys bus prarasti.",
    "Wrong admin recovery password. Please check the password and try again." : "Netinkamas administratoriaus atkūrimo slaptažodis. Prašome pasitikrinti ir bandyti vėl.",
    "Backend does not support password change, but the encryption of the account key was updated." : "Posistemė nepalaiko slaptažodžio keitimo funkcijos, tačiau buvo atnaujintas paskyros rakto šifravimas.",
    "Administrator documentation" : "Administratoriaus dokumentacija",
    "User documentation" : "Vartotojo dokumentacija",
    "Nextcloud help overview" : "„Nextcloud“ pagalbos apžvalga",
    "Invalid SMTP password." : "Neteisingas SMTP slaptažodis.",
    "Email setting test" : "El. pašto nustatymo testas",
    "Well done, %s!" : "Gerai padirbėjote, %s!",
    "If you received this email, the email configuration seems to be correct." : "Jeigu gavote šį laišką, tuomet atrodo, jog el. pašto konfigūracija yra teisinga.",
    "Email could not be sent. Check your mail server log" : "El. laiškas nebuvo išsiųstas. Peržiūrėkite savo pašto serverio žurnalą.",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Siunčiant el. laišką atsirado problemų. Peržiūrėkite savo nustatymus. (Klaida: %s)",
    "You need to set your account email before being able to send test emails. Go to %s for that." : "Prieš siunčiant bandomuosius laiškus, turite nustatyti savo paskyros el. pašto adresą. Tam eikite į %s.",
    "Recently active" : "Neseniai aktyvus",
    "Disabled accounts" : "Išjungtos paskyros",
    "Settings" : "Nustatymai",
    "Invalid account" : "Neteisinga paskyra",
    "Invalid mail address" : "Neteisingas pašto adresas",
    "Settings saved" : "Nustatymai įrašyti",
    "Unable to change full name" : "Nepavyko pakeisti vardo ir pavardės",
    "Unable to change email address" : "Nepavyko pakeisti el. pašto adresą",
    "Unable to set invalid phone number" : "Nepavyko nustatyti netinkamo telefono numerio",
    "Unable to set invalid website" : "Nepavyko nustatyti netinkamos internetinės svetainės",
    "Some account data was invalid" : "Kai kurie paskyros duomenys buvo neteisingi",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Norėdami patvirtinti savo „Twitter“ paskyrą, paskelbkite šį trumpą įrašą  „Twitter“ programoje (prašome, įsitikinkite kad įrašas neturi jokių jokių eilutės pertraukų):\n  ",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Norėdami patvirtinti savo interneto svetainę, išsaugokite turinį web-root aplanke: „.well-know/CloudIdVerificationCode.txt“ (Prašome įsitikinkite, kad visas tekstas yra vienoje eilutėje):",
    "%1$s changed your password on %2$s." : "%1$s pakeitė jūsų slaptažodį %2$s",
    "Your password on %s was changed." : "Jūsų %s slaptažodis buvo pakeistas. ",
    "Your password on %s was reset by an administrator." : "Administratorius atstatė jūsų %s slaptažodį.  ",
    "Your password on %s was reset." : "Jūsų %s slaptažodis buvo atstatytas.",
    "Password for %1$s changed on %2$s" : "%1$s slaptažodis, buvo pakeistas %2$s",
    "Password changed for %s" : "Pakeistas %s slaptažodis",
    "If you did not request this, please contact an administrator." : "Jeigu nebuvote to užklausę, susisiekite su administratoriumi.",
    "Your email address on %s was changed." : "Buvo pakeistas Jūsų el. pašto adress %s.",
    "Your email address on %s was changed by an administrator." : "Administratorius pakeitė Jūsų el. pašto adresą %s.",
    "Email address for %1$s changed on %2$s" : "%1$s el. pašto adresas buvo pakeistas %2$s. ",
    "Email address changed for %s" : "Pakeistas %s el. pašto adresas. ",
    "The new email address is %s" : "Naujasis el. pašto adresas yra %s",
    "Appearance and accessibility" : "Išvaizda ir prieinamumas",
    "Personal settings" : "Asmeniniai nustatymai",
    "Administration settings" : "Administravimo nustatymai",
    "Accounts" : "Paskyros",
    "Help & privacy" : "Pagalba ir privatumas",
    "Your %s account was created" : "Jūsų paskyra %s sukurta",
    "Welcome aboard" : "Sveikiname prisijungus",
    "Welcome aboard %s" : "%s, sveikiname prisijungus",
    "Welcome to your %s account, you can add, protect, and share your data." : "Turėdami %s paskyrą duomenis galite pridėti, apsaugoti ir jais pasidalinti.",
    "Your Login is: %s" : "Jūsų prisijungimas yra: %s",
    "Set your password" : "Nustatykite savo slaptažodį.",
    "Go to %s" : "Pereiti į %s",
    "Install Client" : "Įdiegti kliento programą",
    "Logged in account must be a sub admin" : "Prisijungęs vartotojas turi turėti sub-administratoriaus teises",
    "Personal" : "Asmeniniai",
    "Administration" : "Administravimas",
    "Users" : "Vartotojai",
    "Additional settings" : "Papildomi nustatymai",
    "Assistant" : "Asistentas.",
    "Administration privileges" : "Administravimo teisės",
    "Groupware" : "Grupinio darbo įranga",
    "Office" : "Biuras",
    "Overview" : "Apžvalga",
    "Quick presets" : "Greitieji nustatymai",
    "Basic settings" : "Pagrindiniai nustatymai",
    "Sharing" : "Bendrinimas",
    "Availability" : "Pasiekiamumas",
    "Calendar" : "Kalendorius",
    "Personal info" : "Asmeninė informacija",
    "Mobile & desktop" : "Mobilieji ir darbalaukiai",
    "Artificial Intelligence" : "Dirbtinis intelektas",
    "None / STARTTLS" : "Nėra/STARTTLS",
    "Email server" : "El. pašto serveris",
    "Mail Providers" : "Pašto paslaugų tiekėjai",
    "Mail provider enables sending emails directly through the user's personal email account. At present, this functionality is limited to calendar invitations. It requires Nextcloud Mail 4.1 and an email account in Nextcloud Mail that matches the user's email address in Nextcloud." : "Pašto paslauga leidžia siųsti el. laiškus tiesiogiai per vartotojo asmeninę el. pašto paskyrą. Šiuo metu ši funkcija taikoma tik kalendoriaus kvietimams. Tam reikalinga „Nextcloud Paštas“ 4.1 versija ir „Nextcloud Paštas“ el. pašto paskyra, kurios adresas atitinka vartotojo el. pašto adresą „Nextcloud“ sistemoje.",
    "Send emails using" : "Siųskite el. laiškus naudodami",
    "User's email account" : "Vartotojo el. pašto paskyra",
    "System email account" : "Sistemos el. pašto paskyra",
    "Security & setup checks" : "Saugumo ir sąrankos patikrinimai",
    "Settings presets" : "Nustatymų išankstiniai nustatymai",
    "Background jobs" : "Foninės užduotys",
    "Unlimited" : "Neribotai",
    "Verifying" : "Tikrinimas",
    "Verifying …" : "Tikrinama...",
    "Verify" : "Patikrinti",
    "Allowed admin IP ranges" : "Leidžiami administratorių IP adresų rėžiai",
    "Admin IP filtering isn't applied." : "Administratoriaus IP adresų filtravimas netaikomas.",
    "Configuration key \"%1$s\" expects an array (%2$s found). Admin IP range validation will not be applied." : "Konfigūracijos raktas „%1$s“ turi būti masyvas (rastas %2$s). Administratoriaus IP adresų rėžio patikrinimas nebus taikomas.",
    "Configuration key \"%1$s\" contains invalid IP range(s): \"%2$s\"" : "Konfigūracijos raktas „%1$s“ turi neteisingą (-us) IP adresų rėžį (-ius): „%2$s“",
    "Admin IP filtering is correctly configured." : "Administratoriaus IP adresų filtravimas yra tinkamai sukonfigūruotas.",
    "App directories owner" : "Programėlių katalogų savininkas",
    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:\n%s" : "Kai kurie programėlių katalogai priklauso kitam vartotojui, nei tas, kuriam priklauso žiniatinklio serveris. Taip gali būti, jei programėlės buvo įdiegtos rankiniu būdu. Patikrinkite šių programėlių katalogų teises:\n%s",
    "App directories have the correct owner \"%s\"" : "Programų kataloguose nurodytas teisingas savininkas „%s“",
    "Brute-force Throttle" : "Aklosios jėgos atakos apribojimas",
    "Your remote address could not be determined." : "Nepavyko nustatyti jūsų nuotolinio adreso.",
    "Your remote address was identified as \"%s\" and is brute-force throttled at the moment slowing down the performance of various requests. If the remote address is not your address this can be an indication that a proxy is not configured correctly." : "Jūsų nuotolinis adresas buvo nustatytas kaip „%s“ ir šiuo metu jam taikomas aklosios jėgos atakos ribojimas, dėl kurio sulėtėja įvairių užklausų apdorojimas. Jei šis nuotolinis adresas nėra jūsų adresas, tai gali reikšti, kad tarpinis serveris nėra tinkamai sukonfigūruotas.",
    "Your remote address \"%s\" is not brute-force throttled." : "Jūsų nuotolinio serverio adresas „%s“ nėra ribojamas dėl aklosios jėgos atakų.",
    "Old administration imported certificates" : "Seni administracijos importuoti sertifikatai",
    "A background job is pending that checks for administration imported SSL certificates. Please check back later." : "Laukiama foninio darbo, kuris tikrina, ar nėra importuotų administratoriaus SSL sertifikatų. Patikrinkite vėliau.",
    "There are some administration imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Yra keletas administratoriaus importuotų SSL sertifikatų, kurie nebenaudojami su „Nextcloud 21“. Juos galima importuoti komandinėje eilutėje naudojant komandą „occ security:certificates:import“. Jų keliai duomenų kataloge pateikti žemiau.",
    "Code integrity" : "Kodo vientisumas",
    "Integrity checker has been disabled. Integrity cannot be verified." : "Vientisumo tikrintuvas išjungtas. Vientisumo negalima patikrinti.",
    "No altered files" : "Jokių pakeistų failų",
    "Some files have not passed the integrity check. {link1} {link2}" : "Kai kurie failai nepraėjo vientisumo patikrinimo. {link1} {link2}",
    "List of invalid files…" : "Neteisingų failų sąrašas…",
    "Rescan…" : "Skanuoti iš naujo…",
    "Cron errors" : "Cron klaidos",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:\n%s" : "Cron užduoties nebuvo įmanoma įvykdyti per komandinę eilutę. Atsirado šios techninės klaidos:\n%s",
    "The last cron job ran without errors." : "Paskutinė „cron“ užduotis buvo įvykdyta be klaidų.",
    "Cron last run" : "Paskutinis Cron užduoties vykdymas",
    "Last background job execution ran %s. Something seems wrong. {link}." : "Paskutinis fono užduoties vykdymas baigtas %s. Atrodo, kad kažkas ne taip. {link}.",
    "Last background job execution ran %s." : "Paskutinis fono užduoties vykdymas įvyko %s.",
    "Data directory protected" : "Duomenų katalogas apsaugotas",
    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Jūsų duomenų katalogas ir failai tikriausiai pasiekiami internetu. .htaccess failas neveikia. Primygtinai rekomenduojama sukonfigūruoti žiniatinklio serverį taip, kad duomenų katalogas nebebūtų pasiekiamas, arba perkelti duomenų katalogą už žiniatinklio serverio dokumento šakninio katalogo ribų.",
    "Could not check that the data directory is protected. Please check manually that your server does not allow access to the data directory." : "Nepavyko patikrinti, ar duomenų katalogas yra apsaugotas. Patikrinkite rankiniu būdu, ar jūsų serveris neleidžia pasiekti duomenų katalogo.",
    "Database missing columns" : "Duomenų bazėje trūksta stulpelių",
    "Missing optional column \"%s\" in table \"%s\"." : "Pasirenkamo stulpelio „%s“ trūksta \"%s\" lentelėje",
    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "Duomenų bazėje trūksta kai kurių pasirenkamų stulpelių. Kadangi stulpelių pridėjimas didelėse lentelėse gali užtrukti, jie nebuvo pridėti automatiškai, nors tai gali būti pasirenkama. Paleidus „occ db:add-missing-columns“, trūkstamus stulpelius galima pridėti rankiniu būdu, kol elementas veikia. Pridėjus stulpelius, kai kurios funkcijos gali pagerinti reagavimą arba naudojimo patogumą.",
    "Database missing indices" : "Duomenų bazėje trūksta indeksų",
    "Missing indices:" : "Trūkstami indeksai:",
    "\"%s\" in table \"%s\"" : "\"%s\" lentelėje \"%s\"",
    "Detected some missing optional indices. Occasionally new indices are added (by Nextcloud or installed applications) to improve database performance. Adding indices can sometimes take awhile and temporarily hurt performance so this is not done automatically during upgrades. Once the indices are added, queries to those tables should be faster. Use the command `occ db:add-missing-indices` to add them." : "Aptikta trūkstamų pasirenkamų indeksų. Kartais („Nextcloud“ arba įdiegtų progamėlių) pridedami nauji indeksai, siekiant pagerinti duomenų bazės našumą. Indeksų pridėjimas kartais gali užtrukti ir laikinai pakenkti našumui, todėl tai nėra daroma automatiškai atnaujinimų metu. Pridėjus indeksus, užklausos į šias lenteles turėtų būti greitesnės. Norėdami juos pridėti, naudokite komandą `occ db:add-missing-indices`.",
    "Database missing primary keys" : "Duomenų bazėje trūksta pirminių raktų",
    "Missing primary key on table \"%s\"." : "Lentelėje „%s“ trūksta pirminio rakto.",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "Duomenų bazėje trūksta kai kurių pirminių raktų. Kadangi pirminių raktų pridėjimas didelėse lentelėse gali užtrukti, jie nebuvo pridėti automatiškai. Paleidus „occ db:add-missing-primary-keys“, trūkstamus pirminius raktus galima pridėti rankiniu būdu, kol egzempliorius veikia.",
    "Database pending bigint migrations" : "Duomenų bazėje laukiama „bigint“ tipo duomenų perkėlimo",
    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline." : "Kai kuriose duomenų bazės stulpeliuose trūksta konversijos į „big int“ tipą. Kadangi stulpelių tipų keitimas didelėse lentelėse gali užtrukti, jie nebuvo pakeisti automatiškai. Vykdant komandą „occ db:convert-filecache-bigint“, šiuos laukiančius pakeitimus galima pritaikyti rankiniu būdu. Šią operaciją reikia atlikti, kai instancija yra neprisijungusi.",
    "Debug mode" : "Derinimo veiksena",
    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "Šis procesas veikia derinimo režimu. Įjunkite šią funkciją tik vietiniam programavimo darbui, o ne gamybinėje aplinkoje.",
    "Debug mode is disabled." : "Derinimo veiksena yra išjungta.",
    "Default phone region" : "Numatytasis telefono regionas",
    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective ISO 3166-1 code of the region to your config file." : "Jūsų įdiegime nėra nustatytas numatytasis telefono regionas. Tai būtina, kad profilio nustatymuose būtų galima patvirtinti telefono numerius be šalies kodo. Norėdami leisti naudoti numerius be šalies kodo, į savo konfigūracijos failą įtraukite „default_phone_region“ su atitinkamu regiono ISO 3166-1 kodu.",
    "Email test" : "El. pašto testas",
    "Mail delivery is disabled by instance config \"%s\"." : "Pašto pristatymas yra išjungtas pagal elemento config „%s“.",
    "Email test was successfully sent" : "Bandomasis laiškas buvo sėkmingai išsiųstas",
    "You have not set or verified your email server configuration, yet. Please head over to the \"Basic settings\" in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "Jūs dar nenustatėte ir nepatikrinote savo el. pašto serverio konfigūracijos. Norėdami ją nustatyti, eikite į skyrių „Pagrindiniai nustatymai“. Po to naudokite mygtuką „Siųsti el. laišką“, esantį po forma, kad patikrintumėte savo nustatymus.",
    "Transactional File Locking" : "Transakcinis failų užrakinimas",
    "Transactional File Locking is disabled. This is not a a supported configuraton. It may lead to difficult to isolate problems including file corruption. Please remove the `'filelocking.enabled' => false` configuration entry from your `config.php` to avoid these problems." : "Transakcinių failų užrakinimas išjungtas. Tai nėra palaikoma konfigūracija. Tai gali sukelti sunkumų išskiriant problemas, įskaitant failų sugadinimą. Norėdami išvengti šių problemų, pašalinkite konfigūracijos įrašą „filelocking.enabled“ => false iš savo `config.php` failo.",
    "The database is used for transactional file locking. To enhance performance, please configure memcache, if available." : "Duomenų bazė naudojama transakciniams failams užrakinti. Norėdami pagerinti našumą, sukonfigūruokite „memcache“, jei yra.",
    "Forwarded for headers" : "Persiųsta dėl antraščių",
    "Your \"trusted_proxies\" setting is not correctly set, it should be an array." : "Jūsų nustatymas „trusted_proxies“ nustatytas neteisingai, tai turėtų būti masyvas.",
    "Your \"trusted_proxies\" setting is not correctly set, it should be an array of IP addresses - optionally with range in CIDR notation." : "Jūsų nustatymas „trusted_proxies“ nustatytas neteisingai, tai turėtų būti IP adresų masyvas – pasirinktinai su ribomis CIDR notacijoje.",
    "The reverse proxy header configuration is incorrect. This is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud." : "Atvirkštinio proxy antraštės konfigūracija yra neteisinga. Tai kelia grėsmę saugumui ir leidžia įsilaužėliui paslėpti savo IP adresą, kad „Nextcloud“ jo nematytų.",
    "Your IP address was resolved as %s" : "Jūsų IP adresas buvo nustatytas kaip %s",
    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud." : "Neteisingai sukonfigūruotas atvirkštinio proxy antraštės parametras arba prisijungiate prie „Nextcloud“ per patikimą proxy. Jei taip nėra, tai kelia saugumo problemą ir leidžia įsilaužėliui paslėpti savo IP adresą, kad „Nextcloud“ jo nematytų.",
    "HTTPS access and URLs" : "Prieiga per HTTPS ir URL adresai",
    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead. Without it some important web functionality like \"copy to clipboard\" or \"service workers\" will not work!" : "Prieiga prie svetainės vykdoma nesaugiu HTTP protokolu. Primygtinai rekomenduojame sukonfigūruoti serverį taip, kad jis reikalautų naudoti HTTPS protokolą. Be jo neveiks kai kurios svarbios svetainės funkcijos, pavyzdžiui, „kopijuoti į iškarpinę“ ar „paslaugų tvarkytojai“!",
    "Accessing site insecurely via HTTP." : "Prisijungimas prie svetainės nesaugiu HTTP protokolu.",
    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This likely means that your instance is behind a reverse proxy and the Nextcloud `overwrite*` config values are not set correctly." : "Prie savo elemento jungiatės saugiu ryšiu, tačiau jis generuoja nesaugius URL. Tai greičiausiai reiškia, kad jūsų elementas veikia per atvirkštinį tarpinį serverį ir „Nextcloud“ konfigūracijos reikšmės „overwrite*“ yra nustatytos neteisingai.",
    "Your instance is generating insecure URLs. If you access your instance over HTTPS, this likely means that your instance is behind a reverse proxy and the Nextcloud `overwrite*` config values are not set correctly." : "Jūsų elementas generuoja nesaugius URL. Jei prie savo elemento prisijungiate per HTTPS, tai greičiausiai reiškia, kad jūsų elementas veikia per atvirkštinį tarpinį serverį ir „Nextcloud“ konfigūracijos reikšmės „overwrite*“ yra nustatytos neteisingai.",
    "You are accessing your instance over a secure connection, and your instance is generating secure URLs." : "Prie savo elemento prisijungiate saugiu ryšiu, o jūsų elementas generuoja saugius URL.",
    "Internet connectivity" : "Interneto ryšys",
    "Internet connectivity is disabled in configuration file." : "Interneto ryšys yra išjungtas konfigūracijos faile.",
    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Šiame serveryje neveikia interneto ryšys: nepavyko pasiekti kelių galinių įrenginių. Tai reiškia, kad kai kurios funkcijos, pvz., išorinės atmintinės prijungimas, pranešimai apie atnaujinimus ar trečiųjų šalių programėles diegimas, neveiks. Taip pat gali neveikti nuotolinė prieiga prie failų ir pranešimų el. laiškų siuntimas. Norėdami naudotis visomis funkcijomis, užmegzkite ryšį iš šio serverio su internetu.",
    "JavaScript modules support" : "JavaScript modulių palaikymas",
    "Unable to run check for JavaScript support. Please remedy or confirm manually if your webserver serves `.mjs` files using the JavaScript MIME type." : "Nepavyko patikrinti, ar yra „JavaScript“ palaikymas. Jei jūsų žiniatinklio serveris teikia „.mjs“ failus naudodamas „JavaScript“ MIME tipą, ištaisykite arba patvirtinkite rankiniu būdu.",
    "Your webserver does not serve `.mjs` files using the JavaScript MIME type. This will break some apps by preventing browsers from executing the JavaScript files. You should configure your webserver to serve `.mjs` files with either the `text/javascript` or `application/javascript` MIME type." : "Jūsų žiniatinklio serveris neaptarnauja „.mjs“ failų naudojant „JavaScript“ MIME tipą. Tai sutrikdys kai kurių programėlių veikimą, neleisdama naršyklėms vykdyti „JavaScript“ failų. Turėtumėte sukonfigūruoti savo žiniatinklio serverį taip, kad jis aptarnautų „.mjs“ failus su „text/javascript“ arba „application/javascript“ MIME tipu.",
    "JavaScript source map support" : "JavaScript šaltinio žemėlapių palaikymas",
    "Your webserver is not set up to serve `.js.map` files. Without these files, JavaScript Source Maps won't function properly, making it more challenging to troubleshoot and debug any issues that may arise." : "Jūsų žiniatinklio serveris nėra sukonfigūruotas aptarnauti `.js.map` failus. Be šių failų „JavaScript“ šaltinio žemėlapiai neveiks tinkamai, todėl bus sunkiau nustatyti ir ištaisyti galimas problemas.",
    "Old server-side-encryption" : "Senasis šifravimas serverio pusėje",
    "Disabled" : "Išjungta",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "Įjungtas senasis šifravimo serverio pusėje formatas. Rekomenduojame jį išjungti.",
    "Logging level" : "Žurnalų registravimo lygis",
    "The %1$s configuration option must be a valid integer value." : "Konfigūracijos parinktis %1$s turi būti galiojanti sveikųjų skaičių reikšmė.",
    "The logging level is set to debug level. Use debug level only when you have a problem to diagnose, and then reset your log level to a less-verbose level as it outputs a lot of information, and can affect your server performance." : "Žurnalo registravimo lygis nustatytas į „debug“ lygį. „Debug“ lygį naudokite tik tada, kai reikia diagnozuoti problemą, o po to nustatykite žurnalo registravimo lygį į mažiau išsamų, nes šis lygis pateikia daug informacijos ir gali turėti įtakos jūsų serverio našumui.",
    "Logging level configured correctly." : "Žurnalo registravimo lygis nustatytas teisingai.",
    "Maintenance window start" : "Priežiūros laikotarpio pradžia",
    "Server has no maintenance window start time configured. This means resource intensive daily background jobs will also be executed during your main usage time. We recommend to set it to a time of low usage, so users are less impacted by the load caused from these heavy tasks." : "Serveryje nenustatytas techninės priežiūros laikotarpio pradžios laikas. Tai reiškia, kad daug išteklių reikalaujančios kasdienės foninės užduotys bus vykdomos ir pagrindiniu naudojimo laiku. Rekomenduojame nustatyti laiką, kai naudojimas yra mažas, kad šių didelės apkrovos užduočių sukeliamas krūvis mažiau paveiktų vartotojus.",
    "Maintenance window to execute heavy background jobs is between {start}:00 UTC and {end}:00 UTC" : "Techninės priežiūros laikotarpis, skirtas sudėtingoms foninėms užduotims vykdyti, yra nuo {start}:00 UTC iki {end}:00 UTC",
    "Memcache" : "\"Memcache\"",
    "Memcached is configured as distributed cache, but the wrong PHP module (\"memcache\") is installed. Please install the PHP module \"memcached\"." : "„Memcached“ sukonfigūruotas kaip paskirstytoji talpykla, tačiau įdiegtas netinkamas PHP modulis („memcache“). Įdiekite PHP modulį „memcached“.",
    "Memcached is configured as distributed cache, but the PHP module \"memcached\" is not installed. Please install the PHP module \"memcached\"." : "„Memcached“ sukonfigūruotas kaip paskirstytoji talpykla, tačiau PHP modulis „memcached“ nėra įdiegtas. Įdiekite PHP modulį „memcached“.",
    "No memory cache has been configured. To enhance performance, please configure a memcache, if available." : "Atminties talpyklos nekonfigūruota. Norėdami padidinti našumą, jei įmanoma, sukonfigūruokite „memcache“.",
    "Failed to write and read a value from local cache." : "Nepavyko įrašyti ir išskaityti reikšmės iš vietinės tarpinės atminties.",
    "Failed to write and read a value from distributed cache." : "Nepavyko įrašyti ir perskaityti reikšmės iš paskirstytos tarpinės atminties.",
    "Configured" : "Sukonfigūruota",
    "Mimetype migrations available" : "„Mimetype“ migracijos galimos",
    "One or more mimetype migrations are available. Occasionally new mimetypes are added to better handle certain file types. Migrating the mimetypes take a long time on larger instances so this is not done automatically during upgrades. Use the command `occ maintenance:repair --include-expensive` to perform the migrations." : "Galima atlikti vieną ar kelis mimetype perkėlimus. Kartais pridedami nauji mimetype, kad būtų galima geriau tvarkyti tam tikrus failų tipus. Didesnėse instancijose mimetype perkėlimas trunka ilgai, todėl atnaujinimo metu tai nėra atliekama automatiškai. Norėdami atlikti perkėlimus, naudokite komandą `occ maintenance:repair --include-expensive`.",
    "MySQL row format" : "MySQL eilučių formatas",
    "You are not using MySQL" : "Jūs nenaudojate MySQL",
    "None of your tables use ROW_FORMAT=Compressed" : "Nė viena iš jūsų lentelių nenaudoja ROW_FORMAT=Compressed",
    "Incorrect row format found in your database. ROW_FORMAT=Dynamic offers the best database performances for Nextcloud. Please update row format on the following list: %s." : "Jūsų duomenų bazėje aptiktas netinkamas eilučių formatas. ROW_FORMAT=Dynamic užtikrina geriausią „Nextcloud“ duomenų bazės našumą. Atnaujinkite eilučių formatą šiame sąraše: %s.",
    "MySQL Unicode support" : "MySQL Unicode palaikymas",
    "MySQL is used as database and does support 4-byte characters" : "MySQL yra naudojama kaip duomenų bazė ir palaiko 4 baitų simbolius",
    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL." : "Duomenų bazei naudojama „MySQL“, tačiau ji nepalaiko 4 baitų simbolių. Kad būtų galima be problemų naudoti 4 baitų simbolius (pavyzdžiui, emociukus) failų pavadinimuose ar komentaruose, rekomenduojama „MySQL“ įjungti 4 baitų simbolių palaikymą.",
    "OCS provider resolving" : "OCS teikėjo problemų sprendimas",
    "Could not check if your web server properly resolves the OCM and OCS provider URLs." : "Nepavyko patikrinti, ar jūsų žiniatinklio serveris tinkamai išsprendžia OCM ir OCS teikėjų URL adresus.",
    "Your web server is not properly set up to resolve %1$s.\nThis is most likely related to a web server configuration that was not updated to deliver this folder directly.\nPlease compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx.\nOn Nginx those are typically the lines starting with \"location ~\" that need an update." : "Jūsų žiniatinklio serveris nėra tinkamai sukonfigūruotas, kad galėtų išspręsti %1$s.\nTai greičiausiai susiję su žiniatinklio serverio konfigūracija, kuri nebuvo atnaujinta taip, kad šis aplankas būtų pateikiamas tiesiogiai.\nPalyginkite savo konfigūraciją su pateiktomis perrašymo taisyklėmis „.htaccess“ faile (Apache atveju) arba su taisyklėmis, pateiktomis Nginx dokumentacijoje.\nNginx atveju paprastai atnaujinti reikia eilučių, prasidedančių žodžiais „location ~“.",
    "Overwrite CLI URL" : "Pakeisti CLI URL adresą",
    "The \"overwrite.cli.url\" option in your config.php is correctly set to \"%s\"." : "Jūsų failo „config.php“ parinktis „overwrite.cli.url“ yra teisingai nustatyta kaip „%s“.",
    "The \"overwrite.cli.url\" option in your config.php is set to \"%s\" which is a correct URL. Suggested URL is \"%s\"." : "Jūsų failo „config.php“ parinktis „overwrite.cli.url“ yra nustatyta kaip „%s“, o tai yra teisingas URL. Siūlomas URL yra „%s“.",
    "Please make sure to set the \"overwrite.cli.url\" option in your config.php file to the URL that your users mainly use to access this Nextcloud. Suggestion: \"%s\". Otherwise there might be problems with the URL generation via cron. (It is possible though that the suggested URL is not the URL that your users mainly use to access this Nextcloud. Best is to double check this in any case.)" : "Būtinai nustatykite „overwrite.cli.url“ parametrą failo „config.php“ taip, kad jis atitiktų URL adresą, kurį jūsų vartotojai dažniausiai naudoja prisijungdami prie šio „Nextcloud“. Rekomendacija: „%s“. Kitaip gali kilti problemų generuojant URL adresą per „cron“. (Tačiau gali būti, kad siūlomas URL adresas nėra tas, kurį jūsų vartotojai dažniausiai naudoja prisijungdami prie šio „Nextcloud“. Bet kuriuo atveju geriausia tai patikrinti.)",
    "PHP APCu configuration" : "PHP APCu konfigūracija",
    "Your APCu cache has been running full, consider increasing the apc.shm_size php setting." : "Jūsų APCu tarpinė atmintis yra beveik išnaudota, todėl rekomenduojame padidinti PHP parametrą „apc.shm_size“.",
    "Your APCu cache is almost full at %s%%, consider increasing the apc.shm_size php setting." : " Jūsų APCu tarpinė atmintis yra beveik užpildyta %s%%, todėl rekomenduojame padidinti PHP parametrą „apc.shm_size“.",
    "PHP default charset" : "PHP numatytasis simbolių rinkinys",
    "PHP configuration option \"default_charset\" should be UTF-8" : "PHP konfigūracijos parametras „default_charset“ turėtų būti nustatytas kaip UTF-8",
    "PHP set_time_limit" : "PHP funkcija „set_time_limit“",
    "The function is available." : "Ši funkcija yra prieinama.",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "PHP funkcija „set_time_limit“ nėra įjungta. Dėl to skriptai gali būti nutraukti vykdymo eigoje, o tai gali sutrikdyti jūsų sistemos veikimą. Labai rekomenduojama įjungti šią funkciją.",
    "Freetype" : "\"Freetype\"",
    "Supported" : "Palaikoma",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Jūsų PHP neturi FreeType palaikymo, kas savo ruožtu sąlygoja profilio paveikslėlių ir nustatymų sąsajos neteisingą atvaizdavimą.",
    "PHP getenv" : "\"PHP getenv\"",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "Atrodo, kad PHP nėra tinkamai sukonfigūruotas sistemos aplinkos kintamųjų užklausoms. Bandymas su getenv(„PATH“) grąžina tik tuščią atsakymą.",
    "PHP file size upload limit" : "PHP failų dydžio įkėlimo riba",
    "The PHP upload_max_filesize is too low. A size of at least %1$s is recommended. Current value: %2$s." : "PHP parametras „upload_max_filesize“ yra per mažas. Rekomenduojamas dydis – ne mažiau kaip %1$s. Dabartinė reikšmė: %2$s.",
    "The PHP post_max_size is too low. A size of at least %1$s is recommended. Current value: %2$s." : "PHP parametras „post_max_size“ yra per mažas. Rekomenduojamas dydis – ne mažiau kaip %1$s. Dabartinė reikšmė: %2$s.",
    "The PHP max_input_time is too low. A time of at least %1$s is recommended. Current value: %2$s." : "PHP parametras „max_input_time“ yra per mažas. Rekomenduojama nustatyti ne mažesnį kaip %1$s laiką. Dabartinė reikšmė: %2$s.",
    "The PHP max_execution_time is too low. A time of at least %1$s is recommended. Current value: %2$s." : "PHP parametras „max_execution_time“ yra per mažas. Rekomenduojama nustatyti ne mažesnį kaip %1$s laiką. Dabartinė reikšmė: %2$s.",
    "PHP memory limit" : "PHP atminties limitas",
    "The PHP memory limit is below the recommended value of %s. Some features or apps - including the Updater - may not function properly." : "PHP atminties riba yra mažesnė už rekomenduojamą %s vertę. Kai kurios funkcijos ar programėlės, įskaitant „Updater“, gali neveikti tinkamai.",
    "PHP modules" : "PHP moduliai",
    "increases language translation performance and fixes sorting of non-ASCII characters" : "pagerina vertimo kokybę ir išsprendžia ne ASCII simbolių rūšiavimo problemą",
    "for Argon2 for password hashing and Ed25519 signature verification for RFC 9421 http message signatures" : "„Argon2“ slaptažodžių maišymui ir „Ed25519“ parašo tikrinimui RFC 9421 http pranešimų parašams",
    "required for SFTP storage and recommended for WebAuthn performance" : "būtina SFTP saugojimui ir rekomenduojama WebAuthn našumui",
    "for picture rotation in server and metadata extraction in the Photos app" : "nuotraukų pasukimui serveryje ir metaduomenų išgavimui programėlėje „Nuotraukos“",
    "This instance is missing some required PHP modules. It is required to install them: %s." : "Šioje instancijoje trūksta kai kurių būtinų PHP modulių. Juos būtina įdiegti: %s.",
    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them:\n%s" : "Šiame elemente trūksta kai kurių rekomenduojamų PHP modulių. Siekiant užtikrinti geresnį našumą ir suderinamumą, labai rekomenduojama juos įdiegti:\n%s",
    "PHP opcache" : "\"PHP opcache\"",
    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "PHP OPcache modulis nėra įkeltas. Geresniam našumui rekomenduojame įkelti šį modulį į savo PHP diegimą.",
    "OPcache is disabled. For better performance, it is recommended to apply \"opcache.enable=1\" to your PHP configuration." : "OPcache yra išjungta. Siekiant užtikrinti geresnį našumą, rekomenduojama PHP konfigūracijoje nurodyti „opcache.enable=1“.",
    "The shared memory based OPcache is disabled. For better performance, it is recommended to apply \"opcache.file_cache_only=0\" to your PHP configuration and use the file cache as second level cache only." : "Bendrintos atminties pagrindu veikiantis OPcache yra išjungtas. Siekiant užtikrinti geresnį našumą, rekomenduojama PHP konfigūracijoje nustatyti parametrą „opcache.file_cache_only=0“ ir naudoti failų tarpinę atmintį tik kaip antrojo lygio tarpinę atmintį.",
    "OPcache is not working as it should, opcache_get_status() returns false, please check configuration." : "OPcache neveikia taip, kaip turėtų; funkcija opcache_get_status() grąžina reikšmę „false“; patikrinkite konfigūraciją.",
    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be kept in the cache, it is recommended to apply \"opcache.max_accelerated_files\" to your PHP configuration with a value higher than \"%s\"." : "Beveik pasiektas maksimalus OPcache raktų skaičius. Kad būtų užtikrinta, jog visi skriptai būtų išsaugoti tarpinėje atmintyje, rekomenduojama PHP konfigūracijoje nustatyti parametrą „opcache.max_accelerated_files“ su didesne nei „%s“ reikšme.",
    "The OPcache buffer is nearly full. To assure that all scripts can be hold in cache, it is recommended to apply \"opcache.memory_consumption\" to your PHP configuration with a value higher than \"%s\"." : "OPcache buferis beveik užpildytas. Kad būtų užtikrinta, jog visi skriptai tilptų į tarpinę atmintį, rekomenduojama PHP konfigūracijoje nustatyti parametrą „opcache.memory_consumption“ su didesne nei „%s“ reikšme.",
    "The OPcache interned strings buffer is nearly full. To assure that repeating strings can be effectively cached, it is recommended to apply \"opcache.interned_strings_buffer\" to your PHP configuration with a value higher than \"%s\"." : "OPcache interned_strings_buffer buferis beveik užpildytas. Kad pasikartojančios eilutės būtų veiksmingai įrašomos į tarpinę atmintį, rekomenduojama PHP konfigūracijoje nustatyti „opcache.interned_strings_buffer“ parametrą, kurio reikšmė būtų didesnė už „%s“.",
    "OPcache is configured to remove code comments. With OPcache enabled, \"opcache.save_comments=1\" must be set for Nextcloud to function." : "OPcache yra sukonfigūruotas taip, kad pašalintų kodo komentarus. Įjungus OPcache, kad Nextcloud veiktų, būtina nustatyti parametrą „opcache.save_comments=1“.",
    "Nextcloud is not allowed to use the OPcache API. With OPcache enabled, it is highly recommended to include all Nextcloud directories with \"opcache.restrict_api\" or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "„Nextcloud“ negali naudoti OPcache API. Įjungus OPcache, labai rekomenduojama visus „Nextcloud“ katalogus įtraukti į „opcache.restrict_api“ sąrašą arba išjungti šį nustatymą, kad būtų panaikinti OPcache API apribojimai ir išvengta klaidų atnaujinant „Nextcloud“ branduolį ar programas.",
    "Checking from CLI, OPcache checks have been skipped." : "Patikrinus per komandinę eilutę paaiškėjo, kad OPcache patikrinimai buvo praleisti.",
    "The PHP OPcache module is not properly configured. %s." : "PHP OPcache modulis nėra tinkamai sukonfigūruotas. %s.",
    "Correctly configured" : "Tinkamai sukonfigūruotas",
    "PHP version" : "PHP versija",
    "You are currently running PHP %1$s. PHP %2$s is deprecated since Nextcloud %3$s. Nextcloud %4$s may require at least PHP %5$s. Please upgrade to one of the officially supported PHP versions provided by the PHP Group as soon as possible." : "Šiuo metu naudojate PHP %1$s. PHP %2$syra pasenusi versija nuo Nextcloud %3$s. Nextcloud %4$s gali reikalauti bent jau PHP %5$s. Prašome kuo greičiau atnaujinti į vieną iš oficialiai palaikomų PHP versijų, kurias teikia PHP Group.",
    "You are currently running PHP %s." : "Šiuo metu jūsų sistemoje veikia PHP %s.",
    "PHP \"output_buffering\" option" : "PHP „output_buffering“ parametras",
    "PHP configuration option \"output_buffering\" must be disabled" : "PHP konfigūracijos parametras „output_buffering“ turi būti išjungtas",
    "Push service" : "Pranešimų siuntimo paslauga",
    "Valid enterprise license" : "Galiojanti licencija Įmonėms",
    "Free push service" : "Nemokama pranešimų siuntimo paslauga",
    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications are limited to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at {link}." : "Tai yra neoficiali „Nextcloud“ bendruomenės sukurta versija. Atsižvelgiant į šio serverio dydį, negalime garantuoti jo našumo, patikimumo ir mastelio. Pranešimų siuntimai yra ribojami, siekiant išvengti mūsų nemokamos paslaugos perkrovos. Daugiau apie „Nextcloud Enterprise“ privalumus sužinokite adresu {link}.",
    "Random generator" : "Atsitiktinių skaičių generatorius",
    "No suitable source for randomness found by PHP which is highly discouraged for security reasons." : "PHP nerado tinkamo atsitiktinumo šaltinio, o tai dėl saugumo priežasčių yra labai nerekomenduojama.",
    "Secure" : "Saugus",
    "Configuration file access rights" : "Konfigūracijos failo prieigos teisės",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Įjungtas tik skaitymo režimas. Dėl to kai kurias nustatymų parinktis neįmanoma keisti per žiniatinklio sąsają. Be to, prieš kiekvieną atnaujinimą failą reikia rankiniu būdu padaryti įrašomą.",
    "Nextcloud configuration file is writable" : "„Nextcloud“ konfigūracijos failas yra įrašomas",
    "Sanitize and merge duplicate system tags available" : "Išvalyti ir sujungti pasiekiamas dubliuojamas sistemos žymas.",
    "One or more system tags need to be sanitized or merged. This can take a long time on larger instances so this is not done automatically during upgrades. Use the command `occ maintenance:repair --include-expensive` to perform the migrations." : "Vieną ar kelias sistemos žymas reikia išvalyti arba sujungti. Didelėse sistemose šis procesas gali užtrukti ilgai, todėl atnaujinimo metu jis neatliekamas automatiškai. Norėdami atlikti šiuos perkėlimo veiksmus, naudokite komandą `occ maintenance:repair --include-expensive`.",
    "Scheduling objects table size" : "Planavimo objektų lentelės dydis",
    "You have more than %s rows in the scheduling objects table. Please run the expensive repair jobs via occ maintenance:repair --include-expensive." : "Planavimo objektų lentelėje yra daugiau nei %s eilučių. Brangius taisymo darbus paleiskite naudodami „occ maintenance:repair --include-expensive“.",
    "Scheduling objects table size is within acceptable range." : "Planavimo objektų lentelės dydis yra priimtinose ribose.",
    "HTTP headers" : "HTTP antraštės",
    "- The `%1$s` HTTP header is not set to `%2$s`. Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "- HTTP `%1$s` antraštė nenustatyta kaip `%2$s` . Kai kurios funkcijos gali veikti netinkamai, todėl rekomenduojama atitinkamai pakoreguoti šį nustatymą.",
    "- The `%1$s` HTTP header is not set to `%2$s`. This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "- HTTP `%1$s` antraštė nenustatyta kaip `%2$s`. Tai kelia potencialią grėsmę saugumui ar privatumui, todėl rekomenduojama atitinkamai pakoreguoti šį nustatymą.",
    "- The `%1$s` HTTP header is not set to `%2$s`, `%3$s`, `%4$s`, `%5$s` or `%6$s`. This can leak referer information. See the {w3c-recommendation}." : "- HTTP `%1$s` antraštė nėra nustatyta kaip `%2$s`, `%3$s`, `%4$s`, `%5$s` arba `%6$s`. Dėl to gali nutekėti informacija apie nukreipusįjį šaltinį. Žr. {w3c-recommendation}.",
    "- The `Strict-Transport-Security` HTTP header is not set to at least `%d` seconds (current value: `%d`). For enhanced security, it is recommended to use a long HSTS policy." : "- HTTP antraštė „Strict-Transport-Security“ nėra nustatyta bent jau `%d` sekundžių (dabartinė vertė: `%d`). Siekiant užtikrinti didesnį saugumą, rekomenduojama taikyti ilgalaikę HSTS politiką.",
    "- The `Strict-Transport-Security` HTTP header is malformed: `%s`. For enhanced security, it is recommended to enable HSTS." : "- HTTP antraštė „Strict-Transport-Security“ yra netinkamai suformuota: `%s`. Siekiant užtikrinti didesnį saugumą, rekomenduojama įjungti HSTS.",
    "- The `Strict-Transport-Security` HTTP header is not set (should be at least `%d` seconds). For enhanced security, it is recommended to enable HSTS." : "- Nėra nustatytas HTTP antraštė `Strict-Transport-Security` (turėtų būti ne mažiau kaip `%d` sekundžių). Siekiant užtikrinti didesnį saugumą, rekomenduojama įjungti HSTS.",
    "Some headers are not set correctly on your instance" : "Kai kurios antraštės jūsų instancijoje nustatytos neteisingai",
    "Could not check that your web server serves security headers correctly. Please check manually." : "Nepavyko patikrinti, ar jūsų žiniatinklio serveris teisingai pateikia saugos antraštes. Patikrinkite rankiniu būdu.",
    "Could not check that your web server serves security headers correctly, unable to query `%s`" : "Nepavyko patikrinti, ar jūsų žiniatinklio serveris teisingai pateikia saugumo antraštes, negalima atlikti užklausos `%s`",
    "Your server is correctly configured to send security headers." : "Jūsų serveris tinkamai sukonfigūruotas siųsti saugos antraštes.",
    "Configuration server ID" : "Konfigūracijos serverio ID",
    "Server identifier isn’t configured. It is recommended if your Nextcloud instance is running on several PHP servers. Add a server ID in your configuration." : "Serverio identifikatorius nėra nustatytas. Tai rekomenduojama, jei jūsų „Nextcloud“ elementas veikia keliuose PHP serveriuose. Konfigūracijoje įveskite serverio ID.",
    "\"%d\" is not a valid server identifier. It must be between 0 and 511." : "„%d“ nėra galiojantis serverio identifikatorius. Jis turi būti nuo 0 iki 511.",
    "Server identifier is configured and valid." : "Serverio identifikatorius sukonfigūruotas ir galiojantis.",
    "Database version" : "Duomenų bazės versija",
    "MariaDB version 10.6 detected, this version is end-of-life and only supported as part of Ubuntu 22.04. MariaDB >=%1$s and <=%2$s is suggested for best performance, stability and functionality with this version of Nextcloud." : "Aptikta „MariaDB“ 10.6 versija, ši versija yra nebenaudojama ir palaikoma tik kaip „Ubuntu 22.04“ dalis. Siekiant geriausio našumo, stabilumo ir funkcionalumo su šia „Nextcloud“ versija, rekomenduojama naudoti MariaDB >=%1$s ir <=%2$s",
    "MariaDB version \"%1$s\" detected. MariaDB >=%2$s and <=%3$s is suggested for best performance, stability and functionality with this version of Nextcloud." : "Aptikta „MariaDB“ versija „%1$s“. Siekiant geriausio našumo, stabilumo ir funkcionalumo naudojant šią „Nextcloud“ versiją, rekomenduojama naudoti MariaDB „>=%2$s“ ir „<=%3$s“.",
    "MySQL version \"%1$s\" detected. MySQL >=%2$s and <=%3$s is suggested for best performance, stability and functionality with this version of Nextcloud." : "Aptikta „MySQL“ versija „%1$s“. Siekiant geriausio našumo, stabilumo ir funkcionalumo naudojant šią „Nextcloud“ versiją, rekomenduojama naudoti MySQL „>=%2$s“ ir „<=%3$s“.",
    "PostgreSQL version \"%1$s\" detected. PostgreSQL >=%2$s and <=%3$s is suggested for best performance, stability and functionality with this version of Nextcloud." : "Aptikta „PostgreSQL“ versija „%1$s“. Siekiant geriausio našumo, stabilumo ir funkcionalumo naudojant šią „Nextcloud“ versiją, rekomenduojama naudoti PostgreSQL „>=%2$s“ ir „<=%3$s“.",
    "Nextcloud %d does not support your current version, so be sure to update the database before updating your Nextcloud Server." : "„Nextcloud“ %d nepalaiko jūsų dabartinės versijos, todėl prieš atnaujindami „Nextcloud“ serverį būtinai atnaujinkite duomenų bazę.",
    "Oracle version \"%1$s\" detected. Oracle >=%2$s and <=%3$s is suggested for best performance, stability and functionality with this version of Nextcloud." : "Aptikta „Oracle“ versija „%1$s“. Siekiant geriausio našumo, stabilumo ir funkcionalumo naudojant šią „Nextcloud“ versiją, rekomenduojama naudoti Oracle „>=%2$s“ ir „<=%3$s“.",
    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend. This is particularly recommended when using the desktop client for file synchronisation. To migrate to another database use the command line tool: \"occ db:convert-type\"." : "Šiuo metu kaip vidinė duomenų bazė naudojama „SQLite“. Didesniems elementams rekomenduojame perjungti kitą duomenų bazės vidinę sistemą. Tai ypač rekomenduojama, kai failų sinchronizavimui naudojamas darbalaukio klientas. Norėdami perkelti į kitą duomenų bazę, naudokite komandinės eilutės įrankį: „occ db:convert-type“.",
    "Unknown database platform" : "Nežinoma duomenų bazės platforma",
    "Architecture" : "Architektūra",
    "64-bit" : "64 bitų",
    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit!" : "Panašu, kad naudojate 32 bitų PHP versiją. „Nextcloud“ reikia 64 bitų versijos, kad gerai veiktų. Atnaujinkite savo OS ir PHP iki 64 bitų!",
    "Task Processing pickup speed" : "Užduotis Apdorojant paėmimo greitį",
    "_No scheduled tasks in the last day._::_No scheduled tasks in the last %n days._" : ["Paskutinę dieną nebuvo suplanuotų užduočių.","Per pastarąsias %n dienas nebuvo suplanuotų užduočių.","Per pastarąsias %n dienų nebuvo suplanuotų užduočių.","Per pastarąsias %n dienų nebuvo suplanuotų užduočių."],
    "_The task pickup speed has been ok in the last day._::_The task pickup speed has been ok in the last %n days._" : ["Užduočių atlikimo greitis pastarąją dieną buvo geras.","Užduočių atlikimo greitis per pastarąsias %n dienas buvo geras.","Užduočių atlikimo greitis per pastarąsias %n dienų buvo geras.","Užduočių atlikimo greitis per pastarąsias %n dienų buvo geras."],
    "_The task pickup speed has been slow in the last day. Many tasks took longer than 4 minutes to be picked up. Consider setting up a worker to process tasks in the background._::_The task pickup speed has been slow in the last %n days. Many tasks took longer than 4 minutes to be picked up. Consider setting up a worker to process tasks in the background._" : ["Užduočių paėmimo greitis pastarąją dieną buvo lėtas. Daugelio užduočių paėmimas užtruko ilgiau nei 4 minutes. Apsvarstykite galimybę nustatyti darbininką, kuris apdorotų užduotis fone.","Užduočių paėmimo greitis per pastarąsias %n dienas buvo lėtas. Daugelio užduočių paėmimas užtruko ilgiau nei 4 minutes. Apsvarstykite galimybę nustatyti darbininką, kuris apdorotų užduotis fone.","Užduočių paėmimo greitis per pastarąsias %n dienų buvo lėtas. Daugelio užduočių paėmimas užtruko ilgiau nei 4 minutes. Apsvarstykite galimybę nustatyti darbininką, kuris apdorotų užduotis fone.","Užduočių paėmimo greitis per pastarąsias %n dienų buvo lėtas. Daugelio užduočių paėmimas užtruko ilgiau nei 4 minutes. Apsvarstykite galimybę nustatyti darbininką, kuris apdorotų užduotis fone."],
    "Task Processing success rate" : "Užduočių apdorojimo sėkmės rodiklis",
    "_No scheduled tasks in the last %n day._::_No scheduled tasks in the last %n days._" : ["Per pastarąją %n d. nebuvo suplanuota užduočių.","Per pastarąsias %n d. nebuvo suplanuota užduočių.","Per pastarąsias %n d. nebuvo suplanuota užduočių.","Per pastarąsias %n d. nebuvo suplanuota užduočių."],
    "_Most tasks were successful in the last %n day._::_Most tasks were successful in the last %n days._" : ["Dauguma užduočių per pastarąją %n d. buvo sėkmingai atliktos.","Dauguma užduočių per pastarąsias %n d. buvo sėkmingai atliktos.","Dauguma užduočių per pastarąsias %n d. buvo sėkmingai atliktos.","Dauguma užduočių per pastarąsias %n d. buvo sėkmingai atliktos."],
    "_A lot of tasks failed in the last day. Consider checking the nextcloud log for errors and investigating whether the AI provider apps have been set up correctly._::_A lot of tasks failed in the last %n days. Consider checking the nextcloud log for errors and investigating whether the AI provider apps have been set up correctly._" : ["Per pastarąją dieną daug užduočių nepavyko atlikti. Apsvarstykite galimybę patikrinti „Nextcloud“ žurnalą, ar nėra klaidų, ir išsiaiškinti, ar dirbtinio intelekto teikėjo programos buvo tinkamai nustatytos.","Per pastarąsias %n dienas nepavyko atlikti daug užduočių. Apsvarstykite galimybę patikrinti „Nextcloud“ žurnalą, ar nėra klaidų, ir išsiaiškinti, ar dirbtinio intelekto teikėjo programos buvo tinkamai nustatytos.","Per pastarąsias %n dienų nepavyko atlikti daug užduočių. Apsvarstykite galimybę patikrinti „nextcloud“ žurnalą, ar nėra klaidų, ir išsiaiškinti, ar dirbtinio intelekto teikėjo programos buvo tinkamai nustatytos.","Per pastarąsias %n dienų nepavyko atlikti daug užduočių. Apsvarstykite galimybę patikrinti „nextcloud“ žurnalą, ar nėra klaidų, ir išsiaiškinti, ar dirbtinio intelekto teikėjo programos buvo tinkamai nustatytos."],
    "Task Processing worker status" : "Užduočių apdorojimo vykdytojo būsena",
    "_The Task Processing worker has run in the last %n minute._::_The Task Processing worker has run in the last %n minutes._" : ["Užduočių apdorojimo darbuotojas veikė %n pastarąją minutę.","Užduočių apdorojimo darbuotojas veikė %n pastarąsias minutes.","Užduočių apdorojimo darbuotojas veikė %n pastarųjų minučių.","Užduočių apdorojimo darbuotojas veikė %n pastarųjų minučių."],
    "The Task Processing worker does not seem to be running. The last run was at %s." : "Atrodo, kad užduočių apdorojimo vykdytojas neveikia. Paskutinį kartą paleistas prieš %s.",
    "The Task Processing worker does not seem to be running. It seems it has never run so far." : "Atrodo, kad užduočių apdorojimo vykdytojas neveikia. Atrodo, kad jis dar nė karto nebuvo paleistas.",
    "Temporary space available" : "Yra laisvos vietos",
    "Error while checking the temporary PHP path - it was not properly set to a directory. Returned value: %s" : "Tikrinant laikiną PHP kelią įvyko klaida – jis nebuvo tinkamai nustatytas į katalogą. Grąžinta reikšmė: %s",
    "The PHP function \"disk_free_space\" is disabled, which prevents the check for enough space in the temporary directories." : "PHP funkcija „disk_free_space“ yra išjungta, todėl negalima patikrinti, ar laikinųjų katalogų talpa yra pakankama.",
    "Error while checking the available disk space of temporary PHP path or no free disk space returned. Temporary path: %s" : "Tikrinant laikino PHP kelio disko vietą įvyko klaida arba laisvos vietos diske nerasta. Laikinas kelias: %s",
    "- %.1f GiB available in %s (PHP temporary directory)" : "- %.1fGiB pasiekiama %s (PHP laikinajame kataloge)",
    "- %.1f GiB available in %s (Nextcloud temporary directory)" : "- %.1f GiB pasiekiama %s (\"Nextcloud\" laikinajame kataloge)",
    "Temporary directory is correctly configured:\n%s" : "Laikinas katalogas teisingai sukonfigūruotas:\n%s",
    "This instance uses an S3 based object store as primary storage, and has enough space in the temporary directory.\n%s" : "Šis elementas kaip pagrindinę saugyklą naudoja S3 pagrindu veikiančią objektų saugyklą ir laikinajame kataloge yra pakankamai vietos.\n%s",
    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GiB of free space available in the temp directory of PHP. To improve this please change the temporary directory in the php.ini or make more space available in that path. \nChecking the available space in the temporary path resulted in %.1f GiB instead of the recommended 50 GiB. Path: %s" : "Šiame elemente kaip pagrindinė saugykla naudojama S3 pagrindu sukurta objektų saugykla. Įkelti failai serveryje saugomi laikinai, todėl rekomenduojama turėti 50 GiB laisvos vietos PHP laikinajame kataloge. Norėdami tai pagerinti, pakeiskite laikinąjį katalogą php.ini faile arba atlaisvinkite daugiau vietos tame kelyje.\nPatikrinant laisvą vietą laikinajame kelyje, gauta %.1f GiB, o ne rekomenduojami 50 GiB. Kelias: %s",
    "Database transaction isolation level" : "Duomenų bazės operacijų izoliacijos lygis",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Jūsų duomenų bazė neveikia su operacijų izoliacijos lygiu „READ COMMITTED“. Tai gali sukelti problemų, kai lygiagrečiai vykdomi keli veiksmai.",
    "Was not able to get transaction isolation level: %s" : "Nepavyko gauti operacijos izoliacijos lygio: %s",
    "Second factor configuration" : "Antrojo faktoriaus konfigūracija",
    "This instance has no second factor provider available." : "Šiame elemente nėra pasiekiamo antrojo faktoriaus teikėjo.",
    "Second factor providers are available but two-factor authentication is not enforced." : "Yra dviejų veiksnių autentifikavimo paslaugų teikėjų, tačiau dviejų veiksnių autentifikavimas nėra įgalintas.",
    "Second factor providers are available and enforced: %s." : "Antrojo faktoriaus teikėjai yra prieinami ir įgalinti: %s.",
    ".well-known URLs" : "\".well-known\" URL adresai",
    "`check_for_working_wellknown_setup` is set to false in your configuration, so this check was skipped." : "Jūsų konfigūracijoje parametro `check_for_working_wellknown_setup` reikšmė yra „false“, todėl šis patikrinimas buvo praleistas.",
    "Could not check that your web server serves `.well-known` correctly. Please check manually." : "Nepavyko patikrinti, ar jūsų žiniatinklio serveris teisingai teikia `.well-known` aplanką. Patikrinkite rankiniu būdu.",
    "Your web server is not properly set up to resolve `.well-known` URLs, failed on:\n`%s`" : "Jūsų žiniatinklio serveris netinkamai nustatytas identifikuoti „.well-known“ URL. Nepavyko:\n`%s`",
    "Your server is correctly configured to serve `.well-known` URLs." : "Jūsų serveris yra tinkamai sukonfigūruotas aptarnauti „.well-known“ URL adresus.",
    "Font file loading" : "Įkeliamas šrifto failas",
    "Could not check for {extension} loading support. Please check manually if your webserver serves `.{extension}` files." : "Nepavyko patikrinti, ar {extension} yra palaikymo įkėlimas. Patikrinkite rankiniu būdu, ar jūsų žiniatinklio serveris teikia `.{extension}` failus.",
    "Your web server is not properly set up to deliver .{extension} files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustment to also deliver .{extension} files. Compare your Nginx configuration to the recommended configuration in our documentation." : "Jūsų žiniatinklio serveris netinkamai nustatytas teikti .{extension} failus. Paprastai tai yra „Nginx“ konfigūracijos problema. „Nextcloud 15“ sistemoje reikia atlikti pakeitimus, kad būtų teikiami ir .{extension} failai. Palyginkite savo „Nginx“ konfigūraciją su rekomenduojama konfigūracija mūsų dokumentacijoje.",
    "Profile information" : "Profilio informacija",
    "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Profilio paveikslėlis, vardas, pavardė, el. paštas, telefono numeris, adresas, svetainė, „Twitter“, organizacija, vaidmuo, santrauka apie jus, biografija bei tai, ar jūsų profilis yra įjungtas, ar ne",
    "Nextcloud settings" : "Nextcloud nustatymai",
    "Generate text" : "Generuoti tekstą",
    "Unified task processing" : "Vieningas užduočių apdorojimas",
    "AI tasks can be implemented by different apps. Here you can set which app should be used for which task." : "Dirbtinio intelekto užduotis gali įgyvendinti skirtingos programėlės. Čia galite nustatyti, kuri programėlė turėtų būti naudojama kuriai užduočiai atlikti.",
    "Allow AI usage for guest users" : "Leisti dirbtinio intelekto naudojimą svečiams",
    "Provider for Task types" : "Užduočių tipų teikėjas",
    "Enable" : "Įjungti",
    "None of your currently installed apps provide Task processing functionality" : "Nė viena iš šiuo metu įdiegtų programėlių neteikia užduočių apdorojimo funkcijos",
    "Hide legacy provider settings" : "Slėpti senojo teikėjo nustatymus",
    "Show legacy provider settings" : "Rodyti senojo teikėjo nustatymus",
    "Machine translation (Legacy)" : "Mašininis vertimas (senasis)",
    "Machine translation can be implemented by different apps. Here you can define the precedence of the machine translation apps you have installed at the moment." : "Mašininį vertimą gali atlikti įvairios programėlės. Čia galite apibrėžti šiuo metu įdiegtų mašininio vertimo programėlių prioritetą.",
    "This API is deprecated. Install apps that provide Unified task processing to get the best experience." : "Ši API nebenaudojama. Įdiekite programėles, kurios teikia vieningą užduočių apdorojimą, kad gautumėte geriausią patirtį.",
    "Learn more about AI providers" : "Sužinokite daugiau apie dirbtinio intelekto teikėjus",
    "Image generation (Legacy)" : "Vaizdo generavimas (palikimas)",
    "Image generation can be implemented by different apps. Here you can set which app should be used." : "Paveikslėlių generavimą galima įgyvendinti naudojant įvairias programėles. Čia galite nustatyti, kuri programėlė turėtų būti naudojama.",
    "None of your currently installed apps provide image generation functionality" : "Nė viena iš šiuo metu įdiegtų jūsų programėlių neturi paveikslėlių kūrimo funkcijos",
    "Text processing (Legacy)" : "Teksto apdorojimas (senasis)",
    "Text processing tasks can be implemented by different apps. Here you can set which app should be used for which task." : "Teksto apdorojimo užduotys gali būti atliekamos naudojant įvairias programėles. Čia galite nustatyti, kuri programėlė turi būti naudojama konkrečiai užduočiai atlikti.",
    "Task:" : "Užduotis:",
    "None of your currently installed apps provide text processing functionality using the Text Processing API." : "Nė viena iš šiuo metu įdiegtų jūsų programėlių nepalaiko teksto apdorojimo funkcijos, naudojant Teksto apdorojimo API.",
    "Here you can decide which group can access certain sections of the administration settings." : "Čia galite nuspręsti, kuri grupė galės gauti prieigą prie tam tikrų administravimo nustatymų sekcijų.",
    "Unable to modify setting" : "Nepavyko modifikuoti nustatymo",
    "None" : "Nėra",
    "Changed disclaimer text" : "Pakeistas atsakomybės apribojimo tekstas",
    "Deleted disclaimer text" : "Ištrintas atsakomybės apribojimo tekstas",
    "Could not set disclaimer text" : "Nepavyko nustatyti atsakomybės ribojimo teksto",
    "Allow apps to use the Share API" : "Leisti programėlėms naudoti bendrinimo API",
    "Allow resharing" : "Leisti bendrinti iš naujo",
    "Allow sharing with groups" : "Leisti bendrinti su grupėmis",
    "Restrict users to only share with users in their groups" : "Apriboti vartotojus ir leisti jiems bendrinti tik su vartotojais savo grupėse",
    "Ignore the following groups when checking group membership" : "Tikrinant grupės narystę, ignoruoti šias grupes",
    "Allow users to preview files even if download is disabled" : "Leisti vartotojams peržiūrėti failus net jei atsisiuntimas yra išjungtas",
    "Users will still be able to screenshot or record the screen. This does not provide any definitive protection." : "Vartotojai vis tiek galės daryti ekrano kopijas arba jas įrašyti. Tai nesuteikia jokios galutinės apsaugos.",
    "Allow users to share via link and emails" : "Leisti vartotojams bendrinti per nuorodą ir el. laiškus",
    "Allow public uploads" : "Leisti viešus įkėlimus",
    "Allow public shares to be added to other clouds by federation." : "Leisti federacijos būdu pridėti viešuosius bendrinamus failus prie kitų debesų.",
    "This will add share permissions to all newly created link shares." : "Tai suteiks bendrinimo teises visiems naujai sukurtiems nuorodų bendrinimams.",
    "Always ask for a password" : "Visada prašyti slaptažodžio",
    "Enforce password protection" : "Priverstinė apsauga slaptažodžiu",
    "Exclude groups from password requirements" : "Išskirti grupes nuo slaptažodžio reikalavimų",
    "Exclude groups from creating link shares" : "Išskirti grupes iš nuorodų bendrinimo kūrimo",
    "Allow users to set custom share link tokens" : "Leisti vartotojams nustatyti pasirinktinus bendrinimo nuorodų žymenis",
    "Shares with custom tokens will continue to be accessible after this setting has been disabled" : "Bendrinimai su pasirinktiniais žymenimis ir toliau bus pasiekiami išjungus šį nustatymą.",
    "Shares with guessable tokens may be accessed easily" : "Prie bendrinamų išteklių su atspėjamaisiais žymenimis galima lengvai prisijungti",
    "Limit sharing based on groups" : "Apriboti bendrinimą pagal grupes",
    "Allow sharing for everyone (default)" : "Leisti bendrinti visiems (numatytasis nustatymas)",
    "Exclude some groups" : "Išskirti kai kurias grupes",
    "Allow some groups" : "Leisti kai kurias grupes",
    "Groups allowed to share" : "Grupėms leidžiama bendrinti",
    "Groups excluded from sharing" : "Grupės, kurioms netaikomas bendrinimas",
    "Not allowed groups will still be able to receive shares, but not to initiate them." : "Neleidžiamos grupės vis tiek galės gauti bendrinimus, bet negalės jų inicijuoti.",
    "Set default expiration date for internal shares" : "Nustatykite numatytąją vidinių bendrinimų galiojimo pabaigos datą",
    "Enforce expiration date" : "Priverstinė galiojimo pabaigos data",
    "Default expiration time of new shares in days" : "Numatytasis naujų bendrinimų galiojimo laikas dienomis",
    "Expire shares after x days" : "Bendrinimų galiojimo laikas baigiasi po x dienų",
    "Set default expiration date for shares to other servers" : "Nustatykite numatytąją bendrinamų duomenų su kitais serveriais galiojimo pabaigos datą",
    "Enforce expiration date for remote shares" : "Priversti galioti nuotolinių bendrinimų galiojimo datą",
    "Default expiration time of remote shares in days" : "Numatytasis nuotolinių bendrinimų galiojimo laikas dienomis",
    "Expire remote shares after x days" : "Nuotolinių bendrinimų galiojimas baigiasi po x dienų",
    "Set default expiration date for shares via link or mail" : "Nustatykite numatytąją bendrinimo per nuorodą arba el. paštu galiojimo datą",
    "Enforce expiration date for link or mail shares" : "Priverstinai nustatyti nuorodų arba el. laiškų bendrinimo galiojimo datą",
    "Default expiration time of shares in days" : "Numatytasis bendrinimų galiojimo laikas dienomis",
    "Privacy settings for sharing" : "Privatumo nustatymai dalijimuisi",
    "Allow account name autocompletion in share dialog and allow access to the system address book" : "Leisti automatinį paskyros vardo užbaigimą dalijimosi lange ir suteikti prieigą prie sistemos adresų knygos",
    "Sharing autocompletion restrictions" : "Automatinio užbaigimo apribojimų bendrinimas",
    "If autocompletion restrictions for both \"same group\" and \"phonebook integration\" are enabled, a match in either is enough to show the user." : "Jei įjungti automatinio užbaigimo apribojimai ir „tai pačiai grupei“, ir „telefonų knygos integracijai“, pakanka atitikmens bet kurioje iš jų, kad būtų parodytas vartotojui.",
    "Restrict account name autocompletion and system address book access to users within the same groups" : "Apriboti paskyros pavadinimo automatinio užbaigimo ir sistemos adresų knygos prieigą vartotojams, kurie yra tose pačiose grupėse",
    "Restrict account name autocompletion to users based on their phonebook" : "Apriboti paskyros pavadinimo automatinį pildymą vartotojams pagal jų telefonų knygą",
    "Allow autocompletion to full match when entering the full name (ignoring restrictions like group membership or missing phonebook match)" : "Leisti automatinį užbaigimą pagal pilną atitikmenį įvedant pilną vardą ir pavardę (ignoruojant apribojimus, pvz., grupės narystę ar neatitikimą telefonų knygoje)",
    "Full match autocompletion restrictions" : "Pilni atitikmenų automatinio užbaigimo apribojimai",
    "Also allow autocompletion on full match of the user ID" : "Taip pat leisti automatinį užbaigimą, kai vartotojo ID visiškai sutampa",
    "Also allow autocompletion on full match of the display name" : "Taip pat leisti automatinį užbaigimą, kai rodomas vardas atitinka visą atitikmenį",
    "Also allow autocompletion on full match of the user email" : "Taip pat leisti automatinį užbaigimą, kai visiškai atitinka vartotojo el. pašto adresą",
    "Do not use second user displayname for full match" : "Nenaudokite antrojo vartotojo rodomo vardo, jei ieškote pilno atitikmens",
    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Rodyti atsakomybės ribojimo tekstą įkėlimo per viešąją nuorodą puslapyje (rodomas tik tada, kai failų sąrašas yra paslėptas)",
    "Disclaimer text" : "Atsakomybės ribojimo tekstas",
    "This text will be shown on the public link upload page when the file list is hidden." : "Šis tekstas bus rodomas viešų nuorodų įkėlimo puslapyje, kai failų sąrašas bus paslėptas.",
    "Default share permissions" : "Numatytieji bendrinimų leidimai",
    "Two-Factor Authentication" : "Dviejų faktorių tapatybės nustatymas",
    "Two-factor authentication can be enforced for all accounts and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Dviejų veiksnių autentifikavimą galima taikyti visoms paskyroms ir konkrečioms grupėms. Jei jos neturi sukonfigūruoto dviejų faktorių teikėjo, negalės prisijungti prie sistemos.",
    "Enforce two-factor authentication" : "Priversti naudoti dviejų faktorių tapatybės nustatymą",
    "Limit to groups" : "Apriboti iki grupių",
    "Enforcement of two-factor authentication can be set for certain groups only." : "Priverstinis dviejų faktorių tapatybės nustatymas gali būti nustatytas tik tam tikroms grupėms.",
    "Two-factor authentication is enforced for all members of the following groups." : "Dviejų faktorių tapatybės nustatymas yra priverstinis visiems šių grupių nariams.",
    "Enforced groups" : "Priverstines grupės",
    "Two-factor authentication is not enforced for members of the following groups." : "Dviejų faktorių tapatybės nustatymas nėra priverstinis šių grupių nariams.",
    "Excluded groups" : "Pašalintos grupės",
    "When groups are selected/excluded, they use the following logic to determine if an account has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If an account is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Kai grupės pasirenkamos/išskiriamos, jos naudoja šią logiką, kad nustatytų, ar paskyroje įjungtas 2FA: jei nepasirinkta jokių grupių, 2FA įjungtas visiems, išskyrus neįtrauktų grupių narius. Jei pasirinktos grupės, 2FA įjungtas visiems jų nariams. Jei paskyra yra ir pasirinktoje, ir neįtrauktoje grupėje, pasirinktoji turi pirmenybę ir 2FA yra įgalintas.",
    "Save changes" : "Įrašyti pakeitimus",
    "Failed to load groups" : "Nepavyko įkelti grupių",
    "Failed to create group" : "Nepavyko sukurti grupės",
    "List of groups. This list is not fully populated for performance reasons. The groups will be loaded as you navigate or search through the list." : "Grupės sąrašas. Dėl našumo priežasčių šis sąrašas nėra visiškai užpildytas. Grupės bus įkeltos, kai naršysite sąraše arba jame atliksite paiešką.",
    "Groups" : "Grupės",
    "Creating group…" : "Kuriama grupė…",
    "Create group" : "Sukurti grupę",
    "Group name" : "Grupės pavadinimas",
    "Please enter a valid group name" : "Įveskite galiojantį grupės pavadinimą",
    "Loading groups…" : "Įkeliamos grupės…",
    "Google Chrome for Android" : "Google Chrome, skirta Android",
    "{productName} iOS app" : "{productName} „iOS“ programėlė",
    "{productName} Android app" : "{productName} „Android“ programėlė",
    "{productName} Talk for iOS" : "{productName} „Pokalbiai“ skirtas iOS",
    "{productName} Talk for Android" : "{productName} „Pokalbiai“ skirtas Android",
    "Sync client" : "Sinchronizuoti klientą",
    "This session" : "Šis seansas",
    "{client} - {version} ({system})" : "{client} – {version} ({system})",
    "{client} - {version}" : "{client} – {version}",
    "Confirm wipe" : "Patvirtinti duomenų ištrynimą",
    "Do you really want to wipe your data from this device?" : "Ar tikrai norite ištrinti šiame įrenginyje esančius savo duomenis?",
    "Wipe device" : "Ištrinti duomenis įrenginyje",
    "Cancel" : "Atšaukti",
    "Device name" : "Įrenginio pavadinimas",
    "Cancel renaming" : "Atsisakyti pervadinimo",
    "Save new name" : "Išsaugoti naują vardą",
    "Marked for remote wipe" : "Pažymėtas nuotolinių duomenų ištrynimui",
    "Device settings" : "Įrenginio nustatymai",
    "Allow filesystem access" : "Leisti prieigą prie failų sistemos",
    "Rename" : "Pervadinti",
    "Revoke" : "Panaikinti",
    "Revoking this token might prevent the wiping of your device if it has not started the wipe yet." : "Šio žymens panaikinimas gali užkirsti kelią jūsų įrenginio duomenų ištrynimui, jei šis procesas dar neprasidėjo.",
    "Revoke and cancel pending wipe?" : "Atšaukti ir atšaukti laukiantį valymą?",
    "Only continue if you no longer need the device to be wiped." : "Tęskite tik tuo atveju, jei nebereikia išvalyti įrenginio duomenų.",
    "Revoke and cancel wipe" : "Atšaukti ir panaikinti išvalymą",
    "Revoke app password?" : "Atšaukti programėlės slaptažodį?",
    "The app or device will lose access on its next sync. This cannot be undone." : "Programėlė arba įrenginys praras prieigą kito sinchronizavimo metu. Šio veiksmo atšaukti negalima.",
    "Remote wipe has not started yet." : "Nuotolinis valymas dar nepradėtas.",
    "Revoking now cancels the wipe. The device keeps its synced data." : "Atšaukus dabar, valymas bus atšauktas. Įrenginyje išsaugomi sinchronizuoti duomenys.",
    "Device" : "Įrenginys",
    "Last activity" : "Paskutinė veikla",
    "Actions" : "Veiksmai",
    "Devices & sessions" : "Įrenginiai ir seansai",
    "Web, desktop and mobile clients currently logged in to your account." : "Saityno, darbalaukio ir mobilieji klientai, kurie šiuo metu yra prisijungę prie jūsų paskyros.",
    "Error while creating device token" : "Klaida, kuriant įrenginio žymenį",
    "App name" : "Programėlės pavadinimas",
    "Create new app password" : "Sukurti naują programėlės slaptažodį",
    "App password copied!" : "Programėlės slaptažodis nukopijuotas!",
    "Copy app password" : "Kopijuoti programėlės slaptažodį",
    "Login name copied!" : "Prisijungimo vardas nukopijuotas!",
    "Copy login name" : "Kopijuoti prisijungimo vardą",
    "Could not copy app password. Please copy it manually." : "Nepavyko nukopijuoti programos slaptažodžio. Nukopijuokite jį ranka.",
    "Could not copy login name. Please copy it manually." : "Nepavyko nukopijuoti prisijungimo vardą. Nukopijuokite jį rankiniu būdu.",
    "New app password" : "Naujas programėlės slaptažodis",
    "Use the credentials below to configure your app or device. For security reasons this password will only be shown once." : "Naudokite žemiau pateiktus prisijungimo duomenis, kad sukonfigūruotumėte savo programėlę ar įrenginį. Saugumo sumetimais šis slaptažodis bus rodomas tik vieną kartą.",
    "Login" : "Prisijungti",
    "Password" : "Slaptažodis",
    "Show QR code for mobile apps" : "Rodyti mobiliųjų programėlių QR kodą",
    "Use system cron service to call the cron.php file every 5 minutes." : "Naudokite sistemos cron paslaugą, kad kas 5 minutes iškviestumėte cron.php failą.",
    "The cron.php needs to be executed by the system account \"{user}\"." : "Sistemos paskyra „{user}“ turi vykdyti „cron.php“.",
    "The PHP POSIX extension is required. See {linkstart}PHP documentation{linkend} for more details." : "Reikalingas PHP POSIX plėtinys. Daugiau informacijos rasite {linkstart} PHP dokumentacijoje {linkend}.",
    "Unable to update background job mode" : "Nepavyko atnaujinti foninių užduočių veiksenos",
    "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information." : "Tam, kad serveris tinkamai veiktų, yra svarbu teisingai sukonfigūruoti fonines užduotis. „Cron“ yra rekomenduojamas nustatymas. Išsamesnei informacijai žiūrėkite dokumentaciją.",
    "Last job execution ran {time}. Something seems wrong." : "Paskutinis užduoties vykdymas buvo atliktas {time}. Atrodo, kad kažkas nutiko.",
    "Last job ran {relativeTime}." : "Paskutinis užduoties vykdymas buvo atliktas {relativeTime}.",
    "Background job did not run yet!" : "Foninės užduotys kol kas nebuvo vykdomos!",
    "AJAX" : "„AJAX“",
    "Execute one task with each page loaded. Use case: Single account instance." : "Vykdyti vieną užduotį su kiekvienu įkeltu puslapiu. Naudojimo atvejis: vienas paskyros elementas.",
    "Webcron" : "„Webcron“",
    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 accounts depending on the usage)." : "„cron.php“ yra užregistruotas „webcron“ paslaugoje, kad iškviestų „cron.php“ kas 5 minutes per HTTP. Naudojimas: labai mažais atvejais (1–5 paskyros, priklausomai nuo naudojimo).",
    "Cron (Recommended)" : "„Cron“ (Rekomenduojama)",
    "Unable to update profile default setting" : "Nepavyko atnaujinti numatytųjų profilio nustatymų",
    "Unable to update profile picker setting" : "Nepavyko atnaujinti profilio parinkiklio nustatymo",
    "Profile" : "Profilis",
    "Enable or disable profile by default for new accounts." : "Įjungti arba išjungti profilį pagal numatytuosius nustatymus naujoms paskyroms.",
    "Enable the profile picker" : "Įgalinkite profilio pasirinkimo funkciją",
    "Enable or disable the profile picker in the Smart Picker and the profile link previews." : "Įjunkite arba išjunkite profilio pasirinkimo funkciją „Išmanusis rinkiklis“ ir profilio nuorodų peržiūrose.",
    "Password confirmation is required" : "Reikalingas slaptažodžio patvirtinimas",
    "Failed to save setting" : "Nepavyko įrašyti nustatymo",
    "{app}'s declarative setting field: {name}" : "{app} deklaratyvus nustatymų laukas: {name}",
    "Unable to update server side encryption config" : "Nepavyko atnaujinti serverio pusės šifravimo konfigūracijos",
    "Server-side encryption" : "Šifravimas serverio pusėje",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Šifravimas serverio pusėje leidžia užšifruoti failus, kurie yra įkelti į serverį. Įjungti tik ik būtinais atvejais.",
    "To encrypt all existing files run this OCC command:" : "Norėdami užšifruoti visus esamus failus, paleiskite šią OCC komandą:",
    "Enable server-side encryption" : "Įjungti šifravimą serverio pusėje",
    "Disabling server side encryption is only possible using OCC, please refer to the documentation." : "Išjungti šifravimą serverio pusėje galima tik naudojant OCC; prašome susipažinti su dokumentacija.",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Neįkeltas joks šifravimo modulis, įjunkite šifravimo modulį programėlės meniu.",
    "Select default encryption module:" : "Pasirinkite numatytąjį šifravimo modulį:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}" : "Jūs turite perkelti savo šifravimo raktus iš senojo šifravimo (ownCloud <= 8.0) į naująjį. Įjunkite „Numatytąjį šifravimo modulį“ ir paleiskite komandą {command}",
    "Cancel encryption" : "Atšaukti šifravimą",
    "Enable encryption" : "Įjungti šifravimą",
    "Confirm enabling encryption" : "Patvirtinkite šifravimo įgalinimą",
    "Please read carefully before activating server-side encryption:" : "Prieš įjungdami šifravimą serverio pusėje, atidžiai perskaitykite:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Nuo to momento kai šifravimas aktyvuotas, visi failai įkelti į serverį bus užšifruoti ir saugomi serveryje. Vėliau išjungti šifravimą galėsite tik jei šifravimo modulius turi tokią galimybę, ir visos sąlygos (pvz. atstatymo rakto nustatymas) išpildytos.",
    "By default a master key for the whole instance will be generated. Please check if that level of access is compliant with your needs." : "Pagal numatytuosius nustatymus bus sukurtas pagrindinis raktas, galiojantis visais atvejais. Patikrinkite, ar toks prieigos lygis atitinka jūsų poreikius.",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Vien tik šifravimas negarantuoja sistemos saugumo. Išsamesnei informacijai apie tai, kaip veikia šifravimo programėlė ir galimus naudojimo scenarijus, žiūrėkite dokumentaciją.",
    "Be aware that encryption always increases the file size." : "Turėkite omenyje, kad šifravimas visada padidina failų dydį.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Visada yra gerai daryti reguliarias atsargines duomenų kopijas. Esant šifravimui, nepamirškite kartu su savo duomenų atsargine kopija, pasidaryti ir šifravimo raktų atsarginę kopiją.",
    "Refer to the admin documentation on how to manually also encrypt existing files." : "Kaip rankiniu būdu užšifruoti esamus failus, skaitykite administratoriaus dokumentacijoje.",
    "This is the final warning: Do you really want to enable encryption?" : "Tai yra paskutinis įspėjimas: Ar tikrai norite įjungti šifravimą?",
    "Failed to delete group \"{group}\"" : "Nepavyko ištrinti grupės „{group}“",
    "Please confirm the group removal" : "Patvirtinkite grupės pašalinimą",
    "You are about to delete the group \"{group}\". The accounts will NOT be deleted." : "Ketinate ištrinti grupę „{group}“. Paskyros NEBUS ištrintos.",
    "Confirm" : "Patvirtinti",
    "Submit" : "Pateikti",
    "Rename group" : "Pervadinti grupę",
    "Delete group" : "Ištrinti grupę",
    "Current password" : "Dabartinis slaptažodis",
    "New password" : "Naujas slaptažodis",
    "Change password" : "Keisti slaptažodį",
    "Choose your profile picture" : "Pasirinkite savo profilio paveikslėlį",
    "Please select a valid png or jpg file" : "Pasirinkite tinkamą png ar jpg failą",
    "Error setting profile picture" : "Klaida nustatant profilio paveikslėlį",
    "Error cropping profile picture" : "Klaida apkerpant profilio paveikslėlį",
    "Error saving profile picture" : "Klaida įrašant profilio paveikslėlį",
    "Error removing profile picture" : "Klaida šalinant profilio paveikslėlį",
    "Your profile picture" : "Jūsų profilio paveikslėlis",
    "Upload profile picture" : "Įkelti profilio paveikslėlį",
    "Choose profile picture from Files" : "Pasirinkite profilio paveikslėlį iš „Failai“",
    "Remove profile picture" : "Šalinti profilio paveikslėlį",
    "The file must be a PNG or JPG" : "Failas privalo būti PNG ar JPG tipo",
    "Picture provided by original account" : "Paveikslėlis gautas iš pagrindinės paskyros",
    "Set as profile picture" : "Nustatyti kaip profilio paveikslėlį",
    "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "Turėkite omenyje, kad gali praeiti iki 24 valandų, kol jūsų profilis bus visur atnaujintas.",
    "Your biography. Markdown is supported." : "Jūsų biografija. Palaikoma „Markdown“.",
    "Unable to update date of birth" : "Nepavyko atnaujinti gimimo datos",
    "Enter your date of birth" : "Įveskite savo gimimo datą",
    "Bluesky handle" : "„Bluesky“ identifikatorius",
    "You are using {s}{usage}{/s}" : "Jūs naudojate {s} {usage} {/s}",
    "You are using {s}{usage}{/s} of {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})" : "Jūs naudojate {s} {usage} {/s} iš {s} {totalSpace} {/s} ({s} {usageRelative} % {/s})",
    "Details" : "Išsamiau",
    "You are a member of the following groups:" : "Jūs esate šių grupių narys:",
    "Your full name" : "Jūsų visas vardas",
    "Unable to update primary email address" : "Nepavyko atnaujinti pirminio el. pašto adreso",
    "Unable to delete additional email address" : "Nepavyko ištrinti papildomo el. pašto adreso",
    "No email address set" : "Nenustatytas joks el. pašto adresas",
    "Email options" : "El. pašto parinktys",
    "Options for additional email address {index}" : "Papildomo el. pašto adreso parinktys {index}",
    "Remove primary email" : "Šalinti pirminį el. paštą",
    "Delete email" : "Ištrinti el. paštą",
    "This address is not confirmed" : "Šis adresas nėra patvirtintas",
    "Unset as primary email" : "Atšaukti kaip pirminį el. pašto adresą",
    "Set as primary email" : "Nustatyti kaip pirminį el. paštą",
    "Additional email address {index}" : "Papildomas el. pašto adresas {index}",
    "Unable to delete primary email address" : "Nepavyko ištrinti pirminio el. pašto adreso",
    "Unable to add additional email address" : "Nepavyko pridėti papildomo el. pašto adreso",
    "Unable to update additional email address" : "Nepavyko atnaujinti papildomo el. pašto adreso",
    "Primary email for password reset and notifications" : "Pirminis el. paštas, skirtas slaptažodžio atstatymui bei pranešimams",
    "Your handle" : "Jūsų identifikatorius",
    "Derived from your locale ({weekDayName})" : "Pagal jūsų lokalę ({weekDayName})",
    "Unable to update first day of week" : "Nepavyksta atnaujinti savaitės pirmosios dienos",
    "Day to use as the first day of week" : "Diena, kuri laikoma pirmąja savaitės diena",
    "Your headline" : "Santrauka apie jus",
    "No language set" : "Nenustatyta jokia kalba",
    "Unable to update language" : "Nepavyko atnaujinti kalbos",
    "Languages" : "Kalbos",
    "Help translate" : "Padėkite išversti",
    "No locale set" : "Nenustatyta lokalė",
    "Unable to update locale" : "Nepavyko atnaujinti lokalę",
    "Locales" : "Lokalės",
    "Week starts on {firstDayOfWeek}" : "Savaitės pradžia yra {firstDayOfWeek}",
    "Your city" : "Jūsų miestas",
    "Your organisation" : "Jūsų organizacija",
    "Your phone number" : "Jūsų telefono numeris",
    "Edit your Profile visibility" : "Taisyti savo profilio matomumą",
    "Unable to update profile enabled state" : "Nepavyko atnaujinti profilio įjungimo būsenos",
    "Enable profile" : "Įgalinti profilį",
    "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "Jūsų profilyje taikomas griežtesnis matomumo arba taikymo srities nustatymas. Pavyzdžiui, jei matomumas nustatytas kaip „Rodyti visiems“, o taikymo sritis – kaip „Privatus“, taikomas „Privatus“ nustatymas.",
    "Unable to update visibility of {displayId}" : "Nepavyko atnaujinti {displayId} matomumo",
    "she/her" : "ji/jos",
    "he/him" : "jis/jo",
    "they/them" : "jie/jiems",
    "Your pronouns. E.g. {pronounsExample}" : "Jūsų įvardžiai. Pvz. {pronounsExample}",
    "Your role" : "Jūsų vaidmuo",
    "Timezone" : "Laiko juosta",
    "Your X (formerly Twitter) handle" : "Jūsų X (anksčiau „Twitter“) identifikatorius",
    "Your website" : "Jūsų svetainė",
    "Invalid value" : "Negalima reikšmė",
    "Unable to update {property}" : "Nepavyko atnaujinti {property}",
    "No {property} set" : "Nenustatyta {property}",
    "Change scope level of {property}, current scope is {scope}" : "Pakeisti {property} apimties lygį, dabartinė apimtis yra {scope}",
    "Unable to update federation scope of the primary {property}" : "Nepavyko atnaujinti pirminės {property} federacijos apimties.",
    "Unable to update federation scope of additional {property}" : "Nepavyko atnaujinti papildomos {property} federacijos apimties.",
    "Add additional email" : "Pridėti papildomą el. paštą",
    "Add" : "Pridėti",
    "Create" : "Sukurti",
    "Change" : "Keisti",
    "Delete" : "Ištrinti",
    "Reshare" : "Pakartotinai bendrinti",
    "Default config values" : "Numatytosios konfigūracijos reikšmės",
    "Applications config" : "Programėlių konfigūracijos",
    "User config" : "Vartotojo konfigūracija",
    "Bundled applications" : "Sujungtos programėlės",
    "Enabled applications" : "Įgalintos programėlės",
    "Disabled applications" : "Išjungtos programėlės",
    "Large organization" : "Labai didelė organizacija",
    "Big organization" : "Didelė organizacija",
    "Small organization" : "Maža organizacija",
    "Hosting company" : "\"Hosting\" kompanija",
    "University" : "Universitetas",
    "School" : "Mokykla",
    "Club or association" : "Klubas arba asociacija",
    "Family" : "Šeima",
    "Personal use" : "Asmeniniam naudojimui",
    "Default" : "Numatytasis",
    "Setup errors" : "Sąrankos klaidos",
    "Setup warnings" : "Sąrankos įspėjimai",
    "Setup recommendations" : "Sąrankos rekomendacijos",
    "Default language" : "Numatytoji kalba",
    "Common languages" : "Bendrosios kalbos",
    "Other languages" : "Kitos kalbos",
    "Password change is disabled because the master key is disabled" : "Slaptažodžių keitimas išjungtas, nes yra išjungtas pagrindinis raktas",
    "No accounts" : "Nėra paskyrų",
    "Loading accounts …" : "Įkeliamos paskyros  …",
    "List of accounts. This list is not fully rendered for performance reasons. The accounts will be rendered as you navigate through the list." : "Paskyrų sąrašas. Dėl našumo šis sąrašas nėra pilnai pateiktas. Paskyros bus pateikiamos jums naršant sąrašą.",
    "Account name" : "Paskyros vardas",
    "Account updated" : "Paskyra atnaujinta",
    "Failed to update account" : "Nepavyko atnaujinti paskyros",
    "Edit account" : "Taisyti paskyrą",
    "Saving …" : "Įrašoma …",
    "Save" : "Įrašyti",
    "Account name will be autogenerated" : "Paskyros pavadinimas bus sukurtas automatiškai",
    "Account name (required)" : "Paskyros pavadinimas (būtina)",
    "Password (required)" : "Slaptažodis (būtina)",
    "Email (required)" : "El. paštas (būtina)",
    "Email" : "El. paštas",
    "New account" : "Nauja paskyra",
    "Adding new account …" : "Pridedama nauja paskyra …",
    "Add new account" : "Pridėti naują paskyrą",
    "Display name" : "Rodomas vardas",
    "Either password or email is required" : "Reikalingas slaptažodis arba el. pašto adresas",
    "Member of the following groups (required)" : "Šių grupių narys (būtina)",
    "Member of the following groups" : "Šių grupių narys",
    "Failed to search groups" : "Nepavyko ieškoti grupių",
    "Set account groups" : "Nustatykite paskyrų grupes",
    "Admin of the following groups" : "Šių grupių administratorius",
    "Set account as admin for …" : "Nustatyti paskyrą kaip administratoriaus paskyrą  …",
    "Language" : "Kalba",
    "Set default language" : "Nustatyti numatytąją kalbą",
    "Manager" : "Vadovas",
    "Search for a manager…" : "Ieškoti vadovo…",
    "Quota" : "Leidžiamas duomenų kiekis",
    "Set account quota" : "Nustatykite paskyros kvotą",
    "_{userCount} account …_::_{userCount} accounts …_" : ["{userCount} paskyra  ...","{userCount} paskyros  ...","{userCount} paskyrų  ...","{userCount} paskyrų  ..."],
    "_{userCount} account_::_{userCount} accounts_" : ["{userCount} paskyra","{userCount} paskyros","{userCount} paskyrų","{userCount} paskyrų"],
    "Total rows summary" : "Bendras eilučių skaičius",
    "Scroll to load more rows" : "Slinkite, kad būtų įkelta daugiau eilučių",
    "Avatar" : "Avataras",
    "Group admin for" : "Grupės administratorius",
    "Account backend" : "Paskyros posistemė",
    "Storage location" : "Saugyklos vieta",
    "First login" : "Pirmas prisijungimas",
    "Last login" : "Paskutinis prisijungimas",
    "Account actions" : "Veiksmai su paskyra",
    "Unknown" : "Nežinoma",
    "Never" : "Niekada",
    "{size} used" : "{size} naudojama",
    "Delete account" : "Ištrinti paskyrą",
    "Disconnect all devices and delete local data" : "Atjungti visus įrenginius ir ištrinti vietinius duomenis",
    "Disable account" : "Išjungti paskyrą",
    "Enable account" : "Įjungti paskyrą",
    "Resend welcome email" : "Siųsti dar kartą pasveikinimo el. laišką",
    "In case of lost device or exiting the organization, this can remotely wipe the {productName} data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Pametus įrenginį arba išėjus iš organizacijos, ši funkcija gali nuotoliniu būdu ištrinti {productName} duomenis iš visų įrenginių susietų su {userid}. Veikia tik tada, kai įrenginiai prijungti prie interneto.",
    "Remote wipe of devices" : "Nuotolinių duomenų įrenginiuose ištrynimas",
    "Wipe {userid}'s devices" : "Ištrinti duomenis vartotojo {userid} įrenginiuose",
    "Wiped {userid}'s devices" : "Išvalyti {userid} įrenginiai",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "Pilnai ištrinta {userid} paskyra, įskaitant visus asmeninius failus, programos duomenis ir pan. ",
    "Account deletion" : "Paskyros ištrynimas",
    "Delete {userid}'s account" : "Ištrinti vartotojo {userid} paskyrą",
    "Welcome mail sent!" : "Pasveikinimo laiškas išsiųstas!",
    "Loading account …" : "Įkeliama paskyra  …",
    "Toggle account actions menu" : "Perjungti paskyrų veiksmų meniu",
    "Edit" : "Redaguoti",
    "Account management settings" : "Paskyros valdymo nustatymai",
    "Visibility" : "Matomumas",
    "Show language" : "Rodyti kalbą",
    "Show account backend" : "Rodyti paskyros posistemę",
    "Show storage path" : "Rodyti saugyklos kelią",
    "Show first login" : "Rodyti pirmą prisijungimą",
    "Show last login" : "Rodyti paskutinį prisijungimą",
    "Sorting" : "Rikiavimas",
    "The system config enforces sorting the groups by name. This also disables showing the member count." : "Sistemos konfigūracija reikalauja, kad grupės būtų rūšiuojamos pagal pavadinimą. Tai taip pat išjungia narių skaičiaus rodymą.",
    "Group list sorting" : "Grupių sąrašų rūšiavimas",
    "Sorting only applies to the currently loaded groups for performance reasons. Groups will be loaded as you navigate or search through the list." : "Rūšiavimas taikomas tik šiuo metu įkeltoms grupėms dėl našumo priežasčių. Grupės bus įkeltos naršant arba ieškant sąraše.",
    "By member count" : "Pagal narių skaičių",
    "By name" : "Pagal vardą",
    "Send email" : "Siųsti el. paštą",
    "Send welcome email to new accounts" : "Siųsti pasveikinimo el. laišką naujoms paskyroms",
    "Defaults" : "Numatytieji nustatymai",
    "Default quota" : "Numatytasis leidžiamas duomenų kiekis",
    "Select default quota" : "Pasirinkite numatytą leidžiamą duomenų kiekį ",
    "Search" : "Paieška",
    "Focus search" : "Fokusuota paieška",
    "Help" : "Pagalba",
    "Show those shortcuts" : "Rodyti tuos sparčiuosius klavišus",
    "Server error while trying to complete WebAuthn device registration" : "Serverio klaida, bandant pabaigti WebAuthn įrenginio regsitraciją",
    "Passwordless authentication requires a secure connection." : "Tapatybės nustatymas be slaptažodžio reikalauja saugaus ryšio.",
    "Add WebAuthn device" : "Pridėti WebAuthn įrenginį",
    "Please authorize your WebAuthn device." : "Prašome, autorizikuote savo WebAuthn įrenginį.",
    "Adding your device …" : "Pridedamas jūsų įrenginys  …",
    "Unnamed device" : "Įrenginys be pavadinimo",
    "Passwordless Authentication" : "Tapatybės nustatymas be slaptažodžio",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "Nustatykite savo paskyrai tapatybės nustatymą be slaptažodžio, pagal FIDO2 standartą.",
    "No devices configured." : "Nėra sukonfiguruotų įrenginių.",
    "The following devices are configured for your account:" : "Jūsų paskyrai sukonfiguruoti šie įrenginiai:",
    "Your browser does not support WebAuthn." : "Jūsų naršyklė nepalaiko WebAuthn.",
    "Email sent successfully" : "El. paštas sėkmingai išsiųstas",
    "Failed to send email" : "Nepavyko išsiųsti el. laiško",
    "Failed to save email settings" : "Nepavyko išsaugoti el. pašto nustatymų",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Svarbu nustatyti šį serverį, kad galėtumėte siųsti el. laiškus, kaip, pavyzdžiui, slaptažodžio atstatymą ar pranešimus.",
    "The server configuration is read-only so the mail settings cannot be changed using the web interface." : "Serverio konfigūracija yra skirta tik skaitymui, todėl pašto nustatymų negalima keisti naudojant žiniatinklio sąsają.",
    "Mail delivery is disabled by instance config \"{config}\"." : "Pašto pristatymas yra išjungtas pagal elemento config „{config}“.",
    "Send mode" : "Siuntimo veiksena",
    "Encryption" : "Šifravimas",
    "Sendmail mode" : "El. pašto siuntimo veiksena",
    "Disable certificate verification (insecure)" : "Išjungti sertifikatų tikrinimą (nesaugu)",
    "From address" : "Siuntėjo adresas",
    "Domain" : "Domenas",
    "Server address" : "Serverio adresas",
    "Host" : "Serveris",
    "Port" : "Prievadas",
    "Authentication" : "Tapatybės nustatymas",
    "Authentication required" : "Reikalingas tapatybės nustatymas",
    "Sending test email…" : "Siunčiamas bandomasis el. laiškas…",
    "Send test email" : "Siųsti bandomąjį el. laišką",
    "Saving…" : "Įrašoma…",
    "Save settings" : "Įrašyti nustatymus",
    "Please double check the {linkStartInstallationGuides}installation guides{linkEnd}, and check for any errors or warnings in the {linkStartLog}log{linkEnd}." : "Prašome dar kartą peržiūrėti {linkStartInstallationGuides} diegimo instrukcijas {linkEnd} ir patikrinti, ar {linkStartLog} žurnale {linkEnd} nėra klaidų ar įspėjimų.",
    "Check the security of your {productName} over {linkStart}our security scan{linkEnd}." : "Patikrinkite savo {productName} saugumą {linkStart} naudodamiesi mūsų saugumo patikrinimo įrankiu {linkEnd}.",
    "Security & setup warnings" : "Saugumo ir sąrankos įspėjimai",
    "It is important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Siekiant užtikrinti jūsų instancijos saugumą ir našumą, svarbu, kad viskas būtų tinkamai sukonfigūruota. Kad jums tai pavyktų, atliekame keletą automatinių patikrinimų. Daugiau informacijos rasite nuorodoje pateiktoje dokumentacijoje.",
    "Checking your server …" : "Tikrinamas jūsų serveris  …",
    "Failed to run setup checks" : "Nepavyko paleisti sąrankos patikrinimų",
    "Try again" : "Bandyti dar kartą",
    "All checks passed." : "Visi patikros rezultatai teigiami.",
    "There are some errors regarding your setup." : "Yra klaidų, susijusių su jūsų sąranką.",
    "There are some warnings regarding your setup." : "Yra įspėjimų, susijusių su jūsų sąranka.",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Būdami administratoriumi, galite reguliuoti bendrinimo elgseną. Išsamesnei informacijai, žiūrėkite dokumentaciją.",
    "You need to enable the File sharing App." : "Turite įjungti Failų bendrinimo programėlę.",
    "Failed to save selected preset." : "Nepavyko išsaugoti pasirinkto išankstinio nustatymo.",
    "Select a configuration preset for easy setup." : "Pasirinkite konfigūracijos nustatymą, kad galėtumėte lengvai atlikti sąranką.",
    "Apply" : "Taikyti",
    "All accounts" : "Visos paskyros",
    "Admins" : "Administratoriai",
    "Account group: {group}" : "Paskyros grupė: {group}",
    "Account management" : "Paskyros valdymas",
    "Search accounts and groups…" : "Ieškoti paskyrų ir grupių...",
    "For performance reasons, when you enable encryption on a {productName} server only new and changed files are encrypted." : "Dėl našumo priežasčių, įjungus šifravimą {productName} serveryje, šifruojami tik nauji ir pakeisti failai.",
    "Location" : "Vieta",
    "Profile picture" : "Profilio paveikslėlis",
    "About" : "Apie",
    "Date of birth" : "Gimimo data",
    "Full name" : "Vardas, pavardė",
    "Additional email" : "Papildomas el. paštas",
    "Fediverse (e.g. Mastodon)" : "\"Fediverse\" (pvz. Mastodon)",
    "Headline" : "Santrauka",
    "Organisation" : "Organizacija",
    "Phone number" : "Telefono numeris",
    "Pronouns" : "Vardikliai",
    "Role" : "Vaidmuo",
    "X (formerly Twitter)" : "X (anksčiau „Twitter“)",
    "Bluesky" : "\"Bluesky\"",
    "Website" : "Svetainė",
    "Profile visibility" : "Profilio matomumas",
    "Locale" : "Lokalė",
    "First day of week" : "Pirmoji savaitės diena",
    "timezone" : "laiko juosta",
    "Private" : "Privatus",
    "Only visible to people matched via phone number integration through Talk on mobile" : "Matoma tik žmonėms, su kuriais „Pokalbiai“ programėlėje mobiliajame įrenginyje buvo rasta atitiktis per telefono numerio integraciją",
    "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Ši funkcija nėra prieinama, nes šis parametras yra būtinas pagrindinėms funkcijoms, įskaitant failų dalijimąsi ir kvietimus į kalendoriuje numatytus renginius",
    "Local" : "Vietinis",
    "Only visible to people on this instance and guests" : "Matoma tik žmonėms šiame egzemplioriuje ir svečiams",
    "Federated" : "Federacinis",
    "Only synchronize to trusted servers" : "Sinchronizuoti tik į patikimus serverius",
    "Not available as federation has been disabled for your account, contact your system administration if you have any questions" : "Ši funkcija nėra prieinama, nes jūsų paskyroje išjungta federacija. Jei turite klausimų, kreipkitės į sistemos administratorių.",
    "Published" : "Paskelbtas",
    "Synchronize to trusted servers and the global and public address book" : "Sinchronizuoti į patikimus serverius ir į visuotinę bei viešą adresų knygą",
    "Not available as publishing account specific data to the lookup server is not allowed, contact your system administration if you have any questions" : "Nepasiekiama, nes neleidžiama skelbti konkrečios paskyros duomenų paieškos serveryje. Jei turite klausimų, susisiekite su sistemos administratoriumi.",
    "Discover" : "Atrasti",
    "Your apps" : "Jūsų programėlės",
    "Active apps" : "Aktyvios programėlės",
    "Disabled apps" : "Išjungtos programėlės",
    "Updates" : "Atnaujinimai",
    "App bundles" : "Programėlių rinkiniai",
    "Featured apps" : "Siūlomos programėlės",
    "Supported apps" : "Palaikomos programėlės",
    "Show to everyone" : "Rodyti visiems",
    "Show to logged in accounts only" : "Rodyti tik prisijungusiems vartotojams",
    "Hide" : "Slėpti",
    "Could not register device: Network error" : "Nepavyko registruoti įrenginio: Tinklo klaida",
    "Could not register device: Probably already registered" : "Nepavyko registruoti įrenginio: Tikriausiai, jau užregistruotas",
    "Could not register device" : "Nepavyko registruoti įrenginio",
    "Could not delete the app token" : "Nepavyko ištrinti programėlės žymens",
    "Error while wiping the device with the token" : "Įvyko klaida valant įrenginį panaudojant žymenį",
    "Error while updating device token name" : "Įvyko klaida atnaujinant įrenginio žymens pavadinimą",
    "Error while updating device token scope" : "Įvyko klaida atnaujinant įrenginio žymens taikymą",
    "An error occurred during the request. Unable to proceed." : "Užklausos metu įvyko klaida. Nepavyksta tęsti.",
    "Could not set group sorting" : "Nepavyko nustatyti grupių rūšiavimo",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Iš jūsų tinklo buvo per daug užklausų. Bandykite dar kartą vėliau arba, jeigu tai klaida, susisiekite su savo administratoriumi.",
    "Error" : "Klaida",
    "Account documentation" : "Paskyros dokumentacija",
    "Administration documentation" : "Administracinė dokumentacija",
    "Documentation" : "Dokumentacija",
    "Forum" : "Forumas",
    "Nextcloud help & privacy resources" : "„Nextcloud“ pagalbos ir privatumo ištekliai",
    "General documentation" : "Bendra dokumentacija",
    "Legal notice" : "Teisinis pranešimas",
    "Privacy policy" : "Privatumo politika",
    "Version" : "Versija",
    "Reasons to use Nextcloud in your organization" : "Priežastys, kodėl turėtumėte naudoti „Nextcloud“ savo organizacijoje",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Sukurta {communityopen}„Nextcloud“ bendruomenės{linkclose}, {githubopen}pirminis kodas{linkclose} yra licencijuotas pagal {licenseopen}AGPL{linkclose}.",
    "Like our Facebook page" : "Spauskite „Patinka“ mūsų „Facebook“ puslapyje",
    "Follow us on Bluesky" : "Sekite mus „Bluesky“ platformoje",
    "Follow us on Mastodon" : "Sekite mus Mastodon",
    "Check out our blog" : "Peržvelkite mūsų tinklaraštį",
    "Subscribe to our newsletter" : "Prenumeruokite mūsų naujienlaiškį",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Ši „Nextcloud“ bendruomenės versija nepalaikoma ir momentiniai pranešimai nepasiekiami.",
    "Open documentation" : "Atverti dokumentaciją",
    "Use a second factor besides your password to increase security for your account." : "Be savo slaptažodžio naudokite ir antrąjį faktorių, kad padidintumėte savo paskyros saugumą.",
    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Jei prisijungimui prie „Nextcloud“ naudojate trečiųjų šalių programėles, prieš įjungdami antrojo faktoriaus autentifikavimą, būtinai sukurkite ir sukonfigūruokite kiekvienos programėlės slaptažodį.",
    "Very weak password" : "Labai silpnas slaptažodis",
    "Weak password" : "Silpnas slaptažodis",
    "So-so password" : "Neblogas slaptažodis",
    "Good password" : "Geras slaptažodis",
    "Strong password" : "Stiprus slaptažodis",
    "Group list is empty" : "Grupės sąrašas yra tuščias",
    "Unable to retrieve the group list" : "Nepavyko nuskaityti grupių sąrašo",
    "Could not remove app." : "Nepavyko pašalinti programėlės.",
    "Could not update app." : "Nepavyko atnaujinti programėlės.",
    "Apps" : "Programėlės",
    "for Argon2 for password hashing" : "„Argon2“ slaptažodžių maišymui",
    "MariaDB version 10.3 detected, this version is end-of-life and only supported as part of Ubuntu 20.04. MariaDB >=%1$s and <=%2$s is suggested for best performance, stability and functionality with this version of Nextcloud." : "Aptikta „MariaDB“ 10.3 versija, ši versija yra nebenaudojama ir palaikoma tik kaip „Ubuntu 20.04“ dalis. Siekiant geriausio našumo, stabilumo ir funkcionalumo su šia „Nextcloud“ versija, rekomenduojama naudoti MariaDB „>=%1$s“ ir „<=%2$s“.",
    "_Most tasks were successful in the last day._::_Most tasks were successful in the last %n days._" : ["Dauguma užduočių paskutinę dieną buvo sėkmingai atliktos.","Dauguma užduočių per pastarąsias %n dienas buvo sėkmingai atliktos.","Dauguma užduočių per pastarąsias %n dienų buvo sėkmingai atliktos.","Dauguma užduočių per pastarąsias %n dienų buvo sėkmingai atliktos."],
    "_The Task Processing worker has run in the last minute._::_The Task Processing worker has run in the last %n minutes._" : ["Užduočių apdorojimo vykdytojas buvo paleistas per paskutinę minutę.","Užduočių apdorojimo vykdytojas buvo paleistas per paskutines %n minutes","Užduočių apdorojimo vykdytojas buvo paleistas per paskutines %n minučių","Užduočių apdorojimo vykdytojas buvo paleistas per paskutines %n minučių"],
    "Machine translation" : "Mašininis vertimas",
    "Image generation" : "Paveikslėlio generavimas",
    "Text processing" : "Teksto apdorojimas",
    "Exclude some groups from sharing" : "Neleisti bendrinti kai kurioms grupėms",
    "Limit sharing to some groups" : "Apriboti bendrinimą tik tam tikroms grupėms",
    "Also allow autocompletion on full match of the user id" : "Taip pat leisti automatinį užbaigimą, kai vartotojo ID visiškai atitinka",
    "Choose Deploy Daemon for {appName}" : "Pasirinkite diegimo tarnybą {appName}",
    "Registered Deploy daemons list" : "Registruotų diegimo tarnybų sąrašas",
    "No Deploy daemons configured" : "Nėra sukonfigūruotų diegimo tarnybų",
    "Register a custom one or setup from available templates" : "Užregistruokite savo šabloną arba pasirinkite vieną iš siūlomų šablonų",
    "Manage Deploy daemons" : "Tvarkyti diegimo tarnybas",
    "Show details for {appName} app" : "Rodyti {appName} programėlės informaciją",
    "Update to {update}" : "Atnaujinti į {update}",
    "Remove" : "Šalinti",
    "Featured" : "Siūlomos",
    "This app is supported via your current Nextcloud subscription." : "Ši programėlė yra palaikoma per jūsų esamą „Nextcloud“ prenumeratą.",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Siūlomos programėlės yra kuriamos bendruomenės viduje ir jas kuria bendruomenė. Šios programėlės siūlo svarbiausią funkcionalumą ir yra paruoštos kasdieniam naudojimui.",
    "Community rating: {score}/5" : "Bendruomenės įvertinimas: {score}/5",
    "Disable all" : "Išjungti visas",
    "Download and enable all" : "Atsisiųskite ir įgalinkite viską",
    "All apps are up-to-date." : "Visos programėlės yra naujausios laidos.",
    "Icon" : "Piktograma",
    "Name" : "Vardas",
    "Level" : "Lygmuo",
    "Results from other categories" : "Rezultatai iš kitų kategorijų",
    "No apps found for your version" : "Jūsų versijai programėlių nėra",
    "_%n app has an update available_::_%n apps have an update available_" : ["%n programėlei yra prieinamas atnaujinimas","%n programėlėms yra prieinamas atnaujinimas","%n programėlių yra prieinamas atnaujinimas","%n programėlei yra prieinamas atnaujinimas"],
    "_Update_::_Update all_" : ["Atnaujinti","Atnaujinti visas","Atnaujinti visas","Atnaujinti visas"],
    "Search groups…" : "Ieškoti grupių...",
    "Could not load app discover section" : "Nepavyko įkelti programėlių radimo skilties",
    "Could not render element" : "Nepavyko atvaizduoti elemento",
    "Nothing to show" : "Nėra ką rodyti",
    "Could not load section content from app store." : "Nepavyko įkelti skyriaus turinio iš programėlių parduotuvės.",
    "Loading" : "Įkeliama",
    "Fetching the latest news…" : "Gaunamos paskiausios naujienos…",
    "Carousel" : "\"Carousel\"",
    "Previous slide" : "Ankstesnė skaidrė",
    "Next slide" : "Kita skaidrė",
    "Choose slide to display" : "Pasirinkti rodytiną skaidrę",
    "{index} of {total}" : "{index} iš {total}",
    "Daemon" : "Tarnyba",
    "Deploy Daemon" : "Diegimo tarnyba",
    "Type" : "Tipas",
    "Display Name" : "Rodomas vardas",
    "GPUs support" : "GPU palaikymas",
    "Compute device" : "Skaičiavimo įrenginys",
    "Advanced deploy options" : "Išplėstinės diegimo parinktys",
    "Edit ExApp deploy options before installation" : "Redaguokite „ExApp“ diegimo parinktis prieš diegimą",
    "Configured ExApp deploy options. Can be set only during installation" : "Sukonfigūruotos „ExApp“ diegimo parinktys. Galima nustatyti tik diegimo metu",
    "Learn more" : "Sužinoti daugiau",
    "Environment variables" : "Aplinkos kintamieji",
    "ExApp container environment variables" : "ExApp konteinerio aplinkos kintamieji",
    "No environment variables defined" : "Aplinkos kintamieji nenustatyti",
    "Mounts" : "Prijunginiai",
    "Define host folder mounts to bind to the ExApp container" : "Nustatykite, kokie pagrindinio kompiuterio aplankų prijungimai turi būti susieti su „ExApp“ konteineriu",
    "Must exist on the Deploy daemon host prior to installing the ExApp" : "Prieš diegiant „ExApp“, tai jau turi būti diegimo tarnybos serveryje.",
    "Host path" : "Pagrindinis kelias",
    "Container path" : "Kelias į konteinerį",
    "Read-only" : "Tik skaitymui",
    "Remove mount" : "Pašalinti jungtį",
    "New mount" : "Nauja jungtis",
    "Enter path to host folder" : "Įveskite kelią iki pagrindinio aplanko",
    "Enter path to container folder" : "Įveskite kelią iki konteinerio aplanko",
    "Toggle read-only mode" : "Perjungti tik skaitymo režimą",
    "Confirm adding new mount" : "Patvirtinkite naujos jungties pridėjimą",
    "Cancel adding mount" : "Atšaukti jungties pridėjimą",
    "Add mount" : "Pridėti jungtį",
    "ExApp container mounts" : "ExApp konteinerio jungtis",
    "No mounts defined" : "Jungtys neapibrėžtos",
    "Description" : "Aprašas",
    "View in store" : "Rodyti parduotuvėje",
    "Visit website" : "Aplankyti svetainę",
    "Usage documentation" : "Naudojimo dokumentacija",
    "Admin documentation" : "Administratoriaus dokumentacija",
    "Developer documentation" : "Plėtotojo dokumentacija",
    "All" : "Visos",
    "Limit app usage to groups" : "Programėlės panaudojimas ribojamas grupėms",
    "No results" : "Nieko nerasta",
    "Update to {version}" : "Atnaujinti į versiją {version}",
    "Deploy options" : "Įdiegti parinktis",
    "Default Deploy daemon is not accessible" : "Numatytoji diegimo tarnyba nepasiekiama",
    "Delete data on remove" : "Ištrinti duomenis pašalinus",
    "This app has no minimum {productName} version assigned. This will be an error in the future." : "Šiai programėlei nenurodyta {productName} minimali versija. Ateityje tai bus klaida.",
    "This app has no maximum {productName} version assigned. This will be an error in the future." : "Šiai programėlei nėra priskirta {productName} maksimali versija. Ateityje tai bus klaida.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Ši programėlė negali būti įdiegta, nes nėra patenkintos žemiau išvardintos priklausomybės:",
    "Latest updated" : "Paskutinį kartą atnaujinta",
    "Author" : "Autorius",
    "Categories" : "Kategorijos",
    "Resources" : "Ištekliai",
    "Interact" : "Sąveikauti",
    "Report a bug" : "Pranešti apie klaidą",
    "Request feature" : "Prašyti funkcionalumo",
    "Ask questions or discuss" : "Užduokite klausimus arba diskutuokite",
    "Rate the app" : "Įvertinkite programėlę",
    "Rate" : "Įvertinkite",
    "Changelog" : "Keitinių žurnalas",
    "Loading accounts …" : "Įkeliamos paskyros ...",
    "Set line manager" : "Nustatyti tiesioginį vadovą",
    "Set account as admin for …" : "Nustatyti paskyrą kaip administratoriaus paskyrą...",
    "_{userCount} account …_::_{userCount} accounts …_" : ["{userCount} paskyra ...","{userCount} paskyros ...","{userCount} paskyrų...","{userCount} paskyrų..."],
    "Password or insufficient permissions message" : "Pranešimas apie slaptažodį arba nepakankamus leidimus",
    "Failed to load groups with details" : "Nepavyko įkelti grupių su išsamia informacija",
    "Failed to load sub admin groups with details" : "Nepavyko įkelti sub-administratorių grupių su išsamia informacija",
    "Failed to update line manager" : "Nepavyko atnaujinti tiesioginio vadovo",
    "Display name was successfully changed" : "Rodomas vardas sėkmingai pakeistas",
    "Password can't be empty" : "Slaptažodžio laukelis negali būti tuščias",
    "Password was successfully changed" : "Slaptažodis buvo sėkmingai pakeistas",
    "Email can't be empty" : "El. pašto laukelis negali būti tuščias",
    "Email was successfully changed" : "El. paštas buvo sėkmingai pakeistas",
    "Loading account …" : "Įkeliama paskyra…",
    "Change display name" : "Keisti rodomą vardą",
    "Set new password" : "Nustatyti naują slaptažodį",
    "You do not have permissions to see the details of this account" : "Jūs neturite leidimo matyti išsamesnę informaciją apie šią paskyrą",
    "Set new email address" : "Nustatyti naują el. pašto adresą",
    "Add account to group" : "Pridėti paskyrą į grupę",
    "Set account as admin for" : "Nustatyti paskyrą kaip administratoriaus paskyrą",
    "Select account quota" : "Pasirinkite paskyros kvotą",
    "Set the language" : "Nustatyti kalbą",
    "Done" : "Atlikta",
    "Adding your device …" : "Pridedamas jūsų įrenginys …",
    "App Store" : "App Store",
    "Loading app list" : "Įkeliamas programėlių sąrašas",
    "Loading categories" : "Įkeliamos kategorijos",
    "Version {version}, {license}-licensed" : "Versija {version}, {license}-licencijuota",
    "Version {version}" : "Versija {version}",
    "Sending…" : "Siunčiama…",
    "Email sent" : "El. paštas išsiųstas",
    "Manually installed apps cannot be updated" : "Rankiniu būdu įdiegtų programėlių atnaujinti negalima",
    "{progress}% Deploying …" : "{progress} % diegiama…",
    "{progress}% Initializing …" : "{progress}% inicijuojama…",
    "Health checking" : "Būklės patikrinimas",
    "Deploy and Enable" : "Įdiegti ir įjungti",
    "Download and enable" : "Atsisiųsti ir įjungti",
    "Disable" : "Išjungti",
    "Allow untested app" : "Leisti naudoti nepatikrintą programėlę",
    "The app will be downloaded from the App Store" : "Programėlė bus atsisiųsta iš programėlių parduotuvės",
    "This app is not marked as compatible with your {productName} version." : "Ši programėlė nėra pažymėta kaip suderinama su jūsų {productName} versija.",
    "If you continue you will still be able to install the app. Note that the app might not work as expected." : "Jei tęsite, vis tiek galėsite įdiegti programėlę. Atkreipkite dėmesį, kad programėlė gali neveikti taip, kaip tikėtasi.",
    "The app has been enabled but needs to be updated." : "Programėlė įjungta, bet turi būti atnaujinta.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Klaida: Ši programėlė negali būti įjungta, nes ji neigiamai veikia serverio stabilumą",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Programėlė įjungta, tačiau turi būti atnaujinta. Po 5 sekundžių būsite peradresuoti į atnaujinimo puslapį.",
    "None/STARTTLS" : "Nėra/STARTTLS",
    "SSL" : "SSL",
    "Credentials" : "Prisijungimo duomenys",
    "SMTP Login" : "SMTP Prisijungimas",
    "SMTP Password" : "SMTP slaptažodis",
    "Test and verify email settings" : "Išbandyti ir patikrinti el. pašto nustatymus",
    "Office suite switching is managed through the Nextcloud All-in-One interface." : "Biuro programų paketo perjungimas valdomas per „Nextcloud All-in-One“ sąsają.",
    "Please use the AIO interface to switch between office suites." : "Norėdami pereiti iš vieno biuro programų paketo į kitą, naudokite AIO sąsają.",
    "Select your preferred office suite. Please note that installing requires manual server setup." : "Pasirinkite pageidaujamą biuro programų paketą. Atkreipkite dėmesį, kad diegimui reikės rankiniu būdu sukonfigūruoti serverį.",
    "installed" : "įdiegta",
    "Disable office suites" : "Išjungti biuro programų rinkinius",
    "All office suites disabled" : "Visi biuro programų rinkiniai išjungti",
    "{name} enabled" : "{name} įgalinta",
    "Best Nextcloud integration" : "Geriausia \"Nextcloud\" integracija",
    "Open source" : "Atvirojo kodo",
    "Good performance" : "Geras našumas",
    "Best security: documents never leave your server" : "Geriausias saugumas: dokumentai niekada nepalieka jūsų serverio",
    "Best ODF compatibility" : "Geriausias ODF suderinamumas",
    "Best support for legacy files" : "Geriausias palaikymas senesniems failams",
    "Good Nextcloud integration" : "Gera \"Nextcloud\" integracija",
    "Open core" : "Atviro branduolio",
    "Best performance" : "Geriausias našumas",
    "Limited ODF compatibility" : "Ribotas suderinamumas su ODF",
    "Best Microsoft compatibility" : "Geriausias suderinamumas su „Microsoft“",
    "{progress}% Deploying …" : "{progress} % diegiama  …",
    "{progress}% Initializing …" : "{progress}% inicijuojama  …"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
