OC.L10N.register(
    "nextcloud_announcements",
    {
    "Nextcloud announcements" : "Meddelelser fra Nextcloud",
    "Nextcloud announcement" : "Meddelelse fra Nextcloud",
    "Read more" : "Læs mere",
    "Disable announcements" : "Deaktiver annonceringer",
    "(These announcements are only shown to administrators)" : "(Disse annonceringer vises kun til administratorer)",
    "Nextcloud announcements brings the latest news of Nextcloud into your notifications" : "Meddelelser fra Nextcloud leverer de seneste nyheder fra Nextcloud i dine notifikationer. "
},
"nplurals=2; plural=(n != 1);");
