OC.L10N.register(
    "files_pdfviewer",
    {
    "PDF viewer" : "PDF-läsare",
    "Directly view PDF documents in your Nextcloud. \nAs an added bonus, this app can also display Adobe Illustrator (.ai) files. \nPowered by [pdf.js](https://mozilla.github.io/pdf.js/)" : "Visa PDF-dokument direkt i ditt Nextcloud. \nSom en extra bonus kan den här appen även visa Adobe Illustrator (.ai)-filer. \nDrivs av [pdf.js](https://mozilla.github.io/pdf.js/)",
    "Failed to load settings" : "Kunde inte läsa in inställningar",
    "Failed to save settings" : "Kunde inte spara inställningarna",
    "PDF Viewer" : "PDF-läsare",
    "Configure PDF viewer settings" : "Konfigurera inställningar för PDF-läsare",
    "Enable PDF scripting" : "Aktivera PDF-skriptning",
    "Enabling PDF scripting allows JavaScript execution within PDF documents. This enables form calculations and dynamic content, but may pose security risks with untrusted PDFs. PDF scripts run in a sandboxed environment." : "Att aktivera PDF-skriptning tillåter körning av JavaScript i PDF-dokument. Detta möjliggör formulärberäkningar och dynamiskt innehåll, men kan innebära säkerhetsrisker med opålitliga PDF-filer. PDF-skript körs i en sandlådemiljö.",
    "File upload failed." : "Filuppladdning misslyckades.",
    "To view a shared PDF file, the download needs to be allowed for this file share" : "För att se en delad PDF-fil måste nedladdningen vara tillåten för denna fildelning"
},
"nplurals=2; plural=(n != 1);");
