OC.L10N.register(
    "bruteforcesettings",
    {
    "Brute-force settings" : "Setări pentru forță-brută",
    "Whitelist IPs" : "IP-uri permise",
    "Comment" : "Comentariu",
    "Add" : "Adaugă",
    "Save" : "Salvează"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
