OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "Filpåminnelser",
    "Reminder for {name}" : "Påminnelse för {name}",
    "View file" : "Visa fil",
    "View folder" : "Visa mapp",
    "Files reminder" : "Filpåminnelse",
    "The \"files_reminders\" app can work properly." : "Appen \"files_reminders\" kan fungera korrekt.",
    "The \"files_reminders\" app needs the notification app to work properly. You should either enable notifications or disable files_reminder." : "Appen \"files_reminders\" behöver appen Aviseringar för att fungera korrekt. Du bör antingen aktivera Aviseringar eller inaktivera Filpåminnelser.",
    "Set file reminders" : "Ställ in filpåminnelser",
    "**📣 File reminders**\n\nSet file reminders.\n\nNote: to use the `File reminders` app, ensure that the `Notifications` app is installed and enabled. The `Notifications` app provides the necessary APIs for the `File reminders` app to work correctly." : "**📣 Filpåminnelser**\n\nStäll in påminnelser för filer.\n\nObs! För att använda appen `Filpåminnelser` måste appen `Aviseringar` vara installerad och aktiverad. Appen `Aviseringar` tillhandahåller de API:er som krävs för att appen `Filpåminnelser` ska fungera korrekt.",
    "Please choose a valid date & time" : "Välj ett giltigt datum och en giltig tid",
    "Reminder set for \"{fileName}\"" : "Påminnelse har ställts in för \"{fileName}\"",
    "Failed to set reminder" : "Det gick inte att ställa in påminnelsen",
    "Reminder cleared for \"{fileName}\"" : "Påminnelsen för \"{fileName}\" har tagits bort",
    "Failed to clear reminder" : "Det gick inte att ta bort påminnelsen",
    "Reminder at custom date & time" : "Påminnelse vid anpassat datum och tid",
    "We will remind you of this file" : "Du kommer att påminnas om den här filen",
    "Cancel" : "Avbryt",
    "Clear reminder" : "Ta bort påminnelse",
    "Set reminder" : "Ställ in påminnelse",
    "Set reminder for " : "Ställ in påminnelse för ",
    "Reminder set" : "Påminnelsen har ställts in",
    "Custom reminder" : "Anpassad påminnelse",
    "Later today" : "Senare idag",
    "Set reminder for later today" : "Ställ in påminnelse för senare idag",
    "Tomorrow" : "I morgon",
    "Set reminder for tomorrow" : "Ställ in påminnelse för i morgon",
    "This weekend" : "I helgen",
    "Set reminder for this weekend" : "Ställ in en påminnelse till helgen",
    "Next week" : "Nästa vecka",
    "Set reminder for next week" : "Ställ in påminnelse för nästa vecka",
    "Set reminder for \"{fileName}\"" : "Ställ in påminnelse för \"{fileName}\""
},
"nplurals=2; plural=(n != 1);");
