<?php
// This file is auto-generated. Do not edit!
return array('Adlm'=>'adlam pismo','Afak'=>'afaka pismo','Aghb'=>'Aghb','Ahom'=>'Ahom','Hluw'=>'anatolijski hijeroglifi','Armi'=>'aramejsko pismo','Arab'=>array(''=>'arapsko pismo','variant'=>array('perzijsko-arapsko pismo')),'Armn'=>'armensko pismo','Avst'=>'avestansko pismo','Bali'=>'balijsko pismo','Bamu'=>'bamum pismo','Bass'=>'bassa vah pismo','Batk'=>'batak pismo','Beng'=>'bengalsko pismo','Bhks'=>'Bhks','Blis'=>'blissymbols','Bopo'=>'bopomofo pismo','Brah'=>'brahmi pismo','Brai'=>'brajica','Bugi'=>'buginsko pismo','Buhd'=>'buhid pismo','Cakm'=>'čakmansko pismo','Cham'=>'čamsko pismo','Cher'=>'čeroki pismo','Chrs'=>'Chrs','Cyrl'=>'ćirilica','Cirt'=>'cirth pismo','Cpmn'=>'Cpmn','Cprt'=>'cypriot pismo','Dsrt'=>'deseret pismo','Deva'=>'devangari pismo','Diak'=>'Diak','Dogr'=>'Dogr','Dupl'=>'Dupl','Egyp'=>'egipatski hijeroglifi','Egyh'=>'egipatsko hijeratsko pismo','Egyd'=>'egipatsko narodno pismo','Elba'=>'Elba','Elym'=>'Elym','Zsye'=>'emotikoni','Ethi'=>'etiopsko pismo','Phnx'=>'feničko pismo','Latf'=>'fraktur latinica','Lisu'=>'fraser pismo','Glag'=>'glagoljica','Gong'=>'Gong','Gonm'=>'Gonm','Goth'=>'gotičko pismo','Gran'=>'grantha pismo','Grek'=>'grčko pismo','Geok'=>'gruzijsko khutsuri pismo','Geor'=>'gruzijsko pismo','Gujr'=>'gudžaratsko pismo','Guru'=>'gurmukhi pismo','Hanb'=>'hanb pismo','Hang'=>'hangul pismo','Rohg'=>'hanifi pismo','Hani'=>'hansko pismo','Hano'=>'hanunoo pismo','Hatr'=>'Hatr','Hebr'=>'hebrejsko pismo','Hira'=>'hiragana pismo','Hmnp'=>'Hmnp','Inds'=>'indijsko pismo','Jamo'=>'jamo pismo','Jpan'=>'japansko pismo','Hrkt'=>'japansko slogovno pismo','Java'=>'javansko pismo','Zxxx'=>'jezik bez pismenosti','Jurc'=>'jurchen pismo','Kthi'=>'kaithi pismo','Knda'=>'kannada pismo','Cari'=>'karijsko pismo','Kana'=>'katakana pismo','Kawi'=>'Kawi','Kali'=>'kayah li pismo','Latg'=>'keltska latinica','Khar'=>'kharoshthi pismo','Khoj'=>'khojki pismo','Sind'=>'khudawadi pismo','Kits'=>'Kits','Khmr'=>'kmersko pismo','Copt'=>'koptsko pismo','Kore'=>'korejsko pismo','Kpel'=>'kpelle pismo','Lana'=>'lanna pismo','Laoo'=>'laosko pismo','Latn'=>'latinica','Lepc'=>'lepcha pismo','Lydi'=>'lidijsko pismo','Lyci'=>'likijsko pismo','Limb'=>'limbu pismo','Lina'=>'linear A pismo','Linb'=>'linear B pismo','Loma'=>'loma pismo','Mahj'=>'Mahj','Maya'=>'majanski hijeroglifi','Maka'=>'Maka','Mlym'=>'malajalamsko pismo','Mand'=>'mandai pismo','Mani'=>'manihejsko pismo','Marc'=>'Marc','Zmth'=>'matematičko znakovlje','Medf'=>'Medf','Mtei'=>'meitei mayek pismo','Mend'=>'mende pismo','Mero'=>'meroitic pismo','Merc'=>'meroitski kurziv','Mymr'=>'mjanmarsko pismo','Modi'=>'Modi','Mong'=>'mongolsko pismo','Moon'=>'moon pismo','Mroo'=>'mro pismo','Mult'=>'Mult','Nkoo'=>'n’ko pismo','Nbat'=>'nabatejsko pismo','Nagm'=>'Nagm','Nand'=>'Nand','Zinh'=>'nasljedno pismo','Aran'=>'nastaliq pismo','Nkgb'=>'naxi geba pismo','Zzzz'=>'nepoznato pismo','Newa'=>'Newa','Talu'=>'novo tai lue pismo','Nshu'=>'nushu pismo','Ogam'=>'ogham pismo','Olck'=>'ol chiki pismo','Orya'=>'orijsko pismo','Orkh'=>'orkhon pismo','Osge'=>'Osge','Osma'=>'osmanya pismo','Ougr'=>'Ougr','Hmng'=>'pahawh hmong pismo','Phlv'=>'pahlavi pismo','Palm'=>'palmyrene pismo','Pauc'=>'Pauc','Phag'=>'phags-pa pismo','Phli'=>'pisani pahlavi','Prti'=>'pisani parthian','Syrn'=>'pismo istočne Sirije','Syrj'=>'pismo zapadne Sirije','Hans'=>array(''=>'pojednostavljeno pismo','stand-alone'=>array('pojednostavljeno hansko pismo')),'Plrd'=>'pollard fonetsko pismo','Phlp'=>'psalter pahlavi','Rjng'=>'rejang pismo','Roro'=>'rongorongo pismo','Runr'=>'runsko pismo','Samr'=>'samaritansko pismo','Sara'=>'sarati pismo','Saur'=>'saurashtra pismo','Shrd'=>'sharada pismo','Shaw'=>'shavian pismo','Sidd'=>'Sidd','Zsym'=>'simboli','Sinh'=>'sinhaleško pismo','Syre'=>'sirijsko estrangelo pismo','Syrc'=>'sirijsko pismo','Sogd'=>'Sogd','Sogo'=>'Sogo','Sora'=>'sora sompeng pismo','Soyo'=>'Soyo','Sarb'=>'staro južnoarapsko pismo','Hung'=>'staro mađarsko pismo','Perm'=>'staro permic pismo','Xpeo'=>'staro perzijsko pismo','Narb'=>'staro sjevernoarapsko pismo','Ital'=>'staro talijansko pismo','Cyrs'=>'staroslavenska crkvena čirilica','Xsux'=>'sumersko-akadsko cuneiform pismo','Sund'=>'sundansko pismo','Sylo'=>'syloti nagri pismo','Tglg'=>'tagalog pismo','Tagb'=>'tagbanwa pismo','Tale'=>'tai le pismo','Tavt'=>'tai viet pismo','Thai'=>'tajsko pismo','Takr'=>'takri pismo','Taml'=>'tamilsko pismo','Tang'=>'tangut pismo','Telu'=>'teluško pismo','Teng'=>'tengwar pismo','Thaa'=>'thaana pismo','Tibt'=>'tibetansko pismo','Tfng'=>'tifinagh pismo','Tirh'=>'tirhuta pismo','Tnsa'=>'Tnsa','Toto'=>'Toto','Hant'=>array(''=>'tradicionalno pismo','stand-alone'=>array('tradicionalno hansko pismo')),'Ugar'=>'ugaritsko pismo','Cans'=>'unificirani kanadski aboriđinski slogovi','Vaii'=>'vai pismo','Wara'=>'varang kshiti pismo','Visp'=>'Visible Speech','Vith'=>'Vith','Wcho'=>'Wcho','Wole'=>'woleai pismo','Yezi'=>'Yezi','Yiii'=>'yi pismo','Zyyy'=>'zajedničko pismo','Zanb'=>'Zanb','Qaag'=>'zawgyi','Sgnw'=>'znakovno pismo');
