[data-v-913cdc75] .photos-picker{display:flex;padding-inline-end:0!important}.photos-picker__navigation__month[data-v-913cdc75]{margin:4px}.photos-picker__navigation__month-select[data-v-913cdc75]{flex:1;padding-inline-end:12px;padding-block-end:6px}.photos-picker__file-list[data-v-913cdc75]{flex-grow:1;min-width:0;height:100%;padding:0 4px}.photos-picker__file-list--placeholder[data-v-913cdc75]{background:var(--color-primary-element-light);border-radius:var(--border-radius-large)}.photos-picker__file-list .section-header[data-v-913cdc75]{font-weight:700;font-size:20px;padding:8px 0 4px}.photos-picker__file-list[data-v-913cdc75] .empty-content{height:fit-content;margin-block:1em;margin-inline-end:12px;width:calc(100% - 12px)}.photos-picker__actions[data-v-913cdc75]{display:flex;flex-direction:column;flex-grow:1}.photos-picker__actions__buttons[data-v-913cdc75]{display:flex;align-items:center;justify-content:flex-end;gap:16px}
