OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Integritet",
    "-" : "-",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "Integritetscentret visar var dina data lagras och vem som kan komma åt dem, antingen genom delning eller i egenskap av administratör.",
    "Error loading additional administrator." : "Det gick inte att läsa in den ytterligare administratören.",
    "Error adding new administrator." : "Det gick inte att lägga till den nya administratören.",
    "Error deleting new administrator." : "Det gick inte att ta bort den nya administratören.",
    "Administrators" : "Administratörer",
    "The following accounts are designated administrators and may potentially have access to your data through system storage or backups. However, they do not have easy access to your data via the web interface or client applications." : "Följande konton är utsedda administratörer och kan potentiellt få åtkomst till dina data via systemlagring eller säkerhetskopior. De har dock inte direkt åtkomst till dina data via webbgränssnittet eller klientapparna.",
    "Loading administrators …" : "Läser in administratörer …",
    "Remove external {propertyName} admin" : "Ta bort den externa administratören {propertyName}",
    "Add external admin" : "Lägg till extern administratör",
    "Cancel" : "Avbryt",
    "Add" : "Lägg till",
    "Name of external admin" : "Namn på extern administratör",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key. It means that administrators can access your files, but not read their content." : "Din hemmalagring krypteras med {linkopen}kryptering på serversidan ↗{linkclose} och en huvudnyckel. Administratörer kan komma åt filerna, men inte läsa deras innehåll.",
    "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key based on their configuration." : "Filer på externa lagringsenheter kan, beroende på konfigurationen, krypteras med {linkopen}kryptering på serversidan ↗{linkclose} och en huvudnyckel.",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual user key. It means that administrators can access your files, but not read their content." : "Din hemmalagring krypteras med {linkopen}kryptering på serversidan ↗{linkclose} och en individuell användarnyckel. Administratörer kan komma åt filerna, men inte läsa deras innehåll.",
    "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual key based on their configuration." : "Filer på externa lagringsenheter kan, beroende på konfigurationen, krypteras med {linkopen}kryptering på serversidan ↗{linkclose} och en individuell nyckel.",
    "Additionally, this server is protected with full-disk-encryption." : "Dessutom skyddas servern med heldiskkryptering.",
    "This server is protected with full-disk-encryption." : "Servern skyddas med heldiskkryptering.",
    "Your files are not protected by encryption." : "Dina filer är inte skyddade med kryptering.",
    "Error saving new state of full-disk-encryption" : "Det gick inte att spara den nya inställningen för heldiskkryptering",
    "Encryption" : "Kryptering",
    "Edit encryption" : "Redigera kryptering",
    "Edit" : "Redigera",
    "This server is using full-disk-encryption." : "Servern använder heldiskkryptering.",
    "Privacy policy" : "Integritetspolicy",
    "Read the privacy policy ↗" : "Läs integritetspolicyn ↗",
    "Error loading information about shares." : "Det gick inte att läsa in information om delningar.",
    "People you've shared with" : "Personer du har delat med",
    "Loading people you've shared with …" : "Läser in personer som du har delat med …",
    "You do not have any shares with individual users." : "Du har inga delningar med enskilda användare.",
    "Your {serverName} account" : "Ditt {serverName}-konto",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Dina data speglar vem du är och kan lätt missbrukas. På Nextcloud anser vi att du har rätt att bestämma vad som händer med dina data. Nextcloud skyddar dina rättigheter enligt manifestet för användardata!",
    "Who has access to your data?" : "Vem har åtkomst till dina data?",
    "Error saving new location of the server" : "Det gick inte att spara serverns nya plats",
    "Where is your data?" : "Var finns dina data?",
    "Your data is located in:" : "Dina data finns i:",
    "An admin has not selected the location of the server yet." : "En administratör har ännu inte valt en plats för servern.",
    "Change data location" : "Ändra dataplats",
    "Region" : "Region",
    "Please select a region" : "Välj en region",
    "{bold}Control{/bold} over user data access" : "{bold}Kontroll{/bold} över åtkomsten till användardata",
    "{bold}Knowledge{/bold} of how the data is stored" : "{bold}Kunskap{/bold} om hur uppgifterna lagras",
    "{bold}Freedom{/bold} to choose a platform" : "{bold}Frihet{/bold} att välja plattform",
    "User Data Manifesto 2.0" : "Manifestet för användardata 2.0",
    "Defining basic rights for people to control their own data in the internet age." : "Fastställer grundläggande rättigheter för människor att kontrollera sina egna data i internetåldern.",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Data som uttryckligen laddas upp av en användare bör vara under kontroll av den användaren. Användare ska kunna bestämma vem som har direkt åtkomst till deras data och med vilka rättigheter och licenser sådan åtkomst beviljas.",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "När data laddas upp till en viss tjänsteleverantör bör användarna informeras om var den specifika tjänsteleverantören lagrar data, hur länge, i vilken jurisdiktion den specifika tjänsteleverantören är verksam och vilka lagar som gäller.",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Användare bör alltid kunna hämta ut sina data från tjänsten när som helst utan att uppleva någon leverantörsinlåsning. Öppna standarder för format och protokoll är nödvändiga för att kunna garantera detta.",
    "Learn more ↗" : "Läs mer ↗",
    "Somaliland" : "Somaliland",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "Förenade Arabemiraten",
    "Afghanistan" : "Afghanistan",
    "Antigua and Barbuda" : "Antigua och Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Albanien",
    "Armenia" : "Armenien",
    "Angola" : "Angola",
    "Antarctica" : "Antarktis",
    "Argentina" : "Argentina",
    "American Samoa" : "Amerikanska Samoa",
    "Austria" : "Österrike",
    "Australia" : "Australien",
    "Aruba" : "Aruba",
    "Åland Islands" : "Åland",
    "Azerbaijan" : "Azerbajdzjan",
    "Bosnia and Herzegovina" : "Bosnien och Hercegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Belgien",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgarien",
    "Bahrain" : "Bahrain",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "S:t Barthélemy",
    "Bermuda" : "Bermuda",
    "Brunei" : "Brunei",
    "Bolivia" : "Bolivia",
    "Bonaire, Sint Eustatius and Saba" : "Karibiska Nederländerna",
    "Brazil" : "Brasilien",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Bhutan",
    "Bouvet Island" : "Bouvetön",
    "Botswana" : "Botswana",
    "Belarus" : "Belarus",
    "Belize" : "Belize",
    "Canada" : "Kanada",
    "Cocos (Keeling) Islands" : "Kokosöarna",
    "Democratic Republic of the Congo" : "Kongo-Kinshasa",
    "Central African Republic" : "Centralafrikanska republiken",
    "Congo" : "Kongo-Brazzaville",
    "Switzerland" : "Schweiz",
    "Cote d'Ivoire" : "Elfenbenskusten",
    "Cook Islands" : "Cooköarna",
    "Chile" : "Chile",
    "Cameroon" : "Kamerun",
    "China" : "Kina",
    "Colombia" : "Colombia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Kuba",
    "Cabo Verde" : "Kap Verde",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Julön",
    "Cyprus" : "Cypern",
    "Czech" : "Tjeckien",
    "Germany" : "Tyskland",
    "Djibouti" : "Djibouti",
    "Denmark" : "Danmark",
    "Dominican Republic" : "Dominikanska republiken",
    "Algeria" : "Algeriet",
    "Ecuador" : "Ecuador",
    "Estonia" : "Estland",
    "Egypt" : "Egypten",
    "West Sahara" : "Västsahara",
    "Eritrea" : "Eritrea",
    "Spain" : "Spanien",
    "Ethiopia" : "Etiopien",
    "Finland" : "Finland",
    "Fiji" : "Fiji",
    "Falkland Islands" : "Falklandsöarna",
    "Micronesia" : "Mikronesien",
    "Faroe Islands" : "Färöarna",
    "France" : "Frankrike",
    "Gabon" : "Gabon",
    "United Kingdom" : "Storbritannien",
    "Grenada" : "Grenada",
    "Georgia" : "Georgien",
    "French Guiana" : "Franska Guyana",
    "Guernsey" : "Guernsey",
    "Ghana" : "Ghana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Grönland",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Guadeloupe" : "Guadeloupe",
    "Equatorial Guinea" : "Ekvatorialguinea",
    "Greece" : "Grekland",
    "South Georgia and the South Sandwich Islands" : "Sydgeorgien och Sydsandwichöarna",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinea-Bissau",
    "Guyana" : "Guyana",
    "Hong Kong" : "Hongkong SAR",
    "Heard Island and McDonald Islands" : "Heardön och McDonaldöarna",
    "Honduras" : "Honduras",
    "Croatia" : "Kroatien",
    "Haiti" : "Haiti",
    "Hungary" : "Ungern",
    "Indonesia" : "Indonesien",
    "Ireland" : "Irland",
    "Israel" : "Israel",
    "Isle of Man" : "Isle of Man",
    "India" : "Indien",
    "British Indian Ocean Territory" : "Brittiska territoriet i Indiska oceanen",
    "Iraq" : "Irak",
    "Iran" : "Iran",
    "Iceland" : "Island",
    "Italy" : "Italien",
    "Jamaica" : "Jamaica",
    "Jordan" : "Jordanien",
    "Japan" : "Japan",
    "Kenya" : "Kenya",
    "Kyrgyzstan" : "Kirgizistan",
    "Cambodia" : "Kambodja",
    "Kiribati" : "Kiribati",
    "Comores" : "Komorerna",
    "Saint Kitts and Nevis" : "S:t Kitts och Nevis",
    "North Korea" : "Nordkorea",
    "South Korea" : "Sydkorea",
    "Kuwait" : "Kuwait",
    "Cayman Islands" : "Caymanöarna",
    "Kazakhstan" : "Kazakstan",
    "Laos" : "Laos",
    "Lebanon" : "Libanon",
    "Saint Lucia" : "S:t Lucia",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Litauen",
    "Luxembourg" : "Luxemburg",
    "Latvia" : "Lettland",
    "Libya" : "Libyen",
    "Morocco" : "Marocko",
    "Monaco" : "Monaco",
    "Moldova" : "Moldavien",
    "Montenegro" : "Montenegro",
    "Saint Martin" : "Saint Martin",
    "Madagascar" : "Madagaskar",
    "Marshall Islands" : "Marshallöarna",
    "Macedonia" : "Makedonien",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar (Burma)",
    "Mongolia" : "Mongoliet",
    "Macao" : "Macao SAR",
    "Northern Mariana Islands" : "Nordmarianerna",
    "Mauritania" : "Mauretanien",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Mauritius",
    "Maldives" : "Maldiverna",
    "Malawi" : "Malawi",
    "Mexico" : "Mexiko",
    "Malaysia" : "Malaysia",
    "Mozambique" : "Moçambique",
    "Namibia" : "Namibia",
    "New Caledonia" : "Nya Kaledonien",
    "Niger" : "Niger",
    "Norfolk Island" : "Norfolkön",
    "Nigeria" : "Nigeria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Nederländerna",
    "Norway" : "Norge",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Nya Zeeland",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "French Polynesia" : "Franska Polynesien",
    "Papua New Guinea" : "Papua Nya Guinea",
    "Philippines" : "Filippinerna",
    "Pakistan" : "Pakistan",
    "Poland" : "Polen",
    "Saint Pierre and Miquelon" : "S:t Pierre och Miquelon",
    "Pitcairn" : "Pitcairnöarna",
    "Puerto Rico" : "Puerto Rico",
    "Palestine" : "Palestina",
    "Portugal" : "Portugal",
    "Palau" : "Palau",
    "Paraguay" : "Paraguay",
    "Qatar" : "Qatar",
    "Réunion" : "Réunion",
    "Romania" : "Rumänien",
    "Serbia" : "Serbien",
    "Russia" : "Ryssland",
    "Rwanda" : "Rwanda",
    "Saudi Arabia" : "Saudiarabien",
    "Solomon Islands" : "Salomonöarna",
    "Seychelles" : "Seychellerna",
    "Sudan" : "Sudan",
    "Sweden" : "Sverige",
    "Singapore" : "Singapore",
    "Saint Helena, Ascension and Tristan da Cunha" : "S:t Helena",
    "Slovenia" : "Slovenien",
    "Svalbard and Jan Mayen" : "Svalbard och Jan Mayen",
    "Slovakia" : "Slovakien",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "Suriname" : "Surinam",
    "South Sudan" : "Sydsudan",
    "Sao Tome and Principe" : "São Tomé och Príncipe",
    "El Salvador" : "El Salvador",
    "Sint Maarten" : "Sint Maarten",
    "Syria" : "Syrien",
    "Swaziland" : "Swaziland",
    "Turks and Caicos Islands" : "Turks- och Caicosöarna",
    "Chad" : "Tchad",
    "Fr. S. Antarctic Lands" : "Franska sydterritorierna",
    "Togo" : "Togo",
    "Thailand" : "Thailand",
    "Tajikistan" : "Tadzjikistan",
    "Tokelau" : "Tokelauöarna",
    "Timor-Leste" : "Östtimor",
    "Turkmenistan" : "Turkmenistan",
    "Tunisia" : "Tunisien",
    "Tonga" : "Tonga",
    "Turkey" : "Turkiet",
    "Trinidad and Tobago" : "Trinidad och Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan" : "Taiwan",
    "Tanzania" : "Tanzania",
    "Ukraine" : "Ukraina",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "USA:s yttre öar",
    "United States" : "USA",
    "Uruguay" : "Uruguay",
    "Uzbekistan" : "Uzbekistan",
    "Holy See" : "Vatikanstaten",
    "Saint Vincent and the Grenadines" : "S:t Vincent och Grenadinerna",
    "Venezuela" : "Venezuela",
    "Virgin Islands (British)" : "Brittiska Jungfruöarna",
    "Virgin Islands (U.S.)" : "Amerikanska Jungfruöarna",
    "Vietnam" : "Vietnam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis- och Futunaöarna",
    "Samoa" : "Samoa",
    "Yemen" : "Jemen",
    "Mayotte" : "Mayotte",
    "South Africa" : "Sydafrika",
    "Zambia" : "Zambia",
    "Zimbabwe" : "Zimbabwe",
    "Loading administrators …" : "Läser in administratörer …",
    "Loading people you've shared with …" : "Laddar personer du har delat med …",
    "Control" : "Kontroll",
    "over user data access" : "över användardataåtkomst",
    "Knowledge" : "Kunskap",
    "of how the data is stored" : "om hur data lagras",
    "Freedom" : "Frihet",
    "to choose a platform" : "att välja en plattorm"
},
"nplurals=2; plural=(n != 1);");
