OC.L10N.register(
    "files_sharing",
    {
    "File shares" : "Partilha de ficheiros",
    "Downloaded via public link" : "Transferido via hiperligação pública",
    "Downloaded by {email}" : "Transferido por {email}",
    "{file} downloaded via public link" : "{file} transferido via hiperligação pública",
    "{email} downloaded {file}" : "{email} transferiu {file}",
    "Shared with group {group}" : "Partilhado com o grupo {group}",
    "Removed share for group {group}" : "Removeu a partilha para o grupo {group}",
    "{actor} shared with group {group}" : "{actor} partilhou com o grupo {group}",
    "{actor} removed share for group {group}" : "{actor} removeu a partilha para o grupo {group}",
    "Share for group {group} expired" : "Partilha para o grupo {group} expirou",
    "You shared {file} with group {group}" : "Partilhaste {file} com o grupo {group}",
    "You removed group {group} from {file}" : "Removeste o grupo {group} de {file}",
    "{actor} shared {file} with group {group}" : "{actor} partilhou {file} com o grupo {group}",
    "{actor} removed group {group} from {file}" : "{actor} removeu o grupo {group} de {file}",
    "Share for file {file} with group {group} expired" : "A partilha do ficheiro {file} com o grupo {group} expirou",
    "Shared as public link" : "Partilhado como hiperligação pública",
    "Removed public link" : "Hiperligação pública removida",
    "Public link expired" : "A hiperligação pública expirou",
    "{actor} shared as public link" : "{actor} partilhou como hiperligação pública",
    "{actor} removed public link" : "{actor} removeu a hiperligação pública",
    "Public link of {actor} expired" : "Hiperligação pública de {actor} expirou",
    "You shared {file} as public link" : "Partilhou {file} como hiperligação pública",
    "You removed public link for {file}" : "Removeu a hiperligação pública de {file}",
    "Public link expired for {file}" : "Hiperligação pública expirada para {file}",
    "{actor} shared {file} as public link" : "{actor} partilhou {file} como hiperligação pública",
    "{actor} removed public link for {file}" : "{actor} removeu a hiperligação pública de {file}",
    "Public link of {actor} for {file} expired" : "Hiperligação pública de {actor} para {file} expirou",
    "{user} accepted the remote share" : "{user} aceitou a partilha remota",
    "{user} declined the remote share" : "{user} rejeitou a partilha remota",
    "You received a new remote share {file} from {user}" : "Recebeu uma nova partilha remota {file} de {user}",
    "{user} accepted the remote share of {file}" : "{user} aceitou a partilha remota de {file}",
    "{user} declined the remote share of {file}" : "{user} rejeitou a partilha remota de {file}",
    "{user} unshared {file} from you" : "{user} cancelou a partilha de {file} consigo",
    "Shared with {user}" : "Partilhado com {user}",
    "Removed share for {user}" : "Partilha removida para {user}",
    "You removed yourself" : "Você auto removeu-se",
    "{actor} removed themselves" : "{actor} removeu eles mesmos",
    "{actor} shared with {user}" : "{actor} partilhou com {user}",
    "{actor} removed share for {user}" : "{actor} removeu partilha com {user}",
    "Shared by {actor}" : "Partilhado por {actor}",
    "{actor} removed share" : "{actor} removeu partilha",
    "Share for {user} expired" : "Partilha para {user} expirou",
    "Share expired" : "A partilha expirou",
    "You shared {file} with {user}" : "Partilhaste {file} com {user}",
    "You removed {user} from {file}" : "Removeste {user} de {file}",
    "You removed yourself from {file}" : "Você removeu-se de {file}",
    "{actor} removed themselves from {file}" : "{actor} removeram-se de {file}",
    "{actor} shared {file} with {user}" : "{actor} partilhou {file} com {user}",
    "{actor} removed {user} from {file}" : "{actor} removeu {user} de {file}",
    "{actor} shared {file} with you" : "{actor} partilhou {file} consigo",
    "{actor} removed you from the share named {file}" : "{actor} removeu-o da partilha com o nome {file}",
    "Share for file {file} with {user} expired" : "A partilha do ficheiro {file} com {user} expirou",
    "Share for file {file} expired" : "A partilha do ficheiro {file} expirou",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Um ficheiro ou pasta partilhado por e-mail ou hiperligação publica foi <strong>transferido</strong>",
    "Files have been <strong>uploaded</strong> to a folder shared by mail or by public link" : "Os ficheiros foram <strong>enviados</strong> para uma pasta partilhada por e-mail ou por link público",
    "A file or folder was shared from <strong>another server</strong>" : "Um ficheiro ou pasta foi partilhado a partir de <strong>outro servidor</strong>",
    "Sharing" : "Partilha",
    "A file or folder has been <strong>shared</strong>" : "Foi <strong>partilhado</strong> um ficheiro ou uma pasta",
    "Shared link" : "Link partilhado",
    "Wrong share ID, share does not exist" : "ID de partilha incorreto, a partilha não existe.",
    "Could not delete share" : "Não foi possível eliminar a partilha",
    "Please specify a file or folder path" : "Por favor, especifique um ficheiro ou caminho de pasta",
    "Wrong path, file/folder does not exist" : "Caminho errado, ficheiro/pasta não existe",
    "Could not create share" : "Não foi possível criar partilha",
    "Please specify a valid account to share with" : "Por favor, especifique uma conta válida para partilhar.",
    "Please specify a valid group" : "Por favor, especifique um grupo válido",
    "Please specify a valid email address" : "Por favor, especifique um endereço de e-mail válido.",
    "Sharing %s sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "A partilha de %s com envio da palavra-passe pelo Nextcloud Talk falhou porque o Nextcloud Talk não está ativado.",
    "Please specify a valid federated account ID" : "Por favor, especifique um ID de conta federada válido",
    "Please specify a valid federated group ID" : "Por favor, especifique um ID de grupo federado válido ",
    "Please specify a valid team" : "Por favor, especifique uma equipe válida",
    "Sharing %s failed because the back end does not support room shares" : "O compartilhamento de %s falhou porque o back-end não é compatível com compartilhamentos de salas",
    "Unknown share type" : "Tipo de partilha desconhecido",
    "Not a directory" : "Não é uma diretoria",
    "Public upload is only possible for publicly shared folders" : "O envio público só é possível para as pastas partilhadas publicamente",
    "Share must at least have READ or CREATE permissions" : "O compartilhamento deve ter pelo menos permissões de READ (ler) ou CREATE (criar)",
    "Share must have READ permission if UPDATE or DELETE permission is set" : "O compartilhamento deve ter permissão de READ (ler) se a permissão UPDATE (atualizar) ou DELETE (excluir) estiver definida",
    "Could not lock path" : "Não foi possível bloquear o caminho",
    "no sharing rights on this item" : "sem permissões de compartilhamento para este item",
    "You are not allowed to edit incoming shares" : "Você não tem permissão para editar compartilhamentos recebidos",
    "Wrong or no update parameter given" : "Parâmetro indicado errado ou desatualizado",
    "\"Sending the password by Nextcloud Talk\" for sharing a file or folder failed because Nextcloud Talk is not enabled." : "O \"envio da senha pelo Nextcloud Talk\" para compartilhar um arquivo ou pasta falhou porque o Nextcloud Talk não está ativado. ",
    "Tokens must be between 1 and %s characters long and may only contain letters, numbers, or a hyphen" : "Os tokens devem ter entre 1 e %s caracteres e só podem conter letras, números ou um hífen",
    "Invalid date. Format must be YYYY-MM-DD" : "Data inválida. O formato deve ser AAAA-MM-DD",
    "No sharing rights on this item" : "Sem permissões de compartilhamento para este item",
    "Invalid share attributes provided: \"%s\"" : "Atributos de compartilhamento inválidos fornecidos: \"%s\"",
    "Wrong password" : "Palavra-passe errada",
    "Error while sending mail notification" : "Erro ao enviar notificação por e-mail",
    "Failed to generate a unique token" : "Falha ao gerar um token único",
    "This share does not exist or is no longer available" : "Este compartilhamento não existe ou não está mais disponível",
    "shared by %s" : "partilhado por %s",
    "Download" : "Transferir",
    "Add to your %s" : "Adicione ao seu  %s",
    "Direct link" : "Hiperligação direta",
    "Share API is disabled" : "A partilha de API está desativada",
    "File sharing" : "Partilha de ficheiro",
    "Share will expire tomorrow" : "Compartilhamento irá expirar amanhã",
    "Your share of {node} will expire tomorrow" : "Seu compartilhamento de {node} irá expirar amanhã",
    "You received {share} as a share by {user}" : "Você recebeu {share} como um compartilhamento de {user}",
    "You received {share} to group {group} as a share by {user}" : "Você recebeu {share} para o grupo {group} como um compartilhamento de {user}",
    "Accept" : "Aceitar",
    "Decline" : "Recusar",
    "We would like to kindly remind you that you have not yet uploaded any files to the shared folder." : "Gostaríamos de lembrar que você ainda não carregou nenhum arquivo para a pasta compartilhada.",
    "This application enables people to share files within Nextcloud. If enabled, the admin can choose which groups can share files. The applicable people can then share files and folders with other accounts and groups within Nextcloud. In addition, if the admin enables the share link feature, an external link can be used to share files with other people outside of Nextcloud. Admins can also enforce passwords, expirations dates, and enable server to server sharing via share links, as well as sharing from mobile devices.\nTurning the feature off removes shared files and folders on the server for all share recipients, and also on the sync clients and mobile apps. More information is available in the Nextcloud Documentation." : "Este aplicativo permite que as pessoas compartilhem arquivos dentro do Nextcloud. Se ativado, o administrador pode escolher quais grupos podem compartilhar arquivos. As pessoas aplicáveis ​​podem então compartilhar arquivos e pastas com outras contas e grupos dentro do Nextcloud. Além disso, se o administrador ativar o recurso de link de compartilhamento, um link externo poderá ser usado para compartilhar arquivos com outras pessoas fora do Nextcloud. Os administradores também podem impor senhas, datas de expiração e permitir o compartilhamento de servidor para servidor por meio de links de compartilhamento, bem como compartilhamento a partir de dispositivos móveis. \nDesativar o recurso remove arquivos e pastas compartilhados no servidor para todos os destinatários de compartilhamento e também nos clientes de sincronização e aplicativos móveis. Mais informações estão disponíveis na Documentação do Nextcloud.",
    "you" : "Você",
    "The request will expire on {date} at midnight and will be password protected." : "A solicitação expirará em {date} à meia-noite e será protegida por senha.",
    "The request will be password protected." : "A solicitação será protegida por senha.",
    "Expiration date" : "Data de expiração",
    "Select a date" : "Selecione uma data",
    "Your administrator has enforced a {count} days expiration policy." : "Seu administrador aplicou uma política de expiração de {count} dias.",
    "Set a password" : "Definir uma palavra-passe",
    "Password" : "Password",
    "Generate a new password" : "Gerar uma nova senha",
    "Link copied" : "Link copiado",
    "Invalid email address" : "Endereço de e-mail inválido",
    "_The following email address is not valid: {emails}_::_The following email addresses are not valid: {emails}_" : ["O seguinte endereço de e-mail não é válido: {emails}","Os seguintes endereços de e-mail não são válidos: {emails}","Os seguintes endereços de e-mail não são válidos: {emails}"],
    "_{count} email address already added_::_{count} email addresses already added_" : ["{count} endereço de e-mail já adicionado","{count} endereços de e-mail já adicionados","{count} endereços de e-mail já adicionados"],
    "_{count} email address added_::_{count} email addresses added_" : ["{count} endereço de e-mail adicionado","{count} endereços de e-mail adicionados","{count} endereços de e-mail adicionados"],
    "You can now share the link below to allow people to upload files to your directory." : "Agora você pode compartilhar o link abaixo para permitir que as pessoas carreguem arquivos em seu diretório.",
    "Share link" : "Share link",
    "Copy" : "Copiar",
    "Send link via email" : "Enviar hiperligação por mensagem",
    "Select a destination" : "Selecione um destino",
    "Select" : "Selecionar",
    "Where should these files go?" : "Para onde esses arquivos devem ir?",
    "The uploaded files are visible only to you unless you choose to share them." : "Os arquivos enviados ficam visíveis apenas para você, a menos que você opte por compartilhá-los.",
    "Add a note to help people understand what you are requesting." : "Adicione uma nota para ajudar as pessoas a entenderem o que você está solicitando.",
    "Close" : "Fechar",
    "_Send email and close_::_Send {count} emails and close_" : ["Envie e-mail e feche","Envie {count} e-mails e feche","Envie {count} e-mails e feche"],
    "Please select a folder, you cannot share the root directory." : "Selecione uma pasta, você não pode compartilhar o diretório raiz.",
    "File request created" : "Solicitação de arquivo criada",
    "_File request created and email sent_::_File request created and {count} emails sent_" : ["Solicitação de arquivo criada e e-mail enviado","Solicitação de arquivo criada e {count} e-mails enviados","Solicitação de arquivo criada e {count} e-mails enviados"],
    "Error creating the share" : "Erro ao criar o compartilhamento",
    "Error sending emails: {errorMessage}" : "Erro ao enviar e-mails: {errorMessage}",
    "Error sending emails" : "Erro ao enviar e-mails",
    "Collect files from others even if they do not have an account." : "Colete arquivos de outras pessoas, mesmo que elas não tenham uma conta.",
    "File request" : "Solicitação de arquivo",
    "Previous step" : "Etapa anterior",
    "Cancel" : "Cancelar",
    "Continue" : "Continuar",
    "Error while toggling options" : "Erro ao alternar opções",
    "Choose a default folder for accepted shares" : "Escolha uma pasta padrão para os compartilhamentos aceitos",
    "Invalid path selected" : "Caminho inválido selecionado",
    "Unknown error" : "Erro desconhecido",
    "Reset" : "Reiniciar",
    "Share expiration: {date}" : "Expiração do compartilhamento: {date}",
    "group" : "grupo",
    "conversation" : "conversação",
    "remote" : "remoto",
    "remote group" : "grupo remoto",
    "guest" : "convidado",
    "by {initiator}" : "por {initiator}",
    "Shared with the conversation {user} by {owner}" : "Compartilhado com a conversa {user} por {owner}",
    "Shared with {user} by {owner}" : "Compartilhado com {user} por {owner}",
    "Open Sharing Details" : "Abrir Detalhes de Compartilhamento",
    "Added by {initiator}" : "Adicionado por {initiator}",
    "Unshare" : "Cancelar partilha",
    "Cannot copy, please copy the link manually" : "Não foi possível copiar, copie a ligação manualmente",
    "Copy internal link" : "Copiar ligação interna",
    "For people who already have access" : "Para as pessoas que já têm acesso",
    "Internal link" : "Ligação interna",
    "{shareWith} by {initiator}" : "{shareWith} por {initiator}",
    "File request ({label})" : "Solicitação de arquivo ({label})",
    "Mail share ({label})" : "Compartilhamento por e-mail ({label})",
    "Share link ({label})" : "Hiperligação de partilha ({label})",
    "Mail share" : "Compartilhamento por e-mail",
    "Share link ({index})" : "Hiperligação de partilha ({index})",
    "Create public link" : "Criar link público",
    "Copy public link of \"{title}\"" : "Copiar link público de \"{title}\"",
    "Link share created" : "Compartilhamento por link criado",
    "Error while creating the share" : "Erro ao criar o compartilhamento",
    "Your browser does not support copying, please copy the link manually:" : "Seu navegador não suporta copiar. Por favor, copie o link manualmente:",
    "Please enter the following required information before creating the share" : "Digite as seguintes informações necessárias antes de criar o compartilhamento",
    "Password protection (enforced)" : "Proteção por senha (imposta)",
    "Password protection" : "Protegido por palavra-passe",
    "Enter a password" : "Insira uma palavra-passe",
    "Enable link expiration (enforced)" : "Ativar expiração de link (imposta)",
    "Enable link expiration" : "Ativar expiração de link",
    "Enter expiration date" : "Insira a data de expiração",
    "Create share" : "Criar partilha",
    "Generate QR code" : "Gerar código QR",
    "Add another link" : "Adicionar outra hiperligação",
    "Create a new share link" : "Criar um novo link de compartilhamento",
    "Quick share options, the current selected is \"{selectedOption}\"" : "Opções de compartilhamento rápido, o atual selecionado é \"{selectedOption}\"",
    "View only" : "Visualizar apenas",
    "Can edit" : "Pode editar",
    "Custom permissions" : "Permissões personalizadas",
    "Resharing is not allowed" : "Voltar a partilhar não é permitido",
    "Name, email, or Federated Cloud ID …" : "Nome, e-mail ou ID da Nuvem Federada …",
    "Searching …" : "A procurar…",
    "No elements found." : "Não foram encontrados elementos.",
    "Search everywhere" : "Pesquisar em todo o lado",
    "Guest" : "Convidado",
    "Group" : "Grupo",
    "Email" : "E-mail",
    "Team" : "Grupo",
    "Talk conversation" : "Conversa Talk",
    "Deck board" : "Painel de Deck",
    "ScienceMesh" : "ScienceMesh",
    "on {server}" : "em {server}",
    "Search for internal recipients" : "Pesquisar destinatários internos",
    "Note:" : "Nota:",
    "File drop" : "File drop",
    "Successfully uploaded files" : "Arquivos carregados com sucesso",
    "Terms of service" : "Termos de serviço",
    "Share with {user}" : "Compartilhar com {user}",
    "Share with email {email}" : "Compartilhar com e-mail {email}",
    "Share with group" : "Compartilhar com grupo",
    "Share with {user} on remote server {server}" : "Compartilhar com {user} no servidor remoto {server}",
    "Share with remote group" : "Compartilhar com grupo remoto",
    "Share with guest" : "Compartilhar com convidado",
    "Update share" : "Atualizar compartilhamento",
    "Save share" : "Salvar compartilhamento",
    "Read" : "Ler",
    "Create" : "Criar",
    "Edit" : "Editar",
    "Share" : "Partilhar",
    "Delete" : "Apagar",
    "Password field cannot be empty" : "O campo da senha não pode estar vazio",
    "Replace current password" : "Substituir senha atual",
    "Allow upload and editing" : "Permtir carregamentos e edições",
    "Allow editing" : "Permitir edição",
    "Upload only" : "Somente upload",
    "Advanced settings" : "Definições avançadas",
    "Share label" : "Share label",
    "Share link token" : "Token do link de compartilhamento",
    "Set the public share link token to something easy to remember or generate a new token. It is not recommended to use a guessable token for shares which contain sensitive information." : "Defina o token do link de compartilhamento público para algo fácil de lembrar ou gere um novo token. Não é recomendado usar um token fácil de adivinhar para compartilhamentos que contenham informações confidenciais.",
    "Generating…" : "Gerando…",
    "Generate new token" : "Gerar novo token",
    "Set password" : "Definir palavra-passe",
    "Expiration date (enforced)" : "Data de vencimento (imposta)",
    "Set expiration date" : "Definir a data de expiração",
    "Hide download" : "Ocultar transferência",
    "Allow download and sync" : "Permitir transferência e sincronizar",
    "Note to recipient" : "Nota para o destinatário",
    "Delete share" : "Excluir compartilhamento",
    "Others with access" : "Outros com acesso",
    "No other accounts with access found" : "Nenhuma outra conta com acesso encontrada",
    "Toggle list of others with access to this directory" : "Alternar lista de outros utilizadores com acesso a esta pasta",
    "Toggle list of others with access to this file" : "Alternar lista de outros utilizadores com acesso a este ficheiro",
    "Unable to fetch inherited shares" : "Não foi possível buscar compartilhamentos herdados",
    "Shares" : "Partilhas",
    "Share files within your organization. Recipients who can already view the file can also use this link for easy access." : "Compartilhe arquivos dentro da sua organização. Os destinatários que já conseguem visualizar o arquivo também podem usar este link para facilitar o acesso.",
    "Share files with others outside your organization via public links and email addresses. You can also share to {productName} accounts on other instances using their federated cloud ID." : "Compartilhe arquivos com outras pessoas fora da sua organização por meio de links públicos e endereços de e-mail. Você também pode compartilhar com contas {productName} em outras instâncias usando seu ID de nuvem federada.",
    "Shares from apps or other sources which are not included in internal or external shares." : "Partilhas provenientes de aplicações ou outras fontes que não estão incluídas nas partilhas internas ou externas.",
    "Type names or teams" : "Digite nomes ou equipes",
    "Type an email" : "Introduza um e-mail",
    "Unable to load the shares list" : "Não foi possível carregar a lista de compartilhamentos",
    "Expires {relativetime}" : "Expira {relativetime}",
    "this share just expired." : "esse compartilhamento acabou de expirar.",
    "Shared with you by {owner}" : "Partilhado consigo por {owner}",
    "Internal shares" : "Partilhas internas",
    "Internal shares explanation" : "Explicação das partilhas internas",
    "External shares" : "Partilhas externas",
    "External shares explanation" : "Explicação das partilhas externas",
    "Additional shares" : "Partilhas adicionais",
    "Additional shares explanation" : "Explicação das partilhas adicionais",
    "Link to a file" : "Criar link para um arquivo",
    "_Accept share_::_Accept shares_" : ["Aceitar compartilhamento","Aceitar compartilhamentos","Aceitar compartilhamentos"],
    "Open in Files" : "Abrir em Arquivos",
    "_Reject share_::_Reject shares_" : ["Rejeitar compartilhamento","Rejeitar compartilhamentos","Rejeitar compartilhamentos"],
    "_Restore share_::_Restore shares_" : ["Restaurar compartilhamento","Restaurar compartilhamentos","Restaurar compartilhamentos"],
    "Shared" : "Partilhados",
    "Shared by {ownerDisplayName}" : "Shared by {ownerDisplayName}",
    "Shared multiple times with different people" : "Compartilhado várias vezes com pessoas diferentes",
    "Shared with others" : "Partilhado com terceiros",
    "You do not have enough permissions to share this file." : "Você não tem permissões suficientes para compartilhar este arquivo.",
    "People" : "Pessoas",
    "Create file request" : "Criar solicitação de arquivo",
    "Upload files to {foldername}" : "Fazer upload de arquivos para {foldername}",
    "No file" : "Sem arquivo",
    "The file shared with you will show up here" : "O ficheiro partilhado consigo aparecerá aqui.",
    "Public share" : "Compartilhamento público",
    "Publicly shared files." : "Arquivos compartilhados publicamente.",
    "No files" : "Sem arquivos",
    "Files and folders shared with you will show up here" : "Ficheiros e pastas partilhados consigo aparecerão aqui aqui",
    "No shares" : "Sem compartilhamentos",
    "Files and folders you shared or have been shared with you will show up here" : "Os ficheiros e pastas que partilhou ou que foram partilhados consigo aparecerão aqui.",
    "Shared with you" : "Partilhado consigo ",
    "List of files that are shared with you." : "Lista de ficheiros que foram partilhados consigo.",
    "Nothing shared with you yet" : "Ainda não foi partilhado nada consigo",
    "Files and folders others shared with you will show up here" : "Os ficheiros e pastas que outras pessoas partilharam consigo aparecerão aqui.",
    "List of files that you shared with others." : "Lista de ficheiros que partilhou com outras pessoas.",
    "Nothing shared yet" : "Ainda não foi partilhado nada",
    "Files and folders you shared will show up here" : "Arquivos e pastas que você compartilhou aparecerão aqui",
    "Shared by link" : "Partilhado por hiperligação",
    "List of files that are shared by link." : "Lista de arquivos compartilhados por link.",
    "No shared links" : "Sem hiperligações partilhadas",
    "Files and folders you shared by link will show up here" : "Arquivos e pastas que você compartilhou por link aparecerão aqui",
    "List of file requests." : "Lista de solicitações de arquivos.",
    "File requests you have created will show up here" : "As solicitações de arquivo que você criou aparecerão aqui",
    "Deleted shares" : "Partilhas eliminadas",
    "List of shares you left." : "Lista de compartilhamentos dos quais você saiu.",
    "Shares you have left will show up here" : "Os compartilhamentos dos quais você saiu aparecerão aqui",
    "Pending shares" : "Partilhas pendentes",
    "List of unapproved shares." : "Lista de compartilhamentos não aprovados.",
    "No pending shares" : "Não há compartilhamentos pendentes",
    "Shares you have received but not approved will show up here" : "Os compartilhamentos que você recebeu, mas não aprovou, aparecerão aqui",
    "Error updating the share" : "Erro ao atualizar o compartilhamento",
    "Folder \"{path}\" has been unshared" : "A pasta \"{path}\" foi descompartilhada",
    "Could not update share" : "Não foi possível atualizar o compartilhamento",
    "Share saved" : "Compartilhamento salvo",
    "Share hide-download state saved" : "Estado ocultar/transferir da partilha guardado",
    "Share label saved" : "Rótulo de compartilhamento salvo",
    "Share note for recipient saved" : "Nota para o destinatário do compartilhamento salva",
    "Share password saved" : "Senha do compartilhamento salva",
    "Share permissions saved" : "Permissões do compartilhamento salvas",
    "Upload files to {folder}" : "Fazer upload de arquivos para {folder}",
    "Please confirm your name to upload files to {folder}" : "Confirme seu nome para fazer upload de arquivos para {folder}",
    "{ownerDisplayName} shared a folder with you." : "{ownerDisplayName} partilhou uma pasta consigo.",
    "Names must not be empty." : "Os nomes não podem estar vazios.",
    "\"{char}\" is not allowed inside a name." : "\"{char}\" não é permitido dentro de um nome.",
    "\"{extension}\" is not an allowed name." : "\"{extension}\" não é um nome permitido.",
    "Names must not end with \"{extension}\"." : "Os nomes não devem terminar com \"{extension}\".",
    "Invalid name." : "Nome inválido.",
    "Password created successfully" : "Senha criada com sucesso",
    "Error generating password from password policy" : "Erro ao gerar senha usando a política de senha",
    "Shared with you and the group {group} by {owner}" : "Partilhado consigo e com o grupo {group} por {owner}",
    "Shared with you and {circle} by {owner}" : "Partilhado consigo e com {circle} por {owner}",
    "Shared with you and the conversation {conversation} by {owner}" : "Partilhado consigo e com a conversação {conversation} por {owner}",
    "Shared with you in a conversation by {owner}" : "Partilhado consigo numa conversação por {owner}",
    "Share not found" : "Partilha não encontrada",
    "Back to %s" : "Voltar a %s",
    "Add to your Nextcloud" : "Adicionar à sua Nextcloud",
    "Group sharing is disabled by the administrator" : "A partilha em grupo está desativada pelo administrador",
    "Public link sharing is disabled by the administrator" : "A partilha da hiperligação pública está desativada pelo administrador",
    "Public upload disabled by the administrator" : "Envio público desativado pelo administrador",
    "Tokens must contain at least 1 character and may only contain letters, numbers, or a hyphen" : "Os tokens devem conter pelo menos 1 caractere e podem incluir apenas letras, números ou um hífen",
    "Name or email …" : "Nome ou e-mail...",
    "Searching …" : "À procura …"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
