OC.L10N.register(
    "files_sharing",
    {
    "File shares" : "Zdieľané súbory",
    "Downloaded via public link" : "Stiahnuté prostredníctvom verejného odkazu",
    "Downloaded by {email}" : "Stiahnuté prostredníctvom {email}",
    "{file} downloaded via public link" : "{file} stiahnutý cez verejne dostupný odkaz",
    "{email} downloaded {file}" : "{email} stiahol {file}",
    "Shared with group {group}" : "Zdieľané so skupinou {group}",
    "Removed share for group {group}" : "Odstránené zdieľanie pre skupinu {group}",
    "{actor} shared with group {group}" : "{actor} sprístupnil skupine {group}",
    "{actor} removed share for group {group}" : "{actor} zrušil zdieľanie pre skupinu {group}",
    "Share for group {group} expired" : "Zdieľanie pre skupinu {group} vypršalo",
    "You shared {file} with group {group}" : "Sprístupnili ste {file} skupine {group}",
    "You removed group {group} from {file}" : "Zrušili ste zdieľanie súboru {file} skupine {group}",
    "{actor} shared {file} with group {group}" : "{actor} zdieľa {file} skupine {group}",
    "{actor} removed group {group} from {file}" : "{actor} zrušil zdieľanie súboru {file} skupine {group}",
    "Share for file {file} with group {group} expired" : "Zdieľanie súboru {file} so skupinou {group} vypršalo",
    "Shared as public link" : "Zdieľané ako verejný odkaz",
    "Removed public link" : "Verejný odkaz odstránený",
    "Public link expired" : "Verejnému odkazu vypršala platnosť",
    "{actor} shared as public link" : "{actor} sprístupnil ako verejný odkaz",
    "{actor} removed public link" : "{actor} odstránil verejný odkaz",
    "Public link of {actor} expired" : "Verejný odkaz {actor} vypršal",
    "You shared {file} as public link" : "Sprístupnili ste súbor {file} ako verejný odkaz",
    "You removed public link for {file}" : "Odstránili ste verejný odkaz pre {file}",
    "Public link expired for {file}" : "Verejný odkaz pre {file} vypršal",
    "{actor} shared {file} as public link" : "{actor} sprístupnil {file} ako verejný odkaz",
    "{actor} removed public link for {file}" : "{actor} odstránil verejný odkaz pre {file}",
    "Public link of {actor} for {file} expired" : "Verejný odkaz používateľa {actor} pre {file} vypršal",
    "{user} accepted the remote share" : "používateľ {user} prijal vzdialené zdieľanie",
    "{user} declined the remote share" : "používateľ {user} odmietol vzdialené zdieľanie",
    "You received a new remote share {file} from {user}" : "Obdržali ste nové vzdialené zdieľanie súboru {file} používateľom {user}",
    "{user} accepted the remote share of {file}" : "používateľ {user} prijal vzdialené zdieľanie súboru {file}",
    "{user} declined the remote share of {file}" : "používateľ {user} odmietol vzdialené spristupnenie súboru {file} ",
    "{user} unshared {file} from you" : "používateľ {user} vám už nesprístupňuje súbor {file}",
    "Shared with {user}" : "Zdieľané s {user}",
    "Removed share for {user}" : "Odstránené zdieľanie pre používateľa {user}",
    "You removed yourself" : "Odobrali ste sami seba",
    "{actor} removed themselves" : "{actor} odobral(a) sám seba",
    "{actor} shared with {user}" : "{actor} zdieľal s {user}",
    "{actor} removed share for {user}" : "{actor} odstránil zdieľanie pre používateľa {user}",
    "Shared by {actor}" : "Sprístupnil {actor}",
    "{actor} removed share" : "{actor} zrušil zdieľanie",
    "Share for {user} expired" : "Zdieľanie pre používateľa {user} vypršalo",
    "Share expired" : "Zdieľanie vypršalo",
    "You shared {file} with {user}" : "Sprístupnili ste {file} používateľovi {user}",
    "You removed {user} from {file}" : "Zrušili ste zdieľanie {file} používateľovi {user} ",
    "You removed yourself from {file}" : "Odobrali ste sami seba z {file}",
    "{actor} removed themselves from {file}" : "{actor} odobral(a) sám seba z {file}",
    "{actor} shared {file} with {user}" : "{actor} sprístupnil {file} používateľovi {user}",
    "{actor} removed {user} from {file}" : "{actor} zrušil zdieľanie {file} pre používateľa {user}",
    "{actor} shared {file} with you" : "{actor} vám sprístupnil {file}",
    "{actor} removed you from the share named {file}" : "{actor} vás odstránil z prístupu k {file} ",
    "Share for file {file} with {user} expired" : "Zdieľanie súboru {file} s používateľom {user} vypršalo",
    "Share for file {file} expired" : "Zdieľanie súboru {file} vypršalo",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Súbor alebo adresár zdieľaný cez email alebo verejný odkaz bol <strong>stiahnutý</strong>",
    "Files have been <strong>uploaded</strong> to a folder shared by mail or by public link" : "Súbory boli <strong>nahrané</strong> do adresára zdieľaného e-mailom alebo verejným odkazom",
    "A file or folder was shared from <strong>another server</strong>" : "Súbor alebo priečinok bol sprístupnený z <strong>iného servera</strong>",
    "Sharing" : "Zdieľanie",
    "A file or folder has been <strong>shared</strong>" : "Súbor alebo priečinok bol <strong>sprístupnený</strong>",
    "Shared link" : "Zdieľaný odkaz",
    "Wrong share ID, share does not exist" : "Neplatné ID zdieľania, zdieľanie neexistuje",
    "Could not delete share" : "Nie je možné zmazať zdieľanie",
    "Please specify a file or folder path" : "Zvoľte prosím súbor alebo cestu k priečinku",
    "Wrong path, file/folder does not exist" : "Neplatná cesta, súbor alebo priečinok neexistuje",
    "Could not create share" : "Nie je možné sprístupniť",
    "Please specify a valid account to share with" : "Prosím, uveďte platný účet, s ktorým chcete zdieľať",
    "Please specify a valid group" : "Zvoľte prosím platnú skupinu",
    "Please specify a valid email address" : "Prosím, zadajte platnú emailovú adresu",
    "Sharing %s sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "Zdieľanie %s odoslaním hesla cez Nextcloud Talk /Rozhovor/ zlyhalo, pretože Nextcloud Rozhovor nie je zapnutý",
    "Please specify a valid federated account ID" : "Prosím zvoľte platné ID združeného účtu.",
    "Please specify a valid federated group ID" : "Prosím zvoľte platné ID združenej skupiny",
    "You cannot share to a Team if the app is not enabled" : "Nemôžete zdieľat do aplikácie Team, keď nie je povolená",
    "Please specify a valid team" : "Zadajte platný tím",
    "Sharing %s failed because the back end does not support room shares" : "Zdieľanie %s sa nepodarilo, pretože backend  nepodporuje zdieľanie miestností",
    "Unknown share type" : "Neplatný typ sprístupnenia",
    "Not a directory" : "Nie je priečinok",
    "Could not lock node" : "Uzol sa nedarí uzamknúť",
    "Public upload is only possible for publicly shared folders" : "Verejné nahrávanie je možné len do verejne sprístupnených priečinkov",
    "Share must at least have READ or CREATE permissions" : "Zdieľanie musí mať aspoň povolenia READ alebo CREATE",
    "Share must have READ permission if UPDATE or DELETE permission is set" : "Ak je nastavené oprávnenie UPDATE alebo DELETE, zdieľanie musí mať povolenie READ.",
    "Could not lock path" : "Nie je možné uzamknúť cestu",
    "no sharing rights on this item" : "žiadne práva pre zdieľanie tejto položky",
    "You are not allowed to edit incoming shares" : "Nemáte práva pre úpravu príchodzích zdieľaní",
    "Wrong or no update parameter given" : "Zlý alebo žiadny zadaný parameter aktualizácie",
    "\"Sending the password by Nextcloud Talk\" for sharing a file or folder failed because Nextcloud Talk is not enabled." : "\"Odoslanie hesla cez Nextcloud Talk / Rozhovor/\" pre zdieľanie súboru alebo priečinka zlyhalo, pretože Nextcloud Talk /Rozhovor/ nie je zapnutý.",
    "Custom share link tokens have been disabled by the administrator" : "Správca zakázal vlastné tokeny zdieľania",
    "Invalid date. Format must be YYYY-MM-DD" : "Neplatný dátum. Formát musí byť YYYY-MM-DD",
    "No sharing rights on this item" : "Žiadne práva pre zdieľanie tejto položky",
    "Invalid share attributes provided: \"%s\"" : "Boli zadané neplatné atribúty zdieľania: \"%s\"",
    "You are not allowed to send mail notifications" : "Nemáte povolené odosielať e-mailové upozornenia",
    "No mail notification configured for this share type" : "Pre tento typ zdieľania nie je nakonfigurované žiadne e-mailové upozornenie",
    "Wrong password" : "Nesprávne heslo",
    "Error while sending mail notification" : "Chyba pri odosielaní notifikácie e-mailom",
    "Failed to generate a unique token" : "Chyba pri generovaní unikátneho tokenu",
    "This share does not exist or is no longer available" : "Toto zdieľanie neexistuje alebo už nie je dostupné",
    "shared by %s" : "Sprístupnil %s",
    "Download" : "Stiahnuť",
    "Add to your %s" : "Pridať do vášho %s",
    "Direct link" : "Priama linka",
    "Share API is disabled" : "API pre zdieľanie je zakázané",
    "File sharing" : "Zdieľanie súborov",
    "Share will expire tomorrow" : "Platnosť sprístupnenia skončí zajtra",
    "Your share of {node} will expire tomorrow" : "Vášmu zdieľaniu {node} zajtra skončí platnosť",
    "You received {share} as a share by {user}" : "Od {user} ste obdržali zdieľanie {share}",
    "You received {share} to group {group} as a share by {user}" : "Od {user} ste pre skupinu {group} obdržali zdieľanie {share}",
    "Accept" : "Prijať",
    "Decline" : "Zahodiť",
    "Remember to upload the files to %s" : "Nezabudnite nahrať súbory do %s",
    "We would like to kindly remind you that you have not yet uploaded any files to the shared folder." : "Radi by sme vám pripomenuli, že ste do zdieľaného adresára ešte nenahrali žiadne súbory.",
    "Open \"%s\"" : "Otvoriť \"%s\"",
    "This application enables people to share files within Nextcloud. If enabled, the admin can choose which groups can share files. The applicable people can then share files and folders with other accounts and groups within Nextcloud. In addition, if the admin enables the share link feature, an external link can be used to share files with other people outside of Nextcloud. Admins can also enforce passwords, expirations dates, and enable server to server sharing via share links, as well as sharing from mobile devices.\nTurning the feature off removes shared files and folders on the server for all share recipients, and also on the sync clients and mobile apps. More information is available in the Nextcloud Documentation." : "Táto aplikácia umožňuje ľuďom si navzájom zdieľať súbory v rámci Nextcloud. Ak je zapnutá, správca môže zvoliť, ktoré skupiny môžu súbory zdieľať ostatným. Príslušní ľudia potom môžu tieto súbory a priečinky zdieľať ostatným účtom a skupinám v rámci Nextcloud. Navyše, ak správca zapne funkciu zdieľať pomocou odkazu, je možné súbory zdieľať aj mimo Nextcloud a to pomocou externého odkazu (linku). Správcovia tiež môžu vynútiť používanie hesiel, dátumov expirácie a povoliť zdielanie server-server pomocou zdieľaných odkazov, ako aj zdielanie z mobilných zariadení.\nVypnutím tejto funkcie odoberie zdielané súbory a priečinky na serveri pre všetkých príjemcov zdieľania, a taktiež aj na synchronizačných klientoch a mobilných aplikáciách. Viac informácií je k dispozícii v dokumentácii Nextcloud.",
    "Filter accounts" : "Filtrovať účty",
    "you" : "vy",
    "The request will expire on {date} at midnight and will be password protected." : "Platnosť žiadosti vyprší {date} o polnoci a bude chránená heslom.",
    "The request will expire on {date} at midnight." : "Platnosť žiadosti vyprší {date} o polnoci.",
    "The request will be password protected." : "Žiadosť bude chránená heslom.",
    "When should the request expire?" : "Kedy by mala žiadosť vypršať?",
    "Set a submission expiration date" : "Nastaviť dátum vypršania platnosti odoslania",
    "Expiration date" : "Dátum vypršania",
    "Select a date" : "Vybrať dátum",
    "Your administrator has enforced a {count} days expiration policy." : "Váš správca presadil pravidlá uplynutia platnosti na {count} dní.",
    "What password should be used for the request?" : "Aké heslo by sa malo použiť pre žiadosť?",
    "Set a password" : "Nastavte si heslo",
    "Password" : "Heslo",
    "Enter a valid password" : "Vložte platné heslo",
    "Generate a new password" : "Vygenerovať nové heslo",
    "Your administrator has enforced a password protection." : "Váš administrátor vynútil ochranu heslom.",
    "Automatically copying failed, please copy the share link manually" : "Automatické kopírovanie zlyhalo, skopírujte odkaz na zdieľanie manuálne",
    "Link copied" : "Odkaz bol skopírovaný",
    "Email already added" : "Tento email už bol pridaný",
    "Invalid email address" : "Neplatná emailová adresa",
    "_The following email address is not valid: {emails}_::_The following email addresses are not valid: {emails}_" : ["Nasledujúce e-mailové adresý nie sú platné: {emails}","Nasledujúce e-mailové adresý nie sú platné: {emails}","Nasledujúce e-mailové adresý nie sú platné: {emails}","Nasledujúce e-mailové adresý nie sú platné: {emails}"],
    "_{count} email address already added_::_{count} email addresses already added_" : ["{count} e-mailová adriesa už bola pridaná","{count} e-mailové adriesy už boli pridané","{count} e-mailových adries už bolo pridaných","{count} e-mailových adries už bolo pridaných"],
    "_{count} email address added_::_{count} email addresses added_" : ["{count} e-mailová adriesa bola pridaná","{count} pridané e-mailové adriesy","{count} pridaných e-mailových adries","{count} pridaných e-mailových adries"],
    "You can now share the link below to allow people to upload files to your directory." : "Teraz môžete zdieľať odkaz nižšie, aby ste ľuďom umožnili nahrávať súbory do vášho adresára.",
    "Share link" : "Sprístupniť odkaz",
    "Copy" : "Kopírovať",
    "Send link via email" : "Poslať odkaz emailom",
    "Enter an email address or paste a list" : "Vložte emailovú adresu alebo vložte zoznam",
    "Remove email" : "Odobrať email",
    "Select a destination" : "Vybrať cieľ",
    "Select" : "Vybrať",
    "What are you requesting?" : "Čo požadujete?",
    "Request subject" : "Vyžiadať predmet",
    "Birthday party photos, History assignment…" : "Fotky s narodeninových party, Historické aktivity...",
    "Where should these files go?" : "Kam tieto súbory pôjdu?",
    "Upload destination" : "Cieľ pre nahranie",
    "Revert to default" : "Vrátiť na predvolené",
    "The uploaded files are visible only to you unless you choose to share them." : "Nahrané súbory sú viditeľné iba pre vás, pokiaľ sa ich nerozhodnete zdieľať.",
    "Add a note" : "Pridať poznámku",
    "Note for recipient" : "Poznámka pre príjemcu",
    "Add a note to help people understand what you are requesting." : "Pridajte poznámku, aby ľudia pochopili, čo požadujete.",
    "You can add links, date or any other information that will help the recipient understand what you are requesting." : "Môžete pridať odkazy, dátum alebo akékoľvek iné informácie, ktoré príjemcovi pomôžu pochopiť, čo požadujete.",
    "Close" : "Zatvoriť",
    "_Send email and close_::_Send {count} emails and close_" : ["Odoslať e-mail a zavrieť","Odoslať {count} e-maily a zavrieť","Odoslať {count} e-mailov a zavrieť","Odoslať {count} e-mailov a zavrieť"],
    "Please select a folder, you cannot share the root directory." : "Vyberte adresár, nemôžete zdieľať koreňový adresár.",
    "File request created" : "Žiadosť o súbor vytvorená",
    "_File request created and email sent_::_File request created and {count} emails sent_" : ["Požiadavka na súbor bola vytvorená a bol odslaný e-mail","Požiadavka na súbor bola vytvorená a bolo odslané {count} e-maily","Požiadavka na súbor bola vytvorená a bolo odslaných {count} e-mailov","Požiadavka na súbor bola vytvorená a bolo odslaných {count} e-mailov"],
    "Error creating the share: {errorMessage}" : "Chyba pri vytváraní zdieľania: {errorMessage}",
    "Error creating the share" : "Chyba pri vytváraní zdieľania",
    "Error sending emails: {errorMessage}" : "Chyba pri posielaní emailov: {errorMessage}",
    "Error sending emails" : "Chyba pri posielaní emailov",
    "Create a file request" : "Vytvoriť žiadosť o súbor",
    "Collect files from others even if they do not have an account." : "Zbierajte súbory od ostatných, aj keď nemajú účet.",
    "To ensure you can receive files, verify you have enough storage available." : "Ak sa chcete ujistiť, že môžete prijímať súbory, skontrolujte, či máte k dispozícii dostatok voľného miesta.",
    "File request" : "Žiadosť o súbor",
    "Previous step" : "Predchodzí krok",
    "Cancel" : "Zrušiť",
    "Cancel the file request creation" : "Zrušiť vytváranie žiadosti o súbor",
    "Close without sending emails" : "Zatvoriť bez odoslania emailov",
    "Continue" : "Pokračovať",
    "Error while toggling options" : "Chyba pri prepínaní možností",
    "Accept shares from other accounts and groups by default" : "Predvolene prijať sprístupnené položky z iných účtov a skupín.",
    "Choose a default folder for accepted shares" : "Nastaviť predvolený priečinok pre prijaté zdieľania",
    "Invalid path selected" : "Bola vybraná neplatná cesta",
    "Unknown error" : "Neznáma chyba",
    "Set default folder for accepted shares" : "Nastaviť predvolený priečinok pre prijaté zdieľania",
    "Reset" : "Resetovať",
    "Reset folder to system default" : "Obnoviť priečinok na predvolené hodnoty systému",
    "Share expiration: {date}" : "Platnosť zdieľania: {date}",
    "Share Expiration" : "Vypršanie platnosti zdieľania",
    "group" : "skupina",
    "conversation" : "rozhovor",
    "remote" : "vzdialený",
    "remote group" : "vzdialená skupina",
    "guest" : "hosť",
    "by {initiator}" : "od {initiator}",
    "Shared with the group {user} by {owner}" : "Sprístupnil(a) {owner} skupine {user}",
    "Shared with the conversation {user} by {owner}" : "{owner} zdieľa konverzáciu {user}",
    "Shared with {user} by {owner}" : "{owner} zdieľa s {user}",
    "Open Sharing Details" : " Otvoriť podrobnosti zdieľania",
    "Added by {initiator}" : "Pridal(a) {initiator}",
    "Via “{folder}”" : "Prostredníctvom „{folder}“",
    "Unshare" : "Zneprístupniť",
    "Cannot copy, please copy the link manually" : "Nedarí sa skopírovať, skopírujte prosím ručne.",
    "Copy internal link" : "Kopírovať interný odkaz",
    "For people who already have access" : "Pre ľudí, ktorí už majú prístup",
    "Internal link" : "Interný odkaz",
    "{shareWith} by {initiator}" : "{shareWith} od {initiator}",
    "Shared via link by {initiator}" : "{initiator} zdieľa odkazom",
    "File request ({label})" : "Žiadosť o súbor ({label})",
    "Mail share ({label})" : "Zdieľanie mailu ({label})",
    "Share link ({label})" : "Odkaz na zdieľanie ({label})",
    "Mail share" : "Zdieľanie emailu",
    "Share link ({index})" : "Zdieľať odkaz ({index})",
    "Create public link" : "Vytvoriť verejný odkaz",
    "Actions for \"{title}\"" : "Akcie pre \"{title}\"",
    "Copy public link of \"{title}\"" : "Skopírujte verejný odkaz na \"{title}\"",
    "Error, please enter proper password and/or expiration date" : "Chyba, zadajte správne heslo a/alebo dátum ukončenia platnosti",
    "Link share created" : "Odkaz na zdieľanie vytvorený",
    "Error while creating the share" : "Chyba pri vytváraní zdieľania",
    "Your browser does not support copying, please copy the link manually:" : "Váš prehliadač nepodporuje kopírovanie, prosím skopírujte odkaz manuálne:",
    "Successfully copied public link" : "Úspešne skopírovaný verejný odkaz",
    "Please enter the following required information before creating the share" : "Pred vytvorením zdieľania zadajte následujúce potrebné informácie",
    "Password protection (enforced)" : "Ochrana heslom (vynúttená)",
    "Password protection" : "Ochrana heslom",
    "Enter a password" : "Zadajte heslo",
    "Enable link expiration (enforced)" : "Povoliť expiráciu odkazu (vyžadované)",
    "Enable link expiration" : "Povoliť expiráciu odkazu",
    "Enter expiration date (enforced)" : "Vložte dátum expirácie (vyžadované)",
    "Enter expiration date" : "Vložte dátum expirácie",
    "Create share" : "Vytvoriť zdieľanie",
    "Customize link" : "Prispôsobiť odkaz",
    "Generate QR code" : "Vygenerovať QR kód",
    "Add another link" : "Pridať ďalší odkaz",
    "Create a new share link" : "Vytvoriť nový odkaz pre zdieľanie",
    "Quick share options, the current selected is \"{selectedOption}\"" : "Rýchle možnosti zdieľania, aktuálne je vybrané \"{selectedOption}\"",
    "View only" : "Iba pre čítanie",
    "Can edit" : "Môže upravovať",
    "Custom permissions" : "Vlastné oprávnenia",
    "Resharing is not allowed" : "Opätovné zdieľanie nie je povolené",
    "Name or email …" : "Meno alebo email …",
    "Name, email, or Federated Cloud ID …" : "Meno, email, alebo ID federatívneho cloudu …",
    "Searching …" : "Vyhľadáva sa …",
    "No elements found." : "Nenájdené žiadne prvky.",
    "Search everywhere" : "Hľadať všade",
    "Guest" : "Hosť",
    "Group" : "Skupina",
    "Email" : "E-mail",
    "Team" : "Tím",
    "Talk conversation" : "Konverzácia v Talk /Rozhovoroch/",
    "Deck board" : "Palubná doska",
    "ScienceMesh" : "ScienceMesh",
    "on {server}" : "na {server}",
    "Enter external recipients" : "Zadajte externých príjemcov",
    "Search for internal recipients" : "Hľadať interných príjemcov",
    "Note from" : "Poznámka od",
    "Note:" : "Poznámka:",
    "File drop" : "Vložiť súbor",
    "Upload files to {foldername}." : "Nahrať súbory do {foldername}.",
    "By uploading files, you agree to the terms of service." : "Nahraním súborov vyjadrujete súhlas s podmienkami služby.",
    "Successfully uploaded files" : "Súbory boli úspešne nahrané.",
    "View terms of service" : "Zobraziť podmienky používania",
    "Terms of service" : "Všeobecné podmienky",
    "Share with {user}" : "Zdielať s {user}",
    "Share with email {email}" : "Zdieľať s emailom {email}",
    "Share with group" : "Zdieľať so skupinou",
    "Share in conversation" : "Zdieľať v rozhovore",
    "Share with {user} on remote server {server}" : "Sprístupniť s {user} na vzdialenom servery {server}",
    "Share with remote group" : "Zdieľať so vzdialenou skupinou",
    "Share with guest" : "Zdieľať s hosťom",
    "Update share" : "Aktualizovať zdieľanie",
    "Save share" : "Uložiť zdieľanie",
    "Read" : "Čítať",
    "Create" : "Vytvoriť",
    "Edit" : "Upraviť",
    "Share" : "Sprístupniť",
    "Delete" : "Zmazať",
    "Password field cannot be empty" : "Pole hesla nemôže byť prázdne",
    "Replace current password" : "Nahradiť aktuálne heslo",
    "Failed to generate a new token" : "Nepodarilo sa vygenerovať nový token",
    "Allow upload and editing" : "Povoliť nahrávanie a úpravy",
    "Allow editing" : "Povoliť úpravy",
    "Upload only" : "Iba nahrávať",
    "Advanced settings" : "Rozšírené nastavenia",
    "Share label" : "Štítok zdieľania",
    "Share link token" : "Zdieľať token pre odkaz",
    "Set the public share link token to something easy to remember or generate a new token. It is not recommended to use a guessable token for shares which contain sensitive information." : "Nastavte token odkazu pre verejné zdieľanie na niečo, čo sa ľahko zapamätá, alebo vygenerujte nový token. Neodporúča sa používať uhádnuteľný token pre zdieľania, ktoré obsahujú citlivé informácie.",
    "Generating…" : "Generuje sa...",
    "Generate new token" : "Vygenerovať nový token",
    "Set password" : "Nastaviť heslo",
    "Password expires {passwordExpirationTime}" : "Heslo expiruje za {passwordExpirationTime}",
    "Password expired" : "Heslo expirovalo",
    "Video verification" : "Overovanie pomocou videa",
    "Expiration date (enforced)" : "Dátum ukončenia platnosti (vynútené)",
    "Set expiration date" : "Nastaviť dátum expirácie",
    "Hide download" : "Skryť sťahovanie",
    "Allow download and sync" : "Povoliť sťahovanie a synchronizáciu",
    "Note to recipient" : "Poznámka pre príjemcu",
    "Enter a note for the share recipient" : "Zadajte poznámku pre príjemcu zdieľania",
    "Show files in grid view" : "Zobraziť zobrazenie súborov v mriežke",
    "Delete share" : "Odstrániť zdieľanie",
    "Others with access" : "Ďalší, ktorí majú prístup",
    "No other accounts with access found" : "Neboli nájdené žiadne ďalšie účty s prístupom",
    "Toggle list of others with access to this directory" : "Vypnutie/zapnutie zoznamu ostatných s prístupom k tomuto priečinku",
    "Toggle list of others with access to this file" : "Vypnutie/zapnutie zoznamu ostatných s prístupom k tomuto súboru",
    "Unable to fetch inherited shares" : "Nedarí sa získať prevzaté zdieľania",
    "Link shares" : "Zdieľané odkazy",
    "Shares" : "Sprístupnené položky",
    "Share files within your organization. Recipients who can already view the file can also use this link for easy access." : "Zdieľajte súbory v rámci vašej organizácie. Príjemcovia, ktorí už môžu súbor zobraziť, môžu tento odkaz využiť na jednoduchý prístup.",
    "Share files with others outside your organization via public links and email addresses. You can also share to {productName} accounts on other instances using their federated cloud ID." : "Zdieľajte súbory s ostatnými mimo vašej organizácie prostredníctvom verejných odkazov a emailových adries. Súbory môžete tiež zdieľať s účtami {productName} na iných inštanciách pomocou ich ID združeného cloudu",
    "Shares from apps or other sources which are not included in internal or external shares." : "Akcie z aplikácií alebo iných zdrojov, ktoré nie sú zahrnuté v interných alebo externých akciách.",
    "Type names, teams, federated cloud IDs" : "Zadajte názvy, tímy, federované ID cloudu",
    "Type names or teams" : "Zadajte mená alebo tímy",
    "Type a federated cloud ID" : "Zadajte ID združeného cloudu",
    "Type an email" : "Zadajte email",
    "Type an email or federated cloud ID" : "Zadajte e-mail alebo ID združeného cloudu",
    "Unable to load the shares list" : "Nedarí sa načítať zoznam zdieľaní",
    "Expires {relativetime}" : "Platnosť končí {relativetime}",
    "this share just expired." : "platnosť tohto zdieľania práve skončila.",
    "Shared with you by {owner}" : "Zdieľané s vami používateľom {owner}",
    "Internal shares" : "Interné zdieľania",
    "Internal shares explanation" : "Vysvetlenie interných zdieľaní",
    "External shares" : "Externé zdieľania",
    "External shares explanation" : "Vysvetlenie externých zdieľaní",
    "Additional shares" : "Ďalšie zdieľania",
    "Additional shares explanation" : "Vysvetlenie ďalších zdieľaní",
    "Link to a file" : "Odkaz na súbor",
    "_Accept share_::_Accept shares_" : ["Prijať sprístupnenú položku","Prijať sprístupnené položky","Prijať sprístupnené položky","Prijať sprístupnené položky"],
    "Open in Files" : "Otvoriť v súboroch",
    "_Reject share_::_Reject shares_" : ["Odmietnuť zdieľanie","Odmietnuť zdieľania","Odmietnuť zdieľaní","Odmietnuť zdieľania"],
    "_Restore share_::_Restore shares_" : ["Obnoviť sprístupnenú položku","Obnoviť sprístupnené položky","Obnoviť sprístupnené položky","Obnoviť sprístupnené položky"],
    "Shared" : "Sprístupnené",
    "Shared by {ownerDisplayName}" : "Zdiľané od {ownerDisplayName}",
    "Shared multiple times with different people" : "Zdieľané viackrát rôznymi ľuďmi",
    "Sharing options" : "Možnosti zdieľania",
    "Shared with others" : "Sprístupnené ostatným",
    "You do not have enough permissions to share this file." : "Nemáte dostatočné oprávnenia na zdieľanie tohto súboru.",
    "People" : "Ľudia",
    "Create file request" : "Vytvoriť žiadosť o súbor",
    "Upload files to {foldername}" : "Nahrať súbory do {foldername}",
    "Public file share" : "Verejné zdieľanie súborov",
    "Publicly shared file." : "Verejne zdieľaný súbor.",
    "No file" : "Žiadny súbor",
    "The file shared with you will show up here" : "Tu budú zobrazené súbory zdieľané s vami",
    "Public share" : "Verejné zdieľanie",
    "Publicly shared files." : "Verejne zdieľané súbory.",
    "No files" : "Žiadne súbory",
    "Files and folders shared with you will show up here" : "Tu budú zobrazené súbory a adresáre zdieľané s vami",
    "Overview of shared files." : "Prehľad zdieľaných súborov.",
    "No shares" : "Žiadne sprístupnené položky",
    "Files and folders you shared or have been shared with you will show up here" : "Súbory a priečinky, ktoré ste zdieľali alebo vám boli zdieľané, sa tu zobrazia.",
    "Shared with you" : "Vám sprístupnené",
    "List of files that are shared with you." : "Zoznam súborov, ktoré sú zdiľané s vami.",
    "Nothing shared with you yet" : "Zatiaľ vám nikto nič nesprístupnil",
    "Files and folders others shared with you will show up here" : "Tu budú zobrazené súbory a adresáre, ktoré vám ostatní nazdieľali",
    "List of files that you shared with others." : "Zoznam súborov, ktoré zdieľate s ostatnými.",
    "Nothing shared yet" : "Zatiaľ ste nič nesprístupnili",
    "Files and folders you shared will show up here" : "Tu sa zobrazia súbory a adresáre, ktoré ste sprístupnili.",
    "Shared by link" : "Sprístupnené odkazom",
    "List of files that are shared by link." : "Zoznam súborov, ktoré sú zdieľané pomocou odkazu.",
    "No shared links" : "Žiadne sprístupnené odkazy",
    "Files and folders you shared by link will show up here" : "Tu sú zobrazené súbory a adresáre, ktoré ste zdieľali prostredníctvom odkazov.",
    "File requests" : "Žiadosti o súbor",
    "List of file requests." : "Zoznam žiadostí o súbor.",
    "No file requests" : "Žiadne žiadosti o súbor",
    "File requests you have created will show up here" : "Žiadosti o súbor ktoré ste vytvorili sa zobrazia tu",
    "Deleted shares" : "Odstrániť sprístupnenia",
    "List of shares you left." : "Zoznam zdieľaných, ktoré ste opustili.",
    "No deleted shares" : "Žiadne odstránené sprístupnené položky",
    "Shares you have left will show up here" : "Zdieľané položky, ktoré ste opustili, sa zobrazia tu",
    "Pending shares" : "Čakajúce prístupy",
    "List of unapproved shares." : "Zoznam neschválených zdieľaní.",
    "No pending shares" : "Žiadne čakajúce zdieľania",
    "Shares you have received but not approved will show up here" : "Tu sa zobrazia zdieľania, ktoré ste obdržali, ale nepotvrdili",
    "Error deleting the share" : "Pri odstraňovaní zdieľania sa vyskytla chyba",
    "Error updating the share" : "Pri aktualizácii zdieľania sa vyskytla chyba",
    "File \"{path}\" has been unshared" : "Pre súbor \"{path}\" bolo zrušené zdieľanie.",
    "Folder \"{path}\" has been unshared" : "Pre adresár \"{path}\" bolo zrušený zdieľanie.",
    "Could not update share" : "Nie je možné aktualizovať zdieľanie",
    "Share saved" : "Zdieľanie uložené",
    "Share expiry date saved" : "Dátum expirácie zdieľania bolo uložené",
    "Share hide-download state saved" : "Stav skryť sťahovanie zdieľania bol uložený",
    "Share label saved" : "Štítok zdieľania bol uložený",
    "Share note for recipient saved" : "Poznámka pre príjemcu zdieľania bola uložená",
    "Share password saved" : "Heslo zdieľania bolo uložené",
    "Share permissions saved" : "Práva zdieľania boli uložené",
    "To upload files to {folder}, you need to provide your name first." : "Ak chcete nahrať súbory do {folder}, musíte najprv zadať svoje meno.",
    "Upload files to {folder}" : "Nahrať súbory do {folder}",
    "Please confirm your name to upload files to {folder}" : "Prosím, potvrďte svoje meno na nahratie súborov do {folder}.",
    "{ownerDisplayName} shared a folder with you." : "{ownerDisplayName} pre vás zdieľal adresár",
    "Names must not be empty." : "Názvy nesmú byť prázdne.",
    "Names must not start with a dot." : "Názvy nesmú začínať bodkou.",
    "\"{char}\" is not allowed inside a name." : "“{char}“ nie je povolené v názve.",
    "\"{segment}\" is a reserved name and not allowed." : "“{segment}“ je rezervovaný názov a nie je povolený.",
    "\"{extension}\" is not an allowed name." : "\"{extension}“ nie je povolený názov.",
    "Names must not end with \"{extension}\"." : "Názov nesmie končiť na \"{extension}\".",
    "Invalid name." : "Neplatný názov.",
    "Password created successfully" : "Heslo úspešne vytvorené.",
    "Error generating password from password policy" : "Chyba pri generovaní hesla podľa bezpečnostnej politiky",
    "Shared with you and the group {group} by {owner}" : "Zdieľané s vami a so skupinou {group} používateľom {owner}",
    "Shared with you and {circle} by {owner}" : "Sprístupnené vám a {circle} od {owner}",
    "Shared with you and the conversation {conversation} by {owner}" : "Sprístupnené vám a rozhovoru {conversation} od {owner}",
    "Shared with you in a conversation by {owner}" : "Sprístupnené vám vrámci rozhovoru s {owner}",
    "Share not found" : "Zdieľanie sa nenašlo",
    "Back to %s" : "Späť na %s",
    "Add to your Nextcloud" : "Pridať do svojho Nextcloud",
    "Group sharing is disabled by the administrator" : "Skupinové zdieľanie je zakázané administrátorom",
    "Public link sharing is disabled by the administrator" : "Zdieľanie pomocou verejných odkazov je zakázané administrátorom",
    "Sharing %1$s failed because the back end does not allow shares from type %2$s" : "Zdieľanie %1$s zlyhalo, backend nepodporuje typ zdieľania %2$s",
    "Sharing %s failed because the back end does not support ScienceMesh shares" : "Zdieľanie %s sa nepodarilo, pretože backend nepodporuje zdieľanie ScienceMesh miestností.",
    "Public upload disabled by the administrator" : "Verejné nahrávanie je zakázané administrátorom",
    "Tokens must contain at least 1 character and may only contain letters, numbers, or a hyphen" : "Tokeny musia obsahovať aspoň 1 znak a môžu obsahovať iba písmená, čísla alebo spojovník",
    "Name or email …" : "Meno alebo e-mail …",
    "Name, email, or Federated Cloud ID …" : "Meno, e-mail alebo ID združeného cloudu …",
    "Searching …" : "Hľadá sa …"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
