OC.L10N.register(
    "appstore",
    {
    "App store" : "App Store",
    "Apps" : "Apps",
    "App name" : "App naam",
    "Version" : "Versie",
    "Groups" : "Groepen",
    "Actions" : "Acties",
    "Show details" : "Tonen details",
    "Grid view" : "Rasterweergave",
    "Cancel" : "Annuleer",
    "Disable office suites" : "Schakel Office-suites uit",
    "installed" : "Geïnstalleerd",
    "Features" : "Mogelijkheden",
    "Learn more" : "Meer weten",
    "Daemon" : "Daemon",
    "Deploy Daemon" : "Deploy Daemon",
    "Type" : "Type",
    "Name" : "Naam",
    "Display Name" : "Weergavenaam",
    "GPUs support" : "GPUs support",
    "Compute device" : "Compute apparaat",
    "Environment variables" : "Omgevingsvariabelen",
    "Read-only" : "Alleen-lezen",
    "Confirm" : "Bevestigen",
    "Description" : "Omschrijving",
    "View in store" : "Bekijk in winkel",
    "Visit website" : "Bezoek website",
    "Usage documentation" : "Gebruiksdocumentatie",
    "Admin documentation" : "Beheerdersdocumentatie",
    "Developer documentation" : "Ontwikkelaarsdocumentatie",
    "Details" : "Details",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Deze app kan niet worden geïnstalleerd, omdat de volgende afhankelijkheden niet zijn ingevuld:",
    "Latest updated" : "Laatste update",
    "Author" : "Auteur",
    "Categories" : "Categorieën",
    "Resources" : "Bronnen",
    "Changelog" : "Wijzigingslog",
    "Supported" : "Ondersteund",
    "Featured" : "Aanbevolen",
    "This app is supported via your current Nextcloud subscription." : "Deze app wordt ondersteund via je huidige Nextcloud abonnement.",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Aanbevolen apps worden ontwikkeld door en binnen de community. Ze bieden centrale functionaliteit en zijn klaar voor productie.",
    "Community rating: {score}/5" : "Gemeenschapsscore: {score}/5",
    "No Deploy daemons configured" : "Geen Deploy Daemons geconfigureerd",
    "Register a custom one or setup from available templates" : "Registreer met de hand of gebruik een van de beschikbare templates",
    "Registered Deploy daemons list" : "Lijst van geregistreerde Deploy Daemons",
    "Default" : "Standaard",
    "Carousel" : "Caroussel",
    "Previous slide" : "Vorige dia",
    "Next slide" : "Volgende dia",
    "Choose slide to display" : "Kies dia om te tonen",
    "{index} of {total}" : "{index} van {total}",
    "Limit to groups" : "Beperk tot groepen",
    "Save" : "Opslaan",
    "Update all" : "Update alles",
    "Loading app list" : "Laden applijst",
    "Search everywhere" : "Zoek in alles",
    "Download and enable all" : "Download en alles inschakelen",
    "Could not load app discover section" : "Kon het onderdeel app ontdekken niet laden",
    "Could not render element" : "Kon het element niet verwerken",
    "Nothing to show" : "Niets te tonen",
    "Could not load section content from app store." : "Kon de inhoud van het onderdeel niet laden vanuit de app store.",
    "Loading" : "Laden",
    "Fetching the latest news…" : "Ophalen laatste nieuws...",
    "Loading categories" : "Laden categorieën",
    "Version {version}, {license}-licensed" : "Versie {version}, {license}-licensed",
    "Version {version}" : "Versie {version}",
    "Disable" : "Uitschakelen",
    "Enable" : "Inschakelen",
    "Download and enable" : "Downloaden en inschakelen",
    "Rate the app" : "Beoordeel de app",
    "Report a bug" : "Rapporteer een fout",
    "Remove" : "Verwijderen",
    "Update to {version}" : "Update naar {version}",
    "Discover" : "Ontdekken",
    "Your apps" : "Jouw apps",
    "Active apps" : "Ingeschakelde apps",
    "Disabled apps" : "Uitgeschakelde apps",
    "Updates" : "Updates",
    "App bundles" : "App bundels",
    "Featured apps" : "Aanbevolen apps",
    "Supported apps" : "Ondersteunde apps",
    "Search results" : "Zoekresultaten",
    "Open source" : "Open source",
    "Best performance" : "Beste prestaties",
    "Limited ODF compatibility" : "Gelimiteerde ODF compatibiliteit",
    "Best Microsoft compatibility" : "Beste Microsoft compatibiliteit",
    "Best Nextcloud integration" : "Beste Nextcloud integratie",
    "Good performance" : "Goede prestaties",
    "An error occurred during the request. Unable to proceed." : "Er is een fout opgetreden tijdens het verzoek. Kan niet doorgaan."
},
"nplurals=2; plural=(n != 1);");
