OC.L10N.register(
    "app_api",
    {
    "Daemon config not found" : "Daemon-Konfiguration nicht gefunden",
    "Error starting install of ExApp" : "Fehler beim Starten der Installation von ExApp",
    "ExApp failed to register, check the NC logs" : "ExApp konnte nicht registriert werden, NC-Protokolle überprüfen.",
    "ExApp not found, failed to get status" : "ExApp nicht gefunden, Status konnte nicht abgerufen werden",
    "Error adding Docker registry" : "Fehler beim Hinzufügen der Docker-Registry",
    "Error removing Docker registry" : "Fehler beim Entfernen der Docker-Registry",
    "This app is not installed from the AppStore. No extra information available. Only enable/disable and remove actions are allowed." : "Diese App ist nicht aus dem App-Store installiert. Keine weiteren Informationen verfügbar. Nur die Aktionen Aktivieren/Deaktivieren und Entfernen sind zulässig.",
    "Could not perform installation of ExApp" : "ExApp konnte nicht installiert werden",
    "Failed to enable ExApp" : "Aktivieren von ExApp fehlgeschlagen",
    "Failed to disable ExApp" : "Deaktivieren von ExApp fehlgeschlagen",
    "Could not update ExApp" : "ExApp konnte nicht aktualisiert werden",
    "Error starting update of ExApp" : "Fehler beim Starten eines Updates von ExApp",
    "Could not perform update of ExApp" : "Update von ExApp konnte nicht durchgeführt werden",
    "ExApp not found, failed to get logs" : "ExApp nicht gefunden, Protokolle konnten nicht abgerufen werden",
    "Failed to get container logs. Note: Downloading Docker container works only for containers with the json-file or journald logging driver. Error: %s" : "Containerprotokolle konnten nicht abgerufen werden. Hinweis: Das Herunterladen des Docker-Containers funktioniert nur für Container mit der JSON-Datei oder dem Journald-Protokollierungstreiber. Fehler: %s",
    "ExApp not found, failed to get deploy options" : "ExApp nicht gefunden, Bereitstellungsoptionen konnten nicht abgerufen werden",
    "AppAPI authentication failed" : "AppAPI-Authentifizierung fehlgeschlagen",
    "AppAPI ExApp notifier" : "AppAPI ExApp Benachrichtigung",
    "AppAPI" : "AppAPI",
    "AI Integration Team" : "KI Integrations-Team",
    "ExApps Settings" : "ExApp-Einstellungen",
    "AppAPI deploy daemon" : "AppAPI-Bereitstellungs-Daemon",
    "AppAPI default deploy daemon is not set. Please register a default deploy daemon in the settings to install External Apps (Ex-Apps)." : "Der Standard-Deploy-Daemon von AppAPI ist nicht eingerichtet. Bitte in den Einstellungen einen Standard-Deploy-Daemon registrieren, um externe Apps (Ex-Apps) zu installieren.",
    "AppAPI default deploy daemon \"%s\" is not accessible. Please check the daemon configuration." : "Auf den AppAPI-Standardbereitstellungs-Daemon \"%s\" kann nicht zugegriffen werden. Bitte die Daemon-Konfiguration überprüfen.",
    "The AppAPI default deploy daemon is not using HaRP. Please consider switching to HaRP for better performance." : "Der AppAPI-Standardbereitstellungsdaemon verwendet nicht HaRP. Bitte für eine bessere Leistung einen Wechsel zu HaRP in Erwägung ziehen.",
    "AppAPI HaRP version check" : "AppAPI HaRP Versionsüberprüfung",
    "Could not retrieve HaRP version from daemon \"%s\"" : "HaRP-Version konnte nicht vom Daemon \"%s\" abgerufen werden",
    "HaRP version for daemon \"%s\" is \"%s\", which is too old. The minimum required version is \"%s\". Please update the daemon to the latest version." : "HaRP-Version für den Daemon \"%s\" ist \"%s\" und damit zu alt. Die mindestens erforderliche Version ist \"%s\". Bitte den Daemon auf die neueste Version aktualisieren.",
    "Failed to check HaRP version for daemon \"%s\": %s" : "HaRP-Version des Daemons \"%s\" konnte nicht überprüft werden: %s",
    "Nextcloud AppAPI" : "Nextcloud AppAPI",
    "### What is AppAPI?\n\nAppAPI is the Nextcloud component that enables **External Apps (ExApps)**.\nExApps are apps whose backend runs **outside** the Nextcloud PHP process (usually as a Docker container), while still integrating with your Nextcloud users, permissions and web UI.\n\n### Do I need it?\n\nNo. If you do not plan to install External Apps, you can disable AppAPI.\n\nIf AppAPI is enabled without a configured Deploy Daemon, Nextcloud will show the info message:\n\n> \"AppAPI default deploy daemon is not set …\"\n\nThat warning means: \"External Apps are not configured yet\".\n\nYou can either disable AppAPI, or configure a Deploy Daemon (see below).\n\n### How do External Apps get deployed?\n\nA **Deploy Daemon** is the service Nextcloud talks to in order to install, start, stop and reach ExApps.\n\nTwo options are available:\n\n- **HaRP** (recommended for Nextcloud 32+) — a high-performance reverse proxy with FRP tunneling\n- **Docker Socket Proxy** (legacy) — scheduled for removal in Nextcloud 35\n\nSee the [admin documentation](https://docs.nextcloud.com/server/latest/admin_manual/exapps_management/DeployConfigurations.html) for setup instructions." : "### Was ist AppAPI?\n\nAppAPI ist die Nextcloud-Komponente, die **Externe Apps (ExApps)** ermöglicht.\nExApps sind Apps, deren Backend **außerhalb** des Nextcloud-PHP-Prozesses (normalerweise als Docker-Container) ausgeführt wird, und trotzdem in die Nextcloud-Konten, -Berechtigungen und -Web-Benutzeroberfläche integriert ist.\n\n### Benötige ich es?\n\nNein. Wenn du nicht vorhast, externe Apps zu installieren, kannst du AppAPI deaktivieren.\n\nWenn AppAPI ohne konfigurierten Deploy-Daemon aktiviert ist, zeigt Nextcloud folgende Meldung an:\n\n> \"AppAPI-Standardbereitstellungs-Daemon ist nicht festgelegt …\"\n\nDiese bedeutet: \"Externe Apps sind noch nicht konfiguriert.\"\n\nDu kannst entweder AppAPI deaktivieren oder einen Deploy-Daemon einrichten (siehe unten).\n\n### Wie werden externe Apps bereitgestellt?\n\nEin **Deploy Daemon** ist der Dienst, mit dem Nextcloud kommuniziert, um ExApps zu installieren, zu starten, zu stoppen und zu erreichen.\n\nEs stehen zwei Optionen zur Verfügung:\n\n- **HaRP** (empfohlen für Nextcloud 32+) — ein leistungsstarker Reverse-Proxy mit FRP-Tunneling\n- **Docker Socket Proxy** (Legacy) — Entfernung in Nextcloud 35 geplant\n\nAnleitungen zur Einrichtung finden sich in der [Administrations-Dokumentation](https://docs.nextcloud.com/server/latest/admin_manual/exapps_management/DeployConfigurations.html).",
    "External Apps management" : "Externe Apps-Verwaltung",
    "Admin options saved" : "Administrationseinstellungen gespeichert",
    "Failed to save admin options" : "Administrationseinstellungen konnten nicht gespeichert werden",
    "The AppAPI Project is an exciting initiative that aims to revolutionize the way applications are developed for Nextcloud through the use of docker containers. Allowing for greater programming language choice and allowing computationally expensive tasks to be offloaded to a different server." : "Das AppAPI-Projekt ist eine spannende Initiative, die darauf abzielt, die Art und Weise, wie Anwendungen für Nextcloud entwickelt werden, durch den Einsatz von Docker-Containern zu revolutionieren. Es ermöglicht eine größere Auswahl an Programmiersprachen sowie das Auslagern rechenintensiver Aufgaben auf einen anderen Server.",
    "Deploy daemons" : "Bereitstellungsdaemons",
    "A deploy daemon (DaemonConfig) is an ExApps orchestration daemon." : "Ein Deploy-Daemon (DaemonConfig) ist ein ExApps Orchestrierungs-Daemon.",
    "Deploy daemons. A deploy daemon (DaemonConfig) is an ExApps orchestration daemon." : "Deploy Daemons. Deploy-Daemon (DaemonConfig) ist ein ExApps Orchestrierungs-Daemon.",
    "Default deploy daemon is not accessible. Please check its configuration" : "Standard-Deploy-Daemon ist nicht zugänglich. Bitte dessen Konfiguration überprüfen",
    "ExApp init timeout (minutes)" : "ExApp Initialisierungs-Timeout (Minuten)",
    "ExApp initialization process timeout after which AppAPI will mark it as failed" : "ExApp Initialisierungsprozess-Timeout, nach der AppAPI ihn als fehlgeschlagen markiert",
    "ExApp init timeout" : "ExApp Initialisierungs-Timeout",
    "ExApp container restart policy" : "ExApp Container Neustartrichtlinie",
    "Choose the container restart policy, e.g. 'always' to ensure ExApps will be running after a daemon server reboot" : "Bitte die Neustartrichtlinie für den Container auswählen, z. B. 'immer', um sicherzustellen, dass ExApps nach einem Neustart des Daemon-Servers ausgeführt werden",
    "This settings changes are effective only for newly created containers" : "Diese Einstellungsänderungen gelten nur für neu erstellte Container.",
    "Deploy daemon deletion confirmation" : "Bestätigung für Löschen des Bereitstellungsdaemons",
    "Are you sure you want delete the \"{name}\" deploy daemon?" : "Soll der Bereitstellungsdaemon \"{name}\" gelöscht werden?",
    "Remove all ExApps installed on this daemon" : "Alle auf diesem Daemon installierten ExApps entfernen",
    "Cancel" : "Abbrechen",
    "Delete" : "Löschen",
    "A \"manual-install\" deploy daemon cannot be set as default" : "Ein \"manual-install\" Bereitstellungsdaemon kann nicht als Standard festgelegt werden",
    "Failed to save admin settings. Check the logs" : "Administrationseinstellungen konnten nicht gespeichert werden. Bitte die Protokolle überprüfen.",
    "Password confirmation failed" : "Fehler bei der Passwortbestätigung",
    "Default" : "Standard",
    "Set as default" : "Als Standard festlegen",
    "Test deploy" : "Bereitstellung testen",
    "Docker registries" : "Docker-Registries",
    "Edit" : "Bearbeiten",
    "Daemon connection successful" : "Verbindung zum Daemon erfolgreich",
    "Failed to connect to the daemon. Check the logs" : "Verbindung zum Daemon fehlgeschlagen. Bitte die Protokolle überprüfen.",
    "Failed to check connection to the daemon. Check the logs" : "Die Verbindung zum Daemon konnte nicht geprüft werden. Bitte die Protokolle überprüfen.",
    "Unlimited" : "Unbegrenzt",
    "{size} GiB" : "{size} GiB",
    "{size} MiB" : "{size} MiB",
    "_{n} CPU_::_{n} CPUs_" : ["{n} CPU","{n} CPUs"],
    "Deploy daemon configuration" : "Konfiguration des Bereitstellungsdaemons",
    "Deploy daemon configuration details" : "Konfigurationsdetails des Bereitstellungsdaemons",
    "Deploy daemon" : "Bereitstellungsdaemon",
    "Default daemon. ExApps will be installed on it" : "Standard-Daemon. ExApps werden hierauf installiert.",
    "The \"Manual install\" daemon is usually used for development. It cannot be set as the default daemon." : "Der \"manual-install\" Daemon wird normalerweise für die Entwicklung verwendet. Er kann nicht als Standard-Daemon festgelegt werden.",
    "Direct Docker access (Docker Socket Proxy) is deprecated and will be removed in Nextcloud 35. Please migrate to a HaRP-based daemon." : "Der direkte Docker-Zugriff (Docker Socket Proxy) ist veraltet und wird in Nextcloud 35 entfernt. Bitte zu einem HaRP-basierten Daemon migrieren.",
    "This is a Kubernetes daemon managed via CLI." : "Dies ist ein Kubernetes-Dämon, der über die Kommandozeile verwaltet wird.",
    "ExApps installed" : "ExApps installiert",
    "Name" : "Name",
    "Protocol" : "Protokoll",
    "Host" : "Host",
    "ExApp direct communication (FRP disabled)" : "Direkte ExApp-Kommunikation (FRP deaktiviert)",
    "Kubernetes settings" : "Kubernetes Einstellungen",
    "Expose type" : "Typ anzeigen",
    "Node port" : "Node-Port",
    "Upstream host" : "Upstream-Host",
    "External traffic policy" : "Richtlinie für externen Datenverkehr",
    "Load balancer IP" : "Load-Balancer-IP",
    "Node address type" : "Node-Adresstyp",
    "Deploy options" : "Bereitstellungsoptionen",
    "Docker network" : "Docker-Netzwerk",
    "Nextcloud URL" : "Nextcloud-URL",
    "HaProxy password" : "HaProxy-Passwort",
    "(not set)" : "(Nicht eingestellt)",
    "GPU support" : "GPU-Unterstützung",
    "Computation device" : "Rechengerät",
    "Memory limit" : "Speicherlimit",
    "CPU limit" : "CPU-Limit",
    "Additional options" : "Zusatzoptionen",
    "Check connection" : "Verbindung prüfen",
    "Registered Deploy daemons list" : "Liste von registrierten Bereitstellungsdaemons",
    "No Deploy daemons are registered" : "Es sind keine Bereitstellungs-Daemons registriert.",
    "Register a custom one or configure one from the available templates" : "Eine benutzerdefinierte Vorlage registrieren oder aus einer der verfügbaren Vorlagen einrichten",
    "Register daemon" : "Daemon registrieren",
    "Register ExApp in Nextcloud" : "ExApp in Nextcloud registrieren",
    "Check if the ExApp is registered in Nextcloud before deployment" : "Überprüfe vor der Bereitstellung, ob die ExApp in Nextcloud registriert ist",
    "Image pull" : "Image abrufen",
    "Check if the image is successfully pulled" : "Überprüfe, ob das Image abgerufen wurde",
    "Container started" : "Container gestartet",
    "Check if the image successfully pulled and container is created and started" : "Überprüfe, ob das Image abgerufen und der Container erstellt und gestartet wurde",
    "Heartbeat" : "Herzschlag",
    "Check for the heartbeat is finished and healthy" : "Überprüfe, ob der Herzschlag vollendet und gesund ist",
    "Init step" : "Initialisierungsphase",
    "Wait for initialization step to finish" : "Warte bis die Initialisierungsphase abgeschlossen ist",
    "Enabled" : "Aktiviert",
    "Check if ExApp successfully handled the enabled event and registered all stuff properly" : "Überprüfen, ob ExApp das aktivierte Ereignis verarbeitet und alles ordnungsgemäß registriert hat",
    "Only if ExApp container is preset" : "Nur wenn ExApp-Container voreingestellt ist",
    "Deploy test passed successfully!" : "Bereitstellungstest bestanden!",
    "Deploy test failed at step \"{step}\"" : "Der Bereitstellungstest ist bei Schritt \"{step}\" fehlgeschlagen",
    "AppAPI will try to install small skeleton ExApp to check that the daemon is configured correctly and the deployment steps are successful." : "AppAPI wird versuchen, ein kleines ExApp-Skelett zu installieren, um zu überprüfen, ob der Daemon richtig konfiguriert ist und die Bereitstellungsschritte erfolgreich sind.",
    "The following deploy test checks must succeed:" : "Die folgenden Bereitstellungstests müssen bestanden werden:",
    "More information" : "Weitere Informationen",
    "Download ExApp logs" : "ExApps-Protokolle herunterladen",
    "Remove the test ExApp" : "Die Test-ExApp entfernen",
    "Start the deploy test" : "Den Bereitstellungstest starten",
    "Stop the deploy test" : "Den Bereitstellungstest anhalten",
    "The test ExApp is unregistered and its container is removed on \"Stop the deploy test\"" : "Die Test-ExApp ist nicht registriert und der Container wird bei \"Den Bereitstellungstest anhalten\" entfernt",
    "Please enter a registry domain" : "Bitte eine Registry-Domäne eingeben",
    "\"From\" cannot be \"local\"" : "\"Von\" darf nicht \"lokal\" sein",
    "This registry mapping already exists" : "Diese Registry-Zuordnung ist bereits vorhanden",
    "\"From\" and \"To\" cannot be the same" : "\"Von\" und \"An\" dürfen nicht identisch sein",
    "Docker registry mapping added" : "Docker Registry-Zuordnung hinzugefügt",
    "Error adding Docker registry mapping" : "Fehler beim Hinzufügen der Docker Registry-Zuordnung",
    "Docker registry mapping removed" : "Docker Registry-Zuordnung entfernt",
    "Error removing Docker registry mapping" : "Fehler beim Entfernen der Docker Registry-Zuordnung",
    "Override Docker registries" : "Docker-Registries überschreiben",
    "Configure Docker registry override mappings for the selected daemon." : "Docker-Registry-Überschreibungszuordnungen für den ausgewählten Daemon konfigurieren.",
    "The matching source registry in ExApp info.xml will be overwritten during deployment (image pull step)." : "Das passende Quellregister in ExApp info.xml wird während der Bereitstellung (Image-Pull-Schritt) überschrieben.",
    "This is useful if you want to use a custom Docker registry, for example, to use a private Docker registry, or to use a different Docker registry for testing." : "Dies ist nützlich, um beispielsweise ein benutzerdefiniertes Docker-Register zu verwenden, um ein privates Docker-Register zu verwenden oder ein anderes Docker-Register zum Testen zu verwenden.",
    "Image pull will be skipped" : "Imageabruf wird übersprungen",
    "Remove" : "Entfernen",
    "No custom Docker registries are registered" : "Es sind keine benutzerdefinierten Docker-Register registriert",
    "Add registry override mapping" : "Registry-Überschreibungszuordnung hinzufügen",
    "From" : "Von",
    "registry URL (e.g. ghcr.io)" : "Registry-URL (z.B. ghcr.io)",
    "To" : "Bis",
    "registry URL (e.g. docker.io)" : "Registry-URL (z.B. docker.io)",
    "Add" : "Hinzufügen",
    "Hostname used by Nextcloud to access the ExApps" : "Hostname der von Nextcloud zum Zugriff auf ExApps verwendet wird",
    "The hostname (and port) at which the {name} is available. This does not need to be a public host, just a host accessible by the Nextcloud server, e.g. {host}." : "Der Hostname (und Port), unter dem {name} verfügbar ist. Dies muss kein öffentlicher Host sein, sondern nur ein Host, auf den der Nextcloud-Server zugreifen kann, z. B. {host}.",
    "The hostname (and port) or path at which the {name} is available. This does not need to be a public host, just a host accessible by the Nextcloud server. It can also be the path to the Docker socket. (e.g. nextcloud-appapi-dsp:2375, /var/run/docker.sock)" : "Der Hostname (und Port) oder Pfad, unter dem {name} verfügbar ist. Dies muss kein öffentlicher Host sein, sondern nur ein Host, auf den der Nextcloud-Server zugreifen kann. Es kann auch ein Pfad zum Docker-Socket sein. (z. B. nextcloud-appapi-dsp:2375, /var/run/docker.sock)",
    "A daemon with this name already exists" : "Ein Daemon mit diesem Namen existiert bereits",
    "The secret key for the HaRP container communication (HP_SHARED_KEY)." : "Der geheime Schlüssel für die HaRP-Containerkommunikation (HP_SHARED_KEY).",
    "AppAPI Docker Socket Proxy authentication password" : "AppAPI Docker Socket Proxy Authentifizierungs-Passwort",
    "Changes are only effective for newly installed ExApps. For existing ExApps, the Docker containers should be recreated to apply the new settings values." : "Änderungen gelten nur für neu installierte ExApps. Bei bestehenden ExApps müssen die Docker-Container neu erstellt werden, damit die neuen Einstellungswerte übernommen werden.",
    "The Docker network that the deployed ExApps will use." : "Das Docker-Netzwerk, das die bereitgestellten ExApps verwenden werden.",
    "The URL should start with http:// or https://" : "Die URL muss mit http:// oder https:// beginnen",
    "For a HTTPS daemon, the Nextcloud URL should be HTTPS" : "Für einen HTTPS-Daemon muss die Nextcloud-URL HTTPS sein",
    "All available GPU devices on the daemon host need to be enabled in ExApp containers by Docker." : "Alle verfügbaren GPU-Geräte auf dem Daemon-Host müssen von Docker in ExApp-Containern aktiviert werden.",
    "DaemonConfig successfully registered" : "Daemonkonfiguration registriert",
    "Failed to register DaemonConfig. Check the logs" : "Daemonkonfiguration konnte nicht registriert werden. Prüfen Sie die Protokolle.",
    "DaemonConfig successfully updated" : "DaemonConfig aktualisiert",
    "Failed to update DaemonConfig. Check the logs" : "DaemonConfig konnte nicht aktualisiert werden. Überprüfe die Protokolle.",
    "Failed to connect to Daemon. Check the logs" : "Verbindung zum Daemon fehlgeschlagen. Prüfen Sie die Protokolle.",
    "Failed to check connection to Daemon. Check the logs" : "Die Verbindung zum Daemon konnte nicht geprüft werden. Prüfen Sie die Protokolle.",
    "Edit the deploy daemon" : "Den Bereitstellungs-Daemon bearbeiten",
    "Register a new deploy daemon" : "Einen neuen Bereitstellungsdaemon registrieren",
    "Daemon configuration template" : "Daemon-Konfigurationsvorlage",
    "Select a daemon configuration template" : "Eine Daemon-Konfigurationsvorlage auswählen",
    "Daemon registration form" : "Formular zur Registrierung des Daemons",
    "Unique deploy daemon name" : "Einzigartiger Bereitstellungs-Daemonname",
    "Unique deploy Daemon name" : "Einzigartiger Bereitstellungs-Daemonname",
    "Display name" : "Anzeigename",
    "Deployment method" : "Bereitstellungsmethode",
    "Select the daemon deploy method" : "Daemon-Bereitstellungsmethode auswählen",
    "HaRP host" : "HaRP-Host",
    "Daemon host" : "Daemon-Host",
    "HaRP shared key" : "Gemeinsamer HaRP-Schlüssel",
    "The password must be at least 12 characters long" : "Das Passwort muss mindestens 12 Zeichen lang sein",
    "Set this daemon as the default one" : "Diesen Daemon als Standard festlegen",
    "Set as the default daemon" : "Als Standard-Daemon festlegen",
    "Enable HTTPS" : "HTTPS aktivieren",
    "Show deploy options" : "Bereitstellungsoptionen anzeigen",
    "Hide deploy options" : "Bereitstellungsoptionen verbergen",
    "Enable HaRP" : "HaRP aktivieren",
    "FRP server address" : "FRP-Serveradresse",
    "The address (host:port) of the FRP server that should be reachable by the ExApp in the network defined in the 'Docker network' section." : "Die Adresse (Host:Port) des FRP-Servers, die von der ExApp in dem im Abschnitt 'Docker-Netzwerk' definierten Netzwerk erreichbar sein sollte.",
    "Docker socket proxy port" : "Docker-Socket-Proxy-Port",
    "The port in HaRP which the Docker socket proxy connects to. This should be exposed but for the in-built one, it is not required to be exposed or changed." : "Der Port in HaRP, mit dem der Docker-Socket-Proxy eine Verbindung herstellt. Dieser sollte angegeben werden, für den integrierten Port ist dies jedoch nicht erforderlich.",
    "Disable FRP" : "FRP deaktivieren",
    "FRP is always disabled for the All-in-One setup." : "FRP ist für das All-in-One-Setup immer deaktiviert.",
    "Flag for advanced setups only. Disables the FRP tunnel between ExApps and HaRP." : "Flag nur für erweiterte Setups. Deaktiviert den FRP-Tunnel zwischen ExApps und HaRP.",
    "Docker network for ex-app deployment must be defined" : "Docker-Netzwerk für Ex-App-Bereitstellung muss definiert werden",
    "Compute device" : "Compute-Gerät",
    "Memory limit (in MiB)" : "Speicherlimit (in MiB)",
    "Must be a positive integer" : "Muss eine positive Ganzzahl sein",
    "Maximum amount of memory that the ExApp container can use in mebibytes" : "Maximaler Speicher in Mebibyte, den der ExApp-Container verwenden darf",
    "CPU limit as decimal value" : "CPU-Limit als Dezimalwert",
    "Must be a positive number" : "Muss eine positive Zahl sein",
    "Maximum number of CPU cores that the ExApp container can use (e.g. 0.5 for half a core, 2 for two cores)" : "Maximale Anzahl an CPU-Kernen, die der ExApp-Container verwenden darf (z. B. 0,5 für einen halben Kern, 2 für zwei Kerne)",
    "Add additional option" : "Zusätzliche Option hinzufügen",
    "Option key (unique)" : "Optionsschlüssel (eindeutig)",
    "Option key (unique, e.g. my_key)" : "Optionsschlüssel (eindeutig, z. B. mein_Schlüssel)",
    "Option key is required" : "Optionsschlüssel ist erforderlich",
    "Option value" : "Optionswert",
    "Option value is required" : "Optionswert ist erforderlich",
    "Confirm" : "Bestätigen",
    "Save" : "Speichern",
    "Register" : "Registrieren",
    "External Apps" : "Externe Apps",
    "### Boost your Nextcloud with AppAPI and its specially designed applications.\n\n\nThe AppAPI is a project within the Nextcloud ecosystem designed to streamline and enhance the process of\napplication development, deployment, and management.\n\nIt introduces a new methodology that allows developers to create\napplications using a variety of programming languages, not limited to PHP, which was traditionally used in Nextcloud development.\n\n### Bundled App\n\n**Starting with Nextcloud 30.0.1, this application is included in the default Nextcloud package.**\n\n### Support\n\nWe appreciate any support for this project:\n\n- ⭐ Star our work on GitHub\n- ❗ Create an Issue or feature request\n- 💁 Resolve an Issue and create a Pull Request\n- 🧑‍💻 Develop your own application using AppAPI\n\nWe are genuinely excited about the future of the AppAPI project and its potential to transform\nthe way applications are developed and experienced within Nextcloud.\n\nAs we embark on this journey, we warmly invite you - developers, thinkers, creators, and visionaries -\nto join us in shaping a more versatile, stable, and secure app landscape.\n\n*Your insights, suggestions, and contributions are invaluable to us.*" : "### Verbessere deine Nextcloud mit AppAPI und hierfür speziell entwickelte Anwendungen.\n\n\nAppAPI ist ein Projekt innerhalb des Nextcloud-Ökosystems, das den Prozess der\nAnwendungsentwicklung, -bereitstellung und -verwaltung rationalisieren und verbessern soll.\n\nEs wird eine neue Methodik eingeführt, die es Entwicklern ermöglicht,\nAnwendungen nicht nur mit PHP, das traditionell in der Nextcloud-Entwicklung\nverwendet wurde, sondern mit einer Vielzahl von Programmiersprachen zu erstellen, .\n### Gebündelte App\n\n**Ab Nextcloud 30.0.1 ist diese Anwendung im Standard-Nextcloud-Paket enthalten.**\n\n### Support\n\nWir freuen uns über jede Unterstützung für dieses Projekt:\n\n- ⭐ Markiere unsere Arbeit auf GitHub\n- ❗ Erstelle ein Problem oder eine Funktionsanfrage\n- 💁 Löse ein Problem und erstelle einen Pull-Request\n- 🧑‍💻 Entwickele deine eigene Anwendung mit AppAPI\n\nWir sind wirklich gespannt auf die Zukunft des AppAPI-Projekts und sein Potenzial,\ndie Art und Weise, wie Anwendungen innerhalb von Nextcloud entwickelt und erlebt werden, zu verändern.\n\nWährend wir uns auf diese Reise begeben, laden wir dich – Entwickler, Denker, Schöpfer und Visionäre – herzlich ein,\nmit uns gemeinsam eine vielseitigere, stabilere und sicherere App-Landschaft zu gestalten.\n\n*Deine Erkenntnisse, Vorschläge und Beiträge sind für uns von unschätzbarem Wert.*",
    "The AppAPI Project is an exciting initiative that aims to revolutionize the way applications are developed for Nextcloud." : "Das AppAPI-Projekt ist eine innovative Initiative, die darauf abzielt, die Art und Weise zu revolutionieren, wie Anwendungen für Nextcloud entwickelt werden.",
    "Deploy Daemons" : "Daemons bereitstellen",
    "Deploy Daemon (DaemonConfig) is an ExApps orchestration daemon." : "Deploy-Daemon (DaemonConfig) ist ein ExApps Orchestrierungs-Daemon.",
    "Deploy Daemons. Deploy Daemon (DaemonConfig) is an ExApps orchestration daemon." : "Deploy Daemons. Deploy-Daemon (DaemonConfig) ist ein ExApps Orchestrierungs-Daemon.",
    "Default Deploy Daemon is not accessible. Please verify its configuration" : "Standard-Deploy-Daemon ist nicht zugänglich. Bitte überprüfe seine Konfiguration.",
    "Specify container restart policy, e.g. 'always' to ensure ExApp running after daemon server reboot" : "Gib die Neustartrichtlinie für den Container an, z. B. 'immer', um sicherzustellen, dass ExApp nach einem Neustart des Daemon-Servers ausgeführt wird",
    "This settings changes are reflected only for newly created containers" : "Diese Einstellungen werden nur für neu erstellte Container übernommen",
    "{license}-licensed" : "{license}-Lizenziert",
    "Update to {version}" : "Aktualisieren auf {version}",
    "Delete data on remove" : "Daten beim Entfernen löschen",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Für diese App wurde keine untere Versionsgrenze für Nextcloud gesetzt. Dies wird zukünftig als Fehler behandelt.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Für diese App wurde keine obere Versionsgrenze für Nextcloud gesetzt. Dies wird zukünftig als Fehler behandelt.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Diese App kann nicht installiert werden, weil die folgenden Abhängigkeiten nicht erfüllt sind:",
    "View in store" : "Im Store anzeigen",
    "Visit website" : "Webseite besuchen",
    "Report a bug" : "Einen technischen Fehler melden",
    "User documentation" : "Benutzer-Dokumentation",
    "Admin documentation" : "Dokumentation für die Administration",
    "Developer documentation" : "Entwickler-Dokumentation",
    "This app is not registered in AppStore. No extra information available. Only enable/disable and remove actions are allowed." : "Diese App ist nicht im App-Store gelistet. Es sind keine weiteren Informationen verfügbar. Nur erlauben/deaktivieren und Aktionen entfernen ist zulässig.",
    "This app is supported via your current Nextcloud subscription." : "Diese App wird von deinem aktuellen Nextcloud-Abonnement unterstützt.",
    "Supported" : "Unterstützt",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Vorgestellte Apps werden von und innerhalb der Nextcloud-Community entwickelt. Sie stellen zentrale Funktionen bereit und sind für den produktiven Einsatz geeignet.",
    "Featured" : "Vorgestellt",
    "Update to {update}" : "Aktualisieren auf {update}",
    "All ExApps are up-to-date." : "Alle ExApps sind auf dem neuesten Stand.",
    "Default Deploy daemon is not accessible" : "Der Standard-Deploy-Daemon ist nicht zugänglich",
    "Icon" : "Symbol",
    "Version" : "Version",
    "Daemon" : "Daemon",
    "Level" : "Stufe",
    "Actions" : "Aktionen",
    "Results from other categories" : "Ergebnisse aus anderen Kategorien",
    "No apps found" : "Keine Apps gefunden",
    "_%n ExApp has an update available_::_%n apps have an update available_" : ["%n ExApp hat ein Update verfügbar.","Für %n Apps ist ein Update verfügbar"],
    "_Update_::_Update all_" : ["Aktualisieren","Alle aktualisieren"],
    "Deploy Daemon" : "Daemon bereitstellen",
    "Type" : "Typ",
    "Display Name" : "Anzeigename",
    "GPUs support" : "GPUs Unterstützung",
    "Are you sure you want delete Deploy Daemon" : "Möchtest du wirklich den Deploy Daemon löschen?",
    "All ExApps on this daemon will be removed" : "Alle ExApps auf diesem Daemon werden entfernt.",
    "All ExApps installed on this daemon will be removed" : "Alle ExApps auf diesem Daemon werden entfernt.",
    "\"manual-install\" Deploy Daemon cannot be set as default" : "\"manual-install\" Bereitstellungsdaemon kann nicht als Standard festgelegt werden",
    "Failed to save admin options. Check the logs" : "Administrationseinstellungen konnten nicht gespeichert werden. Prüfen Sie die Protokolle.",
    "Deploy daemon config details" : "Daemon-Konfigurationsdetails bereitstellen",
    "Manual install daemon usually used for development. It cannot be set as default daemon." : "Manueller installierter Daemon, der normalerweise für die Entwicklung verwendet wird. Er kann nicht als Standard-Daemon festgelegt werden.",
    "Deploy config" : "Bereitstellungseinstellungen",
    "Verify connection" : "Verbindung überprüfen",
    "No Deploy daemons configured" : "Keine Bereitstellungsdämonen konfiguriert",
    "Register a custom one or setup from available templates" : "Registriere eine benutzerdefinierte Vorlage oder richte sie aus verfügbaren Vorlagen ein",
    "Register Daemon" : "Daemon registrieren",
    "AppAPI will try to install small skeleton ExApp to verify Daemon configured correctly and deployment steps are passing." : "AppAPI wird versuchen, ein kleines ExApp-Skelett zu installieren, um zu überprüfen, ob der Hintergrunddienst richtig konfiguriert ist und die Bereitstellungsschritte erfolgreich sind.",
    "The following Deploy test checks must be passed to succeed:" : "Die folgenden Tests müssen für eine erfolgreiche Bereitstellung bestanden werden:",
    "More info" : "Weitere Infos",
    "Remove test ExApp" : "Test-ExApp entfernen",
    "Start Deploy test" : "Bereitstellungstest starten",
    "Stop Deploy test" : "Bereitstellungstest anhalten",
    "ExApp is unregistered and container is removed on \"Stop deploy test\"" : "ExApp ist nicht registriert und der Container wird bei Auswahl von \"Bereitstellungstest beenden\" entfernt.",
    "Hostname to access ExApps" : "Hostname zum Zugriff auf ExApps",
    "Hostname or path to access Docker daemon (e.g. nextcloud-appapi-dsp:2375, /var/run/docker.sock)" : "Hostname oder Pfad zum Zugriff auf den Docker-Daemon (z.B. nextcloud-appapi-dsp:2375, /var/run/docker.sock)",
    "Daemon with this name already exists" : "Ein Daemon mit diesem Namen existiert bereits",
    "Password must be at least 12 characters long" : "Das Passwort muss mindestens 12 Zeichen lang sein",
    "With https enabled network is set to host" : "Bei aktiviertem https ist das Netzwerk auf Host eingestellt",
    "Changes would be applied only for newly installed ExApps. For existing ExApps, Docker containers should be recreated." : "Änderungen werden nur für neu installierte ExApps übernommen. Für vorhandene ExApps sollten die Docker-Container neu erstellt werden.",
    "URL should start with http:// or https://" : "Die URL muss mit http:// oder https:// beginnen",
    "For HTTPS daemon, Nextcloud URL should be HTTPS" : "Für den HTTPS-Daemon sollte die Nextcloud-URL HTTPS sein",
    "All available GPU devices on daemon host will be requested to be enabled in ExApp containers by Docker." : "Alle verfügbaren GPU-Geräte auf dem Daemon-Host werden von Docker aufgefordert, in ExApp-Containern aktiviert zu werden.",
    "Edit Deploy Daemon" : "Bereitstellungs-Daemon bearbeiten",
    "Register Deploy Daemon" : "Bereitstellungsdaemon registrieren",
    "Select daemon configuration template" : "Daemon-Konfigurationsvorlage auswählen",
    "Unique Deploy Daemon Name" : "Einzigartiger Bereitstellungs-Daemonname",
    "Select daemon deploy method" : "Daemon für Bereitstellungsmethode auswählen",
    "Set daemon as default" : "Daemon als Standard auswählen",
    "Set as default daemon" : "Als Standard-Daemon festlegen",
    "Enable https" : "https aktivieren",
    "Show deploy config" : "Bereitstellungseinstellungen anzeigen",
    "Hide deploy config" : "Bereitstellungseinstellungen ausblenden",
    "Network" : "Netzwerk",
    "Docker network name" : "Docker-Netzwerkname",
    "Additional option" : "Zusatzoption",
    "by {author}\n{license}" : "von {author}\n{license}",
    "Your apps" : "Deine Apps",
    "Documentation" : "Dokumentation",
    "Details" : "Details",
    "Changelog" : "Liste der Veränderungen",
    "Active apps" : "Aktive Apps",
    "Disabled apps" : "Deaktivierte Apps",
    "Updates" : "Aktualisierungen",
    "Featured apps" : "Vorgestellte Apps",
    "Supported apps" : "Unterstützte Apps",
    "manual-install apps cannot be updated" : "manual-install Apps können nicht aktualisiert werden",
    "{progress}% Deploying" : "{progress}% bereitstellen",
    "{progress}% Initializing" : "{progress}% Initialisierung",
    "Healthchecking" : "Gesundheitscheck",
    "Deploy and Enable" : "Bereitstellen und Aktivieren",
    "Enable" : "Aktivieren",
    "Disable" : "Deaktivieren",
    "Allow untested app" : "Ungetestete App zulassen",
    "Default Deploy daemon is not accessible. Please verify configuration" : "Standard-Deploy-Daemon ist nicht zugänglich. Bitte überprüfe dessen Konfiguration",
    "The app will be downloaded from the App Store and deployed on default Deploy Daemon" : "Die App wird aus dem App-Store heruntergeladen und auf dem Standard-Deploy-Daemon bereitgestellt",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Diese App ist als nicht-kompatibel mit deiner Nextcloud-Version markiert. Wenn du fortfährst, so kannst du die App installieren. Bitte beachte, dass die App nicht wie erwartet funktionieren könnte.",
    "Your ExApps" : "Deine ExApps",
    "An error occurred during the request. Unable to proceed." : "Es ist ein Fehler bei der Anfrage aufgetreten. Es kann nicht fortgefahren werden.",
    "The app has been enabled but needs to be updated." : "Die App wurde aktiviert, muss jedoch aktualisiert werden.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Fehler: Diese App kann nicht aktiviert werden, da sie den Server instabil macht.",
    "### Boost your Nextcloud with AppAPI and its specially designed applications.\n\n\nThe AppAPI is a project within the Nextcloud ecosystem designed to streamline and enhance the process of\napplication development, deployment, and management.\n\nIt introduces a new methodology that allows developers to create\napplications using a variety of programming languages, not limited to PHP, which was traditionally used in Nextcloud development.\n\n\n### List of applications that require AppAPI:\n\n- [talk_bot_ai_example](https://github.com/cloud-py-api/talk_bot_ai_example)\n- [upscaler_example](https://github.com/cloud-py-api/upscaler_example)\n- [image_to_text_example](https://github.com/cloud-py-api/file_to_text_example)\n- [ai_image_generator_bot](https://github.com/cloud-py-api/ai_image_generator_bot)\n- [SummarAI](https://github.com/nextcloud/sumupbot)\n\n_If you wish to develop an application, we will gladly help and assist you._\n\n### Support\n\nWe appreciate any support for this project:\n\n- ⭐ Star our work on GitHub\n- ❗ Create an Issue or feature request\n- 💁 Resolve an Issue and create a Pull Request\n- 🧑‍💻 Develop your own application using AppAPI\n\nWe are genuinely excited about the future of the AppAPI project and its potential to transform\nthe way applications are developed and experienced within Nextcloud.\n\nAs we embark on this journey, we warmly invite you - developers, thinkers, creators, and visionaries -\nto join us in shaping a more versatile, stable, and secure app landscape.\n\n*Your insights, suggestions, and contributions are invaluable to us.*" : "### Erweiter deine Nextcloud mit AppAPI und den hierfür entwickelten Anwendungen.\n\n\nDie AppAPI ist ein Projekt innerhalb des Nextcloud-Ökosystems, das darauf abzielt, Prozesse der Anwendungsentwicklung, Bereitstellung und\nVerwaltung zu rationalisieren und zu verbessern.\n\nEs führt eine neue Methodik ein, die Entwicklern das Erstellen von Anwendungen nicht nur mit PHP,\ndas bislang in der Nextcloud-Entwicklung verwendet wurde, sondern mit einer Vielzahl von Programmiersprachen ermöglicht.\n\n\n### Liste der Anwendungen, die AppAPI erfordern:\n\n- [talk_bot_ai_example](https://github.com/cloud-py-api/talk_bot_ai_example)\n- [upscaler_example](https://github.com/cloud-py-api/upscaler_example)\n- [image_to_text_example](https://github.com/cloud-py-api/file_to_text_example)\n- [ai_image_generator_bot](https://github.com/cloud-py-api/ai_image_generator_bot)\n- [SummarAI](https://github.com/nextcloud/sumupbot)\n\n_Wenn du eine Anwendung entwickeln möchtest, helfen wir Ihnen gerne weiter._\n\n### Unterstützung\n\nWir freuen uns über jede Unterstützung für dieses Projekt:\n\n- ⭐ Markiere unsere Arbeit auf GitHub\n- ❗ Erstelle ein Issue oder einen Erweiterungsvorschlag\n- 💁 Löse ein Problem und erstelle einen Pull-Request\n- 🧑‍💻 Entwickle deine eigene Anwendung mit AppAPI\n\nWir sind sehr gespannt auf die Zukunft des AppAPI-Projekts und sein Transformationspotenzial\nbezüglich der Art und Weise, wie Anwendungen innerhalb von Nextcloud entwickelt und erlebt werden.\n\nWährend wir uns auf diese Reise begeben, laden wir dich – Entwickler, Denker, Schöpfer und Visionäre – herzlich ein –\ngemeinsam mit uns eine vielseitigere, stabilere und sicherere App-Landschaft zu gestalten.\n\n*Deine Erkenntnisse, Vorschläge und Beiträge sind für uns von unschätzbarem Wert.*"
},
"nplurals=2; plural=(n != 1);");
