OC.L10N.register(
    "circles",
    {
    "You created the team {circle}" : "あなたはチーム {circle} を作成しました",
    "{author} created the team {circle}" : "{author} がチーム {circle} を作成しました",
    "You deleted {circle}" : "あなたは {circle} を削除しました",
    "{author} deleted {circle}" : "{author} が {circle} を削除しました",
    "You made {member} join {circle}" : "あなたは {member} を {circle} に加入させました",
    "{author} made {member} join {circle}" : "{author} は {member} を {circle} に加入させました",
    "You added team {member} as member to {circle}" : "あなたは {circle} にチーム {member} をメンバーとして追加しました",
    "{author} added team {member} as member to {circle}" : "{author}がチーム{member}を{circle}のメンバーとして追加しました",
    "You made {member} leave {circle}" : "あなたは {member} を {circle} から脱退させました",
    "{author} made {member} leave {circle}" : "{author} が {member} を {circle} から脱退させました",
    "You removed {member} from {circle}" : "あなたは {member} を {circle} から除名しました",
    "{author} removed {member} from {circle}" : "{author}が{circle}から{member}を削除しました",
    "You joined {circle}" : "あなたは {circle} に参加しました",
    "{member} joined {circle}" : "{member} が {circle} に参加しました",
    "You accepted the invitation to join {circle}" : "{circle}への招待を受け入れました",
    "{member} accepted the invitation to join {circle}" : "{member}が{circle}への招待を受け入れました",
    "You added {member} as member to {circle}" : "あなたは {member} を {circle} にメンバーとして追加しました",
    "You have been added as member to {circle} by {author}" : "{author}が{circle}にメンバーとして追加しました",
    "{member} has been added as member to {circle} by {author}" : "{author}によって{member}が{circle}のメンバーとして追加されました",
    "You added {external} to {circle}" : "{circle}に{external}を追加しました",
    "{external} has been added to {circle} by {author}" : "{external} が {author} によって {circle} に追加されました",
    "You accepted {member}'s request to join {circle}" : "{member} の {circle} への参加リクエストを受け入れました",
    "Your request to join {circle} has been accepted by {author}" : "あなたの {circle} への参加リクエストは {author} によって承認されました",
    "{member}'s request to join {circle} has been accepted by {author}" : "{member} の {circle} への参加リクエストが{author}に受け入れられました",
    "You left {circle}" : "あなたは {circle} を抜けました",
    "{member} left {circle}" : "{member} が {circle} を抜けました",
    "You declined the invitation to join {circle}" : "{circle}への招待を辞退しました",
    "{member} declined an invitation to join {circle}" : "{member}さんが{circle}への招待を辞退しました",
    "You cancelled your request to join {circle}" : "{circle}への参加リクエストをキャンセルしました。",
    "{member} cancelled a request to join {circle}" : "{member} が {circle} への加入申請を取り消しました",
    "You have been removed from {circle} by {author}" : "{author}が{circle}からあなたを削除しました",
    "{member} has been removed from {circle} by {author}" : "{author}によって{member}が{circle}から削除されました",
    "You removed {external} from {circle}" : "{circle}から{external}を削除しました",
    "{external} has been removed from {circle} by {author}" : "{external} が {author} によって {circle} から削除されました",
    "You cancelled {member}'s invitation to join {circle}" : "{member} の {circle} への招待状をキャンセルしました",
    "Your invitation to join {circle} has been cancelled by {author}" : "{circle}への招待状が{author}によってキャンセルされました",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} {member}の{circle}への招待状をキャンセルしました",
    "You dismissed {member}'s request to join {circle}" : "{member}の{circle}への参加リクエストを却下しました",
    "Your request to join {circle} has been dismissed by {author}" : "{circle}に参加するあなたのリクエストは{author}によって却下されました",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{member} の {circle} への参加リクエストが {author} によって却下されました",
    "You invited {member} to join {circle}" : "{member} に {circle} に参加するように招待しました",
    "You have been invited to join {circle} by {author}" : "{author}が{circle}に参加するように招待されました",
    "{member} has been invited to join {circle} by {author}" : "{author} によって {member} が {circle} に参加するよう招待されました",
    "You changed {member}'s level in {circle} to %1$s" : "{circle}の{member}のレベルを %1$s に変更しました",
    "{author} changed your level in {circle} to %1$s" : "{author}が{circle}のレベルを %1$s に変更しました",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} が{member}{circle} のレベルを %1$s に変更しました",
    "You sent a request to join {circle}" : "{circle}への参加リクエストを送信しました。",
    "{member} sent a request to join {circle}" : "{member}が{circle}への参加リクエストを送信しました",
    "You are the new owner of {circle}" : "あなたは {circle} の新しいオーナーです",
    "{member} is the new owner of {circle}" : "{member} は {circle} の新しいオーナーです",
    "Teams" : "チーム",
    "On events happening in a <strong>team</strong> of which you are a member" : "あなたが所属する<strong>チーム</strong> で起きた出来事について",
    "Any important event in a <strong>team</strong> you are moderating" : "あなたがモデレーターを務める <strong>チーム</strong> の重要なイベント",
    "On global events happening in any <strong>team</strong>" : "どの<strong>チーム</strong>でも起きているグローバルな出来事について",
    "Single" : "シングル",
    "Personal" : "パーソナル",
    "System" : "システム",
    "Visible" : "表示する",
    "Open" : "開く",
    "Invite" : "招待状",
    "Join request" : "参加リクエスト",
    "Friends" : "お友達",
    "Password protected" : "パスワード保護",
    "No Owner" : "オーナーがいません",
    "Hidden" : "非公開",
    "Backend" : "バックエンド",
    "Local" : "ローカル",
    "Root" : "ルート",
    "Team invite" : "チーム招待",
    "Federated" : "連携",
    "Mount point" : "マウントポイント",
    "App" : "アプリ",
    "Nextcloud Account" : "Nextcloud アカウント",
    "Nextcloud Group" : "Nextcloudグループ",
    "Email address" : "メールアドレス",
    "Contact" : "連絡先",
    "Team" : "チーム",
    "Nextcloud App" : "Nextcloudアプリ",
    "Teams App" : "Temsアプリ",
    "Admin Command Line" : "管理者コマンドライン",
    "Member" : "メンバー",
    "Moderator" : "モデレータ",
    "Admin" : "管理者",
    "Owner" : "オーナー",
    "%s shared »%s« with you." : "%sが あなたと »%s«を共有しました",
    "%s shared »%s« with \"%s\"." : "%sが»%s«を\"%s\"と共有しました。",
    "%s on %s" : "%s に %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$sが»%2$s«をあなたと共有しました。\nそれにアクセスするためのリンクが既にEメールで届いているはずです。\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$sさんがあなたと»%2$s«を共有しました。アクセス用のリンクを記載したメールが、既に届いているはずです。",
    "Password to access »%1$s« shared to you by %2$s" : "»%1$s«への共有アクセスのパスワードが %2$s から共有されました",
    "Password to access »%s«" : "»%s« にアクセスするパスワード",
    "It is protected with the following password:" : "次のパスワードで保護されています。",
    "%1$s via %2$s" : "%1$sに%2$sから",
    "Click the button below to open it." : "下のボタンをクリックして開きます。",
    "Open »%s«" : "»%s«を開く",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$sさんがあなたと複数のファイルを共有しました。\nアクセス用のリンクを記載したメールが、既に届いているはずです。\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$sさんがあなたと複数のファイルを共有しました。アクセス用のリンクを記載したメールが、既に届いているはずです。",
    "Password to access files shared to you by %1$s" : "%1$sによって共有されたファイルにアクセスするためのパスワード",
    "Password to access files" : "ファイルアクセスのパスワード",
    "%s shared multiple files with \"%s\"." : "%sが\"%s\"と複数のファイルを共有しました。",
    "%s shared multiple files with you." : "%sがあなたと複数のファイルを共有しました。",
    "Boot up" : "起動時",
    "Nextcloud Initialization" : "Nextcloud初期化",
    "Teams App Initialization" : "Teamsアプリの初期設定",
    "Fresh installation status" : "フレッシュインストールの状況",
    "Building Local Database" : "ローカルデータベースの構築",
    "Testing Basic Team Creation" : "基本的なチーム作成のテスト",
    "Adding local users and moderators" : "ローカルユーザーとモデレーターを追加する",
    "Show all teams" : "すべてのチームを表示",
    "Create a new team" : "新しいチームを作成する",
    "Files" : "ファイル",
    "This feature is not available for personal teams" : "この機能は個人チームでは利用できません。",
    "The team is not federated" : "チームは統合されていません",
    "You cannot join this team" : "あなたはこのチームに参加できません",
    "This member is not a moderator" : "このメンバーはモデレーターではありません",
    "Insufficient privileges" : "権限が不十分です",
    "This member does not exist" : "このメンバーは存在しません",
    "This member is the owner of the team" : "このメンバーはチームのオーナーです",
    "Level cannot be changed for this type of member" : "このタイプのメンバーのレベルを変更することはできません",
    "You are already a member of this team" : "あなたはすでにこのチームのメンバーです。",
    "You have been blocked from this team" : "あなたはこのチームからブロックされています",
    "The account is already a member of this team" : "そのアカウントはすでにこのチームのメンバーです",
    "The account has already been invited into this team" : "そのアカウントはすでにこのチームに招待されています",
    "%s (Team owned by %s)" : "%s (%s が所有するサークル)",
    "You are now a member of the Team \"%2$s\"" : "あなたはチーム \"%2$s\" のメンバーになりました",
    "You have been invited by %1$s into the Team \"%2$s\"" : "あなたは%1$sからチーム \"%2$s\"に招待されています",
    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$sがチーム\"%2$s\"のメンバー申請を送りました",
    "Accept" : "承諾",
    "Refuse" : "拒否する",
    "Leave the team" : "チームを離脱",
    "No image file provided" : "画像ファイルが提供されていません",
    "Invalid file provided" : "無効なファイルが提供されました",
    "File is too big" : "ファイルが大きすぎます",
    "Invalid image" : "無効な画像",
    "Unknown filetype" : "不明なファイルタイプ",
    "%s" : "%s",
    "Personal team" : "パーソナルチーム",
    "%s owned by %s" : "%s%sが所有",
    "You have no permission to create a new team" : "新しいチームを作成する権限がありません",
    "Insufficient permissions to perform this action" : "この操作を実行するための権限が不足しています",
    "%s shared a file with \"%s\"." : "%sは\"%s\"どファイルを共有しました。",
    "%s shared a file with you." : "%sはあなたとファイルを共有しました。",
    "%1$s shared %2$s with %3$s" : "%1$s は %2$s を %3$s と共有しました",
    "%1$s shared %2$s with \"%3$s\"" : "%1$s は %2$s を \"%3$s\" と共有しました",
    "Open %s" : "%sを開く",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s は、いくつかのコンテンツをあなたと共有しました。\nすでに、アクセスするためのリンクが記載された別の電子メールが届いているはずです。\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s は、いくつかのコンテンツをあなたと共有しました。すでに、アクセスするためのリンクが記載された別の電子メールが届いているはずです。",
    "Password to access content shared with you by %1$s" : "%1$sが共有するコンテンツにアクセスするためのパスワード。",
    "Password to access content" : "コンテンツにアクセスするためのパスワード",
    "Federated Teams" : "統合されたチーム",
    "This item is already shared with this team" : "このアイテムは既にこのチームで共有されています",
    "Bring cloud-users closer together." : "クラウドユーザー同士を近づける。",
    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "チームを使って自分のグループ(同僚、友人)を作成することができます。\nこれらのグループは、他のアプリで共有先として使用することができます。",
    "Unable to update federated teams config" : "統合されたチームの設定を更新できません",
    "Invalid URL format. Please provide a valid URL." : " 無効なURL形式です。有効なURLを入力してください。",
    "Changed frontal cloud URL" : " フロントのクラウドURLを変更",
    "Federation allows you to share teams with other trusted servers and make them discoverable across instances." : "フェデレーションでは、信頼できる他のサーバーとチームを共有し、インスタンス間で発見可能にできます。",
    "Enable federated teams" : "統合されたチームを有効にする",
    "Frontal URL" : "フロントURL",
    "https://…" : "https://…",
    "The public URL used by other instances to discover and connect to your teams." : "他のインスタンスがあなたのチームを検出して接続するために使用する公開URL。",
    "Unlimited" : "無制限",
    "Default quota" : "デフォルトのクオータ",
    "Select default quota" : "デフォルトのクオータを選択",
    "Save" : "保存する",
    "Reconnect" : "再接続",
    "Connect" : "接続",
    "New team" : "新しいチーム",
    "Search teams" : "チームを検索",
    "Overview" : "概要",
    "No teams found" : "チームは見つかりませんでした",
    "Try a different search." : "別の検索を試してみてください。",
    "Create a team to get started." : "まずはチームを作成しましょう。",
    "Members" : "メンバー",
    "_%n resource_::_%n resources_" : ["%nリソース"],
    "Team \"{name}\" created" : "チーム\"{name}\"が作成されました",
    "Could not create the team" : "チームを作成できません",
    "Cancel" : "キャンセル",
    "Next" : "次へ",
    "Back" : "戻る",
    "Create team" : "チームを作成する",
    "Team name" : "チーム名",
    "e.g. Design" : "例：デザイン",
    "Search for people to add" : "追加するメンバーを検索",
    "Switch to list view" : "リスト表示へ切り替え",
    "Switch to grid view" : "グリッド表示へ切り替え",
    "Folder" : "フォルダー",
    "Team owner" : "チーム所有者",
    "you" : "あなた",
    "Manage team" : "チームの管理",
    "Copy link" : "リンクをコピー",
    "Leave team" : "チームを離脱",
    "Delete team" : "チームを削除",
    "An error happened during the config change" : "構成の変更中にエラーが発生しました",
    "Confirm enabling federation" : "フェデレーションの有効化を確認する",
    "Enabling this will prevent {circle} from being a member of other teams.\nAre you sure?" : "これを有効にすると、{circle}は他のチームのメンバーになれなくなります。本当に実行しますか？",
    "Enable federation" : "フェデレーションを有効にする",
    "Copied" : "コピー",
    "Could not copy" : "コピーできませんでした",
    "Create link" : "リンクを作成する",
    "Enforce password protection on files shared to this team" : "このチームと共有するファイルにパスワード保護を強制します",
    "Use a unique password for all shares to this team" : "このチームのすべての共有に一意のパスワードを使用します",
    "Unique password …" : "固有パスワード...",
    "Change unique password" : "固有パスワードを変更",
    "Failed to save password. Please try again later." : "パスワードを保存できませんでした。後でもう一度やり直してください",
    "Close" : "閉じる",
    "Choose a team picture" : "チーム写真を選んでください",
    "There is no description for this team" : "このチームの説明はありません",
    "Enter a description for the team" : "チームの説明を入力します",
    "New folder" : "新しいフォルダー",
    "Folder name" : "フォルダー名",
    "Talk conversation" : "会話",
    "New Talk conversation" : "新しい会話",
    "Conversation name" : "会話の名前",
    "Collective" : "Collective",
    "Calendar" : "カレンダー",
    "New calendar" : "新しいカレンダー",
    "Calendar name" : "カレンダー名",
    "Unknown resource type" : "不明なリソースタイプ",
    "Team calendar \"{resourceName}\" created and shared with team" : "チームカレンダー\"{resourceName}\"が作成され、チームと共有されました",
    "{resourceType} \"{resourceName}\" created and shared with team" : "{resourceType} \"{resourceName}\"が作成され、チームと共有されました",
    "A calendar named \"{name}\" already exists. Please choose a different name." : "\"{name}\"という名前のカレンダーはすでに存在します。別の名前を選択してください。",
    "Failed to create {resourceType}: {error}" : "{resourceType} の作成に失敗しました:{error}",
    "Please select a valid png or jpg file" : "pngもしくは、jpgファイルを選択してください",
    "Error picking team picture" : "チーム写真の選択にエラーが発生しました",
    "Error cropping avatar picture" : "アバター画像のトリミングに失敗しました",
    "An error happened while saving {fields}" : "{fields}の保存中にエラーが発生しました",
    "Description" : "説明",
    "Upload team picture" : "チーム写真をアップロードする",
    "Choose from Nextcloud Files" : "Nextcloud Filesから選択",
    "Delete picture" : "画像を削除",
    "Edit" : "編集",
    "Request to join" : "参加リクエスト",
    "Create" : "作成",
    "Show in Calendar" : "カレンダーに表示する",
    "Your request to join this team is pending approval" : "このチームへの参加リクエストは承認待ちです",
    "You are not a member of {circle}" : "あなたはサークル{circle}のメンバーではありません",
    "Add" : "追加",
    "Edit team picture" : "チーム写真を編集する",
    "Apply" : "適用",
    "Remove {type}" : "{type} を削除",
    "Add to group" : "グループに追加",
    "Add members to group" : "ユーザーをグループに追加",
    "Search {types}" : "{types}を検索",
    "Add guest" : "ゲストを追加",
    "Loading …" : "読み込み中…",
    "No results" : "該当なし",
    "Add {type}" : "{type} を追加",
    "Promote as sole owner" : "唯一の所有者に昇格",
    "Promote to {level}" : "{level}に昇格",
    "Demote to {level}" : "{level}に降格",
    "Are you sure you want to leave this team? This action cannot be undone." : "本当にこのチームを離れますか？この操作は元に戻せません。",
    "Leave team failed." : "チームからの離脱に失敗しました。",
    "Could not delete the member {displayName}" : "メンバー{displayName}を削除できませんでした",
    "Could not change the member level to {level}" : "メンバーレベルを{level}に変更できませんでした",
    "Could not accept membership request" : "メンバーシップリクエストを承諾できませんでした",
    "Accept membership request" : "メンバーシップリクエストを受け入れる",
    "Reject membership request" : "メンバーシップリクエストを拒否",
    "Manage level" : "レベルを管理",
    "Remove member" : "メンバーを削除",
    "Pending" : "保留中",
    "Unable to get the results" : "結果を取得できません",
    "Some members could not be added" : "一部のメンバーを追加できませんでした",
    "There was an issue adding members to the team" : "チームへのメンバーの追加で問題が発生しました",
    "There was an error fetching the member list" : "メンバーリストの取得中にエラーが発生しました",
    "The list of members is only visible to members of this team" : "メンバーのリストは、このチームのメンバーにのみ表示されます",
    "Search among current members" : "現在のメンバーの検索",
    "Role" : "ロール",
    "Filter by role" : "役割によるフィルター",
    "Loading members list …" : "メンバーリストを読み込んでいます…",
    "No members found matching your search" : "検索条件に一致するメンバーは見つかりませんでした",
    "You currently have no access to the member list" : "メンバーリストへのアクセス権がありません",
    "Add to {team}" : "{team} に追加",
    "Invite members to {team}" : "メンバーに{team} に参加するように招待します",
    "Your teams and everything shared with them across Nextcloud." : "あなたのチームとすべてがNextcloudを介して共有されています。",
    "Could not load teams" : "チームを読み込めませんでした",
    "Something went wrong while loading your teams." : "チームの読み込み中に問題が発生しました。",
    "Try again" : "もう一度試してください",
    "No teams yet" : "まだチームはありません",
    "Create your first team to start collaborating." : "最初のチームを作成して、コラボレーションを始めましょう。",
    "Create your first team" : "最初のチームを作成する",
    "Your teams" : "あなたのチーム",
    "Loading" : "読み込み中",
    "Go back" : "戻る",
    "Join" : "参加",
    "Could not load the team" : "チームを読み込めませんでした",
    "Team not found" : "チームが見つかりません",
    "This team may have been removed." : "このチームは削除された可能性があります。",
    "Failed to load teams" : "チームの読込に失敗しました",
    "Join or create teams to see them here." : "チームに参加するか作成してここで確認してください。",
    "Loading…" : "読み込み中…",
    "More teams" : "その他のチーム",
    "Link copied to the clipboard" : "リンクがクリップボードにコピーされました",
    "Could not copy link to the clipboard" : "クリップボードにリンクをコピーできませんでした",
    "Are you sure you want to leave {team}?" : "{team}を退会してもよろしいですか？",
    "You left \"{name}\"" : "\"{name}\"を抜けました",
    "Could not leave the team" : "チームを離れることができませんでした",
    "Are you sure you want to delete {team}? This cannot be undone." : "{team}を削除してもよろしいですか？この操作は元に戻せません。",
    "Team deleted" : "チームが削除されました",
    "Could not delete the team" : "チームを削除できませんでした",
    "Join team" : "チームに参加する",
    "You are about to leave {circle}.\nAre you sure?" : "{circle}を離れようとしています。\nよろしいですか？",
    "Please confirm team leave" : "チームの離脱を確認してください",
    "Could not leave the team {displayName}" : "チーム{displayName}から離脱できませんでした",
    "Unable to join the team" : "チームに参加できません",
    "You are about to delete {circle}.\nAre you sure?" : "{circle}を削除しようとしています。\nよろしいですか？",
    "Please confirm team deletion" : "チームの削除を確認してください",
    "Unable to delete the team" : "チームを削除できません",
    "Could not copy link to the clipboard." : "クリップボードにコピーできませんでした",
    "All contacts" : "すべての連絡先",
    "Not grouped" : "グループ化されていません",
    "Recently contacted" : "最近連絡した",
    "Organization chart" : "組織図",
    "Contacts settings" : "連絡先の設定",
    "Create your own teams for sharing. Add Nextcloud users, contacts, or anyone via email." : "共有用のチームを作成しましょう。Nextcloudのユーザーや連絡先、あるいはメール経由で誰でも追加できます。",
    "User" : "ユーザー",
    "Group" : "グループ",
    "Email" : "メール",
    "Invites" : "招待",
    "Anyone can request membership" : "誰でもメンバーへの参加をリクエストできます",
    "Members need to accept invitation" : "メンバーは招待を承認する必要があります",
    "Memberships must be confirmed/accepted by a Moderator (requires \"Anyone can request membership\")" : "メンバシップはモデレータによって確認/承認される必要があります (「誰でもメンバシップをリクエストできます」が必要) 。",
    "Members can also invite" : "メンバーによる招待も可能",
    "Membership" : "メンバー",
    "Prevent teams from being a member of another team" : "チームが別のチームのメンバーになることを禁止する",
    "Federation" : "連携",
    "Allow federated members" : "フェデレーションメンバーを許可する",
    "Privacy" : "プライバシー",
    "Visible to everyone" : "すべての人に公開",
    "users" : "ユーザー",
    "Users" : "ユーザ",
    "groups" : "グループ",
    "Groups" : "グループ",
    "federated users" : "フェデレーションユーザー",
    "Federated users" : "フェデレーションユーザー",
    "teams" : "チーム",
    "email addresses" : "メールアドレス",
    "Email addresses" : "メールアドレス",
    "contacts" : "連絡先",
    "Contacts" : "連絡先",
    "An error has occurred in team(s). Check the console for more details." : "チームでエラーが発生しました。詳細については、コンソールを確認してください。",
    "Unable to create team {circleName}" : "チーム{circleName}を作成できません",
    "Unable to delete team {circleId}" : "チーム {circleId} を削除できません",
    "No files in here" : "ファイルがありません",
    "No entries found in this folder" : "このフォルダーにはエントリーがありません",
    "Name" : "名前",
    "Size" : "サイズ",
    "Modified" : "更新日時",
    "Circles App Initialization" : "Circleアプリの初期化"
},
"nplurals=1; plural=0;");
