OC.L10N.register(
    "logreader",
    {
    "Logging" : "로그",
    "No errors in the logs since %s" : "%s 이래로 로그에 아무런 오류가 기록되지 않았습니다",
    "_%n error in the logs since %s_::_%n errors in the logs since %s_" : ["로그에 %s 이래로 %n개의 오류가 기록되었습니다"],
    "Log Reader" : "로그 리더",
    "A log reader for Nextcloud" : "Nextcloud 로그 리더",
    "Log reader for Nextcloud" : "Nextcloud 로그 리더",
    "Log reader" : "로그 리더",
    "Open log reader settings" : "로그 리더 설정 열기",
    "Log reader settings" : "로그 리더 설정",
    "Level" : "단계",
    "App" : "앱",
    "Time" : "시간",
    "Filter log levels" : "로그 단계 필터링",
    "Set log level" : "로그 단계 설정",
    "Time format" : "시간 형식",
    "Live view" : "실시간 보기",
    "Download/Upload logs" : "로그 다운로드/업로드",
    "Ctrl" : "Ctrl",
    "Download logs" : "로그 다운로드",
    "Show local log file" : "로컬 로그 파일 보기",
    "Upload local log file to be displayed" : "표시할 로컬 로그 파일 업로드",
    "Time format used for displaying the timestamp" : "타임스탬프 표시에 사용되는 시간 형식",
    "(Local log files only support the \"raw\" time format)" : "(로컬 로그 파일은 \"raw\" 형식만 지원합니다)",
    "Could not change date time format." : "시간 형식을 변경할 수 없음",
    "Local time" : "로컬 시간 형식",
    "UTC time" : "UTC 시간 형식",
    "Relative" : "상대적",
    "Could not change live view setting." : "실시간 보기 설정을 변경할 수 없음",
    "Polling (live view)" : "폴링 (실시간 보기 활성화)",
    "Application" : "애플리케이션",
    "Message" : "메시지",
    "No older log entries available" : "사용 가능한 로그 항목 없음",
    "Show details" : "세부 정보",
    "Debug" : "디버그",
    "Info" : "정보",
    "Warning" : "경고",
    "Error" : "오류",
    "Fatal" : "치명적"
},
"nplurals=1; plural=0;");
