OC.L10N.register(
    "circles",
    {
    "You created the team {circle}" : "Anda membuat tim {circle}",
    "{author} created the team {circle}" : "{author} membuat tim {circle}",
    "You deleted {circle}" : "Anda menghapus {circle}",
    "{author} deleted {circle}" : "{author} menghapus {circle}",
    "You made {member} join {circle}" : "Anda membuat {member} bergabung dengan {circle}",
    "{author} made {member} join {circle}" : "{author} membuat {member} bergabung dengan {circle}",
    "You added team {member} as member to {circle}" : "Anda menambahkan tim {member} sebagai anggota ke {circle}",
    "{author} added team {member} as member to {circle}" : "{author} menambahkan tim {member} sebagai anggota ke {circle}",
    "You made {member} leave {circle}" : "Anda membuat {member} keluar dari {circle}",
    "{author} made {member} leave {circle}" : "{author} membuat {member} keluar dari {circle}",
    "You removed {member} from {circle}" : "Anda menghapus {member} dari {circle}",
    "{author} removed {member} from {circle}" : "{author} menghapus {member} dari {circle}",
    "You joined {circle}" : "Anda bergabung dengan {circle}",
    "{member} joined {circle}" : "{member} bergabung dengan {circle}",
    "You accepted the invitation to join {circle}" : "Anda menerima undangan untuk bergabung dengan {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} menerima undangan untuk bergabung dengan {circle}",
    "You added {member} as member to {circle}" : "Anda menambahkan {member} sebagai anggota ke {circle}",
    "You have been added as member to {circle} by {author}" : "Anda telah ditambahkan sebagai anggota ke {circle} oleh {author}",
    "{member} has been added as member to {circle} by {author}" : "{member} telah ditambahkan sebagai anggota ke {circle} oleh {author}",
    "You added {external} to {circle}" : "Anda menambahkan {external} ke {circle}",
    "{external} has been added to {circle} by {author}" : "{external} telah ditambahkan ke {circle} oleh {author}",
    "You accepted {member}'s request to join {circle}" : "Anda menerima permintaan {member} untuk bergabung dengan {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Permintaan Anda untuk bergabung dengan {circle} telah diterima oleh {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "Permintaan {member} untuk bergabung dengan {circle} telah diterima oleh {author}",
    "You left {circle}" : "Anda meninggalkan {circle}",
    "{member} left {circle}" : "{member} meninggalkan {circle}",
    "You declined the invitation to join {circle}" : "Anda menolak undangan untuk bergabung dengan {circle}",
    "{member} declined an invitation to join {circle}" : "{member} menolak undangan untuk bergabung dengan {circle}",
    "You cancelled your request to join {circle}" : "Anda membatalkan permintaan Anda untuk bergabung dengan {circle}",
    "{member} cancelled a request to join {circle}" : "{member} membatalkan permintaan untuk bergabung dengan {circle}",
    "You have been removed from {circle} by {author}" : "Anda telah dikeluarkan dari {circle} oleh {author}",
    "{member} has been removed from {circle} by {author}" : "{member} telah dikeluarkan dari {circle} oleh {author}",
    "You removed {external} from {circle}" : "Anda menghapus {external} dari {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} telah dihapus dari {circle} oleh {author}",
    "You cancelled {member}'s invitation to join {circle}" : "Anda membatalkan undangan {member} untuk bergabung dengan {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "Undangan Anda untuk bergabung dengan {circle} telah dibatalkan oleh {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} membatalkan undangan {member} untuk bergabung dengan {circle}",
    "You dismissed {member}'s request to join {circle}" : "Anda menolak permintaan {member} untuk bergabung dengan {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "Permintaan Anda untuk bergabung dengan {circle} telah ditolak oleh {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "Permintaan {member} untuk bergabung dengan {circle} telah ditolak oleh {author}",
    "You invited {member} to join {circle}" : "Anda mengundang {member} untuk bergabung dengan {circle}",
    "You have been invited to join {circle} by {author}" : "Anda telah diundang untuk bergabung dengan {circle} oleh {author}",
    "{member} has been invited to join {circle} by {author}" : "{member} telah diundang untuk bergabung dengan {circle} oleh {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Anda mengubah tingkat {member} di {circle} menjadi %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} mengubah tingkat Anda di {circle} menjadi %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} mengubah tingkat {member} di {circle} menjadi %1$s",
    "You sent a request to join {circle}" : "Anda mengirim permintaan untuk bergabung dengan {circle}",
    "{member} sent a request to join {circle}" : "{member} mengirim permintaan untuk bergabung dengan {circle}",
    "You are the new owner of {circle}" : "Anda adalah pemilik baru {circle}",
    "{member} is the new owner of {circle}" : "{member} adalah pemilik baru {circle}",
    "Teams" : "Tim",
    "On events happening in a <strong>team</strong> of which you are a member" : "Tentang peristiwa yang terjadi dalam <strong>tim</strong> tempat Anda menjadi anggota",
    "Any important event in a <strong>team</strong> you are moderating" : "Peristiwa penting apa pun dalam <strong>tim</strong> yang Anda moderasi",
    "On global events happening in any <strong>team</strong>" : "Tentang peristiwa global yang terjadi di <strong>tim</strong> mana pun",
    "Single" : "Tunggal",
    "Personal" : "Personal",
    "System" : "Sistem",
    "Visible" : "Tampak",
    "Open" : "Buka",
    "Invite" : "Undangan",
    "Join request" : "Permintaan bergabung",
    "Friends" : "Teman",
    "Password protected" : "Kata sandi dilindungi",
    "No Owner" : "Tidak ada pemilik",
    "Hidden" : "Sembunyi",
    "Backend" : "Backend",
    "Local" : "Lokal",
    "Root" : "Root",
    "Team invite" : "Undangan tim",
    "Federated" : "Federated",
    "Mount point" : "Titik pemasangan",
    "App" : "Aplikasi",
    "Nextcloud Account" : "Akun Nextcloud",
    "Nextcloud Group" : "Grup Nextcloud",
    "Email address" : "Alamat email",
    "Contact" : "Kontak",
    "Team" : "Tim",
    "Nextcloud App" : "Aplikasi Nextcloud",
    "Teams App" : "Aplikasi Teams",
    "Admin Command Line" : "Baris Perintah Admin",
    "Member" : "Anggota",
    "Moderator" : "Moderator",
    "Admin" : "Admin",
    "Owner" : "Owner",
    "%s shared »%s« with you." : "%s membagikan »%s« kepada Anda.",
    "%s shared »%s« with \"%s\"." : "%s membagikan »%s« dengan \"%s\".",
    "%s on %s" : "%s pada %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s membagikan »%2$s« kepada Anda.\nAnda seharusnya sudah menerima email terpisah dengan tautan untuk mengaksesnya.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s membagikan »%2$s« kepada Anda. Anda seharusnya sudah menerima email terpisah dengan tautan untuk mengaksesnya.",
    "Password to access »%1$s« shared to you by %2$s" : "Kata sandi untuk mengakses »%1$s« yang dibagikan kepada Anda oleh %2$s",
    "Password to access »%s«" : "Kata sandi untuk mengakses »%s«",
    "It is protected with the following password:" : "Item tersebut dilindungi dengan kata sandi berikut:",
    "%1$s via %2$s" : "%1$s melalui %2$s",
    "Click the button below to open it." : "Klik tombol di bawah ini untuk membukanya.",
    "Open »%s«" : "Buka »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s membagikan beberapa file kepada Anda.\nAnda seharusnya sudah menerima email terpisah dengan tautan untuk mengaksesnya.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s membagikan beberapa file kepada Anda. Anda seharusnya sudah menerima email terpisah dengan tautan untuk mengaksesnya.",
    "Password to access files shared to you by %1$s" : "Kata sandi untuk mengakses file yang dibagikan kepada Anda oleh %1$s",
    "Password to access files" : "Kata sandi untuk mengakses file",
    "%s shared multiple files with \"%s\"." : "%s membagikan beberapa file dengan \"%s\".",
    "%s shared multiple files with you." : "%s membagikan beberapa file kepada Anda.",
    "Boot up" : "Memulai",
    "Nextcloud Initialization" : "Inisialisasi Nextcloud",
    "Fresh installation status" : "Status instalasi baru",
    "Building Local Database" : "Membangun Database Lokal",
    "Testing Basic Team Creation" : "Menguji Pembuatan Tim Dasar",
    "Adding local users and moderators" : "Menambahkan pengguna lokal dan moderator",
    "Show all teams" : "Tampilkan semua tim",
    "Create a new team" : "Buat tim baru",
    "Files" : "File",
    "This feature is not available for personal teams" : "Fitur ini tidak tersedia untuk tim pribadi",
    "The team is not federated" : "Tim ini tidak terfederasi",
    "You cannot join this team" : "Anda tidak dapat bergabung dengan tim ini",
    "This member is not a moderator" : "Anggota ini bukan moderator",
    "Insufficient privileges" : "Hak akses tidak mencukupi",
    "This member does not exist" : "Anggota ini tidak ada",
    "This member is the owner of the team" : "Anggota ini adalah pemilik tim",
    "Level cannot be changed for this type of member" : "Tingkat tidak dapat diubah untuk jenis anggota ini",
    "You are already a member of this team" : "Anda sudah menjadi anggota tim ini",
    "You have been blocked from this team" : "Anda telah diblokir dari tim ini",
    "The account is already a member of this team" : "Akun tersebut sudah menjadi anggota tim ini",
    "The account has already been invited into this team" : "Akun tersebut sudah diundang ke dalam tim ini",
    "%s (Team owned by %s)" : "%s (Tim dimiliki oleh %s)",
    "You are now a member of the Team \"%2$s\"" : "Anda sekarang menjadi anggota Tim \"%2$s\"",
    "You have been invited by %1$s into the Team \"%2$s\"" : "Anda telah diundang oleh %1$s ke dalam Tim \"%2$s\"",
    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$s mengirim permintaan untuk menjadi anggota Tim \"%2$s\"",
    "Accept" : "Terima",
    "Refuse" : "Tolak",
    "Leave the team" : "Tinggalkan tim",
    "Invalid file provided" : "File yang disediakan tidak valid",
    "File is too big" : "File terlalu besar",
    "Invalid image" : "Gambar tidak valid",
    "Unknown filetype" : "Tipe berkas tak dikenal",
    "%s" : "%s",
    "Personal team" : "Tim pribadi",
    "%s owned by %s" : "%s dimiliki oleh %s",
    "You have no permission to create a new team" : "Anda tidak memiliki izin untuk membuat tim baru",
    "%s shared a file with \"%s\"." : "%s membagikan sebuah file dengan \"%s\".",
    "%s shared a file with you." : "%s membagikan sebuah file kepada Anda.",
    "%1$s shared %2$s with %3$s" : "%1$s membagikan %2$s dengan %3$s",
    "%1$s shared %2$s with \"%3$s\"" : "%1$s membagikan %2$s dengan \"%3$s\"",
    "Open %s" : "Buka %s",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s membagikan sebagian konten kepada Anda.\nAnda seharusnya sudah menerima email terpisah dengan tautan untuk mengaksesnya.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s membagikan sebagian konten kepada Anda. Anda seharusnya sudah menerima email terpisah dengan tautan untuk mengaksesnya.",
    "Password to access content shared with you by %1$s" : "Kata sandi untuk mengakses konten yabg dibagikan dengan Anda oleh %1$s",
    "Password to access content" : "Kata sandi untuk mengakses konten",
    "This item is already shared with this team" : "Item ini sudah dibagikan dengan tim ini",
    "Bring cloud-users closer together." : "Mendekatkan para pengguna cloud.",
    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Teams memungkinkan orang membuat grup orang/kolega/teman mereka sendiri.\nGrup orang tersebut kemudian dapat digunakan oleh aplikasi lain mana pun untuk tujuan berbagi.",
    "Unlimited" : "Tak terbatas",
    "Default quota" : "Kuota standar",
    "Select default quota" : "Pilih kuota bawaan",
    "Save" : "Save",
    "Reconnect" : "Sambungkan kembali",
    "Connect" : "Hubungkan",
    "Overview" : "Ringkasan",
    "No teams found" : "Tidak ada tim yang ditemukan",
    "Members" : "Anggota",
    "Cancel" : "Cancel",
    "Next" : "Berikutnya",
    "Back" : "Kembali",
    "Switch to list view" : "Beralih ke tampilan daftar",
    "Switch to grid view" : "Beralih ke tampilan kisi",
    "Folder" : "Folder",
    "you" : "Anda",
    "Copy link" : "Salin tautan",
    "Copied" : "Disalin",
    "Create link" : "Buat tautan",
    "Close" : "Tutup",
    "New folder" : "Folder baru",
    "Folder name" : "Nama folder",
    "Talk conversation" : "Percakapan Talk",
    "Conversation name" : "Nama percakapan",
    "Calendar" : "Kalender",
    "New calendar" : "Kalender baru",
    "Please select a valid png or jpg file" : "Silakan pilih file png atau jpg yang valid",
    "Description" : "Deskripsi",
    "Edit" : "Edit",
    "Create" : "Buat",
    "Show in Calendar" : "Tampilkan di Kalender",
    "Add" : "Tambah",
    "Apply" : "Terapkan",
    "Remove {type}" : "Hapus {type}",
    "Loading …" : "Memuat …",
    "No results" : "Tidak ada hasil",
    "Add {type}" : "Tambah {type}",
    "Pending" : "Tertunda",
    "Role" : "Peran",
    "Add to {team}" : "Tambahkan ke {team}",
    "Try again" : "Coba lagi",
    "Create your first team" : "Buat tim pertama Anda",
    "Loading" : "Memuat",
    "Go back" : "Kembali",
    "Join" : "Bergabung",
    "Failed to load teams" : "Gagal memuat tim",
    "Join or create teams to see them here." : "Bergabung atau buat tim untuk melihatnya di sini.",
    "Loading…" : "Memuat…",
    "More teams" : "Tim lainnya",
    "All contacts" : "Semua kontak",
    "Recently contacted" : "Baru-baru ini dihubungi",
    "User" : "Pengguna",
    "Group" : "Grup",
    "Email" : "Email",
    "Federation" : "Federasi",
    "Privacy" : "Privasi",
    "Users" : "Pengguna",
    "groups" : "grup",
    "Groups" : "Grup",
    "Contacts" : "Kontak",
    "No files in here" : "Tidak ada berkas di sini",
    "No entries found in this folder" : "Tidak ada entri yang ditemukan dalam folder ini",
    "Name" : "Nama",
    "Size" : "Ukuran",
    "Modified" : "Dimodifikasi",
    "Circles App Initialization" : "Inisialisasi Aplikasi Circles"
},
"nplurals=1; plural=0;");
