OC.L10N.register(
    "sharebymail",
    {
    "Shared with {email}" : "{email} بىلەن ئورتاقلاشتى",
    "Shared with {email} by {actor}" : "{email} تەرىپىدىن {actor} بىلەن ئورتاقلاشتى",
    "Unshared from {email}" : "{email} ئارقىلىق ئورتاقلاشمىدى",
    "Unshared from {email} by {actor}" : "{email} تەرىپىدىن {actor} دىن ئورتاقلاشمىغان",
    "Password for mail share sent to {email}" : "{email} غا ئەۋەتىلگەن خەت ئورتاقلىشىشنىڭ پارولى",
    "Password for mail share sent to you" : "سىزگە ئەۋەتىلگەن خەت ئورتاقلىشىشنىڭ پارولى",
    "You shared {file} with {email} by mail" : "سىز {file} ئارقىلىق {email} ئارقىلىق ئورتاقلاشتىڭىز",
    "{actor} shared {file} with {email} by mail" : "{actor} {email} ئارقىلىق {file} بىلەن ئورتاقلاشتى",
    "You unshared {file} from {email} by mail" : "سىز ئورتاقلاشمىغان {file} ئارقىلىق {email} ئارقىلىق",
    "{actor} unshared {file} from {email} by mail" : "{actor} ھەمبەھىرلەنمىگەن {file} {email} ئارقىلىق",
    "Password to access {file} was sent to {email}" : "{file} نى زىيارەت قىلىدىغان پارول {email} غا ئەۋەتىلدى",
    "Password to access {file} was sent to you" : "{file} نى زىيارەت قىلىدىغان پارول سىزگە ئەۋەتىلدى",
    "Share by mail" : "خەت ئارقىلىق ھەمبەھىرلىنىش",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "%1$s نى ئورتاقلىشىش مەغلۇب بولدى ، چۈنكى بۇ تۈر %2$s ھېساباتى بىلەن ئورتاقلاشتى",
    "We cannot send you the auto-generated password. Please set a valid email address in your personal settings and try again." : "بىز ئاپتوماتىك ھاسىل قىلىنغان پارولنى ئەۋەتەلمەيمىز. شەخسىي تەڭشەكلىرىڭىزگە ئۈنۈملۈك ئېلېكترونلۇق خەت ئادرېسىنى ئورنىتىپ قايتا سىناڭ.",
    "Failed to send share by email. Got an invalid email address" : "ئېلېكترونلۇق خەت ئارقىلىق ھەمبەھىرلەش مەغلۇپ بولدى. ئىناۋەتسىز ئېلېكترونلۇق خەت ئادرېسىغا ئېرىشتى",
    "Failed to send share by email" : "ئېلېكترونلۇق خەت ئارقىلىق ھەمبەھىرلەش مەغلۇپ بولدى",
    "%1$s shared %2$s with you" : "%1$s سىز بىلەن%2$s نى ئورتاقلاشتى",
    "Note:" : "ئەسكەرتىش:",
    "This share is valid until %s at midnight" : "بۇ ئۈلۈش يېرىم كېچىدە %s گىچە كۈچكە ئىگە",
    "Expiration:" : "ۋاقتى:",
    "%1$s via %2$s" : "%2$s ئارقىلىق %1$s",
    "%1$s shared %2$s with you. You should have already received a separate mail with a link to access it." : "%1$s سىز بىلەن %2$s نى ئورتاقلاشتى. ئۇنى زىيارەت قىلىش ئۈچۈن ئۇلانمىسى بار ئايرىم خەتنى تاپشۇرۇۋالغان بولۇشىڭىز كېرەك.",
    "Password to access %1$s shared to you by %2$s" : "%1$s نى زىيارەت قىلىدىغان پارول %2$s",
    "Password to access %s" : "%s نى زىيارەت قىلىدىغان پارول",
    "It is protected with the following password:" : "ئۇ تۆۋەندىكى پارول بىلەن قوغدىلىدۇ:",
    "This password will expire at %s" : "بۇ پارولنىڭ ۋاقتى %s بولىدۇ",
    "%1$s shared %2$s with you and wants to add:" : "%1$s سىز بىلەن %2$s نى ئورتاقلاشتى ۋە قوشماقچى:",
    "%1$s shared %2$s with you and wants to add" : "%1$s بولسا %2$s نى سىز بىلەن ئورتاقلاشتى ۋە قوشماقچى",
    "%s added a note to a file shared with you" : "%s سىز بىلەن ئورتاقلاشقان ھۆججەتكە خاتىرە قوشتى",
    "You just shared %1$s with %2$s. The share was already sent to the recipient. Due to the security policies defined by the administrator of %3$s each share needs to be protected by password and it is not allowed to send the password directly to the recipient. Therefore you need to forward the password manually to the recipient." : "سىز پەقەت %2$s بىلەن %1$s نى ئورتاقلاشتىڭىز. بۇ ئۈلۈش ئاللىبۇرۇن تاپشۇرۇۋالغۇچىغا ئەۋەتىلگەن. باشقۇرغۇچى تەرىپىدىن بېكىتىلگەن بىخەتەرلىك سىياسىتى سەۋەبىدىن %3$sھەر بىر پاينى مەخپىي نومۇر بىلەن قوغداش كېرەك ، پارولنى تاپشۇرۇۋالغۇچىغا بىۋاسىتە ئەۋەتىشكە بولمايدۇ. شۇڭلاشقا پارولنى تاپشۇرۇۋالغۇچىغا قولدا يوللىشىڭىز كېرەك.",
    "Password to access %1$s shared by you with %2$s" : "%2$s بىلەن ئورتاقلاشقان %1$s نى زىيارەت قىلىدىغان پارول",
    "This is the password:" : "بۇ پارول:",
    "You can choose a different password at any time in the share dialog." : "ھەمبەھىر سۆزلەشكۈدە خالىغان ۋاقىتتا باشقا پارولنى تاللىيالايسىز.",
    "Could not find share" : "ئورتاقلىشالمىدى",
    "Share provider which allows you to share files by mail" : "ھۆججەتلەرنى خەت ئارقىلىق ھەمبەھىرلىيەلەيسىز",
    "Unable to update share by mail config" : "خەت سەپلىمىسى ئارقىلىق ھەمبەھىرنى يېڭىلاشقا ئامالسىز",
    "Allows people to share a personalized link to a file or folder by putting in an email address." : "كىشىلەرنىڭ ئېلېكترونلۇق خەت ئادرېسى ئارقىلىق ھۆججەت ياكى ھۆججەت قىسقۇچقا خاسلاشتۇرۇلغان ئۇلىنىشنى ھەمبەھىرلىشىگە يول قويىدۇ.",
    "Send password by mail" : "خەت ئارقىلىق پارول ئەۋەتىڭ",
    "Reply to initiator" : "تەشەببۇس قىلغۇچىغا جاۋاب قايتۇرۇڭ"
},
"nplurals=2; plural=(n != 1);");
