OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Personligt aktivitetsflöde för %s",
    "Your feed URL is invalid" : "URL:en för flödet är felaktig.",
    "Activity feed for %1$s" : "Aktivitetsflöde för %1$s",
    "Activity feed" : "Aktivitetsflöde",
    "Your settings have been updated." : "Dina inställningar har uppdaterats.",
    "Settings have been updated." : "Inställningarna har blivit uppdaterade.",
    "remote user" : "fjärranvändare",
    "Recent activity" : "Senaste händelser",
    "No activities" : "Inga händelser",
    "More activities" : "Fler aktiviteter",
    "Daily activity summary for %s" : "Sammanfattad daglig aktivitet för %s",
    "_and %n more…_::_and %n more…_" : ["och %n till…","och %n till…"],
    "You can disable daily digest emails in the <a href=\"%s\">settings</a>." : "Du kan inaktivera dagliga sammanfattningsmejl i <a href=\"%s\">inställningarna</a>.",
    "You can disable daily digest emails in the settings: %s" : "Du kan inaktivera dagliga sammanfattningsmejl i inställningarna: %s",
    "All activities" : "Alla aktiviteter",
    "By others" : "Andras aktivitet",
    "By you" : "Min aktivitet",
    "Activity at %s" : "Aktivitet på %s",
    "Hello %s" : "Hej %s",
    "Hello %s," : "Hej %s,",
    "There was some activity at %s" : "Det var aktivitet på %s",
    "_and %n more _::_and %n more _" : ["och %n till","och %n till"],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "Du kan ändra frekvensen av dessa meddelanden eller stänga av dem i <a href=\"%s\">inställningarna</a>.",
    "You can change the frequency of these emails or disable them in the settings: %s" : "Du kan ändra frekvensen av dessa meddelanden eller stänga av dem i inställningarna: %s",
    "Mail" : "E-post",
    "Push" : "Push",
    "Activity" : "Aktiviteter",
    "Notifications" : "Notiser",
    "This application enables people to view a log of activities about them, their files or other data." : "Denna applikation låter användare se en aktivitetslogg om sig själva, sina filer eller annan information.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Appen tillåter användare att se åtgärder relaterade till sina filer och data i Nextcloud.\n\t\tAlla användare kan välja egna inställningar,\n\t\tatt välja vilka aktiviteter som skall skickas vidare till mobiler, skickas med e-post\n\t\teller om dagliga sammanställningar skall skicka varje morgon.\n\t\tYtterligare information finns dokumentationen Aktivitet.",
    "Today" : "Idag",
    "Last 7 days" : "Senaste 7 dagarna",
    "Last 30 days" : "Senaste 30 dagarna",
    "Custom range" : "Anpassat intervall",
    "Clear search" : "Rensa sökning",
    "Clear filters" : "Rensa filter",
    "From" : "Från",
    "To" : "Till",
    "Send email" : "Skicka e-post",
    "Send push notification" : "Skicka en push-avisering",
    "Activity notification configuration" : "Inställningar för aktivitetsnotiser",
    "Yesterday" : "Igår",
    "Less" : "Mindre",
    "More" : "Mer",
    "_Downloaded %n time (%s in the last 30 days)_::_Downloaded %n times (%s in the last 30 days)_" : ["Nedladdad %n gång (%s de senaste 30 dagarna)","Nedladdad %n gånger (%s de senaste 30 dagarna)"],
    "_Downloaded %n time_::_Downloaded %n times_" : ["Nedladdad %n gång","Nedladdad %n gånger"],
    "You need to set up your email address before you can receive notification emails." : "Du måste ställa in din e-postadress innan du kan ta emot e-postmeddelanden.",
    "Send activity emails" : "Skicka aktivitets-epost",
    "As soon as possible" : "Så snart som möjligt",
    "Hourly" : "Varje timme",
    "Daily" : "Varje dag",
    "Weekly" : "Varje vecka",
    "You commented" : "Du kommenterade",
    "Message deleted by author" : "Meddelandet togs bort av författaren",
    "Open {filename}" : "Öppna {filename}",
    "in {path}" : "i {path}",
    "Home" : "Hem",
    "Could not load activities" : "Kunde inte läsa in aktiviteter",
    "Loading activities" : "Laddar aktiviteter",
    "This stream will show events like additions, changes & shares" : "Flödet visar händelser så som tillägg, ändringar och delningar",
    "No activity yet" : "Inga aktiviteter ännu",
    "New activities" : "Nya aktiviteter",
    "Loading more activities" : "Laddar fler aktiviteter",
    "No more activities." : "Inga fler aktiviteter.",
    "Could not enable RSS link" : "Kunde inte aktivera RSS-länk",
    "RSS link copied to clipboard" : "RSS-länk kopierad till urklipp",
    "Could not copy the RSS link, please copy manually:" : "Kunde inte kopiera RSS-länken, kopiera manuellt:",
    "Activity settings" : "Aktivitetsinställningar",
    "Enable RSS feed" : "Aktivera RSS-flöde",
    "RSS feed" : "RSS-flöde",
    "Copy RSS feed link" : "Kopiera länk till RSS-flöde",
    "Personal notification settings" : "Egna aviseringsinställningar",
    "Clear selection" : "Rensa markering",
    "Unable to load the activity list" : "Kunde inte ladda aktivitetslistan",
    "Choose for which activities you want to get an email or push notification." : "Välj för vilka aktiviteter du vill få e-post eller push-meddelande.",
    "Choose for which activities you want to get a push notification." : "Välj för vilka aktiviteter du vill få ett push-meddelande.",
    "Notification" : "Notifiering",
    "Enable notification emails" : "Aktivera notifieringar via e-post",
    "Daily activity summary" : "Daglig aktivitetsöversikt",
    "Send daily activity summary in the morning" : "Skicka daglig aktivitetsöversikt på morgonen",
    "Default settings" : "Förvalda inställningar",
    "Configure the default notification settings for new accounts." : "Konfigurera standardinställningar av notifieringar för nya konton.",
    "Unable to save the settings" : "Kunde inte spara inställningarna",
    "No more events to load" : "Inga fler aktiviteter."
},
"nplurals=2; plural=(n != 1);");
