OC.L10N.register(
    "settings",
    {
    "{actor} added you to group {group}" : "{actor} dodał Ciebie do grupy {group}",
    "You added {user} to group {group}" : "Dodałeś {user} do grupy {group}",
    "{actor} added {user} to group {group}" : "{actor} dodał {user} do grupy {group}",
    "An administrator added you to group {group}" : "Administrator dodał Ciebie do grupy {group}",
    "An administrator added {user} to group {group}" : "Administrator dodał {user} do grupy {group}",
    "{actor} removed you from group {group}" : "{actor} usunął Ciebie z grupy {group}",
    "You removed {user} from group {group}" : "Usunąłeś {user} z grupy {group}",
    "{actor} removed {user} from group {group}" : "{actor} usunął {user} z grupy {group}",
    "An administrator removed you from group {group}" : "Administrator usunął Ciebie z grupy {group}",
    "An administrator removed {user} from group {group}" : "Administrator usunął {user} z grupy {group}",
    "Your <strong>group memberships</strong> were modified" : "Twoja <strong>przynależność do grupy</strong> została zmodyfikowana",
    "{actor} changed your password" : "{actor} zmienił Twoje hasło",
    "You changed your password" : "Zmieniłeś swoje hasło",
    "Your password was reset by an administrator" : "Twoje hasło zostało zresetowane przez administratora",
    "Your password was reset" : "Twoje hasło zostało zresetowane",
    "{actor} changed your email address" : "{actor} zmienił Twój adres e-mail",
    "You changed your email address" : "Zmieniłeś swój adres e-mail",
    "Your email address was changed by an administrator" : "Twój adres e-mail został zmieniony przez administratora",
    "You created an app password for a session named \"{token}\"" : "Utworzono hasło aplikacji dla sesji o nazwie \"{token}\"",
    "An administrator created an app password for a session named \"{token}\"" : "Administrator utworzył hasło aplikacji dla sesji o nazwie \"{token}\"",
    "You deleted app password \"{token}\"" : "Usunięto hasło aplikacji \"{token}\"",
    "You deleted app password \"{token}\" and cancelled its pending remote wipe" : "Usunięto hasło aplikacji \"{token}\" i anulowano oczekujące wymazanie zdalne",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Zmieniłeś hasło aplikacji \"{token}\" na \"{newToken}\"",
    "You granted filesystem access to app password \"{token}\"" : "Udzieliłeś dostępu do systemu plików dla hasła aplikacji \"{token}\"",
    "You revoked filesystem access from app password \"{token}\"" : "Cofnąłeś dostęp do systemu plików dla hasła aplikacji \"{token}\"",
    "Security" : "Bezpieczeństwo",
    "You successfully logged in using two-factor authentication (%1$s)" : "Pomyślnie zalogowano się za pomocą uwierzytelniania dwuskładnikowego (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Próba logowania przy użyciu uwierzytelniania dwuskładnikowego nie powiodła się (%1$s)",
    "Remote wipe was started on %1$s" : "Zdalne czyszczenie zostało uruchomione w %1$s",
    "Remote wipe has finished on %1$s" : "Zdalne czyszczenie zakończyło się w %1$s",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Twoje <strong>hasło</strong> lub <strong>e-mail</strong> został zmieniony",
    "One time login" : "Logowanie jednorazowe",
    "QR Code login" : "Logowanie kodem QR",
    "Wrong password" : "Złe hasło",
    "Unable to change personal password" : "Nie można zmienić osobistego hasła",
    "Saved" : "Zapisano",
    "No Login supplied" : "Nie podano loginu",
    "Unable to change password" : "Nie można zmienić hasła",
    "Unable to change password. Password too long." : "Nie można zmienić hasła. Hasło jest za długie.",
    "Authentication error" : "Błąd uwierzytelniania",
    "Please provide an admin recovery password; otherwise, all account data will be lost." : "Podaj hasło odzyskiwania administratora; w przeciwnym razie wszystkie dane konta zostaną utracone.",
    "Wrong admin recovery password. Please check the password and try again." : "Błędne hasło odzyskiwania administratora. Sprawdź hasło i spróbuj ponownie.",
    "Backend does not support password change, but the encryption of the account key was updated." : "System zaplecza nie obsługuje zmiany hasła, ale zaktualizowano szyfrowanie klucza konta.",
    "Administrator documentation" : "Dokumentacja administratora",
    "User documentation" : "Dokumentacja użytkownika",
    "Nextcloud help overview" : "Przegląd pomocy Nextcloud",
    "Invalid SMTP password." : "Nieprawidłowe hasło SMTP.",
    "Email setting test" : "Test ustawień e-mail",
    "Well done, %s!" : "Dobra robota, %s!",
    "If you received this email, the email configuration seems to be correct." : "Jeśli otrzymałeś tego e-maila, to wydaje się, że konfiguracja e-maila jest prawidłowa.",
    "Email could not be sent. Check your mail server log" : "E-mail nie został wysłany. Sprawdź logi swojego serwera poczty",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Wystąpił problem podczas wysyłania wiadomości e-mail. Zmień ustawienia. (Błąd: %s)",
    "You need to set your account email before being able to send test emails. Go to %s for that." : "Zanim będziesz mógł wysyłać wiadomości testowe, musisz ustawić adres e-mail swojego konta. Idź do %s, aby to zrobić.",
    "Recently active" : "Ostatnio aktywny",
    "Disabled accounts" : "Wyłączone konta",
    "Settings" : "Ustawienia",
    "Invalid account" : "Nieprawidłowe konto",
    "Invalid mail address" : "Nieprawidłowy adres e-mail",
    "Settings saved" : "Zapisano ustawienia",
    "Unable to change full name" : "Nie można zmienić pełnej nazwy",
    "Unable to change email address" : "Nie można zmienić adresu e-mail",
    "Unable to set invalid phone number" : "Nie można ustawić nieprawidłowego numeru telefonu",
    "Unable to set invalid website" : "Nie można ustawić nieprawidłowej strony internetowej",
    "Some account data was invalid" : "Niektóre dane konta są nieprawidłowe",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Aby zweryfikować swoje konto Twittera, wyślij poniższego tweeta (upewnij się, że cały tekst zawiera się w jednej linii):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Aby zweryfikować swoją stronę umieść poniższą zawartość w katalogu głównym serwera pod adresem '.well-known/CloudIdVerificationCode.txt' (upewnij się, że cały tekst zawiera się w jednej linii):",
    "%1$s changed your password on %2$s." : "%1$s zmienił Twoje hasło w %2$s.",
    "Your password on %s was changed." : "Twoje hasło w %s zostało zmienione.",
    "Your password on %s was reset by an administrator." : "Twoje hasło w %s zostało zresetowane przez administratora",
    "Your password on %s was reset." : "Twoje hasło w %s zostało zresetowane.",
    "Password for %1$s changed on %2$s" : "Hasło dla %1$s zostało zmienione w %2$s",
    "Password changed for %s" : "Hasło zostało zmienione dla %s",
    "If you did not request this, please contact an administrator." : "Jeśli nie żądałeś tego, skontaktuj się z administratorem.",
    "Your email address on %s was changed." : "Twój adres e-mail w %s został zmieniony.",
    "Your email address on %s was changed by an administrator." : "Twój adres e-mail w %s został zmieniony przez administratora.",
    "Email address for %1$s changed on %2$s" : "Adres e-mail dla %1$s został zmieniony w %2$s",
    "Email address changed for %s" : "Został zmieniony adres e-mail dla %s",
    "The new email address is %s" : "Nowy adres e-mail to %s",
    "Appearance and accessibility" : "Wygląd i dostępność",
    "Personal settings" : "Ustawienia osobiste",
    "Administration settings" : "Ustawienia administracyjne",
    "Accounts" : "Konta",
    "Help & privacy" : "Pomoc i prywatność",
    "Your %s account was created" : "Twoje konto %s zostało utworzone",
    "Welcome aboard" : "Witamy na pokładzie",
    "Welcome aboard %s" : "Witamy na pokładzie %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Witamy na koncie %s, możesz dodawać, chronić i udostępniać swoje dane.",
    "Your Login is: %s" : "Twój login to: %s",
    "Set your password" : "Ustaw hasło",
    "Go to %s" : "Przejdź do %s",
    "Install Client" : "Zainstaluj klienta",
    "Logged in account must be a sub admin" : "Zalogowane konto musi być administratorem podrzędnym",
    "Personal" : "Osobiste",
    "Administration" : "Administracja",
    "Users" : "Użytkownicy",
    "Additional settings" : "Ustawienia dodatkowe",
    "Assistant" : "Asystent",
    "Administration privileges" : "Uprawnienia administracyjne",
    "Groupware" : "Praca grupowa",
    "Office" : "Biuro",
    "Overview" : "Przegląd",
    "Quick presets" : "Szybkie ustawienia",
    "Basic settings" : "Ustawienia podstawowe",
    "Sharing" : "Udostępnianie",
    "Availability" : "Dostępność",
    "Calendar" : "Kalendarz",
    "Personal info" : "Informacje osobiste",
    "Mobile & desktop" : "Mobilne i stacjonarne",
    "Artificial Intelligence" : "Sztuczna inteligencja",
    "None / STARTTLS" : "Brak / STARTTLS",
    "Email server" : "Serwer poczty",
    "Mail Providers" : "Dostawcy poczty",
    "Mail provider enables sending emails directly through the user's personal email account. At present, this functionality is limited to calendar invitations. It requires Nextcloud Mail 4.1 and an email account in Nextcloud Mail that matches the user's email address in Nextcloud." : "Dostawca poczty umożliwia wysyłanie wiadomości e-mail bezpośrednio za pośrednictwem osobistego konta e-mail użytkownika. Obecnie ta funkcjonalność ogranicza się do zaproszeń z kalendarza. Wymaga Nextcloud Mail 4.1 i konta e-mail w Nextcloud Mail odpowiadającego adresowi e-mail użytkownika w Nextcloud.",
    "Send emails using" : "Wysyłaj e-maile za pomocą",
    "User's email account" : "Konto e-mail użytkownika",
    "System email account" : "Systemowe konto e-mail",
    "Security & setup checks" : "Kontrole bezpieczeństwa i konfiguracji",
    "Settings presets" : "Ustawienia wstępne",
    "Background jobs" : "Zadania w tle",
    "Unlimited" : "Bez limitu",
    "Verifying" : "Sprawdzanie",
    "Verifying …" : "Weryfikacja…",
    "Verify" : "Zweryfikuj",
    "Allowed admin IP ranges" : "Dozwolone zakresy adresów IP administratora",
    "Admin IP filtering isn't applied." : "Filtrowanie IP administratora nie zostało zastosowane.",
    "Configuration key \"%1$s\" expects an array (%2$s found). Admin IP range validation will not be applied." : "Klucz konfiguracji \"%1$s\" oczekuje tablicy (znaleziono: %2$s). Walidacja zakresu IP administratora nie zostanie zastosowana.",
    "Configuration key \"%1$s\" contains invalid IP range(s): \"%2$s\"" : "Klucz konfiguracji \"%1$s\" zawiera nieprawidłowy(e) zakres(y) IP: \"%2$s\"",
    "Admin IP filtering is correctly configured." : "Filtrowanie adresów IP administratora jest poprawnie skonfigurowane.",
    "App directories owner" : "Właściciel katalogów aplikacji",
    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:\n%s" : "Niektóre katalogi aplikacji są własnością innego użytkownika tego serwera WWW. Może to wystąpić, gdy aplikacje zostały zainstalowane ręcznie. Sprawdź uprawnienia poniższych katalogów:\n%s",
    "App directories have the correct owner \"%s\"" : "Katalogi aplikacji mają prawidłowego właściciela „%s”",
    "Brute-force Throttle" : "Przepustowość brute-force",
    "Your remote address could not be determined." : "Nie można określić Twojego adresu zdalnego.",
    "Your remote address was identified as \"%s\" and is brute-force throttled at the moment slowing down the performance of various requests. If the remote address is not your address this can be an indication that a proxy is not configured correctly." : "Twój zdalny adres został zidentyfikowany jako \"%s\" i obecnie jest ograniczany metodą brute-force, co spowalnia wykonywanie różnych żądań. Jeśli adres zdalny nie jest Twoim adresem, może to oznaczać, że serwer proxy nie jest poprawnie skonfigurowany.",
    "Your remote address \"%s\" is not brute-force throttled." : "Twój zdalny adres \"%s\" nie jest ograniczany metodą brute-force.",
    "Old administration imported certificates" : "Dawne zaimportowane certyfikaty administracyjne",
    "A background job is pending that checks for administration imported SSL certificates. Please check back later." : "Oczekujące zadanie w tle sprawdza, czy administracja zaimportowała certyfikaty SSL. Sprawdź ponownie później.",
    "There are some administration imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Istnieje kilka certyfikatów SSL zaimportowanych przez administrację, które nie są już używane w Nextcloud 21. Można je zaimportować z wiersza poleceń za pomocą polecenia „occ security:certificates:import”. Ich ścieżki w katalogu danych pokazano poniżej.",
    "Code integrity" : "Integralność kodu",
    "Integrity checker has been disabled. Integrity cannot be verified." : "Sprawdzanie spójności zostało wyłączone. Nie można zweryfikować spójności.",
    "No altered files" : "Brak zmienionych plików",
    "Some files have not passed the integrity check. {link1} {link2}" : "Niektóre pliki nie przeszły kontroli spójności. {link1} {link2}",
    "List of invalid files…" : "Lista nieprawidłowych plików…",
    "Rescan…" : "Skanuj ponownie…",
    "Cron errors" : "Błędy Crona",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:\n%s" : "Nie można było wykonać zadania cron przez CLI. Pojawiły się następujące błędy techniczne:\n%s",
    "The last cron job ran without errors." : "Ostatnie zadanie cron przebiegło bez błędów.",
    "Cron last run" : "Ostatnie działanie Crona",
    "Last background job execution ran %s. Something seems wrong. {link}." : "Ostatnie wykonanie zadania w tle uruchomiono %s. Coś wydaje się nie tak. {link}.",
    "Last background job execution ran %s." : "Ostatnie wykonanie zadania w tle uruchomiono %s.",
    "Data directory protected" : "Katalog danych chroniony",
    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Twój katalog danych i pliki są prawdopodobnie dostępne przez Internet. Plik .htaccess nie działa. Zdecydowanie zaleca się skonfigurowanie serwera WWW w taki sposób, aby katalog danych nie był już dostępny, albo przenieś katalog danych poza główny katalog serwera WWW.",
    "Could not check that the data directory is protected. Please check manually that your server does not allow access to the data directory." : "Nie można sprawdzić, czy katalog danych jest chroniony. Sprawdź ręcznie, czy Twój serwer nie pozwala na dostęp do katalogu danych.",
    "Database missing columns" : "Brakujące kolumny bazy danych",
    "Missing optional column \"%s\" in table \"%s\"." : "Brakuje opcjonalnej kolumny „%s” w tabeli „%s”.",
    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "W bazie danych brakuje niektórych opcjonalnych kolumn. Ze względu na fakt, że dodawanie kolumn do dużych tabel może zająć trochę czasu oraz mogą one być opcjonalne, nie zostały  dodane automatycznie. Brakujące kolumny można dodać ręcznie w trakcie pracy instancji uruchamiając \"occ db:add-missing-columns\". Po dodaniu kolumn niektóre funkcje mogą poprawić czas reakcji lub użyteczność.",
    "Database missing indices" : "Brak indeksów w bazie danych",
    "Missing indices:" : "Brakujące indeksy:",
    "\"%s\" in table \"%s\"" : "„%s” w tabeli „%s”",
    "Detected some missing optional indices. Occasionally new indices are added (by Nextcloud or installed applications) to improve database performance. Adding indices can sometimes take awhile and temporarily hurt performance so this is not done automatically during upgrades. Once the indices are added, queries to those tables should be faster. Use the command `occ db:add-missing-indices` to add them." : "Wykryto brakujące opcjonalne indeksy. Od czasu do czasu nowe indeksy są dodawane (przez Nextcloud lub zainstalowane aplikacje), aby poprawić wydajność bazy danych. Dodanie indeksów może zająć trochę czasu i tymczasowo pogorszyć wydajność, więc nie są one dodawane automatycznie podczas aktualizacji. Po ich dodaniu zapytania do tych tabel powinny być szybsze. Użyj polecenia 'occ db:add-missing-indices', aby je dodać.",
    "Database missing primary keys" : "W bazie danych brakuje kluczy podstawowych",
    "Missing primary key on table \"%s\"." : "Brak klucza podstawowego w tabeli „%s”.",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "W bazie danych brakuje niektórych kluczy podstawowych. Ze względu na fakt, że dodanie kluczy głównych może zająć trochę czasu, dlatego nie zostały one dodane automatycznie. Brakujące klucze podstawowe można dodać ręcznie, w trakcie pracy instancji uruchamiając \"occ db:add-missing-primary-keys\".",
    "Database pending bigint migrations" : "Baza danych oczekująca na migracje bigint",
    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline." : "Niektórym kolumnom w bazie danych brakuje konwersji na typ big int. Zmiana typu kolumny w dużych tabelach może zająć dużo czasu, dlatego nie została przeprowadzona automatycznie. Uruchamiając 'occ db:convert-filecache-bigint', możesz ręcznie zastosować te zmiany – instancja musi być wtedy offline.",
    "Debug mode" : "Tryb debugowania",
    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "Instancja działa w trybie debugowania. Włącz to tylko dla wersji lokalnej, a nie w środowiskach produkcyjnych.",
    "Debug mode is disabled." : "Tryb debugowania jest wyłączony.",
    "Default phone region" : "Domyślny region telefonu",
    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective ISO 3166-1 code of the region to your config file." : "Twoja instalacja nie ma ustawionego domyślnego regionu telefonu. Jest to niezbędne do weryfikacji numerów podanych w profilach użytkowników bez numerów kierunkowych. Aby zezwolić na wprowadzanie numerów bez numeru kierunkowego dodaj \"default_phone_region\" zgodnie z kodami wg ISO 3166-1 do pliku konfiguracyjnego",
    "Email test" : "Test e-maila",
    "Mail delivery is disabled by instance config \"%s\"." : "Dostarczanie poczty jest wyłączone przez konfigurację instancji \"%s\".",
    "Email test was successfully sent" : "Test e-maila został pomyślnie wysłany",
    "You have not set or verified your email server configuration, yet. Please head over to the \"Basic settings\" in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "Nie ustawiłeś albo nie zweryfikowałeś konfiguracji serwera pocztowego. Skorzystaj z opcji podstawowych aby ustawić serwer pocztowy. Następnie użyj przycisku \"Wyślij email\" w celi weryfikacji wprowadzonych ustawień",
    "Transactional File Locking" : "Blokowanie plików transakcyjnych",
    "Transactional File Locking is disabled. This is not a a supported configuraton. It may lead to difficult to isolate problems including file corruption. Please remove the `'filelocking.enabled' => false` configuration entry from your `config.php` to avoid these problems." : "Transakcyjne blokowanie plików jest wyłączone. Nie jest to wspierana konfiguracja i może prowadzić do trudności w rozwiązywaniu problemów, w tym uszkodzenia plików. Usuń wpis `filelocking.enabled => false` z pliku `config.php`, aby uniknąć tych problemów.",
    "The database is used for transactional file locking. To enhance performance, please configure memcache, if available." : "Baza danych służy do blokowania plików transakcyjnych. Aby zwiększyć wydajność, skonfiguruj memcache, jeśli jest dostępny.",
    "Forwarded for headers" : "Przekazany do nagłówków",
    "Your \"trusted_proxies\" setting is not correctly set, it should be an array." : "Twoje ustawienie \"trusted_proxies\" nie jest poprawnie ustawione, powinna to być tablica.",
    "Your \"trusted_proxies\" setting is not correctly set, it should be an array of IP addresses - optionally with range in CIDR notation." : "Ustawienie `trusted_proxies` jest nieprawidłowe — powinno być tablicą adresów IP, opcjonalnie z zakresem w notacji CIDR.",
    "The reverse proxy header configuration is incorrect. This is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud." : "Konfiguracja nagłówka zwrotnego proxy jest nieprawidłowa. Jest to problem związany z bezpieczeństwem i może pozwolić osobie atakującej na sfałszowanie jego adresu IP jako widocznego dla Nextcloud.",
    "Your IP address was resolved as %s" : "Twój adres IP został rozpoznany jako %s",
    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud." : "Konfiguracja nagłówka zwrotnego proxy jest nieprawidłowa lub uzyskujesz dostęp do Nextcloud z zaufanego proxy. Jeśli nie, jest to problem związany z bezpieczeństwem i może pozwolić osobie atakującej na sfałszowanie jego adresu IP jako widocznego dla Nextcloud.",
    "HTTPS access and URLs" : "Dostęp HTTPS i adresy URL",
    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead. Without it some important web functionality like \"copy to clipboard\" or \"service workers\" will not work!" : "Niepewny dostęp do witryny za pośrednictwem protokołu HTTP. Zdecydowanie zaleca się skonfigurowanie serwera tak, aby zamiast tego wymagał protokołu HTTPS. Bez tego niektóre ważne funkcje internetowe, takie jak „kopiuj do schowka” lub „pracownicy usług” nie będą działać!",
    "Accessing site insecurely via HTTP." : "Niepewny dostęp do witryny za pośrednictwem protokołu HTTP.",
    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This likely means that your instance is behind a reverse proxy and the Nextcloud `overwrite*` config values are not set correctly." : "Uzyskujesz dostęp do swojej instancji przez bezpieczne połączenie, jednak instancja generuje niezabezpieczone adresy URL. Najprawdopodobniej instancja działa za odwrotnym proxy, a ustawienia `overwrite` w Nextcloud są nieprawidłowe.",
    "Your instance is generating insecure URLs. If you access your instance over HTTPS, this likely means that your instance is behind a reverse proxy and the Nextcloud `overwrite*` config values are not set correctly." : "Twoja instancja generuje niezabezpieczone adresy URL. Jeśli uzyskujesz dostęp do instancji przez HTTPS, prawdopodobnie działa ona za odwrotnym proxy, a wartości konfiguracyjne `overwrite` w Nextcloud nie są poprawnie ustawione.",
    "You are accessing your instance over a secure connection, and your instance is generating secure URLs." : "Uzyskujesz dostęp do swojej instancji poprzez bezpieczne połączenie i Twoja instancja generuje bezpieczne adresy URL.",
    "Internet connectivity" : "Łączność z Internetem",
    "Internet connectivity is disabled in configuration file." : "Łączność internetowa jest wyłączona w pliku konfiguracyjnym.",
    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Serwer nie ma aktywnego połączenia z Internetem. Wiele połączeń nie może być zrealizowanych. Oznacza to, że część funkcji takich jak zewnętrzny magazyn, powiadomienia o aktualizacjach lub instalacja aplikacji firm trzecich nie będą działać. Dostęp zdalny do plików oraz wysyłanie powiadomień e-mailowych również może nie działać. Nawiąż połączenie z tego serwera do Internetu, aby korzystać ze wszystkich funkcji.",
    "JavaScript modules support" : "Obsługa modułów JavaScript",
    "Unable to run check for JavaScript support. Please remedy or confirm manually if your webserver serves `.mjs` files using the JavaScript MIME type." : "Nie można przeprowadzić sprawdzenia obsługi JavaScript. Napraw lub ręcznie potwierdź, czy Twój serwer WWW obsługuje pliki `.mjs` z odpowiednim typem MIME dla JavaScript.",
    "Your webserver does not serve `.mjs` files using the JavaScript MIME type. This will break some apps by preventing browsers from executing the JavaScript files. You should configure your webserver to serve `.mjs` files with either the `text/javascript` or `application/javascript` MIME type." : "Twój serwer WWW nie obsługuje plików `.mjs` z typem MIME dla JavaScript. Może to uniemożliwić wykonywanie niektórych skryptów przez przeglądarkę. Skonfiguruj serwer do obsługi plików `.mjs` z typem `text/javascript` lub `application/javascript`.",
    "JavaScript source map support" : "Obsługa mapy źródłowej JavaScript",
    "Your webserver is not set up to serve `.js.map` files. Without these files, JavaScript Source Maps won't function properly, making it more challenging to troubleshoot and debug any issues that may arise." : "Twój serwer WWW nie jest skonfigurowany do obsługi plików `.js.map`. Bez tych plików mapy źródłowe JavaScript nie będą działać poprawnie, co utrudni debugowanie i rozwiązywanie problemów.",
    "Old server-side-encryption" : "Stare szyfrowanie po stronie serwera",
    "Disabled" : "Wyłączone",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "Stary format szyfrowania po stronie serwera jest włączony. Zalecamy wyłączenie jego.",
    "Logging level" : "Poziom logowania",
    "The %1$s configuration option must be a valid integer value." : "Opcja konfiguracyjna %1$s musi mieć prawidłową wartość całkowitą.",
    "The logging level is set to debug level. Use debug level only when you have a problem to diagnose, and then reset your log level to a less-verbose level as it outputs a lot of information, and can affect your server performance." : "Poziom logowania jest ustawiony na poziom debugowania. Używaj go tylko w celu diagnozowania problemów, a następnie przywróć mniej szczegółowy poziom, ponieważ ten generuje bardzo dużo informacji i może wpłynąć na wydajność serwera.",
    "Logging level configured correctly." : "Poziom logowania został poprawnie skonfigurowany.",
    "Maintenance window start" : "Rozpoczęcie okna konserwacji",
    "Server has no maintenance window start time configured. This means resource intensive daily background jobs will also be executed during your main usage time. We recommend to set it to a time of low usage, so users are less impacted by the load caused from these heavy tasks." : "Serwer nie ma skonfigurowanego czasu rozpoczęcia okna konserwacji. Oznacza to, że codzienne zadania w tle wymagające dużych zasobów będą również wykonywane w głównym czasie użytkowania. Zalecamy ustawienie czasu niskiego użycia, aby użytkownicy byli mniej obciążeni obciążeniem wynikającym z tych ciężkich zadań.",
    "Maintenance window to execute heavy background jobs is between {start}:00 UTC and {end}:00 UTC" : "Okno konserwacyjne do wykonywania obciążających zadań w tle przypada między {start}):00 UTC a {end}:00 UTC",
    "Memcache" : "Pamięć podręczna",
    "Memcached is configured as distributed cache, but the wrong PHP module (\"memcache\") is installed. Please install the PHP module \"memcached\"." : "Memcached jest skonfigurowany jako rozproszona pamięć podręczna, ale zainstalowano niewłaściwy moduł PHP (\"memcache\"). Zainstaluj moduł PHP \"memcached”.",
    "Memcached is configured as distributed cache, but the PHP module \"memcached\" is not installed. Please install the PHP module \"memcached\"." : "Memcached jest skonfigurowany jako rozproszona pamięć podręczna, ale moduł PHP \"memcached” nie jest zainstalowany. Proszę zainstalować moduł PHP \"memcached”.",
    "No memory cache has been configured. To enhance performance, please configure a memcache, if available." : "Nie skonfigurowano pamięci podręcznej. Aby zwiększyć wydajność, skonfiguruj memcache, jeśli jest dostępne.",
    "Failed to write and read a value from local cache." : "Nie udało się zapisać ani odczytać wartości z lokalnej pamięci podręcznej.",
    "Failed to write and read a value from distributed cache." : "Nie udało się zapisać ani odczytać wartości z rozproszonej pamięci podręcznej.",
    "Configured" : "Skonfigurowano",
    "Mimetype migrations available" : "Dostępne migracje typów MIME",
    "One or more mimetype migrations are available. Occasionally new mimetypes are added to better handle certain file types. Migrating the mimetypes take a long time on larger instances so this is not done automatically during upgrades. Use the command `occ maintenance:repair --include-expensive` to perform the migrations." : "Jedna lub więcej migracji typów MIME jest dostępna. Czasami nowe typy MIME są dodawane, aby lepiej obsługiwać określone typy plików. Migracja typów MIME może długo trwać w większych instancjach, dlatego nie jest przeprowadzana automatycznie podczas aktualizacji. Użyj polecenia `occ maintenance:repair --include-expensive`, aby przeprowadzić migrację.",
    "MySQL row format" : "Format wiersza MySQL",
    "You are not using MySQL" : "Nie używasz MySQL",
    "None of your tables use ROW_FORMAT=Compressed" : "Żadna z twoich tabel nie używa ROW_FORMAT=Compressed",
    "Incorrect row format found in your database. ROW_FORMAT=Dynamic offers the best database performances for Nextcloud. Please update row format on the following list: %s." : "W bazie danych wykryto nieprawidłowy format wiersza. ROW_FORMAT=Dynamic zapewnia najlepszą wydajność bazy danych dla Nextcloud. Zaktualizuj format wiersza dla następującej tabeli: %s",
    "MySQL Unicode support" : "Obsługa Unicode MySQL",
    "MySQL is used as database and does support 4-byte characters" : "MySQL jest używany jako baza danych i obsługuje znaki 4-bajtowe",
    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL." : "MySQL jest używany jako baza danych, ale nie obsługuje znaków 4-bajtowych. Aby móc bez problemów obsługiwać znaki 4-bajtowe (takie jak emoji) na przykład w nazwach plików lub komentarzach, zaleca się włączenie obsługi 4-bajtowych w MySQL.",
    "OCS provider resolving" : "Rozpoznawanie dostawcy OCS",
    "Could not check if your web server properly resolves the OCM and OCS provider URLs." : "Nie można sprawdzić, czy serwer WWW prawidłowo rozwiązuje adresy URL dostawców OCM i OCS.",
    "Your web server is not properly set up to resolve %1$s.\nThis is most likely related to a web server configuration that was not updated to deliver this folder directly.\nPlease compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx.\nOn Nginx those are typically the lines starting with \"location ~\" that need an update." : "Twój serwer WWW nie jest prawidłowo skonfigurowany do obsługi %1$s.\nPrawdopodobnie jest to związane z nieaktualną konfiguracją serwera, która nie umożliwia bezpośredniego dostępu do tego folderu. \nPorównaj konfigurację z regułami w \".htaccess\" (dla Apache) lub z instrukcją dla Nginx. \nDla Nginx najczęściej wymagają aktualizacji reguły zaczynające się od \"location ~\".",
    "Overwrite CLI URL" : "Nadpisanie adresu URL w CLI",
    "The \"overwrite.cli.url\" option in your config.php is correctly set to \"%s\"." : "Opcja \"overwrite.cli.url” w pliku config.php jest poprawnie ustawiona na \"%s\".",
    "The \"overwrite.cli.url\" option in your config.php is set to \"%s\" which is a correct URL. Suggested URL is \"%s\"." : "Opcja \"overwrite.cli.url” w pliku config.php jest ustawiona na \"%s”, co jest poprawnym adresem URL. Sugerowany adres URL to ”%s\".",
    "Please make sure to set the \"overwrite.cli.url\" option in your config.php file to the URL that your users mainly use to access this Nextcloud. Suggestion: \"%s\". Otherwise there might be problems with the URL generation via cron. (It is possible though that the suggested URL is not the URL that your users mainly use to access this Nextcloud. Best is to double check this in any case.)" : "Upewnij się, że opcja \"overwrite.cli.url” w pliku config.php jest ustawiona na adres URL, którego użytkownicy najczęściej używają do uzyskania dostępu do Nextcloud. Sugerowany adres: \"%s”. W przeciwnym razie mogą wystąpić problemy z generowaniem adresu URL przez cron. (Możliwe, że sugerowany adres nie jest tym, którego użytkownicy używają najczęściej — warto to sprawdzić).",
    "PHP APCu configuration" : "Konfiguracja PHP APCu",
    "Your APCu cache has been running full, consider increasing the apc.shm_size php setting." : "Twoja pamięć podręczna APCu jest pełna. Rozważ zwiększenie ustawienia php apc.shm_size.",
    "Your APCu cache is almost full at %s%%, consider increasing the apc.shm_size php setting." : " Twoja pamięć podręczna APCu jest prawie pełna: %s%%. Rozważ zwiększenie ustawienia apc.shm_size w PHP.",
    "PHP default charset" : "Domyślny zestaw znaków PHP",
    "PHP configuration option \"default_charset\" should be UTF-8" : "Opcja konfiguracyjna PHP \"default_charset\" powinna mieć format UTF-8",
    "PHP set_time_limit" : "PHP set_time_limit",
    "The function is available." : "Funkcja jest dostępna.",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "Funkcja PHP \"set_time_limit\" nie jest dostępna. Może to spowodować zatrzymanie skryptów w trakcie wykonywania, przerywając instalację. Zdecydowanie zaleca się włączenie tej funkcji.",
    "Freetype" : "Typ dowolny",
    "Supported" : "Wspierany",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Twoje PHP nie posiada wsparcia dla FreeType, co powoduje problemy ze zdjęciami profilowymi i interfejsem ustawień.",
    "PHP getenv" : "PHP getenv",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "Wygląda na to, że PHP nie jest poprawnie skonfigurowany do wysyłania zapytań o zmienne środowiskowe systemu. Test gentenv(\"PATH\") zwraca tylko pustą wartość.",
    "PHP file size upload limit" : "Limit rozmiaru pliku przesyłanego przez PHP",
    "The PHP upload_max_filesize is too low. A size of at least %1$s is recommended. Current value: %2$s." : "Wartość upload_max_filesize w PHP jest zbyt niska. Zalecana wartość to co najmniej %1$s. Obecna wartość: %2$s.",
    "The PHP post_max_size is too low. A size of at least %1$s is recommended. Current value: %2$s." : "Wartość post_max_size w PHP jest zbyt niska. Zalecana wartość to co najmniej %1$s. Obecna wartość: %2$s.",
    "The PHP max_input_time is too low. A time of at least %1$s is recommended. Current value: %2$s." : "Wartość max_input_time w PHP jest zbyt niska. Zalecany czas to co najmniej %1$s. Obecna wartość: %2$s.",
    "The PHP max_execution_time is too low. A time of at least %1$s is recommended. Current value: %2$s." : "Wartość max_execution_time w PHP jest zbyt niska. Zalecany czas to co najmniej %1$s. Obecna wartość: %2$s.",
    "PHP memory limit" : "Limit pamięci PHP",
    "The PHP memory limit is below the recommended value of %s. Some features or apps - including the Updater - may not function properly." : "Limit pamięci PHP jest poniżej zalecanej wartości %s. Niektóre funkcje lub aplikacje — w tym aktualizator — mogą nie działać prawidłowo.",
    "PHP modules" : "Moduły PHP",
    "increases language translation performance and fixes sorting of non-ASCII characters" : "zwiększa wydajność tłumaczenia języka i naprawia sortowanie znaków innych niż ASCII",
    "for Argon2 for password hashing and Ed25519 signature verification for RFC 9421 http message signatures" : "dla Argon2 do hashowania hasła oraz weryfikacji podpisu Ed25519 dla sygnatur wiadomości RFC 9421",
    "required for SFTP storage and recommended for WebAuthn performance" : "wymagane dla przechowywania SFTP i zalecane dla wydajności WebAuthn",
    "for picture rotation in server and metadata extraction in the Photos app" : "do obracania zdjęć na serwerze i ekstrakcji metadanych w aplikacji Zdjęcia",
    "This instance is missing some required PHP modules. It is required to install them: %s." : "Ta instancja ma brakujące moduły PHP. Należy zainstalować następujące moduły: %s",
    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them:\n%s" : "W tej instancji brakuje niektórych zalecanych modułów PHP. W celu poprawy wydajności i lepszej kompatybilności zdecydowanie zaleca się ich zainstalowanie:\n%s",
    "PHP opcache" : "PHP OPCache",
    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "Moduł PHP OPcache nie jest wczytany. Aby uzyskać lepszą wydajność, zaleca się wczytanie go do instalacji PHP.",
    "OPcache is disabled. For better performance, it is recommended to apply \"opcache.enable=1\" to your PHP configuration." : "OPcache jest wyłączone. Aby uzyskać lepszą wydajność, zaleca się zastosowanie „opcache.enable=1” w konfiguracji PHP.",
    "The shared memory based OPcache is disabled. For better performance, it is recommended to apply \"opcache.file_cache_only=0\" to your PHP configuration and use the file cache as second level cache only." : "Oparta na pamięci współdzielonej pamięć OPcache jest wyłączona. Aby uzyskać lepszą wydajność, zaleca się zastosowanie „opcache.file_cache_only=0” do konfiguracji PHP i używanie pamięci podręcznej plików tylko jako pamięci podręcznej drugiego poziomu.",
    "OPcache is not working as it should, opcache_get_status() returns false, please check configuration." : "OPcache nie działa prawidłowo — opcache_get_status() zwraca false. Sprawdź konfigurację.",
    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be kept in the cache, it is recommended to apply \"opcache.max_accelerated_files\" to your PHP configuration with a value higher than \"%s\"." : "Maksymalna liczba kluczy OPcache jest bliska przekroczenia. Aby zapewnić, że wszystkie skrypty będą mogły zostać zapisane w pamięci podręcznej, zaleca się ustawienie w konfiguracji PHP wartości \"opcache.max_accelerated_files\" większej niż \"%s\".",
    "The OPcache buffer is nearly full. To assure that all scripts can be hold in cache, it is recommended to apply \"opcache.memory_consumption\" to your PHP configuration with a value higher than \"%s\"." : "Bufor OPcache jest prawie pełny. Aby zapewnić możliwość przechowywania wszystkich skryptów w pamięci podręcznej, zaleca się ustawienie \"opcache.memory_consumption\" w konfiguracji PHP na wartość większą niż \"%s\".",
    "The OPcache interned strings buffer is nearly full. To assure that repeating strings can be effectively cached, it is recommended to apply \"opcache.interned_strings_buffer\" to your PHP configuration with a value higher than \"%s\"." : "Bufor ciągów zinterowanych OPcache jest prawie pełny. Aby zapewnić skuteczne buforowanie powtarzających się ciągów, zaleca się ustawienie \"opcache.interned_strings_buffer\" w konfiguracji PHP na wartość większą niż \"%s\".",
    "OPcache is configured to remove code comments. With OPcache enabled, \"opcache.save_comments=1\" must be set for Nextcloud to function." : "OPcache jest skonfigurowany do usuwania komentarzy w kodzie. Aby Nextcloud działał poprawnie, musi być ustawione \"opcache.save_comments=1\".",
    "Nextcloud is not allowed to use the OPcache API. With OPcache enabled, it is highly recommended to include all Nextcloud directories with \"opcache.restrict_api\" or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud nie może korzystać z API OPcache. Po włączeniu OPcache zdecydowanie zaleca się uwzględnienie wszystkich katalogów Nextcloud z „opcache.restrict_api” lub odznaczenie tego ustawienia, aby wyłączyć ograniczenia API OPcache, aby zapobiec błędom podczas aktualizacji rdzenia Nextcloud lub aplikacji.",
    "Checking from CLI, OPcache checks have been skipped." : "Sprawdzanie z poziomu CLI – pominięto testy OPcache.",
    "The PHP OPcache module is not properly configured. %s." : "Moduł OPcache PHP nie jest poprawnie skonfigurowany. %s.",
    "Correctly configured" : "Poprawnie skonfigurowany",
    "PHP version" : "Wersja PHP",
    "You are currently running PHP %1$s. PHP %2$s is deprecated since Nextcloud %3$s. Nextcloud %4$s may require at least PHP %5$s. Please upgrade to one of the officially supported PHP versions provided by the PHP Group as soon as possible." : "Obecnie używasz PHP %1$s. PHP %2$s jest przestarzały od Nextcloud %3$s. Nextcloud %4$s może wymagać co najmniej PHP %5$s. Zaktualizuj do jednej z oficjalnie wspieranych wersji PHP od PHP Group tak szybko, jak to możliwe.",
    "You are currently running PHP %s." : "Aktualnie używasz PHP w wersji %s",
    "PHP \"output_buffering\" option" : "Opcja PHP \"output_buffering\"",
    "PHP configuration option \"output_buffering\" must be disabled" : "Opcja konfiguracji PHP \"output_buffering\" musi być wyłączona",
    "Push service" : "Usługa push",
    "Valid enterprise license" : "Ważna licencja korporacyjna",
    "Free push service" : "Wolna usługa push",
    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications are limited to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at {link}." : "To jest nieobsługiwana kompilacja społecznościowa Nextcloud. Biorąc pod uwagę rozmiar tej instancji, nie można zagwarantować wydajności, niezawodności i skalowalności. Powiadomienia push są ograniczone, aby uniknąć przeciążenia naszej bezpłatnej usługi. Dowiedz się więcej o zaletach Nextcloud Enterprise pod adresem {link}.",
    "Random generator" : "Generator losowy",
    "No suitable source for randomness found by PHP which is highly discouraged for security reasons." : "Brak odpowiedniego źródła dla losowości znalezionej przez PHP, co jest zdecydowanie odradzane ze względów bezpieczeństwa.",
    "Secure" : "Bezpieczne",
    "Configuration file access rights" : "Prawa dostępu do pliku konfiguracyjnego",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Włączono konfigurację tylko do odczytu. Zapobiega to ustawianiu niektórych konfiguracji przez interfejs internetowy. Ponadto plik musi być zapisany ręcznie przy każdej aktualizacji.",
    "Nextcloud configuration file is writable" : "Plik konfiguracyjny Nextcloud jest \"do zapisu\"",
    "Sanitize and merge duplicate system tags available" : "Wydziel i połącz dostępne zduplikowane tagi systemowe",
    "One or more system tags need to be sanitized or merged. This can take a long time on larger instances so this is not done automatically during upgrades. Use the command `occ maintenance:repair --include-expensive` to perform the migrations." : "Co najmniej jeden z tagów systemowych powinien zostaw wydzielony lub połączony. To może potrwać dłuższej w większych instancjach i dlatego nie jest robione automatycznie przy aktualizacjach. Użyj `occ maintenance:repair --include-expensive` aby przeprowadzić migrację.",
    "Scheduling objects table size" : "Planowanie rozmiaru tabeli obiektów",
    "You have more than %s rows in the scheduling objects table. Please run the expensive repair jobs via occ maintenance:repair --include-expensive." : "W tabeli obiektów planowania znajduje się więcej niż %s wierszy. Proszę wykonywać kosztowne prace naprawcze poprzez occ maintenance:repair --include-expensive.",
    "Scheduling objects table size is within acceptable range." : "Rozmiar tabeli obiektów planowania mieści się w dopuszczalnym zakresie.",
    "HTTP headers" : "Nagłówki HTTP",
    "- The `%1$s` HTTP header is not set to `%2$s`. Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "Nagłówek HTTP `%1$s` nie jest ustawiony na `%2$s`. Niektóre funkcje mogą nie działać poprawnie, dlatego zaleca się dostosowanie tego ustawienia.",
    "- The `%1$s` HTTP header is not set to `%2$s`. This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "Nagłówek HTTP `%1$s` nie jest ustawiony na `%2$s`. Stanowi to potencjalne zagrożenie dla bezpieczeństwa lub prywatności, dlatego zaleca się dostosowanie tego ustawienia.",
    "- The `%1$s` HTTP header is not set to `%2$s`, `%3$s`, `%4$s`, `%5$s` or `%6$s`. This can leak referer information. See the {w3c-recommendation}." : "Nagłówek HTTP `%1$s` nie jest ustawiony na `%2$s`,`%3$s`,`%4$s`,`%5$s` lub `%6$s`. Może to powodować wyciek informacji o odsyłaczu. Zobacz {w3c-recommendation}",
    "- The `Strict-Transport-Security` HTTP header is not set to at least `%d` seconds (current value: `%d`). For enhanced security, it is recommended to use a long HSTS policy." : "Nagłówek HTTP `Strict-Transport-Security` nie jest ustawiony na co najmniej `%d` sekund (obecna wartość: `%d`). Dla lepszego bezpieczeństwa zaleca się stosowanie długiej polityki HSTS.",
    "- The `Strict-Transport-Security` HTTP header is malformed: `%s`. For enhanced security, it is recommended to enable HSTS." : "Nagłówek HTTP `Strict-Transport-Security` jest nieprawidłowy: `%s`. Dla lepszego bezpieczeństwa zaleca się włączenie HSTS.",
    "- The `Strict-Transport-Security` HTTP header is not set (should be at least `%d` seconds). For enhanced security, it is recommended to enable HSTS." : "Nagłówek HTTP `Strict-Transport-Security` nie jest ustawiony (powinien wynosić co najmniej `%d` sekund). Dla lepszego bezpieczeństwa zaleca się włączenie HSTS.",
    "Some headers are not set correctly on your instance" : "Niektóre nagłówki nie są poprawnie ustawione w Twojej instancji",
    "Could not check that your web server serves security headers correctly. Please check manually." : "Nie można sprawdzić, czy serwer WWW prawidłowo obsługuje nagłówki zabezpieczeń. Sprawdź ręcznie.",
    "Could not check that your web server serves security headers correctly, unable to query `%s`" : "Nie można sprawdzić, czy serwer WWW poprawnie wysyła nagłówki bezpieczeństwa, nie udało się wykonać zapytania `%s`",
    "Your server is correctly configured to send security headers." : "Twój serwer jest poprawnie skonfigurowany do wysyłania nagłówków zabezpieczeń.",
    "Configuration server ID" : "Identyfikator serwera konfiguracji",
    "Server identifier isn’t configured. It is recommended if your Nextcloud instance is running on several PHP servers. Add a server ID in your configuration." : "Identyfikator serwera nie jest skonfigurowany. Jest to zalecane, jeśli instancja Nextcloud działa na kilku serwerach PHP. Dodaj identyfikator serwera w konfiguracji.",
    "\"%d\" is not a valid server identifier. It must be between 0 and 511." : "\"%d\" nie jest prawidłowym identyfikatorem serwera. Musi mieć wartość między 0 a 511.",
    "Server identifier is configured and valid." : "Identyfikator serwera jest skonfigurowany i prawidłowy.",
    "Database version" : "Wersja bazy danych",
    "MariaDB version 10.6 detected, this version is end-of-life and only supported as part of Ubuntu 22.04. MariaDB >=%1$s and <=%2$s is suggested for best performance, stability and functionality with this version of Nextcloud." : "Wykryto MariaDB w wersji 10.3, ta wersja jest nieobsługiwana i wspierana jedynie w ramach Ubuntu 20.04. Zalecana jest MariaDB >=%1$s i <= %2$s dla najlepszej wydajności, stabilności i kompatybilności z tą wersją Nextcloud.",
    "MariaDB version \"%1$s\" detected. MariaDB >=%2$s and <=%3$s is suggested for best performance, stability and functionality with this version of Nextcloud." : "Wykryto MariaDB `%1$s`. Zalecana jest wersja >= %2$s i <= %3$s dla najlepszej wydajności, stabilności i kompatybilności z tą wersją Nextcloud.",
    "MySQL version \"%1$s\" detected. MySQL >=%2$s and <=%3$s is suggested for best performance, stability and functionality with this version of Nextcloud." : "Wykryto MySQL w wersji \"%1$s\". Zalecana jest wersja MySQL >= %2$s i <= %3$s dla najlepszej wydajności, stabilności i funkcjonalności w tej wersji Nextcloud.",
    "PostgreSQL version \"%1$s\" detected. PostgreSQL >=%2$s and <=%3$s is suggested for best performance, stability and functionality with this version of Nextcloud." : "Wykryto PostgreSQL w wersji \"%1$s\". Zalecana jest wersja PostgreSQL >= %2$s i <= %3$s dla najlepszej wydajności, stabilności i funkcjonalności w tej wersji Nextcloud.",
    "Nextcloud %d does not support your current version, so be sure to update the database before updating your Nextcloud Server." : "Nextcloud %d nie obsługuje bieżącej wersji, dlatego przed aktualizacją serwera Nextcloud należy zaktualizować bazę danych.",
    "Oracle version \"%1$s\" detected. Oracle >=%2$s and <=%3$s is suggested for best performance, stability and functionality with this version of Nextcloud." : "Wykryto wersję Oracle \"%1$s\". Dla najlepszej wydajności, stabilności i funkcjonalności z tą wersją Nextcloud zalecana jest Oracle ≥ %2$s i ≤ %3$s.",
    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend. This is particularly recommended when using the desktop client for file synchronisation. To migrate to another database use the command line tool: \"occ db:convert-type\"." : "SQLite jest obecnie używany jako baza danych zaplecza. W przypadku większych instalacji zalecamy przejście na inną bazę danych. Jest to szczególnie zalecane w przypadku korzystania z klienta stacjonarnego do synchronizacji plików. Aby przeprowadzić migrację do innej bazy danych, użyj narzędzia wiersza poleceń: „occ db:convert-type”.",
    "Unknown database platform" : "Nieznana platforma baz danych",
    "Architecture" : "Architektura",
    "64-bit" : "64-bit",
    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit!" : "Wygląda na to, że korzystasz z 32-bitowej wersji PHP. Nextcloud wymaga wersji 64-bitowej do poprawnego działania. Zaktualizuj proszę swój system i PHP do wersji 64-bitowych!",
    "Task Processing pickup speed" : "Prędkość pobierania zadań do przetworzenia",
    "_No scheduled tasks in the last day._::_No scheduled tasks in the last %n days._" : ["Brak zaplanowanych zadań w ciągu ostatniego dnia.","Brak zaplanowanych zadań w ciągu ostatnich %n dni.","Brak zaplanowanych zadań w ciągu ostatnich %n dni.","Brak zaplanowanych zadań w ciągu ostatnich %n dni."],
    "_The task pickup speed has been ok in the last day._::_The task pickup speed has been ok in the last %n days._" : ["Szybkość podejmowania zadań była prawidłowa w ciągu ostatniego dnia.","Szybkość podejmowania zadań była prawidłowa w ciągu ostatnich %n dni.","Szybkość podejmowania zadań była prawidłowa w ciągu ostatnich %n dni.","Szybkość podejmowania zadań była prawidłowa w ciągu ostatnich %n dni."],
    "_The task pickup speed has been slow in the last day. Many tasks took longer than 4 minutes to be picked up. Consider setting up a worker to process tasks in the background._::_The task pickup speed has been slow in the last %n days. Many tasks took longer than 4 minutes to be picked up. Consider setting up a worker to process tasks in the background._" : ["Szybkość podejmowania zadań była niska w ciągu ostatniego dnia. Wiele zadań było podejmowanych dłużej niż 4 minuty. Rozważ skonfigurowanie workera do przetwarzania zadań w tle.","Szybkość podejmowania zadań była niska w ciągu ostatnich %n dni. Wiele zadań było podejmowanych dłużej niż 4 minuty. Rozważ skonfigurowanie workera do przetwarzania zadań w tle.","Szybkość podejmowania zadań była niska w ciągu ostatnich %n dni. Wiele zadań było podejmowanych dłużej niż 4 minuty. Rozważ skonfigurowanie workera do przetwarzania zadań w tle.","Szybkość podejmowania zadań była niska w ciągu ostatnich %n dni. Wiele zadań było podejmowanych dłużej niż 4 minuty. Rozważ skonfigurowanie workera do przetwarzania zadań w tle."],
    "Task Processing success rate" : "Wskaźnik powodzenia przetwarzania zadań",
    "_No scheduled tasks in the last %n day._::_No scheduled tasks in the last %n days._" : ["Brak zaplanowanych zadań w ciągu ostatniego dnia.","Brak zaplanowanych zadań w ostatnich %n dniach.","Brak zaplanowanych zadań w ostatnich %n dniach.","Brak zaplanowanych zadań w ciągu ostatnich %n dni."],
    "_Most tasks were successful in the last %n day._::_Most tasks were successful in the last %n days._" : ["Większość zadań zakończyła się sukcesem w ciągu ostatniego dnia.","Większość zadań zakończyła się sukcesem w ciągu ostatnich %n dni.","Większość zadań zakończyła się sukcesem w ciągu ostatnich %n dni.","Większość zadań zakończyła się sukcesem w ciągu ostatnich %n dni."],
    "_A lot of tasks failed in the last day. Consider checking the nextcloud log for errors and investigating whether the AI provider apps have been set up correctly._::_A lot of tasks failed in the last %n days. Consider checking the nextcloud log for errors and investigating whether the AI provider apps have been set up correctly._" : ["Wiele zadań zakończyło się niepowodzeniem w ciągu ostatniego dnia. Rozważ sprawdzenie logów Nextcloud pod kątem błędów oraz upewnienie się, że aplikacje dostawców AI zostały poprawnie skonfigurowane.","Wiele zadań zakończyło się niepowodzeniem w ciągu ostatnich %n dni. Rozważ sprawdzenie logów Nextcloud pod kątem błędów oraz upewnienie się, że aplikacje dostawców AI zostały poprawnie skonfigurowane.","Wiele zadań zakończyło się niepowodzeniem w ciągu ostatnich %n dni. Rozważ sprawdzenie logów Nextcloud pod kątem błędów oraz upewnienie się, że aplikacje dostawców AI zostały poprawnie skonfigurowane.","Wiele zadań zakończyło się niepowodzeniem w ciągu ostatnich %n dni. Rozważ sprawdzenie logów Nextcloud pod kątem błędów oraz upewnienie się, że aplikacje dostawców AI zostały poprawnie skonfigurowane."],
    "Task Processing worker status" : "Status roboczego procesu przetwarzania zadań",
    "_The Task Processing worker has run in the last %n minute._::_The Task Processing worker has run in the last %n minutes._" : ["Wątek przetwarzania zadań był aktywny w ciągu ostatniej minuty.","Wątek przetwarzania zadań był aktywny w ciągu ostatnich %n minut.","Wątek przetwarzania zadań był aktywny w ciągu ostatnich %n minut.","Wątek przetwarzania zadań był aktywny w ciągu ostatnich %n minut."],
    "The Task Processing worker does not seem to be running. The last run was at %s." : "Proces roboczy przetwarzania zadań prawdopodobnie nie działa. Ostatnie uruchomienie miało miejsce o %s.",
    "The Task Processing worker does not seem to be running. It seems it has never run so far." : "Proces roboczy przetwarzania zadań prawdopodobnie nie działa. Wygląda na to, że nigdy nie został uruchomiony",
    "Temporary space available" : "Dostępna przestrzeń tymczasowa",
    "Error while checking the temporary PHP path - it was not properly set to a directory. Returned value: %s" : "Błąd podczas sprawdzania tymczasowej ścieżki PHP - nie została ona poprawnie ustawiona na katalog. Wartość zwrócona: %s",
    "The PHP function \"disk_free_space\" is disabled, which prevents the check for enough space in the temporary directories." : "Funkcja PHP „disk_free_space” jest wyłączona, co uniemożliwia sprawdzenie wystarczającej ilości miejsca w katalogach tymczasowych.",
    "Error while checking the available disk space of temporary PHP path or no free disk space returned. Temporary path: %s" : "Błąd podczas sprawdzania dostępnego miejsca na dysku tymczasowej ścieżki PHP lub zwrócona informacja o braku wolnego miejsca na dysku. Ścieżka tymczasowa: %s",
    "- %.1f GiB available in %s (PHP temporary directory)" : "- %.1f GiB dostępne w %s (tymczasowy katalog PHP)",
    "- %.1f GiB available in %s (Nextcloud temporary directory)" : "- %.1f dostępne w %s (tymczasowy katalog Nextcloud)",
    "Temporary directory is correctly configured:\n%s" : "Katalog tymczasowy jest poprawnie skonfigurowany:\n%s",
    "This instance uses an S3 based object store as primary storage, and has enough space in the temporary directory.\n%s" : "Ta instancja używa magazynu obiektowego opartego na S3 jako głównego magazynu i posiada wystarczającą ilość miejsca w katalogu tymczasowym.\n%s",
    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GiB of free space available in the temp directory of PHP. To improve this please change the temporary directory in the php.ini or make more space available in that path. \nChecking the available space in the temporary path resulted in %.1f GiB instead of the recommended 50 GiB. Path: %s" : "Ta instancja używa magazynu obiektowego opartego na S3 jako głównego magazynu. Przesłane pliki są tymczasowo przechowywane na serwerze, dlatego zaleca się, aby w katalogu tymczasowym PHP było dostępnych 50 GiB wolnego miejsca. Aby to poprawić, zmień katalog tymczasowy w pliku php.ini lub zwiększ dostępne miejsce w tej lokalizacji.\nSprawdzenie dostępnego miejsca w katalogu tymczasowym wykazało %.1f GiB zamiast zalecanych 50 GiB. Ścieżka: %s",
    "Database transaction isolation level" : "Poziom izolacji transakcji bazy danych",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Baza danych nie działa z poziomem izolacji transakcji \"READ COMMITTED\". Może to powodować problemy, gdy wiele akcji jest wykonywanych równolegle.",
    "Was not able to get transaction isolation level: %s" : "Nie udało się uzyskać poziomu izolacji transakcji: %s",
    "Second factor configuration" : "Konfiguracja drugiego czynnika",
    "This instance has no second factor provider available." : "Ta instancja nie ma dostępnego dostawcy drugiego czynnika.",
    "Second factor providers are available but two-factor authentication is not enforced." : "Dostawcy drugiego czynnika są dostępni, ale uwierzytelnianie dwuskładnikowe nie jest wymuszane.",
    "Second factor providers are available and enforced: %s." : "Dostawcy drugiego czynnika są dostępni i wymuszani: %s.",
    ".well-known URLs" : "adresy URL `.well-known`",
    "`check_for_working_wellknown_setup` is set to false in your configuration, so this check was skipped." : "`check_for_working_wellknown_setup` jest ustawione na false w konfiguracji, więc to sprawdzenie zostało pominięte.",
    "Could not check that your web server serves `.well-known` correctly. Please check manually." : "Nie można sprawdzić, czy Twój serwer WWW poprawnie obsługuje `.well-known`. Sprawdź ręcznie.",
    "Your web server is not properly set up to resolve `.well-known` URLs, failed on:\n`%s`" : "Twój serwer WWW nie jest poprawnie skonfigurowany do obsługi adresów URL `.well-known`, błąd: \n`%s`",
    "Your server is correctly configured to serve `.well-known` URLs." : "Twój serwer jest poprawnie skonfigurowany do obsługi `.well-known` URL.",
    "Font file loading" : "Wczytywanie pliku czcionki",
    "Could not check for {extension} loading support. Please check manually if your webserver serves `.{extension}` files." : "Nie można sprawdzić obsługi ładowania plików {extension}. Sprawdź ręcznie, czy serwer obsługuje pliki `{extension}`.",
    "Your web server is not properly set up to deliver .{extension} files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustment to also deliver .{extension} files. Compare your Nginx configuration to the recommended configuration in our documentation." : "Twój serwer WWW nie jest poprawnie skonfigurowany do obsługi plików {extension}. Zwykle jest to problem z konfiguracją Nginx. Dla Nextcloud 15 należy dodatkowo zezwolić na obsługę plików {extension}. Porównaj swoją konfigurację Nginx z zalecaną konfiguracją w naszej dokumentacji.",
    "Profile information" : "Informacje o profilu",
    "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Zdjęcie profilowe, imię i nazwisko, adres e-mail, numer telefonu, adres, witryna internetowa, Twitter, organizacja, rola, nagłówek, biografia i czy Twój profil jest włączony",
    "Nextcloud settings" : "Ustawienia Nextcloud",
    "Generate text" : "Generuj tekst",
    "Unified task processing" : "Ujednolicone przetwarzanie zadań",
    "AI tasks can be implemented by different apps. Here you can set which app should be used for which task." : "Zadania AI mogą być realizowane przez różne aplikacje. Tutaj możesz ustawić, która aplikacja ma być używana do jakiego zadania.",
    "Allow AI usage for guest users" : "Zezwól na użycie AI dla użytkowników gości",
    "Provider for Task types" : "Dostawca dla typów zadań",
    "Enable" : "Włącz",
    "None of your currently installed apps provide Task processing functionality" : "Żadna z aktualnie zainstalowanych aplikacji nie udostępnia funkcji przetwarzania zadań",
    "Hide legacy provider settings" : "Ukryj ustawienia starszego dostawcy",
    "Show legacy provider settings" : "Pokaż ustawienia starszego dostawcy",
    "Machine translation (Legacy)" : "Tłumaczenie maszynowe (starsze)",
    "Machine translation can be implemented by different apps. Here you can define the precedence of the machine translation apps you have installed at the moment." : "Tłumaczenie maszynowe może być implementowane przez różne aplikacje. Tutaj możesz zdefiniować pierwszeństwo aplikacji do tłumaczenia maszynowego, które masz aktualnie zainstalowane.",
    "This API is deprecated. Install apps that provide Unified task processing to get the best experience." : "To API jest przestarzałe. Instaluj aplikacje, które wspierają przetwarzanie zadań typu Unified w celu osiągnięcia najlepszego doświadczenia.",
    "Learn more about AI providers" : "Dowiedz się więcej o dostawcach usług AI",
    "Image generation (Legacy)" : "Generowanie obrazu (starsze)",
    "Image generation can be implemented by different apps. Here you can set which app should be used." : "Generowanie obrazu może być wykonywane przez różne aplikacje. Tutaj możesz wybrać której aplikacji chcesz używać.",
    "None of your currently installed apps provide image generation functionality" : "Żadna z zainstalowanych aplikacji nie pozwala na generowanie obrazów.",
    "Text processing (Legacy)" : "Przetwarzanie tekstu (starsze)",
    "Text processing tasks can be implemented by different apps. Here you can set which app should be used for which task." : "Zadania przetwarzania tekstu mogą być realizowane przez różne aplikacje. Tutaj można ustawić, która aplikacja ma być używana do danego zadania.",
    "Task:" : "Zadanie",
    "None of your currently installed apps provide text processing functionality using the Text Processing API." : "Żadna z aktualnie zainstalowanych aplikacji nie udostępnia funkcji przetwarzania tekstu przy użyciu interfejsu API Text processing.",
    "Here you can decide which group can access certain sections of the administration settings." : "Możesz zdecydować, która grupa ma dostęp do określonych sekcji ustawień administracyjnych.",
    "Unable to modify setting" : "Nie można zmienić ustawienia",
    "None" : "Brak",
    "Changed disclaimer text" : "Zmieniono tekst zastrzeżenia",
    "Deleted disclaimer text" : "Usunięto tekst zastrzeżenia",
    "Could not set disclaimer text" : "Nie można ustawić tekstu zastrzeżenia",
    "Allow apps to use the Share API" : "Zezwalaj aplikacjom na korzystanie z API udostępniania",
    "Allow resharing" : "Zezwalaj na udostępnianie dalej",
    "Allow sharing with groups" : "Zezwalaj na udostępnianie grupom",
    "Restrict users to only share with users in their groups" : "Ogranicz użytkownikom możliwość udostępniania, pozwól tylko w swoich grupach",
    "Ignore the following groups when checking group membership" : "Podczas sprawdzania członkostwa w grupach ignoruj ​​następujące grupy",
    "Allow users to preview files even if download is disabled" : "Pozwól użytkownikom podglądać pliki, nawet jeśli pobieranie jest wyłączone",
    "Users will still be able to screenshot or record the screen. This does not provide any definitive protection." : "Użytkownicy nadal będą mogli robić zrzuty ekranu lub nagrywać ekran. Nie stanowi to pełnej ochrony.",
    "Allow users to share via link and emails" : "Zezwalaj użytkownikom na udostępnianie za pośrednictwem linków i e-maili",
    "Allow public uploads" : "Zezwalaj na publiczne wysyłanie",
    "Allow public shares to be added to other clouds by federation." : "Zezwalaj na dodawanie publicznych udostępnień do innych chmur przez federację.",
    "This will add share permissions to all newly created link shares." : "Spowoduje to dodanie uprawnień do udostępniania dla wszystkich nowo tworzonych udostępnień za pomocą linku.",
    "Always ask for a password" : "Zawsze pytaj o hasło",
    "Enforce password protection" : "Wymuszaj zabezpieczenie hasłem",
    "Exclude groups from password requirements" : "Wyklucz grupy z wymagań dotyczących haseł",
    "Exclude groups from creating link shares" : "Wyklucz grupy z tworzenia udostępnień linków",
    "Allow users to set custom share link tokens" : "Pozwól użytkownikom ustawiać własne tokeny do udostępniania",
    "Shares with custom tokens will continue to be accessible after this setting has been disabled" : "Udostępnienia z niestandardowymi tokenami będą nadal dostępne po wyłączeniu tego ustawienia",
    "Shares with guessable tokens may be accessed easily" : "Dostęp do udostępnień z tokenami, które można zgadywać, jest łatwy",
    "Limit sharing based on groups" : "Ogranicz udostępnianie w oparciu o grupy",
    "Allow sharing for everyone (default)" : "Zezwalaj wszystkim na udostępnianie (domyślnie)",
    "Exclude some groups" : "Wyklucz niektóre grupy",
    "Allow some groups" : "Zezwól niektórym grupom",
    "Groups allowed to share" : "Grupy mogące się dzielić",
    "Groups excluded from sharing" : "Grupy wykluczone z udostępniania",
    "Not allowed groups will still be able to receive shares, but not to initiate them." : "Niedozwolone grupy nadal będą mogły otrzymywać udziały, ale nie będą mogły ich inicjować.",
    "Set default expiration date for internal shares" : "Ustaw domyślną datę wygaśnięcia udziałów wewnętrznych",
    "Enforce expiration date" : "Wymuszaj datę wygaśnięcia",
    "Default expiration time of new shares in days" : "Domyślny czas wygaśnięcia nowych udostępnień w dniach",
    "Expire shares after x days" : "Udostępnienia wygasają po x dniach",
    "Set default expiration date for shares to other servers" : "Ustaw domyślną datę ważności udostępnień na innych serwerach",
    "Enforce expiration date for remote shares" : "Wymuś datę wygaśnięcia zdalnych udostępnień",
    "Default expiration time of remote shares in days" : "Domyślny czas wygaśnięcia zdalnych udostępnień w dniach",
    "Expire remote shares after x days" : "Wygaśnięcie zdalnych udostępnień po x dniach",
    "Set default expiration date for shares via link or mail" : "Ustaw domyślną datę wygaśnięcia udostępnień za pośrednictwem linku lub poczty",
    "Enforce expiration date for link or mail shares" : "Wymuś datę wygaśnięcia dla udostępnień przez link lub e-mail",
    "Default expiration time of shares in days" : "Domyślny czas wygaśnięcia udostępnień w dniach",
    "Privacy settings for sharing" : "Ustawienia prywatności dotyczące udostępniania",
    "Allow account name autocompletion in share dialog and allow access to the system address book" : "Zezwalaj na automatyczne uzupełnianie nazwy konta w oknie udostępniania i zezwalaj na dostęp do systemowej książki adresowej",
    "Sharing autocompletion restrictions" : "Ograniczenia udostępniania",
    "If autocompletion restrictions for both \"same group\" and \"phonebook integration\" are enabled, a match in either is enough to show the user." : "Jeśli ograniczenia autouzupełniania dla „tej samej grupy” i „integracji z książką adresową” są włączone, dopasowanie w dowolnym z nich wystarczy, aby pokazać użytkownika.",
    "Restrict account name autocompletion and system address book access to users within the same groups" : "Ogranicz autouzupełnianie nazwy konta i dostęp do systemowej książki adresowej do użytkowników w tych samych grupach",
    "Restrict account name autocompletion to users based on their phonebook" : "Ogranicz autouzupełnianie nazw kont do użytkowników na podstawie ich książki adresowej",
    "Allow autocompletion to full match when entering the full name (ignoring restrictions like group membership or missing phonebook match)" : "Zezwól na autouzupełnianie do pełnego dopasowania przy wpisywaniu pełnego imienia i nazwiska (ignorując ograniczenia, takie jak członkostwo w grupie czy brak dopasowania w książce adresowej)",
    "Full match autocompletion restrictions" : "Ograniczenia autouzupełniania pełnego dopasowania",
    "Also allow autocompletion on full match of the user ID" : "Zezwól także na autouzupełnianie przy pełnym dopasowaniu identyfikatora użytkownika",
    "Also allow autocompletion on full match of the display name" : "Zezwól również na autouzupełnianie przy pełnym dopasowaniu nazwy wyświetlanej",
    "Also allow autocompletion on full match of the user email" : "Zezwól także na autouzupełnianie przy pełnym dopasowaniu adresu e-mail użytkownika",
    "Do not use second user displayname for full match" : "Nie używaj drugiej nazwy wyświetlanej użytkownika dla pełnego dopasowania",
    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Pokaż tekst zastrzeżenia na stronie przesyłania linków publicznych (wyświetlane tylko wtedy, gdy lista plików jest ukryta)",
    "Disclaimer text" : "Tekst zastrzeżenia",
    "This text will be shown on the public link upload page when the file list is hidden." : "Ten tekst zostanie wyświetlony na stronie przesyłania linków publicznych, gdy lista plików jest ukryta.",
    "Default share permissions" : "Domyślne uprawnienia dla udostępnień",
    "Two-Factor Authentication" : "Uwierzytelnianie dwuskładnikowe",
    "Two-factor authentication can be enforced for all accounts and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Uwierzytelnianie dwuskładnikowe może być wymuszane dla wszystkich kont i określonych grup. Jeśli nie mają skonfigurowanego dostawcy logowania dwuskładnikowego, nie będą mogli zalogować się do systemu.",
    "Enforce two-factor authentication" : "Wymuś uwierzytelnianie dwuskładnikowe",
    "Limit to groups" : "Ogranicz do grup",
    "Enforcement of two-factor authentication can be set for certain groups only." : "Wymuszanie uwierzytelniania dwuskładnikowego można ustawić tylko dla niektórych grup.",
    "Two-factor authentication is enforced for all members of the following groups." : "Uwierzytelnianie dwuskładnikowe jest wymuszone dla wszystkich członków następujących grup.",
    "Enforced groups" : "Wymuszone grupy",
    "Two-factor authentication is not enforced for members of the following groups." : "Uwierzytelnianie dwuskładnikowe nie jest wymuszane dla członków następujących grup.",
    "Excluded groups" : "Wyłączone grupy",
    "When groups are selected/excluded, they use the following logic to determine if an account has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If an account is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Gdy grupy są zaznaczone lub wykluczone, stosowana jest następująca logika w celu określenia, czy dla konta ma być wymuszona 2FA:. Jeśli nie wybrano żadnych grup, 2FA jest włączone dla wszystkich, z wyjątkiem członków wykluczonych grup. Jeśli grupy są wybrane, 2FA jest włączone dla wszystkich ich członków. Jeśli konto należy zarówno do grupy wybranej, jak i wykluczonej, priorytet ma grupa wybrana i 2FA jest wymuszane.",
    "Save changes" : "Zapisz zmiany",
    "Failed to load groups" : "Nie udało się załadować grup",
    "Failed to create group" : "Nie udało się utworzyć grupy",
    "List of groups. This list is not fully populated for performance reasons. The groups will be loaded as you navigate or search through the list." : "Lista grup. Lista nie jest w pełni załadowana ze względów wydajnościowych. Grupy będą ładowane w miarę przewijania lub wyszukiwania.",
    "Groups" : "Grupy",
    "Creating group…" : "Tworzenie grupy",
    "Create group" : "Utwórz grupę",
    "Group name" : "Nazwa grupy",
    "Please enter a valid group name" : "Podaj właściwą nazwę grupy",
    "Loading groups…" : "Wczytywanie grup…",
    "Google Chrome for Android" : "Google Chrome dla Android",
    "{productName} iOS app" : "Aplikacja {productName} na iOS",
    "{productName} Android app" : "Aplikacja {productName} na Android",
    "{productName} Talk for iOS" : "{productName} Talk dla iOS",
    "{productName} Talk for Android" : "{productName} Talk dla Androida",
    "Sync client" : "Synchronizuj klienta",
    "This session" : "Ta sesja",
    "{client} - {version} ({system})" : "{client} - {version} ({system})",
    "{client} - {version}" : "{client} - {version}",
    "Confirm wipe" : "Potwierdzenie usunięcia",
    "Do you really want to wipe your data from this device?" : "Czy na pewno chcesz usunąć dane z tego urządzenia?",
    "Wipe device" : "Wyczyść urządzenie",
    "Cancel" : "Anuluj",
    "Device name" : "Nazwa urządzenia",
    "Cancel renaming" : "Anuluj zmianę nazwy",
    "Save new name" : "Zapisz nową nazwę",
    "Marked for remote wipe" : "Oznaczone do zdalnego czyszczenia",
    "Device settings" : "Ustawienia urządzenia",
    "Allow filesystem access" : "Zezwalaj na dostęp do systemu plików",
    "Rename" : "Zmień nazwę",
    "Revoke" : "Cofnij",
    "Revoking this token might prevent the wiping of your device if it has not started the wipe yet." : "Unieważnienie tego tokena uniemożliwi czyszczenie urządzenia, jeśli jeszcze nie zostało rozpoczęte.",
    "Revoke and cancel pending wipe?" : "Cofnąć uprawnienie i anulować oczekujące wymazanie?",
    "Only continue if you no longer need the device to be wiped." : "Kontynuuj tylko wtedy, gdy urządzenie nie musi już zostać wymazane.",
    "Revoke and cancel wipe" : "Cofnij uprawnienie i anuluj wymazanie",
    "Revoke app password?" : "Cofnąć hasło aplikacji?",
    "The app or device will lose access on its next sync. This cannot be undone." : "Aplikacja lub urządzenie utraci dostęp przy następnej synchronizacji. Tej operacji nie można cofnąć.",
    "Remote wipe has not started yet." : "Zdalne wymazanie jeszcze się nie rozpoczęło.",
    "Revoking now cancels the wipe. The device keeps its synced data." : "Cofnięcie uprawnienia teraz anuluje wymazanie. Urządzenie zachowa zsynchronizowane dane.",
    "Device" : "Urządzenie",
    "Last activity" : "Ostatnia aktywność",
    "Actions" : "Akcje",
    "Devices & sessions" : "Urządzenia i sesje",
    "Web, desktop and mobile clients currently logged in to your account." : "Klienci internetowi, desktopowi i mobilni aktualnie zalogowani na Twoim koncie.",
    "Error while creating device token" : "Błąd podczas tworzenia tokena urządzenia",
    "App name" : "Nazwa aplikacji",
    "Create new app password" : "Utwórz nowe hasło aplikacji",
    "App password copied!" : "Hasło do aplikacji skopiowane!",
    "Copy app password" : "Skopiuj hasło do aplikacji",
    "Login name copied!" : "Nazwa logowania została skopiowana!",
    "Copy login name" : "Skopiuj nazwę logowania",
    "Could not copy app password. Please copy it manually." : "Nie można skopiować hasła do aplikacji. Skopiuj je ręcznie.",
    "Could not copy login name. Please copy it manually." : "Nie można skopiować nazwy logowania. Skopiuj ją ręcznie.",
    "New app password" : "Nowe hasło do aplikacji",
    "Use the credentials below to configure your app or device. For security reasons this password will only be shown once." : "Użyj poniższych danych uwierzytelniających, aby skonfigurować aplikację lub urządzenie. Ze względów bezpieczeństwa to hasło zostanie wyświetlone tylko raz.",
    "Login" : "Login",
    "Password" : "Hasło",
    "Show QR code for mobile apps" : "Pokaż kod QR dla aplikacji mobilnych",
    "Use system cron service to call the cron.php file every 5 minutes." : "Użyj usługi systemowej cron, aby wywoływać plik cron.php co 5 minut.",
    "The cron.php needs to be executed by the system account \"{user}\"." : "Plik cron.php musi zostać wykonany przez konto systemowe „{user}”.",
    "The PHP POSIX extension is required. See {linkstart}PHP documentation{linkend} for more details." : "Wymagane jest rozszerzenie PHP POSIX. Więcej informacji można znaleźć w {linkstart}dokumentacji PHP{linkend}.",
    "Unable to update background job mode" : "Nie można zaktualizować trybu zadania w tle",
    "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information." : "Dla prawidłowego działania serwera, ważne jest, aby poprawnie skonfigurować zadania w tle. Zalecanym ustawieniem jest Cron. Więcej informacji znajdziesz w dokumentacji.",
    "Last job execution ran {time}. Something seems wrong." : "Wykonanie ostatniego zadania trwało {time}. Coś wydaje się nie tak.",
    "Last job ran {relativeTime}." : "Ostatnie zadanie zostało uruchomione {relativeTime}.",
    "Background job did not run yet!" : "Zadanie w tle nie zostało wykonane ani razu!",
    "AJAX" : "AJAX",
    "Execute one task with each page loaded. Use case: Single account instance." : "Wykonaj jedno zadanie z każdą wczytaną stroną. Przypadek użycia: instancja pojedynczego konta.",
    "Webcron" : "Webcron",
    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 accounts depending on the usage)." : "cron.php jest zarejestrowany w usłudze webcron i wywołuje cron.php co 5 minut przez HTTP. Przypadek użycia: Bardzo mała instancja (1–5 kont w zależności od zastosowania).",
    "Cron (Recommended)" : "Cron (zalecane)",
    "Unable to update profile default setting" : "Nie można zaktualizować domyślnych ustawień profilu",
    "Unable to update profile picker setting" : "Nie można zaktualizować ustawienia wyboru profilu",
    "Profile" : "Profil",
    "Enable or disable profile by default for new accounts." : "Włącz lub wyłącz profil domyślnie dla nowych kont.",
    "Enable the profile picker" : "Włącz wybór profilu",
    "Enable or disable the profile picker in the Smart Picker and the profile link previews." : "Włącz lub wyłącz wybór profilu w Smart Picker oraz w podglądach linków do profilu",
    "Password confirmation is required" : "Wymagane jest potwierdzenie hasła",
    "Failed to save setting" : "Nie udało się zapisać ustawienia",
    "{app}'s declarative setting field: {name}" : "Pole ustawień deklaratywnych aplikacji {app}: {name}",
    "Unable to update server side encryption config" : "Nie można zaktualizować konfiguracji szyfrowania po stronie serwera",
    "Server-side encryption" : "Szyfrowanie po stronie serwera",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Szyfrowanie po stronie serwera umożliwia szyfrowanie plików przesyłanych na ten serwer. Wiąże się to z ograniczeniami, takimi jak spadkiem wydajności, więc włącz to tylko w razie potrzeby.",
    "To encrypt all existing files run this OCC command:" : "Aby zaszyfrować wszystkie istniejące pliki, uruchom to polecenie OCC:",
    "Enable server-side encryption" : "Włącz szyfrowanie po stronie serwera",
    "Disabling server side encryption is only possible using OCC, please refer to the documentation." : "Wyłączenie szyfrowania po stronie serwera jest możliwe tylko za pomocą OCC, zapoznaj się z dokumentacją.",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Moduł szyfrowania nie jest załadowany, należy włączyć moduł szyfrowania w menu aplikacji.",
    "Select default encryption module:" : "Wybierz domyślny moduł szyfrowania:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}" : "Musisz zmigrować swoje klucze szyfrujące ze starego szyfrowania (ownCloud <= 8.0) do nowego. Włącz \"Domyślny moduł szyfrowania\" i uruchom {command}",
    "Cancel encryption" : "Anuluj szyfrowanie",
    "Enable encryption" : "Włącz szyfrowanie",
    "Confirm enabling encryption" : "Potwierdź włączenie szyfrowania",
    "Please read carefully before activating server-side encryption:" : "Przeczytaj uważnie przed aktywacją szyfrowania po stronie serwera:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Po włączeniu szyfrowania wszystkie pliki wysłane na serwer od tej chwili będą szyfrowane na serwerze. Wyłączenie szyfrowania będzie możliwe dopiero, gdy aktywny moduł szyfrowania wykona tę funkcję oraz wszystkie poprzednie warunki będą spełnione (np. ustawienie klucza odzyskiwania).",
    "By default a master key for the whole instance will be generated. Please check if that level of access is compliant with your needs." : "Domyślnie zostanie wygenerowany klucz główny dla całej instancji. Sprawdź, czy taki poziom dostępu odpowiada Twoim wymaganiom.",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Samo szyfrowanie nie gwarantuje bezpieczeństwa systemu. Więcej informacji na temat działania aplikacji szyfrującej i użycia wspieranych przypadków można znaleźć w dokumentacji.",
    "Be aware that encryption always increases the file size." : "Należy pamiętać, że szyfrowanie zawsze zwiększa rozmiar pliku.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Zawsze dobrze jest regularnie wykonywać kopie zapasowe swoich danych. W przypadku szyfrowania upewnij się, aby kopie zapasowe kluczy szyfrowania były wraz z danymi.",
    "Refer to the admin documentation on how to manually also encrypt existing files." : "Zapoznaj się z dokumentacją administratora, aby dowiedzieć się, jak ręcznie zaszyfrować istniejące pliki.",
    "This is the final warning: Do you really want to enable encryption?" : "To ostatnie ostrzeżenie: Czy na pewno chcesz włączyć szyfrowanie?",
    "Failed to delete group \"{group}\"" : "Nie udało się usunąć grupy \"{group}\"",
    "Please confirm the group removal" : "Potwierdź usunięcie grupy",
    "You are about to delete the group \"{group}\". The accounts will NOT be deleted." : "Zamierzasz usunąć grupę \"{group}\". Konta NIE zostaną usunięte.",
    "Confirm" : "Potwierdź",
    "Submit" : "Wyślij",
    "Rename group" : "Zmień nazwę grupy",
    "Delete group" : "Usuń grupę",
    "Current password" : "Bieżące hasło",
    "New password" : "Nowe hasło",
    "Change password" : "Zmień hasło",
    "Choose your profile picture" : "Wybierz swoje zdjęcie profilowe",
    "Please select a valid png or jpg file" : "Wybierz prawidłowy plik PNG lub JPG",
    "Error setting profile picture" : "Błąd podczas ustawiania zdjęcia profilowego",
    "Error cropping profile picture" : "Błąd przycinania zdjęcia profilowego",
    "Error saving profile picture" : "Błąd podczas zapisywania zdjęcia profilowego",
    "Error removing profile picture" : "Błąd podczas usuwania zdjęcia profilowego",
    "Your profile picture" : "Twoje zdjęcie profilowe",
    "Upload profile picture" : "Wyślij zdjęcie profilowe",
    "Choose profile picture from Files" : "Wybierz zdjęcie profilowe z Plików",
    "Remove profile picture" : "Usuń zdjęcie profilowe",
    "The file must be a PNG or JPG" : "Plik musi być w formacie PNG lub JPG",
    "Picture provided by original account" : "Zdjęcie dostarczone przez oryginalne konto",
    "Set as profile picture" : "Ustaw jako zdjęcie profilowe",
    "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "Pamiętaj, że aktualizacja Twojego zdjęcia profilowego może potrwać do 24 godzin.",
    "Your biography. Markdown is supported." : "Twoja biografia. Obsługiwany jest Markdown.",
    "Unable to update date of birth" : "Nie można zapisać daty urodzin",
    "Enter your date of birth" : "Podaj datę swoich urodzin",
    "Bluesky handle" : "Identyfikator Bluesky",
    "You are using {s}{usage}{/s}" : "Używasz {s}{usage}{/s}",
    "You are using {s}{usage}{/s} of {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})" : "Używasz  {s}{usage}{/s} z {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})",
    "Details" : "Szczegóły",
    "You are a member of the following groups:" : "Należysz do następujących grup:",
    "Your full name" : "Twoja pełna nazwa",
    "Unable to update primary email address" : "Nie można zaktualizować głównego adresu e-mail",
    "Unable to delete additional email address" : "Nie można usunąć dodatkowego adresu e-mail",
    "No email address set" : "Brak adresu e-mail",
    "Email options" : "Opcje e-mail",
    "Options for additional email address {index}" : "Opcje dla dodatkowego adresu e-mail {index}",
    "Remove primary email" : "Usuń podstawowy adres e-mail",
    "Delete email" : "Usuń e-mail",
    "This address is not confirmed" : "Ten adres nie jest potwierdzony",
    "Unset as primary email" : "Usuń jako podstawowy adres e-mail",
    "Set as primary email" : "Ustaw jako podstawowy adres e-mail",
    "Additional email address {index}" : "Dodatkowy adres e-mail {index}",
    "Unable to delete primary email address" : "Nie można usunąć głównego adresu e-mail",
    "Unable to add additional email address" : "Nie można dodać dodatkowego adresu e-mail",
    "Unable to update additional email address" : "Nie można zaktualizować dodatkowego adresu e-mail",
    "Primary email for password reset and notifications" : "Główny adres e-mail do resetowania hasła i powiadomień",
    "Your handle" : "Twoja ksywka",
    "Derived from your locale ({weekDayName})" : "Na podstawie twoich ustawień językowych ({weekDayName})",
    "Unable to update first day of week" : "Nie można zaktualizować pierwszego dnia tygodnia",
    "Day to use as the first day of week" : "Dzień używany jako pierwszy dzień tygodnia",
    "Your headline" : "Twój nagłówek",
    "No language set" : "Nie ustawiono języka",
    "Unable to update language" : "Nie można zaktualizować języka",
    "Languages" : "Języki",
    "Help translate" : "Pomóż w tłumaczeniu",
    "No locale set" : "Nie ustawiono regionu",
    "Unable to update locale" : "Nie można zaktualizować regionu",
    "Locales" : "Ustawienia lokalizacyjne",
    "Week starts on {firstDayOfWeek}" : "Tydzień zaczyna się w {firstDayOfWeek}",
    "Your city" : "Miasto",
    "Your organisation" : "Twoja organizacja",
    "Your phone number" : "Twój numer telefonu",
    "Edit your Profile visibility" : "Edycja widoczności swojego profilu",
    "Unable to update profile enabled state" : "Nie można zaktualizować stanu włączenia profilu",
    "Enable profile" : "Włącz profil",
    "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "Bardziej restrykcyjne ustawienie widoczności lub zakresu jest przestrzegane w Twoim profilu. Na przykład, jeśli widoczność jest ustawiona na \"Pokaż wszystkim\", a zakres jest ustawiony na \"Prywatny\", to przestrzegany jest \"Prywatny\".",
    "Unable to update visibility of {displayId}" : "Nie można zaktualizować widoczności {displayId}",
    "she/her" : "ona/jej",
    "he/him" : "on/jego",
    "they/them" : "oni/ich",
    "Your pronouns. E.g. {pronounsExample}" : "Twoje zaimki. Np. {pronounsExample}",
    "Your role" : "Twoja rola społeczna",
    "Timezone" : "Strefa czasowa",
    "Your X (formerly Twitter) handle" : "Twój przeniesiony X (dawniej Twitter).",
    "Your website" : "Twoja strona WWW",
    "Invalid value" : "Niewłaściwa wartość",
    "Unable to update {property}" : "Nie można zaktualizować {property}",
    "No {property} set" : "Nie ustawiono {property}",
    "Change scope level of {property}, current scope is {scope}" : "Zmień poziom zakresu {property}, obecny zakres to {scope}",
    "Unable to update federation scope of the primary {property}" : "Nie można zaktualizować zakresu federacji podstawowej {property}",
    "Unable to update federation scope of additional {property}" : "Nie można zaktualizować zakresu federacji dodatkowego {property}",
    "Add additional email" : "Dodaj dodatkowy e-mail",
    "Add" : "Dodaj",
    "Create" : "Utwórz",
    "Change" : "Zmień",
    "Delete" : "Usuń",
    "Reshare" : "Udostępnianie innym",
    "Default config values" : "Domyślne wartości konfiguracji",
    "Applications config" : "Konfiguracja aplikacji",
    "User config" : "Konfiguracja użytkownika",
    "Bundled applications" : "Dołączone aplikacje",
    "Enabled applications" : "Włączone aplikacje",
    "Disabled applications" : "Wyłączone aplikacje",
    "Large organization" : "Duża organizacja",
    "Big organization" : "Wielka organizacja",
    "Small organization" : "Mała organizacja",
    "Hosting company" : "Firma hostingowa",
    "University" : "Uniwersytet",
    "School" : "Szkoła",
    "Club or association" : "Klub lub stowarzyszenie",
    "Family" : "Rodzina",
    "Personal use" : "Użytek osobisty",
    "Default" : "Domyślny",
    "Setup errors" : "Błędy konfiguracji",
    "Setup warnings" : "Ostrzeżenia konfiguracji",
    "Setup recommendations" : "Rekomendacje konfiguracji",
    "Default language" : "Domyślny język",
    "Common languages" : "Popularne języki",
    "Other languages" : "Inne języki",
    "Password change is disabled because the master key is disabled" : "Zmiana hasła jest zablokowana z powodu włączenia klucza głównego.",
    "No accounts" : "Brak kont",
    "Loading accounts …" : "Wczytywanie kont ...",
    "List of accounts. This list is not fully rendered for performance reasons. The accounts will be rendered as you navigate through the list." : "Lista kont. Ta lista nie jest w pełni renderowana ze względu na wydajność. Konta będą renderowane podczas poruszania się po liście.",
    "Account name" : "Nazwa konta",
    "Account updated" : "Konto zaktualizowane",
    "Failed to update account" : "Nie udało się zaktualizować konta",
    "Edit account" : "Edytuj konto",
    "Saving …" : "Zapisywanie…",
    "Save" : "Zapisz",
    "Account name will be autogenerated" : "Nazwa konta zostanie wygenerowana automatycznie",
    "Account name (required)" : "Nazwa konta (wymagane)",
    "Password (required)" : "Hasło (wymagane)",
    "Email (required)" : "E-mail (wymagany)",
    "Email" : "E-mail",
    "New account" : "Nowe konto",
    "Adding new account …" : "Dodawanie nowego konta …",
    "Add new account" : "Dodaj nowe konto",
    "Display name" : "Wyświetlana nazwa",
    "Either password or email is required" : "Wymagane jest hasło lub adres e-mail",
    "Member of the following groups (required)" : "Członek następujących grup (wymagane)",
    "Member of the following groups" : "Członek następujących grup",
    "Failed to search groups" : "Nie udało się wyszukać grup",
    "Set account groups" : "Ustaw grupy konta",
    "Admin of the following groups" : "Administrator następujących grup",
    "Set account as admin for …" : "Ustaw konto jako administrator dla …",
    "Language" : "Język",
    "Set default language" : "Ustaw domyślny język",
    "Manager" : "Menedżer",
    "Search for a manager…" : "Wyszukaj przełożonego...",
    "Quota" : "Quota",
    "Set account quota" : "Ustaw limit konta",
    "_{userCount} account …_::_{userCount} accounts …_" : ["{userCount} konto ...","{userCount}konta ...","{userCount} kont ...","{userCount} kont ..."],
    "_{userCount} account_::_{userCount} accounts_" : ["{userCount} konto","{userCount} konta","{userCount} kont","{userCount} konta"],
    "Total rows summary" : "Podsumowanie wszystkich wierszy",
    "Scroll to load more rows" : "Przewiń, aby wczytać więcej wierszy",
    "Avatar" : "Awatar",
    "Group admin for" : "Administrator grupy",
    "Account backend" : "Zaplecze konta",
    "Storage location" : "Lokalizacja magazynu",
    "First login" : "Pierwsze logowanie",
    "Last login" : "Ostatnio zalogowany",
    "Account actions" : "Czynności na koncie",
    "Unknown" : "Nieznany",
    "Never" : "Nigdy",
    "{size} used" : "Wykorzystane: {size}",
    "Delete account" : "Usuń konto",
    "Disconnect all devices and delete local data" : "Odłącz wszystkie urządzenia i usuń dane lokalne",
    "Disable account" : "Wyłącz konto",
    "Enable account" : "Włącz konto",
    "Resend welcome email" : "Wyślij ponownie wiadomość powitalną",
    "In case of lost device or exiting the organization, this can remotely wipe the {productName} data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "W przypadku utraty urządzenia lub opuszczenia organizacji można zdalnie wyczyścić dane {productName} ze wszystkich urządzeń powiązanych z {userid}. Działa tylko, jeśli urządzenia są podłączone do internetu.",
    "Remote wipe of devices" : "Zdalne czyszczenie urządzeń",
    "Wipe {userid}'s devices" : "Wyczyść urządzenia {userid}",
    "Wiped {userid}'s devices" : "Wyczyszczono urządzenia użytkownika {userid}",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "Całkowicie usuń konto {userid}, w tym wszystkie pliki osobiste, dane aplikacji itp.",
    "Account deletion" : "Usunięcie konta",
    "Delete {userid}'s account" : "Usuń konto {userid}",
    "Welcome mail sent!" : "Wysłano wiadomość powitalną!",
    "Loading account …" : "Wczytywanie kont ...",
    "Toggle account actions menu" : "Przełącz menu działań na koncie",
    "Edit" : "Edycja",
    "Account management settings" : "Ustawienia zarządzania kontami",
    "Visibility" : "Widoczne",
    "Show language" : "Pokaż język",
    "Show account backend" : "Pokaż moduł konta",
    "Show storage path" : "Pokaż ścieżkę przechowywania",
    "Show first login" : "Pokaż pierwsze logowanie",
    "Show last login" : "Pokaż ostatnie logowanie",
    "Sorting" : "Sortowanie",
    "The system config enforces sorting the groups by name. This also disables showing the member count." : "Konfiguracja systemu wymusza sortowanie grup według nazwy. Wyłącza to również wyświetlanie liczby członków.",
    "Group list sorting" : "Sortowanie listy grup",
    "Sorting only applies to the currently loaded groups for performance reasons. Groups will be loaded as you navigate or search through the list." : "Sortowanie dotyczy tylko aktualnie załadowanych grup ze względów wydajnościowych. Grupy będą ładowane w miarę nawigowania lub wyszukiwania na liście.",
    "By member count" : "Według liczby członków",
    "By name" : "Według nazwy",
    "Send email" : "Wyślij e-mail",
    "Send welcome email to new accounts" : "Wyślij wiadomość powitalną do nowych kont",
    "Defaults" : "Domyślne",
    "Default quota" : "Domyślny limit",
    "Select default quota" : "Wybierz domyślny limit",
    "Search" : "Szukaj",
    "Focus search" : "Wyszukiwanie fokusu",
    "Help" : "Pomoc",
    "Show those shortcuts" : "Pokaż te skróty",
    "Server error while trying to complete WebAuthn device registration" : "Błąd serwera podczas próby ukończenia rejestracji urządzenia WebAuthn",
    "Passwordless authentication requires a secure connection." : "Uwierzytelnianie bez hasła wymaga bezpiecznego połączenia.",
    "Add WebAuthn device" : "Dodaj urządzenie WebAuthn",
    "Please authorize your WebAuthn device." : "Autoryzuj swoje urządzenie WebAuthn.",
    "Adding your device …" : "Dodawanie urządzenia …",
    "Unnamed device" : "Nienazwane urządzenie",
    "Passwordless Authentication" : "Uwierzytelnianie bez hasła",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "Skonfiguruj konto do uwierzytelniania bez hasła zgodnie ze standardem FIDO2.",
    "No devices configured." : "Brak skonfigurowanych urządzeń.",
    "The following devices are configured for your account:" : "Dla Twojego konta skonfigurowane są następujące urządzenia:",
    "Your browser does not support WebAuthn." : "Twoja przeglądarka nie obsługuje WebAuthn.",
    "Email sent successfully" : "Wiadomość e-mail została wysłana pomyślnie",
    "Failed to send email" : "Nie udało się wysłać wiadomości e-mail",
    "Failed to save email settings" : "Nie udało się zapisać ustawień poczty e-mail",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Należy skonfigurować ten serwer, aby umożliwić wysyłanie wiadomości e-mail z powiadomieniami i resetowaniem hasła.",
    "The server configuration is read-only so the mail settings cannot be changed using the web interface." : "Konfiguracja serwera jest tylko do odczytu, dlatego nie można zmienić ustawień poczty e-mail za pomocą interfejsu WWW.",
    "Mail delivery is disabled by instance config \"{config}\"." : "Dostarczanie poczty jest wyłączone w konfiguracji instancji \"{config}\".",
    "Send mode" : "Sposób wysyłania",
    "Encryption" : "Szyfrowanie",
    "Sendmail mode" : "Tryb wysyłania poczty",
    "Disable certificate verification (insecure)" : "Wyłącz weryfikację certyfikatu (niebezpieczne)",
    "From address" : "Z adresu",
    "Domain" : "Domena",
    "Server address" : "Adres serwera",
    "Host" : "Host",
    "Port" : "Port",
    "Authentication" : "Uwierzytelnienie",
    "Authentication required" : "Wymagane uwierzytelnienie",
    "Sending test email…" : "Wysyłanie wiadomości testowej…",
    "Send test email" : "Wyślij wiadomość testową",
    "Saving…" : "Zapisywanie…",
    "Save settings" : "Zapisz ustawienia",
    "Please double check the {linkStartInstallationGuides}installation guides{linkEnd}, and check for any errors or warnings in the {linkStartLog}log{linkEnd}." : "Proszę dokładnie sprawdzić {linkStartInstallationGuides} przewodniki instalacyjne{linkEnd}, oraz wszelkie błędy lub ostrzeżenia w {linkStartLog}logu{linkEnd}.",
    "Check the security of your {productName} over {linkStart}our security scan{linkEnd}." : "Sprawdź bezpieczeństwo swojego {productName} za pomocą naszego {linkStart}skanera bezpieczeństwa{linkEnd}.",
    "Security & setup warnings" : "Ostrzeżenia bezpieczeństwa i konfiguracji",
    "It is important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Ważne jest, aby Twoja instancja była poprawnie skonfigurowana dla bezpieczeństwa i wydajności. Aby Ci w tym pomóc, wykonujemy kilka automatycznych kontroli. Zobacz powiązaną dokumentację, aby uzyskać więcej informacji.",
    "Checking your server …" : "Sprawdzanie serwera …",
    "Failed to run setup checks" : "Nie udało się uruchomić kontroli konfiguracji.",
    "Try again" : "Spróbuj ponownie",
    "All checks passed." : "Wszystkie testy konfiguracji zakończyły się pomyślnie.",
    "There are some errors regarding your setup." : "Występują błędy dotyczące konfiguracji.",
    "There are some warnings regarding your setup." : "Znaleziono zastrzeżenia w Twojej konfiguracji.",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Jako administrator możesz zoptymalizować ustawienia udostępniania. Szczegółowe informacje znajdziesz w dokumentacji.",
    "You need to enable the File sharing App." : "Musisz włączyć aplikację do udostępniania plików.",
    "Failed to save selected preset." : "Nie udało się zapisać wybranego ustawienia wstępnego.",
    "Select a configuration preset for easy setup." : "Wybierz ustawienie wstępne konfiguracji dla łatwej instalacji.",
    "Apply" : "Zastosuj",
    "All accounts" : "Wszystkie konta",
    "Admins" : "Administratorzy",
    "Account group: {group}" : "Grupa kont: {group}",
    "Account management" : "Zarządzanie kontem",
    "Search accounts and groups…" : "Wyszukaj konta i grupy...",
    "For performance reasons, when you enable encryption on a {productName} server only new and changed files are encrypted." : "Ze względów wydajnościowych, gdy włączysz szyfrowanie na serwerze {productName}, tylko nowe i zmienione pliki będą szyfrowane.",
    "Location" : "Lokalizacja",
    "Profile picture" : "Zdjęcie profilowe",
    "About" : "Informacje",
    "Date of birth" : "Data urodzin",
    "Full name" : "Pełna nazwa",
    "Additional email" : "Dodatkowy e-mail",
    "Fediverse (e.g. Mastodon)" : "Fediverse (np. Mastodon)",
    "Headline" : "Nagłówek",
    "Organisation" : "Organizacja",
    "Phone number" : "Numer telefonu",
    "Pronouns" : "Zaimki",
    "Role" : "Rola społeczna",
    "X (formerly Twitter)" : "X (dawniej Twitter)",
    "Bluesky" : "Bluesky",
    "Website" : "Strona internetowa",
    "Profile visibility" : "Widoczność profilu",
    "Locale" : "Region",
    "First day of week" : "Pierwszy dzień tygodnia",
    "timezone" : "strefa czasowa",
    "Private" : "Prywatne",
    "Only visible to people matched via phone number integration through Talk on mobile" : "Widoczne tylko dla osób dopasowanych poprzez integrację numeru telefonu za pomocą Talka na telefonie komórkowym",
    "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Niedostępne, ponieważ ta właściwość jest wymagana do podstawowych funkcji, w tym udostępniania pliku i zaproszeń do kalendarza",
    "Local" : "Lokalne",
    "Only visible to people on this instance and guests" : "Widoczne tylko dla osób w tej instancji i gości",
    "Federated" : "Sfederowane",
    "Only synchronize to trusted servers" : "Synchronizuj tylko z zaufanymi serwerami",
    "Not available as federation has been disabled for your account, contact your system administration if you have any questions" : "Niedostępne, ponieważ federacja została wyłączona dla Twojego konta. Jeśli masz jakiekolwiek pytania, skontaktuj się z administratorem systemu",
    "Published" : "Opublikowane",
    "Synchronize to trusted servers and the global and public address book" : "Synchronizuj z zaufanymi serwerami oraz globalną i publiczną książką adresową",
    "Not available as publishing account specific data to the lookup server is not allowed, contact your system administration if you have any questions" : "Niedostępne, ponieważ publikowanie danych specyficznych dla konta na serwerze wyszukiwania jest niedozwolone. W razie pytań skontaktuj się z administratorem systemu",
    "Discover" : "Odkryj",
    "Your apps" : "Twoje aplikacje",
    "Active apps" : "Aktywne aplikacje",
    "Disabled apps" : "Wyłączone aplikacje",
    "Updates" : "Aktualizacje",
    "App bundles" : "Zestawy aplikacji",
    "Featured apps" : "Polecane aplikacje",
    "Supported apps" : "Obsługiwane aplikacje",
    "Show to everyone" : "Pokaż wszystkim",
    "Show to logged in accounts only" : "Pokaż tylko zalogowanym kontom",
    "Hide" : "Ukryj",
    "Could not register device: Network error" : "Nie można zarejestrować urządzenia: błąd sieci",
    "Could not register device: Probably already registered" : "Nie można zarejestrować urządzenia: Prawdopodobnie zostało już zarejestrowane",
    "Could not register device" : "Nie można zarejestrować urządzenia",
    "Could not delete the app token" : "Nie można usunąć tokena aplikacji",
    "Error while wiping the device with the token" : "Błąd podczas czyszczenia urządzenia za pomocą tokena",
    "Error while updating device token name" : "Błąd podczas aktualizacji nazwy tokena urządzenia",
    "Error while updating device token scope" : "Błąd podczas aktualizacji zakresu tokena urządzenia",
    "An error occurred during the request. Unable to proceed." : "Wystąpił błąd podczas żądania. Nie można kontynuować.",
    "Could not set group sorting" : "Nie można ustawić sortowania grupy",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Zbyt wiele żądań z Twojej sieci. Spróbuj ponownie później lub skontaktuj się z administratorem, jeśli jest to błąd.",
    "Error" : "Błąd",
    "Account documentation" : "Dokumentacja konta",
    "Administration documentation" : "Dokumentacja administracyjna",
    "Documentation" : "Dokumentacja",
    "Forum" : "Forum",
    "Nextcloud help & privacy resources" : "Zasoby pomocy i prywatności w Nextcloud",
    "General documentation" : "Dokumentacja ogólna",
    "Legal notice" : "Nota prawna",
    "Privacy policy" : "Polityka prywatności",
    "Version" : "Wersja",
    "Reasons to use Nextcloud in your organization" : "Dlaczego warto korzystać z Nextcloud w Twojej organizacji",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Opracowane przez {communityopen}społeczność Nextcloud{linkclose}, {githubopen}kod źródłowy{linkclose} jest objęty licencją {licenseopen}AGPL{linkclose}.",
    "Like our Facebook page" : "Polub nas na Facebook'u",
    "Follow us on Bluesky" : "Śledź nas na Bluesky",
    "Follow us on Mastodon" : "Bądź z nami na Mastodonie",
    "Check out our blog" : "Sprawdź nasz blog",
    "Subscribe to our newsletter" : "Subskrybuj nasz newsletter",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "To wydanie społecznościowe Nextcloud nie jest obsługiwane i powiadomienia natychmiastowe są niedostępne.",
    "Open documentation" : "Otwórz dokumentację",
    "Use a second factor besides your password to increase security for your account." : "Użyj drugiego zabezpieczenia oprócz hasła, aby zwiększyć bezpieczeństwo konta.",
    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Jeśli używasz aplikacji innych firm do łączenia się z Nextcloud, upewnij się, że utworzyłeś i skonfigurowałeś hasło aplikacji dla każdej przed włączeniem uwierzytelniania dwuskładnikowego.",
    "Very weak password" : "Bardzo słabe hasło",
    "Weak password" : "Słabe hasło",
    "So-so password" : "Mało skomplikowane hasło",
    "Good password" : "Dobre hasło",
    "Strong password" : "Mocne hasło",
    "Group list is empty" : "Lista grup jest pusta",
    "Unable to retrieve the group list" : "Nie można pobrać listy grup",
    "Could not remove app." : "Usuwanie aplikacji nie powiodło się.",
    "Could not update app." : "Nie można uaktualnić aplikacji.",
    "Apps" : "Aplikacje",
    "for Argon2 for password hashing" : "dla Argon2 do haszowania haseł",
    "MariaDB version 10.3 detected, this version is end-of-life and only supported as part of Ubuntu 20.04. MariaDB >=%1$s and <=%2$s is suggested for best performance, stability and functionality with this version of Nextcloud." : "Wykryto MariaDB w wersji 10.3, ta wersja jest nieobsługiwana i wspierana jedynie w ramach Ubuntu 20.04. Zalecana jest MariaDB >=%1$s i <= %2$s dla najlepszej wydajności, stabilności i kompatybilności z tą wersją Nextcloud.",
    "_Most tasks were successful in the last day._::_Most tasks were successful in the last %n days._" : ["Większość zadań zakończyła się powodzeniem w ciągu ostatnich %n dni.","Większość zadań zakończyła się powodzeniem w ciągu ostatnich %n dni.","Większość zadań zakończyła się powodzeniem w ciągu ostatnich %n dni.","Większość zadań zakończyła się powodzeniem w ciągu ostatnich %n dni."],
    "_The Task Processing worker has run in the last minute._::_The Task Processing worker has run in the last %n minutes._" : ["Proces roboczy przetwarzania zadań działał w ciągu ostatniej %n minuty","Proces roboczy przetwarzania zadań działał w ciągu ostatnich %n minut","Proces roboczy przetwarzania zadań działał w ciągu ostatnich %n minut","Proces roboczy przetwarzania zadań działał w ciągu ostatnich %n minuty"],
    "Machine translation" : "Tłumaczenie maszynowe",
    "Image generation" : "Generowanie obrazu",
    "Text processing" : "Przetwarzanie tekstu",
    "Exclude some groups from sharing" : "Wyklucz niektóre grupy z udostępniania",
    "Limit sharing to some groups" : "Ogranicz udostępnianie do niektórych grup",
    "Also allow autocompletion on full match of the user id" : "Zezwól także na autouzupełnianie przy pełnym dopasowaniu identyfikatora użytkownika",
    "Choose Deploy Daemon for {appName}" : "Wybierz demona wdrożeniowego dla {appName}",
    "Registered Deploy daemons list" : "Lista zarejestrowanych demonów wdrożeniowych",
    "No Deploy daemons configured" : "Brak skonfigurowanych demonów wdrożeniowych",
    "Register a custom one or setup from available templates" : "Zarejestruj własnego lub skonfiguruj z dostępnych szablonów",
    "Manage Deploy daemons" : "Zarządzaj demonami wdrożeniowymi",
    "Show details for {appName} app" : "Pokaż szczegóły aplikacji {appName}",
    "Update to {update}" : "Zaktualizuj do {update}",
    "Remove" : "Usuń",
    "Featured" : "Polecane",
    "This app is supported via your current Nextcloud subscription." : "Ta aplikacja jest obsługiwana za pośrednictwem bieżącej subskrypcji Nextcloud.",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Polecane aplikacje są tworzone przez społeczność. Oferują główną funkcjonalność i są gotowe do użycia w produkcji.",
    "Community rating: {score}/5" : "Ocena społeczności: {score}/5",
    "Disable all" : "Wyłącz wszystkie",
    "Download and enable all" : "Pobierz i włącz wszystko",
    "All apps are up-to-date." : "Wszystkie aplikacje są aktualne.",
    "Icon" : "Ikona",
    "Name" : "Nazwa",
    "Level" : "Poziom",
    "Results from other categories" : "Wyniki z innych kategorii",
    "No apps found for your version" : "Nie znaleziono aplikacji dla Twojej wersji",
    "_%n app has an update available_::_%n apps have an update available_" : ["%n aplikacja ma dostępną aktualizację","%n aplikacje mają dostępną aktualizację","%n aplikacji mają dostępną aktualizację","%n aplikacji mają dostępną aktualizację"],
    "_Update_::_Update all_" : ["Zaktualizuj","Zaktualizuj","Zaktualizuj","Zaktualizuj wszystko"],
    "Search groups…" : "Wyszukaj grupy...",
    "Could not load app discover section" : "Nie można wczytać sekcji odkrywania aplikacji",
    "Could not render element" : "Nie można wyrenderować elementu",
    "Nothing to show" : "Nie ma nic do pokazania",
    "Could not load section content from app store." : "Nie można wczytać zawartości sekcji ze sklepu z aplikacjami.",
    "Loading" : "Wczytywanie",
    "Fetching the latest news…" : "Pobieram najnowsze wiadomości…",
    "Carousel" : "Karuzela",
    "Previous slide" : "Poprzedni slajd",
    "Next slide" : "Następny slajd",
    "Choose slide to display" : "Wybierz slajd do wyświetlenia",
    "{index} of {total}" : "{index} z {total}",
    "Daemon" : "Demon",
    "Deploy Daemon" : "Uruchom demona",
    "Type" : "Rodzaj",
    "Display Name" : "Wyświetlana nazwa",
    "GPUs support" : "Obsługa procesorów graficznych",
    "Compute device" : "Urządzenie obliczeniowe",
    "Advanced deploy options" : "Zaawansowane opcje wdrażania",
    "Edit ExApp deploy options before installation" : "Edytuj opcje wdrażania ExApp przed instalacją",
    "Configured ExApp deploy options. Can be set only during installation" : "Skonfigurowane opcje wdrażania ExApp. Można ustawić tylko podczas instalacji",
    "Learn more" : "Dowiedz się więcej",
    "Environment variables" : "Zmienne środowiskowe",
    "ExApp container environment variables" : "Zmienne środowiskowe kontenera ExApp",
    "No environment variables defined" : "Nie zdefiniowano żadnych zmiennych środowiskowych",
    "Mounts" : "Montowania",
    "Define host folder mounts to bind to the ExApp container" : "Zdefiniuj montowania folderów hosta do powiązania z kontenerem ExApp",
    "Must exist on the Deploy daemon host prior to installing the ExApp" : "Musi istnieć na hoście demona wdrożeniowego przed instalacją ExApp",
    "Host path" : "Ścieżka hosta",
    "Container path" : "Ścieżka kontenera",
    "Read-only" : "Tylko do odczytu",
    "Remove mount" : "Usuń montowanie",
    "New mount" : "Nowe montowanie",
    "Enter path to host folder" : "Wprowadź ścieżkę do folderu hosta",
    "Enter path to container folder" : "Wprowadź ścieżkę do folderu kontenera",
    "Toggle read-only mode" : "Przełącz tryb tylko do odczytu",
    "Confirm adding new mount" : "Potwierdź dodanie nowego montowania",
    "Cancel adding mount" : "Anuluj dodawanie montowania",
    "Add mount" : "Dodaj montowanie",
    "ExApp container mounts" : "Montowania kontenera ExApp",
    "No mounts defined" : "Nie zdefiniowano montowań",
    "Description" : "Opis",
    "View in store" : "Zobacz w sklepie",
    "Visit website" : "Odwiedź stronę",
    "Usage documentation" : "Dokumentacja użytkowania",
    "Admin documentation" : "Dokumentacja administratora",
    "Developer documentation" : "Dokumentacja dewelopera",
    "All" : "Wszystkie",
    "Limit app usage to groups" : "Ogranicz korzystanie z aplikacji dla grup",
    "No results" : "Brak wyników",
    "Update to {version}" : "Zaktualizuj do {version}",
    "Deploy options" : "Opcje wdrażania",
    "Default Deploy daemon is not accessible" : "Domyślny demon wdrażania jest niedostępny",
    "Delete data on remove" : "Usuń dane przy usuwaniu",
    "This app has no minimum {productName} version assigned. This will be an error in the future." : "Ta aplikacja nie ma przypisanej minimalnej wersji {productName}. W przyszłości będzie to błąd.",
    "This app has no maximum {productName} version assigned. This will be an error in the future." : "Ta aplikacja nie ma przypisanej maksymalnej wersji {productName}. W przyszłości będzie to błąd.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Ta aplikacja nie może być zainstalowana, ponieważ nie są spełnione następujące zależności:",
    "Latest updated" : "Ostatnia aktualizacja",
    "Author" : "Autor",
    "Categories" : "Kategorie",
    "Resources" : "Zasoby",
    "Interact" : "Współpraca",
    "Report a bug" : "Zgłoś błąd",
    "Request feature" : "Zgłoś propozycję",
    "Ask questions or discuss" : "Zadaj pytanie lub weź udział w dyskusji",
    "Rate the app" : "Oceń aplikację",
    "Rate" : "Oceń",
    "Changelog" : "Dziennik zmian",
    "Loading accounts …" : "Wczytywanie kont...",
    "Set line manager" : "Ustaw menedżera liniowego",
    "Set account as admin for …" : "Ustaw konto jako administrator dla…",
    "_{userCount} account …_::_{userCount} accounts …_" : ["{userCount} konto...","{userCount} konta...","{userCount} kont...","{userCount} konta..."],
    "Password or insufficient permissions message" : "Komunikat o haśle lub niewystarczających uprawnieniach",
    "Failed to load groups with details" : "Nie udało się załadować grup ze szczegółami",
    "Failed to load sub admin groups with details" : "Nie udało się załadować grup administratorów podrzędnych ze szczegółami",
    "Failed to update line manager" : "Nie udało się zaktualizować menedżera liniowego",
    "Display name was successfully changed" : "Nazwa wyświetlana została zmieniona",
    "Password can't be empty" : "Hasło nie możne być puste",
    "Password was successfully changed" : "Hasło zostało zmienione",
    "Email can't be empty" : "Adres e-mail nie może być pusty",
    "Email was successfully changed" : "Adres e-mail został pomyślnie zmieniony",
    "Loading account …" : "Wczytywanie konta...",
    "Change display name" : "Zmiana wyświetlanej nazwy",
    "Set new password" : "Ustaw nowe hasło",
    "You do not have permissions to see the details of this account" : "Nie masz uprawnień, aby zobaczyć szczegóły tego konta",
    "Set new email address" : "Ustaw nowy adres e-mail",
    "Add account to group" : "Dodaj konto do grupy",
    "Set account as admin for" : "Ustaw konto jako administrator dla",
    "Select account quota" : "Wybierz limit konta",
    "Set the language" : "Ustaw język",
    "Done" : "Gotowe",
    "Adding your device …" : "Dodawanie urządzenia…",
    "App Store" : "Sklep aplikacji",
    "Loading app list" : "Wczytywanie listy aplikacji",
    "Loading categories" : "Wczytywanie kategorii",
    "Version {version}, {license}-licensed" : "Wersja {version}, {license}-licencjonowana",
    "Version {version}" : "Wersja {version}",
    "Sending…" : "Wysyłam…",
    "Email sent" : "E-mail został wysłany",
    "Manually installed apps cannot be updated" : "Aplikacje zainstalowane ręcznie nie mogą być aktualizowane",
    "{progress}% Deploying …" : "{progress} % trwa wdrażanie…",
    "{progress}% Initializing …" : "{progress} % trwa inicjalizacja ...",
    "Health checking" : "Sprawdzanie stanu zdrowia",
    "Deploy and Enable" : "Wdróż i włącz",
    "Download and enable" : "Pobierz i włącz",
    "Disable" : "Wyłącz",
    "Allow untested app" : "Zezwalaj na nietestowane aplikacje",
    "The app will be downloaded from the App Store" : "Aplikacja zostanie pobrana ze sklepu z aplikacjami",
    "This app is not marked as compatible with your {productName} version." : "Ta aplikacja nie jest oznaczona jako kompatybilna z Twoją wersją {productName}.",
    "If you continue you will still be able to install the app. Note that the app might not work as expected." : "Jeśli będziesz kontynuować, nadal będziesz mógł zainstalować aplikację. Pamiętaj jednak, że aplikacja może nie działać zgodnie z oczekiwaniami.",
    "The app has been enabled but needs to be updated." : "Aplikacja została włączona, ale wymaga aktualizacji.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Błąd: Ta aplikacja nie zostanie włączona ze względu na możliwość niestabilnej pracy serwera",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Aplikacja została włączona, ponieważ wymaga aktualizacji. Za 5 sekund nastąpi przekierowanie do strony aktualizacji.",
    "None/STARTTLS" : "Brak/STARTTLS",
    "SSL" : "SSL",
    "Credentials" : "Poświadczenia",
    "SMTP Login" : "Logowanie SMTP",
    "SMTP Password" : "Hasło SMTP",
    "Test and verify email settings" : "Przetestuj i zweryfikuj ustawienia poczty e-mail",
    "Office suite switching is managed through the Nextcloud All-in-One interface." : "Przełączanie pakietu biurowego jest zarządzane przez interfejs Nextcloud All-in-One.",
    "Please use the AIO interface to switch between office suites." : "Użyj interfejsu AIO, aby przełączać się między pakietami biurowymi.",
    "Select your preferred office suite. Please note that installing requires manual server setup." : "Wybierz preferowany pakiet biurowy. Pamiętaj, że instalacja wymaga ręcznej konfiguracji serwera.",
    "installed" : "Zainstalowano",
    "Disable office suites" : "Wyłącz pakiety biurowe",
    "All office suites disabled" : "Wszystkie pakiety biurowe wyłączone",
    "{name} enabled" : "{name} włączony",
    "Best Nextcloud integration" : "Najlepsza integracja z Nextcloud",
    "Open source" : "Oprogramowanie open source",
    "Good performance" : "Dobra wydajność",
    "Best security: documents never leave your server" : "Najlepsze bezpieczeństwo: dokumenty nigdy nie opuszczają Twojego serwera",
    "Best ODF compatibility" : "Najlepsza zgodność z ODF",
    "Best support for legacy files" : "Najlepsza obsługa starszych plików",
    "Good Nextcloud integration" : "Dobra integracja z Nextcloud",
    "Open core" : "Otwarty rdzeń",
    "Best performance" : "Najlepsza wydajność",
    "Limited ODF compatibility" : "Ograniczona zgodność z ODF",
    "Best Microsoft compatibility" : "Najlepsza zgodność z Microsoft",
    "{progress}% Deploying …" : "{progress} % trwa wdrażanie …",
    "{progress}% Initializing …" : "{progress} % trwa inicjalizacja ..."
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
