OC.L10N.register(
    "logreader",
    {
    "Logging" : "Loki",
    "Log Reader" : "Lokilukija",
    "A log reader for Nextcloud" : "Nextcloudin lokilukija",
    "Log reader for Nextcloud" : "Nextcloudin lokilukija",
    "Level" : "Taso",
    "App" : "Sovellus",
    "Time" : "Aika",
    "Download logs" : "Lataa lokit",
    "Relative" : "Suhteellinen",
    "Application" : "Sovellus",
    "Message" : "Viesti",
    "Show details" : "Näytä lisätiedot",
    "Debug" : "Vianjäljitys",
    "Info" : "Tietoa",
    "Warning" : "Varoitus",
    "Error" : "Virhe",
    "Fatal" : "Kriittinen"
},
"nplurals=2; plural=(n != 1);");
