<?php return array(
    'root' => array(
        'name' => 'christophwurst/suspicious_login',
        'pretty_version' => 'dev-stable34',
        'version' => 'dev-stable34',
        'reference' => '7c983cc4e0cfea4c05cfc6604a569da47b4aed16',
        'type' => 'library',
        'install_path' => __DIR__ . '/../../',
        'aliases' => array(),
        'dev' => false,
    ),
    'versions' => array(
        'amphp/amp' => array(
            'pretty_version' => 'v2.6.5',
            'version' => '2.6.5.0',
            'reference' => 'd7dda98dae26e56f3f6fcfbf1c1f819c9a993207',
            'type' => 'library',
            'install_path' => __DIR__ . '/../amphp/amp',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'amphp/byte-stream' => array(
            'pretty_version' => 'v1.8.2',
            'version' => '1.8.2.0',
            'reference' => '4f0e968ba3798a423730f567b1b50d3441c16ddc',
            'type' => 'library',
            'install_path' => __DIR__ . '/../amphp/byte-stream',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'amphp/parallel' => array(
            'pretty_version' => 'v1.4.4',
            'version' => '1.4.4.0',
            'reference' => '508ca221f2f47235327db5120f0a89d43435b69b',
            'type' => 'library',
            'install_path' => __DIR__ . '/../amphp/parallel',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'amphp/parser' => array(
            'pretty_version' => 'v1.1.1',
            'version' => '1.1.1.0',
            'reference' => '3cf1f8b32a0171d4b1bed93d25617637a77cded7',
            'type' => 'library',
            'install_path' => __DIR__ . '/../amphp/parser',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'amphp/process' => array(
            'pretty_version' => 'v1.1.9',
            'version' => '1.1.9.0',
            'reference' => '55b837d4f1857b9bd7efb7bb859ae6b0e804f13f',
            'type' => 'library',
            'install_path' => __DIR__ . '/../amphp/process',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'amphp/serialization' => array(
            'pretty_version' => 'v1.0.0',
            'version' => '1.0.0.0',
            'reference' => '693e77b2fb0b266c3c7d622317f881de44ae94a1',
            'type' => 'library',
            'install_path' => __DIR__ . '/../amphp/serialization',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'amphp/sync' => array(
            'pretty_version' => 'v1.4.2',
            'version' => '1.4.2.0',
            'reference' => '85ab06764f4f36d63b1356b466df6111cf4b89cf',
            'type' => 'library',
            'install_path' => __DIR__ . '/../amphp/sync',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'andrewdalpino/okbloomer' => array(
            'pretty_version' => '1.0.0',
            'version' => '1.0.0.0',
            'reference' => '39321cb515c1e99128d28489b0187120ba7ce84c',
            'type' => 'library',
            'install_path' => __DIR__ . '/../andrewdalpino/okbloomer',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'bamarni/composer-bin-plugin' => array(
            'pretty_version' => '1.9.1',
            'version' => '1.9.1.0',
            'reference' => '641d0663f5ac270b1aeec4337b7856f76204df47',
            'type' => 'composer-plugin',
            'install_path' => __DIR__ . '/../bamarni/composer-bin-plugin',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'christophwurst/suspicious_login' => array(
            'pretty_version' => 'dev-stable34',
            'version' => 'dev-stable34',
            'reference' => '7c983cc4e0cfea4c05cfc6604a569da47b4aed16',
            'type' => 'library',
            'install_path' => __DIR__ . '/../../',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'joomla/string' => array(
            'pretty_version' => '3.0.4',
            'version' => '3.0.4.0',
            'reference' => '0b3d33564db389e27346f7e275c694897c939434',
            'type' => 'joomla-package',
            'install_path' => __DIR__ . '/../joomla/string',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/log' => array(
            'pretty_version' => '3.0.2',
            'version' => '3.0.2.0',
            'reference' => 'f16e1d5863e37f8d8c2a01719f5b34baa2b714d3',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/log',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'rubix/ml' => array(
            'pretty_version' => '2.5.3',
            'version' => '2.5.3.0',
            'reference' => 'e0960dcb19c9722ccbc4826f5b9417a75fa01613',
            'type' => 'library',
            'install_path' => __DIR__ . '/../rubix/ml',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'rubix/tensor' => array(
            'pretty_version' => '3.0.5',
            'version' => '3.0.5.0',
            'reference' => '9f0ee170319280dcf081984adccefa8b0e6f06b8',
            'type' => 'library',
            'install_path' => __DIR__ . '/../rubix/tensor',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/deprecation-contracts' => array(
            'pretty_version' => 'v3.6.0',
            'version' => '3.6.0.0',
            'reference' => '63afe740e99a13ba87ec199bb07bbdee937a5b62',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/deprecation-contracts',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/polyfill-mbstring' => array(
            'pretty_version' => 'v1.33.0',
            'version' => '1.33.0.0',
            'reference' => '6d857f4d76bd4b343eac26d6b539585d2bc56493',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/polyfill-mbstring',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/polyfill-php80' => array(
            'pretty_version' => 'v1.33.0',
            'version' => '1.33.0.0',
            'reference' => '0cc9dd0f17f61d8131e7df6b84bd344899fe2608',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/polyfill-php80',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/polyfill-php82' => array(
            'pretty_version' => 'v1.33.0',
            'version' => '1.33.0.0',
            'reference' => '5d2ed36f7734637dacc025f179698031951b1692',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/polyfill-php82',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/polyfill-php83' => array(
            'pretty_version' => 'v1.33.0',
            'version' => '1.33.0.0',
            'reference' => '17f6f9a6b1735c0f163024d959f700cfbc5155e5',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/polyfill-php83',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'wamania/php-stemmer' => array(
            'pretty_version' => 'v4.0.0',
            'version' => '4.0.0.0',
            'reference' => 'd96509294ea843b4b86e4900df27424a6ea0ace8',
            'type' => 'library',
            'install_path' => __DIR__ . '/../wamania/php-stemmer',
            'aliases' => array(
                0 => '3.0',
            ),
            'dev_requirement' => false,
        ),
    ),
);
