.tag-cover[data-v-01249121]{display:flex;flex-direction:column;padding:16px;border-radius:12px}.tag-cover[data-v-01249121]:hover,.tag-cover[data-v-01249121]:focus{background:var(--color-background-dark)}.tag-cover__image[data-v-01249121]{width:350px;height:350px;object-fit:cover;border-radius:12px}@media only screen and (max-width:1200px){.tag-cover__image[data-v-01249121]{width:250px;height:250px}}.tag-cover__image--placeholder[data-v-01249121]{background:var(--color-primary-element-light)}.tag-cover__image--placeholder[data-v-01249121] .material-design-icon{width:100%;height:100%}.tag-cover__image--placeholder[data-v-01249121] .material-design-icon .material-design-icon__svg{fill:var(--color-primary-element)}.tag-cover__details[data-v-01249121]{display:flex;flex-direction:column;margin-top:16px;width:350px}@media only screen and (max-width:1200px){.tag-cover__details[data-v-01249121]{width:250px}}.tag-cover__details__first-line[data-v-01249121]{display:flex}.tag-cover__details__second-line[data-v-01249121]{display:flex;color:var(--color-text-lighter)}.tag-cover__details__name[data-v-01249121]{flex-grow:1;margin:0;font-weight:400;overflow:hidden;white-space:nowrap;text-overflow:ellipsis}.loader[data-v-cb8dfce8]{margin-top:30vh}.container[data-v-cb8dfce8]{padding-inline-start:44px}.container>h2[data-v-cb8dfce8]{margin-inline-start:14px;margin-top:40px}.popular-tags[data-v-cb8dfce8],.tags[data-v-cb8dfce8]{display:flex;flex-direction:row;gap:8px;flex-wrap:wrap}
