OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "اول ویزاد را اجرا کنید",
    "Add your profile information! For example your email is needed to receive notifications." : "اطلاعات نمایهٔ خود را اضافه کنید! برای نمونه، رایانامهٔ شما برای دریافت اعلان‌ها لازم است.",
    "Add your profile information! For example your email is needed to receive notifications and reset your password." : "اطلاعات نمایهٔ خود را اضافه کنید! برای نمونه، رایانامهٔ شما برای دریافت اعلان‌ها و بازنشانی گذرواژه‌تان لازم است.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "اطلاعات نمایهٔ خود را اضافه کنید! یک تصویر نمایه و نام کامل برای تشخیص آسان‌تر در تمام ویژگی‌ها تنظیم کنید.",
    "Add your profile information! Set a full name for easier recognition across all features." : "اطلاعات نمایهٔ خود را اضافه کنید! یک نام کامل برای تشخیص آسان‌تر در تمام ویژگی‌ها تنظیم کنید.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "اطلاعات نمایهٔ خود را اضافه کنید! برای تشخیص آسان‌تر در تمام ویژگی‌ها، یک تصویر نمایه تنظیم کنید.",
    "App recommendation: Calendar" : "توصیه برنامه: تقویم",
    "Schedule work & meetings, synced with all your devices." : "زمان‌بندی کار و جلسات، همگام‌سازی‌شده با تمام دستگاه‌های شما",
    "App recommendation: Contacts" : "توصیه برنامه: مخاطبین",
    "Keep your colleagues and friends in one place without leaking their private info." : "همکاران و دوستان خود را در یک مکان نگه دارید بدون اینکه اطلاعات خصوصی آنها را بشناسید.",
    "App recommendation: Mail" : "توصیه برنامه: نامه",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "برنامه ایمیل ساده با پرونده ها ، مخاطبین و تقویم یکپارچه شده است.",
    "App recommendation: Tasks" : "توصیه برنامه: کارها",
    "Sync tasks from various devices with your Nextcloud and edit them online." : "وظایف دستگاه های مختلف را با Nextcloud خود همگام سازی کرده و آنها را بصورت آنلاین ویرایش کنید.",
    "App recommendation: Deck" : "توصیه برنامه: کارتابل",
    "Kanban style organization for personal planning and team projects." : "سازمان به سبک کانبان برای برنامه ریزی های شخصی و پروژه های تیمی.",
    "App recommendation: Forms" : "توصیه برنامه: فرم‌ها",
    "Simple surveys and questionnaires, self-hosted" : "نظرسنجی‌ها و پرسشنامه‌های ساده، با میزبانی شخصی",
    "App recommendation: Recognize" : "توصیه برنامه: Recognize",
    "Smart media tagging for Nextcloud" : "برچسب‌گذاری هوشمند رسانه برای Nextcloud",
    "App recommendation: Group folders" : "توصیه برنامه: پوشه های گروه",
    "Admin-configured folders shared by everyone in a group." : "پوشه های پیکربندی اداری که توسط همه افراد در یک گروه به اشتراک گذاشته می شود.",
    "App recommendation: Whiteboard" : "توصیه برنامه: وایت‌بورد",
    "Create and share whiteboards with others and collaborate in real-time." : "وایت‌بوردها را بسازید و با دیگران به اشتراک بگذارید و به‌صورت هم‌زمان همکاری کنید.",
    "Connect your calendar" : "تقویم خود را وصل کنید",
    "Connect your contacts" : "مخاطبین خود را وصل کنید",
    "Access files via WebDAV" : "دسترسی فایل ها از طریق WebDAV",
    "Download macOS/iOS configuration profile" : "نمایه پیکربندی macOS / iOS را بارگیری کنید",
    "Desktop client" : "نرم افزار دسکتاپ",
    "Android app on Google Play Store" : "برنامه اندروید در Google Play Store",
    "Android app on F-Droid" : "برنامه اندروید در F-Droid",
    "iOS app" : "اپ iOS",
    "About & What's new" : "درباره و تازه‌ها",
    "A welcome and introduction wizard for Nextcloud" : "خوش آمد گویی و معرفی ویزارد برای  Nextcloud",
    "This application enables a pop-up window when a user first logs into Nextcloud. This window welcomes new users to Nextcloud, and contains links to the standard desktop client, Android app, and the iOS app. The window also shows a link for accessing Nextcloud via WebDAV. At any time, the first run wizard can be opened again via link \"About\" on settings menu.\nThe First run wizard can be customized to meet specific design goals, or to change links and messages. Create an appropriate theme following the Theming documentation, and changes to the look and feel of this Wizard are simple. More information is available in the first run wizard documentation, as well as the theming documentation." : "این برنامه وقتی کاربر برای اولین بار وارد Nextcloud می شود ، پنجره بازشو را فعال می کند. این پنجره از کاربران جدید به Nextcloud استقبال می کند و شامل پیوندهایی به مشتری استاندارد رومیزی ، برنامه Android و برنامه iOS است. در پنجره همچنین پیوندی برای دسترسی به Nextcloud از طریق WebDAV نشان داده شده است. در هر زمان ، اولین جادوگر اجرا می تواند دوباره از طریق پیوند \"درباره\" در فهرست تنظیمات باز شود.\nجادوگر اجرای اول می تواند برای تحقق اهداف خاص طراحی یا تغییر لینک ها و پیام ها سفارشی شود. با دنبال کردن مستندات Theming ، یک تم مناسب ایجاد کنید و تغییراتی در ظاهر و احساس این جادوگر ساده است. اطلاعات بیشتر در مستندات جادوگر اول اجرا و همچنین اسناد مضامین موجود است.",
    "Download on Apple app store" : "بارگیری از Apple app store",
    "Download on Google play store" : "بارگیری از Google play store",
    "Go to previous page" : "رفتن به صفحهٔ قبلی",
    "Close" : "بسته",
    "More about Nextcloud" : "بیشتر درباره Nextcloud",
    "Explore more apps ↗" : "کاوش در برنامه‌های بیشتر ↗",
    "Extend the functionality of Nextcloud with hundreds of community-developed apps." : "قابلیت‌های Nextcloud را با صدها برنامهٔ توسعه‌یافته به‌دست انجمن گسترش دهید.",
    "Get involved! ↗" : "مشارکت کنید! ↗",
    "Be a part of the community that helps build, design, translate and promote Nextcloud!" : "بخشی از انجمنی باشید که به ساخت، طراحی، ترجمه و معرفی Nextcloud کمک می‌کند!",
    "Need help? ↗" : "نیاز به راهنمایی دارید؟ ↗",
    "Find out more about your Nextcloud setup with the admin, user or developer documentation." : "با مستندات مدیر، کاربر یا توسعه‌دهنده، دربارهٔ پیکربندی Nextcloud خود بیشتر بدانید.",
    "For large organisations ↗" : "برای سازمان‌های بزرگ ↗",
    "Get Nextcloud Enterprise for mission critical environments where advanced security and compliance are important." : "Nextcloud Enterprise را برای محیط‌های حساس و حیاتی که در آن‌ها امنیت و انطباق پیشرفته اهمیت دارد، تهیه کنید.",
    "Seamless integration with your devices." : "یکپارچگی بی‌نقص با دستگاه‌های شما.",
    "Sync your files across your devices with the desktop and mobile apps, and connect your calendar and contacts." : "فایل‌های خود را با برنامه‌های رومیزی و موبایل میان دستگاه‌هایتان همگام کنید و تقویم و مخاطبین خود را وصل کنید.",
    "Desktop app ↗" : "برنامهٔ دسکتاپ ↗",
    "Download For Windows, Mac OS and Linux." : "برای Windows، Mac OS و Linux بارگیری کنید.",
    "Calendar and contacts ↗" : "تقویم و مخاطبین",
    "Connect your calendar and contacts with your devices." : "تقویم و مخاطبین خود را به دستگاه‌هایتان وصل کنید.",
    "Welcome to {cloudName}!" : "به {cloudName} خوش آمدید!",
    "Skip" : "پرش.",
    "This Nextcloud is on version {version}" : "این نسخهٔ Nextcloud برابر با {version} است",
    "A collaboration platform that puts you in control" : "بستری برای همکاری که کنترل را در دست شما می‌گذارد",
    "Privacy" : "محرمانگی",
    "Host your data and files where you decide." : "داده‌ها و فایل‌های خود را هرجا که می‌خواهید میزبانی کنید.",
    "Productivity" : "بهره‌وری",
    "Collaborate and communicate across any platform." : "روی هر بستری همکاری و ارتباط برقرار کنید.",
    "Interoperability" : "قابلیت همکاری",
    "Import and export anything you want with open standards." : "هر چیزی را که بخواهید با استانداردهای باز وارد و صادر کنید.",
    "Community" : "انجمن",
    "Enjoy constant improvements from a thriving open-source community." : "از بهبودهای مداومی که جامعهٔ پرتکاپوی متن‌باز ارائه می‌دهد لذت ببرید.",
    "Nextcloud Hub {version} release" : "انتشار Nextcloud Hub {version}",
    "Read more about it on the Nextcloud Hub {version} blog" : "در وبلاگ Nextcloud Hub {version} بیشتر دربارهٔ آن بخوانید",
    "Find out more on the blog" : "در وبلاگ بیشتر بدانید",
    "Read the Nextcloud Hub {version} blog" : "وبلاگ Nextcloud Hub {version} را بخوانید",
    "Share your opinion about Nextcloud Hub {version}" : "نظر خود را دربارهٔ Nextcloud Hub {version} با ما در میان بگذارید",
    "Share via email" : "اشتراک‌گذاری از طریق ایمیل",
    "Share on {socialMedia}" : "اشتراک‌گذاری در {socialMedia}",
    "New in Nextcloud Hub {version}" : "تازه‌ها در Nextcloud Hub {version}",
    "Connect other apps to {productName}" : "اتصال برنامه‌های دیگر به {productName}",
    "Besides the mobile apps and desktop client you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to {productName}." : "علاوه بر برنامه‌های موبایل و کلاینت دسکتاپ، می‌توانید هر نرم‌افزار دیگری را که از پروتکل‌های WebDAV/CalDAV/CardDAV پشتیبانی می‌کند به {productName} متصل کنید.",
    "Apps to connect to {productName}" : "برنامه‌هایی برای اتصال به {productName}",
    "Set up sync clients using an {linkStart}app password{linkEnd}. That way you can make sure you are able to revoke access in case you lose that device." : "کلاینت‌های همگام‌سازی را با استفاده از {linkStart}گذرواژهٔ برنامه{linkEnd} راه‌اندازی کنید. به این ترتیب می‌توانید مطمئن شوید که در صورت گم کردن آن دستگاه، قادر به لغو دسترسی هستید.",
    "Get the apps to sync your files" : "برنامه ها را دریافت کنید تا فایل هایتان را همگام سازید",
    "{productName} gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "{productName} به شما امکان می‌دهد هر کجا که باشید به پرونده‌هایتان دسترسی داشته باشید. کلاینت‌های دسکتاپ و موبایل آسانِ ما برای تمام سکوهای اصلی به‌صورت رایگان در دسترس هستند.",
    "App for syncing" : "برنامه‌ای برای همگام‌سازی",
    "URL copied" : "نشانی URL رونوشت شد",
    "Could not copy the URL, please copy manually" : "کپی نشانی اینترنتی ممکن نشد؛ لطفاً آن را به‌صورت دستی کپی کنید",
    "Server address" : "آدرس سرور",
    "Use this link to connect your apps and desktop client to this server:" : "برای اتصال برنامه ها و مشتری دسک تاپ خود به این سرور از این لینک استفاده کنید:",
    "Refined design, optimized performance" : "طراحی پالایش‌شده، کارایی بهینه",
    "Empowering developers with an open platform" : "توانمندسازی توسعه‌دهندگان با یک بستر باز",
    "Your choice: Nextcloud Office powered by Collabora or Euro-Office" : "انتخاب با شماست: Nextcloud Office مبتنی بر Collabora یا Euro-Office",
    "Delegate calendars, meetings and mail boxes for better collaboration" : "واگذاری تقویم‌ها، جلسات و صندوق‌های پستی برای همکاری بهتر",
    "Gantt charts, dependencies & more in Nextcloud Deck" : "نمودارهای گانت، وابستگی‌ها و موارد بیشتر در کارتابل نکست کلود",
    "More agency: let the Assistant work for you across files, emails, forms, and more" : "اختیار بیشتر: بگذارید دستیار در پرونده‌ها، ایمیل‌ها، فرم‌ها و موارد دیگر برایتان کار کند",
    "Pexip, Matrix, and more updates in integrations" : "Pexip، Matrix و به‌روزرسانی‌های بیشتر در یکپارچه‌سازی‌ها",
    "… and many more improvements in all apps!" : "… و بهبودهای بسیار بیشتر در همهٔ برنامه‌ها!",
    "Experience the brand new Nextcloud Hub!" : "Nextcloud Hub کاملاً جدید را تجربه کنید!",
    "Get to know the new features of Hub {version}" : "با ویژگی‌های جدید Hub {version} آشنا شوید",
    "Time to own your collaboration: Meet Nextcloud Hub 26 Spring! 🚀" : "وقتش رسیده همکاری‌تان را در دست بگیرید: با Nextcloud Hub 26 Spring آشنا شوید! 🚀",
    "What's new?" : "چه چیز جدیدی هست؟",
    "Nextcloud on all your devices" : "Nextcloud روی همهٔ دستگاه‌های شما",
    "Nextcloud Hub {version}" : "Nextcloud Hub {version}",
    "Share on social media" : "هم‌رسانی در شبکه‌های اجتماعی",
    "Get started!" : "شروع کنید!",
    "Global redesign and usability lift" : "بازطراحی سراسری و ارتقای کاربری",
    "New Office UI: colors, tabs, bars" : "رابط کاربری تازهٔ آفیس: رنگ‌ها، زبانه‌ها و نوارها",
    "Performance and stability boost" : "افزایش کارایی و پایداری",
    "New AI Agency tools unlocked" : "فعال‌سازی ابزارهای تازهٔ عاملیت هوش مصنوعی",
    "Talk threads & live transcription" : "رشته‌های گفتگو و رونویسی زندهٔ Talk",
    "Calendar: date poll for participants" : "تقویم: نظرسنجی تاریخ برای شرکت‌کنندگان",
    "Intuitive file search" : "جستجوی ساده و کاربرپسند پرونده‌ها",
    "Teams 2.0 & quick Guest accounts" : "تیم‌های ۲٫۰ و حساب‌های مهمان سریع",
    "Quick presets & many other admin updates" : "پیش‌تنظیم‌های سریع و بسیاری به‌روزرسانی دیگر برای مدیران",
    "Vue3, WebSockets and more OpenAPI for devs" : "Vue3، WebSockets و OpenAPI بیشتر برای توسعه‌دهندگان",
    "… and much more!" : "… و بسیار بیشتر!",
    "Nextcloud Hub 25 Autumn – Your digital workspace, ready in no time ⚡" : "Nextcloud Hub 25 پاییز – فضای کاری دیجیتال شما، در یک چشم‌به‌هم‌زدن آماده ⚡",
    "Growing sovereignty: new federation features, improved data export and import" : "حاکمیت رو به رشد: ویژگی‌های تازهٔ فدراسیون و صادرات و واردات بهبودیافتهٔ داده‌ها",
    "Nextcloud Talk: live translations, pinned messages, scheduling" : "Nextcloud Talk: ترجمهٔ زنده، پیام‌های سنجاق‌شده، زمان‌بندی",
    "Office document comparison" : "مقایسهٔ سندهای آفیس",
    "Whiteboard: comments, reactions, timers" : "وایت‌برد: دیدگاه‌ها، واکنش‌ها، زمان‌سنج‌ها",
    "Nextcloud Assistant performance upgrade and AI labeling" : "ارتقای کارایی دستیار Nextcloud و برچسب‌گذاری با هوش مصنوعی",
    "Powerful E2EE in the web interface" : "رمزنگاری سرتاسری قدرتمند در رابط وب",
    "Speed-up with ADA engine" : "افزایش سرعت با موتور ADA",
    "Time to own your collaboration: Meet Nextcloud Hub 26 Winter! 🚀" : "وقت آن رسیده که اختیار همکاری‌تان را به دست بگیرید: با Nextcloud Hub 26 Winter آشنا شوید! 🚀"
},
"nplurals=2; plural=(n > 1);");
