OC.L10N.register(
    "files_lock",
    {
    "File is currently locked by %s" : "فایل در حال حاضر توسط %s قفل شده است",
    "File is not locked" : "فایل قفل نیست",
    "File can only be locked with update permissions." : "فایل فقط با مجوز به‌روزرسانی قابل قفل شدن است",
    "File can only be unlocked by providing a valid owner lock token" : "فایل فقط با ارائه یک توکن قفل معتبر مالک قابل باز شدن است",
    "File can only be unlocked by the owner of the lock" : "فایل فقط توسط مالک قفل قابل باز شدن است",
    "Desktop client" : "کلاینت دسکتاپ",
    "iOS client" : "کلاینت iOS",
    "Android client" : "کلاینت Android",
    "Temporary files lock" : "قفل فایل‌های موقت",
    "Temporary lock your files" : "فایل‌های خود را به طور موقت قفل کنید",
    "Allow your users to temporary lock their files to avoid conflicts while working on shared files." : "به کاربران خود اجازه دهید فایل‌های خود را به طور موقت قفل کنند تا از تداخل هنگام کار روی فایل‌های اشتراکی جلوگیری شود",
    "Manually locked by {user}" : "به صورت دستی توسط {user} قفل شده",
    "Locked by editing online in {app}" : "با ویرایش آنلاین در {app} قفل شده",
    "Automatically locked by {user}" : "به طور خودکار توسط {user} قفل شده",
    "Unlock file" : "باز کردن قفل فایل",
    "Lock file" : "قفل کردن فایل",
    "files_lock" : "files_lock",
    "This file has been locked automatically by a client. Removing the lock may lead to a conflict saving the file." : "این فایل به طور خودکار توسط یک کلاینت قفل شده است. برداشتن قفل ممکن است منجر به تداخل در ذخیره‌سازی فایل شود",
    "Keep lock" : "نگه داشتن قفل",
    "Force unlock" : "باز کردن اجباری قفل",
    "Allow your users to temporary lock their files to avoid conflicts while working on shared files.\n\nℹ️ As of Nextcloud 34 this app is bundled with Nextcloud Hub and hence not released through the appstore anymore." : "به کاربران خود اجازه دهید فایل‌های خود را به طور موقت قفل کنند تا از تداخل هنگام کار روی فایل‌های اشتراکی جلوگیری شود"
},
"nplurals=2; plural=(n > 1);");
