OC.L10N.register(
    "oauth2",
    {
    "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path" : "Tavam pārvirzīšanas URL ir jābūt pilnam URL, piemēram https://yourdomain.com/path",
    "OAuth 2.0" : "OAuth 2.0",
    "Allows OAuth2 compatible authentication from other web applications." : "Ļauj OAuth2 saderīgu autentifikāciju citām tīmekļa lietotnēm.",
    "The OAuth2 app allows administrators to configure the built-in authentication workflow to also allow OAuth2 compatible authentication from other web applications." : "OAuth2 lietotne ļauj pārvaldītājiem konfigurēt iebūvēto autentificēšanās darbplūsmu un ļauj ar OAuth2 saderīgu autentificēšanos no citām tīmekļa lietotnēm.",
    "Secret key" : "Slepenā atslēga",
    "Delete" : "Izdzēst",
    "OAuth 2.0 clients" : "OAuth 2.0 klients",
    "Name" : "Nosaukums",
    "Redirection URI" : "Pārvirzāmais URI",
    "Add client" : "Pievienot klientu",
    "Add" : "Pievienot",
    "Client Identifier" : "Klienta identifikators"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
