OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "ئىناۋەتسىز فېدېراتسىيە بۇلۇت كىملىكى",
    "Server to server sharing is not enabled on this server" : "بۇ مۇلازىمېتىردا مۇلازىمېتىردىن ئورتاقلىشىش مۇلازىمىتىرى قوزغىتىلمىغان",
    "Couldn't establish a federated share." : "فېدېراتسىيە ئۈلۈشىنى قۇرالمىدى.",
    "Couldn't establish a federated share, maybe the password was wrong." : "فېدېراتسىيە ھەمبەھىر قۇرالمىدى ، بەلكىم پارول خاتا بولۇشى مۇمكىن.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "فېدېراتسىيە ھەمبەھىر تەلىپى ئەۋەتىلدى ، تەكلىپ تاپشۇرۇۋالىسىز. ئۇقتۇرۇشلىرىڭىزنى تەكشۈرۈڭ.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "فېدېراتسىيە ئۈلۈشىنى قۇرالمىدى ، قارىماققا فېدېراتسىيە بىلەن مۇلازىمېتىر بەك كونا (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "بۇ مۇلازىمېتىردىن فېدېراتسىيە گۇرۇپپا پېيىنى ئەۋەتىشكە بولمايدۇ.",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "%1$s نى ئورتاقلىشىش مەغلۇب بولدى ، چۈنكى بۇ تۈر%2$s ھېساباتى بىلەن ئورتاقلاشتى",
    "Not allowed to create a federated share to the same account" : "ئوخشاش ھېساباتقا فېدېراتسىيە ئورتاقلىشىش قۇرۇشقا بولمايدۇ",
    "Federated shares require read permissions" : "فېدېراتسىيە پاي چېكى ئوقۇش ئىجازىتىنى تەلەپ قىلىدۇ",
    "File is already shared with %s" : "ھۆججەت ئاللىقاچان %s بىلەن ئورتاقلاشتى",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "%1$s نى ئورتاقلىشىش مەغلۇب بولدى ،%2$s نى تاپالمىدى ، بەلكىم مۇلازىمېتىر ھازىرچە ئېرىشكىلى بولمايدۇ ياكى ئۆزى ئىمزا قويغان گۇۋاھنامىنى ئىشلىتىشى مۇمكىن.",
    "Could not find share" : "ئورتاقلىشالمىدى",
    "Federated sharing" : "فېدېراتسىيە ئورتاقلىشىش",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "سىز {user} دىن {share} نى يىراقتىكى ھەمبەھىر سۈپىتىدە تاپشۇرۋالدىڭىز ({behalf} ئۈچۈن)",
    "You received {share} as a remote share from {user}" : "{share} دىن يىراقتىن ئورتاقلىشىش سۈپىتىدە {user} نى تاپشۇرۇۋالدىڭىز",
    "Accept" : "قوبۇل قىلىڭ",
    "Decline" : "رەت قىلىش",
    "Federated Cloud Sharing" : "فېدېراتسىيە بۇلۇتتىن ئورتاقلىشىش",
    "Sharing" : "ھەمبەھىر",
    "Federated file sharing" : "فېدېراتسىيە ھۆججەت ئورتاقلىشىش",
    "Provide federated file sharing across servers" : "مۇلازىمېتىرلاردا فېدېراتسىيە ھۆججەت ئورتاقلىشىشنى تەمىنلەڭ",
    "Confirm data upload to lookup server" : "ئىزدەش سېرۋېرىغا سانلىق مەلۇمات يوللاشنى جەزملەشتۈرۈڭ",
    "When enabled, all account properties (e.g. email address) with scope visibility set to \"published\", will be automatically synced and transmitted to an external system and made available in a public, global address book." : "قوزغىتىلغاندا، دائىرە كۆرۈنۈشچانلىقى «ئېلان قىلىنغان» غا تەڭشەلگەن بارلىق ھېسابات خاسلىقلىرى (مەسىلەن، ئېلخەت ئادرېسى) ئاپتوماتىك ھالدا ماسلاشتۇرۇلۇپ، تاشقى سىستېمىغا يەتكۈزۈلىدۇ ھەمدە ئاممىۋى، دۇنياۋى ئادرېس دەپتىرىدە كۆرسىتىلىدۇ.",
    "Enable data upload" : "چىقىرىشنى قوزغات",
    "Disable upload" : "چىقىرىشنى تاقا",
    "Confirm querying lookup server" : "ئىزدەش مۇلازىمېتىرىغا تەلەپ يوللاشنى جەزىملە",
    "When enabled, the search input when creating shares will be sent to an external system that provides a public and global address book." : "قوزغىتىلغاندا، ئورتاقلىشىشلارنى قۇرغاندا ئىزدەش كىرگۈزۈش سانلىق مەلۇماتلىرى ئاممىۋى ۋە دۇنياۋى ئادرېس دەپتىرى بىلەن تەمىنلەيدىغان سىرتقى سىستېمىغا ئەۋەتىلىدۇ.",
    "This is used to retrieve the federated cloud ID to make federated sharing easier." : "بۇ، فېدېراتسىيەلىك بۇلۇت كىملىكىنى ئېلىش ۋە فېدېراتسىيەلىك ئورتاقلىشىشنى ئاسانلاشتۇرۇش ئۈچۈن ئىشلىتىلىدۇ.",
    "Moreover, email addresses of users might be sent to that system in order to verify them." : "ئۇنىڭ ئۈستىگە، ئىشلەتكۈچىلەرنىڭ ئېلخەت ئادرېسى ئۇلارنى تەكشۈرۈش ئۈچۈن شۇ سىستېمىغا ئەۋەتىلىشى مۇمكىن.",
    "Enable querying" : "بۇيرۇق ئەۋەتىشنى قوزغات",
    "Disable querying" : "بۇيرۇق ئەۋەتىشنى تاقا",
    "Unable to update federated files sharing config" : "فېدېراتسىيە ھۆججەت ئورتاقلىشىش سەپلىمىسىنى يېڭىلاشقا ئامالسىز",
    "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "كىشىلەرنىڭ مۇلازىمېتىر ئارىسىدا قانداق ھەمبەھىرلىنىدىغانلىقىنى تەڭشەڭ. بۇ ئەگەر ئورتاق بەھرىلىنىشنى ئىشلىتىۋاتقان بولسا ، بۇ مۇلازىمېتىردىكى كىشىلەر ئوتتۇرىسىدىكى ئورتاقلىشىشنى ئۆز ئىچىگە ئالىدۇ.",
    "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "بۇ مۇلازىمېتىردىكى كىشىلەرنىڭ باشقا مۇلازىمېتىرلارغا پاي ئەۋەتىشىگە يول قويۇڭ (بۇ تاللاش WebDAV نىڭ ئاممىۋى پاينى زىيارەت قىلىشىغا يول قويىدۇ)",
    "Allow people on this server to receive shares from other servers" : "بۇ مۇلازىمېتىردىكى كىشىلەرنىڭ باشقا مۇلازىمېتىرلاردىن پاي تاپشۇرۇۋېلىشىغا يول قويۇڭ",
    "Allow people on this server to send shares to groups on other servers" : "بۇ مۇلازىمېتىردىكى كىشىلەرنىڭ باشقا مۇلازىمېتىرلاردىكى گۇرۇپپىلارغا ئورتاقلىشىشىغا يول قويۇڭ",
    "Allow people on this server to receive group shares from other servers" : "بۇ مۇلازىمېتىردىكى كىشىلەرنىڭ باشقا مۇلازىمېتىرلاردىن گۇرۇپپا ئۈلۈشىنى قوبۇل قىلىشىغا يول قويۇڭ",
    "The lookup server is only available for global scale." : "ئىزدەش سېرۋېرى پەقەت دۇنياۋى كۆلەمدە ئىشلىتىشكە بولىدۇ.",
    "Search global and public address book for people" : "كىشىلەر ئۈچۈن دۇنياۋى ۋە ئاممىۋى ئادرېس دەپتىرىنى ئىزدەڭ",
    "Allow people to publish their data to a global and public address book" : "كىشىلەرنىڭ سانلىق مەلۇماتلىرىنى دۇنياۋى ۋە ئاممىۋى ئادرېس دەپتىرىگە ئېلان قىلىشىغا يول قويۇڭ",
    "Trusted federation" : "ئىشەنچلىك فېدىراتسىيە",
    "Automatically accept shares from trusted federated accounts and groups by default" : "ئۆزلۈكىدىن ئىشەنچلىك فېدېراتسىيە ھېساباتلىرى ۋە گۇرۇپپىلىرىدىن ئاپتوماتىك ھالدا پاي ئېلىش",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Nextcloud# فېدېراتسىيە بۇلۇت كىملىكىم ئارقىلىق مەن بىلەن ئورتاقلىشىڭ ، {url} see نى كۆرۈڭ",
    "Share with me through my #Nextcloud Federated Cloud ID" : "مېنىڭ Nextcloud# فېدېراتسىيە بۇلۇت كىملىكىم ئارقىلىق مەن بىلەن ئورتاقلىشىڭ",
    "Share with me via Nextcloud" : "Nextcloud ئارقىلىق مەن بىلەن ئورتاقلىشىڭ",
    "Cloud ID copied" : "بۇلۇت ID كۆچۈرۈلدى",
    "Copy" : "كۆچۈرۈڭ",
    "Clipboard not available. Please copy the cloud ID manually." : "چاپلاش تاختىسى يوق. بۇلۇت كىملىكىنى قولدا كۆچۈرۈڭ.",
    "Copied!" : "كۆچۈرۈلگەن!",
    "Federated Cloud" : "فېدېراتسىيە بۇلۇت",
    "You can share with anyone who uses a {productName} server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "{productName} سېرۋېرى ياكى باشقا Open Cloud Mesh (OCM) بىلەن ماس كېلىدىغان سېرۋېر ۋە مۇلازىمەتلەرنى ئىشلىتىدىغان ھەر قانداق ئادەم بىلەن ئورتاقلىشالايسىز! ئۇلارنىڭ فېدېراتسىيەلىك بۇلۇت نومۇرىنى ئورتاقلىشىش سۆزلەشكۈسىگە كىرگۈزۈڭ. ئۇ person@cloud.example.com غا ئوخشايدۇ.",
    "Your Federated Cloud ID" : "فېدېراتسىيە بۇلۇت كىملىكىڭىز",
    "Share it so your friends can share files with you:" : "ھەمبەھىرلەڭ ، دوستلىرىڭىز ھۆججەتلەرنى سىز بىلەن ئورتاقلىشالايدۇ:",
    "Bluesky" : "Bluesky",
    "Facebook" : "Facebook",
    "Mastodon" : "Mastodon",
    "Add to your website" : "تور بېتىڭىزگە قوشۇڭ",
    "Share with me via {productName}" : "مەن بىلەن {productName} ئارقىلىق ھەمبەھىرلە",
    "HTML Code:" : "HTML كودى:",
    "Cancel" : "ۋاز كەچ",
    "Add remote share" : "يىراقتىن ئورتاقلىشىش",
    "Remote share" : "يىراقتىن ئورتاقلىشىش",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "{remote} @ {owner} دىن يىراقتىن ئورتاقلىشىش {name} add نى قوشماقچىمۇ؟",
    "Remote share password" : "يىراقتىن ئورتاقلىشىش پارولى",
    "Incoming share could not be processed" : "كەلگەن ئۈلۈشنى بىر تەرەپ قىلغىلى بولمايدۇ",
    "X (formerly Twitter)" : "X (ئىلگىرىكى Twitter)",
    "formerly Twitter" : "ئىلگىرى Twitter"
},
"nplurals=2; plural=(n != 1);");
