OC.L10N.register(
    "circles",
    {
    "You created the team {circle}" : "您建立了團隊 {circle}",
    "{author} created the team {circle}" : "{author} 建立了團隊 {circle}",
    "You deleted {circle}" : "您刪除了 {circle}",
    "{author} deleted {circle}" : "{author} 刪除了 {circle}",
    "You made {member} join {circle}" : "您讓 {member} 加入了 {circle}",
    "{author} made {member} join {circle}" : "{author} 讓 {member} 加入了 {circle}",
    "You added team {member} as member to {circle}" : "您已將團隊 {member} 新增為 {circle} 的成員",
    "{author} added team {member} as member to {circle}" : "{author} 已將團隊 {member} 新增為 {circle} 的成員",
    "You made {member} leave {circle}" : "您讓 {member} 離開了 {circle}",
    "{author} made {member} leave {circle}" : "{author} 讓 {member} 離開了 {circle}",
    "You removed {member} from {circle}" : "您從 {circle} 移除了 {member}",
    "{author} removed {member} from {circle}" : "{author} 從 {circle} 移除了 {member}",
    "You joined {circle}" : "您已加入了 {circle}",
    "{member} joined {circle}" : "{member} 已加入 {circle}",
    "You accepted the invitation to join {circle}" : "您接受了加入 {circle} 的邀請",
    "{member} accepted the invitation to join {circle}" : "{member} 接受了加入 {circle} 的邀請",
    "You added {member} as member to {circle}" : "您已將 {member} 新增為 {circle} 的成員",
    "You have been added as member to {circle} by {author}" : "{author} 已將您新增為 {circle} 的成員",
    "{member} has been added as member to {circle} by {author}" : "{author} 已將 {member} 新增為 {circle} 的成員",
    "You added {external} to {circle}" : "您已將 {external} 新增到 {circle}",
    "{external} has been added to {circle} by {author}" : "{author} 已將 {external} 新增到 {circle}",
    "You accepted {member}'s request to join {circle}" : "您接受了 {member} 加入了 {circle} 的請求",
    "Your request to join {circle} has been accepted by {author}" : "{author} 接受了您加入了 {circle} 的請求",
    "{member}'s request to join {circle} has been accepted by {author}" : "{author} 接受了 {member} 加入了 {circle} 的請求",
    "You left {circle}" : "您離開了 {circle}",
    "{member} left {circle}" : "{member} 離開了 {circle}",
    "You declined the invitation to join {circle}" : "您拒絕了加入 {circle} 的邀請",
    "{member} declined an invitation to join {circle}" : "{member} 拒絕了加入 {circle} 的邀請",
    "You cancelled your request to join {circle}" : "您取消了您加入 {circle} 的請求",
    "{member} cancelled a request to join {circle}" : "{member} 取消了加入 {circle} 的請求",
    "You have been removed from {circle} by {author}" : "{author} 已將您從 {circle} 移除",
    "{member} has been removed from {circle} by {author}" : "{author} 已將 {member} 從 {circle} 移除",
    "You removed {external} from {circle}" : "您從 {circle} 移除了 {external}",
    "{external} has been removed from {circle} by {author}" : "{author} 從 {circle} 移除了 {external}",
    "You cancelled {member}'s invitation to join {circle}" : "您取消了 {member} 加入 {circle} 的邀請",
    "Your invitation to join {circle} has been cancelled by {author}" : "{author} 取消了您加入 {circle} 的邀請",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} 取消了 {member} 加入 {circle} 的邀請",
    "You dismissed {member}'s request to join {circle}" : "您拒絕了 {member} 加入了 {circle} 的請求",
    "Your request to join {circle} has been dismissed by {author}" : "{author} 拒絕了您加入了 {circle} 的請求",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{author} 拒絕了 {member} 加入了 {circle} 的請求",
    "You invited {member} to join {circle}" : "您邀請了 {member} 加入 {circle}",
    "You have been invited to join {circle} by {author}" : "{author} 已邀請您加入 {circle}",
    "{member} has been invited to join {circle} by {author}" : "{author} 已邀請 {member} 加入 {circle}",
    "You changed {member}'s level in {circle} to %1$s" : "您變更了 {member} 在 {circle} 中的等級到 %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} 變更了 {member} 在 {circle} 中的等級到 %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} 變更了 {member} 在 {circle} 中的等級到 %1$s",
    "You sent a request to join {circle}" : "您傳送了加入 {circle} 的請求",
    "{member} sent a request to join {circle}" : "{member} 傳送了加入 {circle} 的請求",
    "You are the new owner of {circle}" : "您是 {circle} 的新擁有者",
    "{member} is the new owner of {circle}" : "{member} 是 {circle} 的新擁有者",
    "Teams" : "團隊",
    "On events happening in a <strong>team</strong> of which you are a member" : "你所屬的<strong>團隊</strong>中發生的事件",
    "Any important event in a <strong>team</strong> you are moderating" : "您主持的<strong>團隊</strong>中任何重要事件",
    "On global events happening in any <strong>team</strong>" : "在任何<strong>團隊</strong>中發生的全域事件",
    "Single" : "單一",
    "Personal" : "個人",
    "System" : "系統",
    "Visible" : "可見",
    "Open" : "開放",
    "Invite" : "邀請",
    "Join request" : "加入請求",
    "Friends" : "朋友",
    "Password protected" : "受密碼保護",
    "No Owner" : "無擁有者",
    "Hidden" : "隱藏",
    "Backend" : "後端",
    "Local" : "本地",
    "Root" : "根",
    "Team invite" : "團隊邀請",
    "Federated" : "已聯盟",
    "Mount point" : "掛載點",
    "App" : "應用程式",
    "SCIM" : "SCIM",
    "Nextcloud Account" : "Nextcloud 帳號",
    "Nextcloud Group" : "Nextcloud 群組",
    "Email address" : "電子郵件地址",
    "Contact" : "聯絡人",
    "Team" : "團隊",
    "Nextcloud App" : "Nextcloud 應用程式",
    "Teams App" : "團隊應用程式",
    "Admin Command Line" : "管理員命令列",
    "Member" : "成員",
    "Moderator" : "主持人",
    "Admin" : "管理員",
    "Owner" : "擁有者",
    "%s shared »%s« with you." : "%s 與您分享了 %s。",
    "%s shared »%s« with \"%s\"." : "%s 分享了 %s 與「%s」。",
    "%s on %s" : "%s 在 %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s 與您分享了 %2$s。\n您應該已經收到一封包含了可以存取它的連結的單獨電子郵件。\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s 與您分享了 %2$s。您應該已經收到一封包含了可以存取它的連結的單獨電子郵件。",
    "Password to access »%1$s« shared to you by %2$s" : "存取 %2$s 分享給您 %1$s 的密碼",
    "Password to access »%s«" : "存取 %s 的密碼",
    "It is protected with the following password:" : "其受以下密碼保護：",
    "%1$s via %2$s" : "%1$s 由 %2$s",
    "Click the button below to open it." : "點擊下方按鈕以開啟。",
    "Open »%s«" : "開啟 »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s 與您分享了多個檔案。\n您應該已經收到一封包含了可以存取它們的連結的單獨電子郵件。\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s 與您分享了多個檔案。您應該已經收到一封包含了可以存取它們的連結的單獨電子郵件。",
    "Password to access files shared to you by %1$s" : "%1$s 與您分享的檔案密碼",
    "Password to access files" : "存取檔案的密碼",
    "%s shared multiple files with \"%s\"." : "%s 與「%s」分享了多個檔案。",
    "%s shared multiple files with you." : "%s 與您分享了多個檔案。",
    "Boot up" : "啟動",
    "Nextcloud Initialization" : "Nextcloud 初始化",
    "Teams App Initialization" : "團隊應用程式初始化",
    "Fresh installation status" : "全新安裝狀態",
    "Building Local Database" : "正在建構本地資料庫",
    "Testing Basic Team Creation" : "測試基本團隊建立",
    "Adding local users and moderators" : "正在新增本地使用者與主持人",
    "Show all teams" : "顯示所有團隊",
    "Create a new team" : "建立新團隊",
    "Files" : "檔案",
    "This feature is not available for personal teams" : "此功能不適用於個人團隊",
    "The team is not federated" : "團隊未加入聯盟",
    "You cannot join this team" : "您無法加入此團隊",
    "This member is not a moderator" : "該成員並非主持人",
    "Insufficient privileges" : "權限不足",
    "This member does not exist" : "此成員不存在",
    "This member is the owner of the team" : "此成員是團隊的擁有者",
    "Level cannot be changed for this type of member" : "此類型的成員的等級無法變更",
    "You are already a member of this team" : "您已經是此團隊的成員了",
    "You have been blocked from this team" : "您已被此團隊封鎖",
    "The account is already a member of this team" : "帳號已經是此團隊的成員了",
    "The account has already been invited into this team" : "帳號已被邀請至此團隊",
    "%s (Team owned by %s)" : "%s（由 %s 擁有的團隊）",
    "You are now a member of the Team \"%2$s\"" : "您現在是團隊「%2$s」的成員",
    "You have been invited by %1$s into the Team \"%2$s\"" : "您已被 %1$s 邀請至團隊「%2$s」",
    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$s 傳送了成為團隊「%2$s」成員的請求",
    "Accept" : "接受",
    "Refuse" : "拒絕",
    "Leave the team" : "離開團隊",
    "No image file provided" : "未提供圖片檔案",
    "Invalid file provided" : "提供的檔案無效",
    "File is too big" : "檔案太大",
    "Invalid image" : "無效的圖片",
    "Unknown filetype" : "未知的檔案類型",
    "%s" : "%s",
    "Personal team" : "個人團隊",
    "%s owned by %s" : "%s 被 %s 擁有",
    "You have no permission to create a new team" : "您無權建立新的團隊",
    "Insufficient permissions to perform this action" : "權限不足，無法執行此動作",
    "%s shared a file with \"%s\"." : "%s 與「%s」分享了一個檔案。",
    "%s shared a file with you." : "%s 與您分享了一個檔案。",
    "%1$s shared %2$s with %3$s" : "%1$s 與 %3$s 分享了 %2$s",
    "%1$s shared %2$s with \"%3$s\"" : "%1$s 與「%3$s」分享了 %2$s",
    "Open %s" : "開啟 %s",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s 與您分享了一些內容。\n您應該會收到一封包含存取連結的電子郵件。\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s 與您分享了一些內容。您應該會收到一封包含存取連結的電子郵件。",
    "Password to access content shared with you by %1$s" : "使用密碼存取由 %1$s 與您分享的內容",
    "Password to access content" : "用來存取內容的密碼",
    "Federated Teams" : "聯盟式團隊",
    "Team spaces" : "團隊空間",
    "This item is already shared with this team" : "此項目已與此團隊分享",
    "Bring cloud-users closer together." : "讓雲端使用者緊密連結。",
    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "團隊讓您的夥伴可以建立他們自己的夥伴／同事／朋友群組。\n然後，其他任何的應用程式都可以將那些夥伴群組用於分享目的。",
    "Unable to update federated teams config" : "無法更新聯盟式團隊設定",
    "Invalid URL format. Please provide a valid URL." : "無效 URL 格式。請提供有效的 URL。",
    "Changed frontal cloud URL" : "已變更前端雲端儲存空間 URL",
    "Federation allows you to share teams with other trusted servers and make them discoverable across instances." : "聯盟式功能讓您可以與其他信任的伺服器分享團隊，並讓團隊可跨站台探索。",
    "Enable federated teams" : "啟用聯盟式團隊",
    "Frontal URL" : "前端 URL",
    "https://…" : "https://…",
    "The public URL used by other instances to discover and connect to your teams." : "其他站台用於探索並連線到您團隊的公開網址。",
    "Unlimited" : "無限制",
    "Unable to update team space config" : "無法更新團隊空間設定",
    "Changed default team space quota" : "已變更預設團隊空間配額",
    "Quota must be a non-negative number." : "配額必須為非負數字。",
    "Automatically create a shared team space when a new team is created. Requires the Team Folders app to be installed and enabled." : "建立新團隊時，自動建立共享的團隊空間。此功能需先安裝並啟用「團隊資料夾」應用程式。",
    "Automatically create a team space" : "自動建立團隊空間",
    "Default quota" : "預設儲存容量限制",
    "Select default quota" : "選取預設容量限制",
    "Save" : "儲存",
    "Default storage quota applied to each auto-created team space. Use 0 for unlimited storage." : "適用於每個自動建立的團隊空間的預設儲存配額。若要啟用無限儲存空間，請設定為 0。",
    "Connect to OIDC provider" : "連結至 OIDC 提供者",
    "Connect your account to an external OIDC provider to automatically sync your memberships with Nextcloud teams." : "將您的帳號連結至外部 OIDC 提供者，即可自動將您的會員資格與 Nextcloud 團隊同步。",
    "Your account is connected." : "您的帳號已連結。",
    "Reconnect" : "重新連接",
    "Connect" : "連線",
    "New team" : "新團隊",
    "Search teams" : "搜尋團隊",
    "Overview" : "概覽",
    "No teams found" : "找不到團隊",
    "Try a different search." : "試試其他搜尋。",
    "Create a team to get started." : "建立團隊以開始使用。",
    "Members" : "成員",
    "_%n resource_::_%n resources_" : ["%n 個資源"],
    "Please enter a team name" : "請輸入團隊名稱",
    "Some members could not be added to the team" : "部份成員無法新增至團隊",
    "Team created, but the initial members could not be added" : "已建立團隊，但無法新增初始成員",
    "Team \"{name}\" created" : "已建立「{name}」團隊",
    "Could not create the team" : "無法建立團隊",
    "Cancel" : "取消",
    "Next" : "下一步",
    "Back" : "返回",
    "Create team" : "建立團隊",
    "Step {current} of {total}" : "第 {current} 步，共 {total} 步",
    "Name your team" : "為您的團隊命名",
    "Team name" : "團隊名稱",
    "e.g. Design" : "例如：設計",
    "Add initial members" : "新增初始成員",
    "Search people, groups, teams…" : "搜尋夥伴、群組、團隊⋯⋯",
    "Optional, you can also add members later" : "選擇性，您也可以稍後再新增成員",
    "Search for people to add" : "搜尋要新增的人",
    "You can always add or remove members later from the team page." : "您隨時都可以透過團隊頁面新增或移除成員。",
    "Could not load folder contents" : "無法載入資料夾內容",
    "Team space breadcrumbs" : "團隊空間頁面路徑",
    "Switch to list view" : "切換至列表檢視",
    "Switch to grid view" : "切換到格狀檢視",
    "Open folder in Files" : "在 Files 中開啟資料夾",
    "Folder contents unavailable" : "無法存取資料夾內容",
    "Empty folder" : "空資料夾",
    "This team space is empty." : "此團隊空間為空",
    "Folder contents" : "資料夾內容",
    "Preview of {name}" : "{name} 的預覽",
    "Folder" : "資料夾",
    "Team owner" : "團隊擁有者",
    "you" : "您",
    "Team actions" : "團隊動作",
    "Manage team" : "管理團隊",
    "Copy link" : "複製連結",
    "Leave team" : "離開團隊",
    "Delete team" : "刪除團隊",
    "An error happened during the config change" : "設定變更時發生錯誤",
    "Confirm enabling federation" : "確認啟用聯盟功能",
    "Enabling this will prevent {circle} from being a member of other teams.\nAre you sure?" : "啟用後，{circle} 將無法加入其他團隊。\n您確定嗎？",
    "Enable federation" : "啟用聯盟",
    "Copied" : "已複製",
    "Could not copy" : "無法複製",
    "Create link" : "建立連結",
    "This action will make it impossible to join the team using the current link. Do we really want to change the link?" : "此動作將導致無法透過目前的連結加入團隊。我們真的要變更這個連結嗎？",
    "Reset link" : "重設連結",
    "This action will make it impossible to join the team using the current link. Do we really want to delete the link?" : "此動作將導致無法透過目前的連結加入團隊。我們真的要刪除這個連結嗎？",
    "Reject link" : "拒絕連結",
    "Enforce password protection on files shared to this team" : "對分享到此團隊的檔案加上密碼保護",
    "Use a unique password for all shares to this team" : "對此團隊的所有分享使用獨一無二的密碼",
    "Unique password …" : "獨一無二的密碼⋯⋯",
    "Change unique password" : "變更獨一無二的密碼",
    "Failed to save password. Please try again later." : "儲存密碼失敗。請稍後再試。",
    "Close" : "關閉",
    "Choose a team picture" : "選擇團隊圖片",
    "There is no description for this team" : "此團隊沒有描述",
    "Enter a description for the team" : "輸入團隊的描述",
    "Team space" : "團隊空間",
    "Create a shared team space for this team." : "為此團隊建立共享團隊空間。",
    "New folder" : "新增資料夾",
    "Folder name" : "資料夾名稱",
    "This will create a regular folder shared with the team." : "這將建立一個與團隊共享的普通資料夾。",
    "Talk conversation" : "Talk 對話",
    "New Talk conversation" : "新 Talk 對話",
    "Conversation name" : "對話名稱",
    "Collective" : "知識庫",
    "Calendar" : "行事曆",
    "New calendar" : "新日曆",
    "Calendar name" : "日曆名稱",
    "Could not load team space" : "無法載入團隊空間",
    "Could not create the team space" : "無法建立團隊空間",
    "Unknown resource type" : "未知的資源類型",
    "Team calendar \"{resourceName}\" created and shared with team" : "已建立團隊日曆「{resourceName}」並分享給團隊",
    "{resourceType} \"{resourceName}\" created and shared with team" : "已建立 {resourceType}「{resourceName}」並分享給團隊",
    "A calendar named \"{name}\" already exists. Please choose a different name." : "名為「{name}」的日曆已存在。請選擇其他名稱。",
    "Failed to create {resourceType}: {error}" : "建立 {resourceType} 失敗：{error}",
    "Please select a valid png or jpg file" : "請選取有效的 png 或 jpg 檔案",
    "Error picking team picture" : "挑選團隊圖片時發生錯誤",
    "Error cropping avatar picture" : "裁剪大頭照圖片時發生錯誤",
    "An error happened while saving {fields}" : "儲存 {fields} 時發生錯誤",
    "Description" : "描述",
    "Upload team picture" : "上傳團隊圖片",
    "Choose from Nextcloud Files" : "從 Nextcloud Files 選擇",
    "Delete picture" : "刪除圖片",
    "Edit" : "編輯",
    "Request to join" : "要求加入",
    "Create" : "建立",
    "Show in Calendar" : "在日曆中顯示",
    "Your request to join this team is pending approval" : "您加入此團隊的請求正在等待批准",
    "You are not a member of {circle}" : "您不是 {circle} 的成員",
    "Add" : "加",
    "Edit team picture" : "編輯團隊圖片",
    "Apply" : "套用",
    "Remove {type}" : "移除 {type}",
    "Add to group" : "新增至團隊",
    "Add members to group" : "新增成員至群組",
    "Search {types}" : "搜尋 {types}",
    "Add guest" : "新增訪客",
    "Loading …" : "正在載入……",
    "No results" : "沒有符合的結果",
    "Add {type}" : "新增{type}",
    "Promote as sole owner" : "將其權限升級為唯一擁有者",
    "Promote to {level}" : "將其權限升級為 {level}",
    "Demote to {level}" : "將其權限降級為 {level}",
    "Are you sure you want to leave this team? This action cannot be undone." : "您確定您想要離開此團隊嗎？此動作無法還原。",
    "Leave team failed." : "離開團隊失敗。",
    "Could not delete the member {displayName}" : "無法刪除成員 {displayName}",
    "Could not change the member level to {level}" : "無法變更成員等級至 {level}",
    "Could not accept membership request" : "無法接受成員請求",
    "Accept membership request" : "接受成員資格請求",
    "Reject membership request" : "拒絕成員資格請求",
    "Manage level" : "管理等級",
    "Remove member" : "移除成員",
    "Pending" : "待處理",
    "Unable to get the results" : "無法取得結果",
    "Some members could not be added" : "無法新增部份成員",
    "There was an issue adding members to the team" : "將成員新增至團隊時發生錯誤",
    "There was an error fetching the member list" : "擷取成員清單時發生錯誤",
    "The list of members is only visible to members of this team" : "成員清單僅有此團隊的成員可見",
    "Search among current members" : "在目前成員中搜尋",
    "Role" : "角色",
    "Filter by role" : "按角色篩選",
    "Loading members list …" : "正在載入成員清單……",
    "No members found matching your search" : "沒有成員符合您的搜尋",
    "You currently have no access to the member list" : "您目前無權存取成員清單",
    "Add to {team}" : "新增至 {team}",
    "Invite members to {team}" : "邀請成員至 {team}",
    "Your teams and everything shared with them across Nextcloud." : "您的團隊以及透過 Nextcloud 與他們分享的所有內容。",
    "Could not load teams" : "無法載入團隊",
    "Something went wrong while loading your teams." : "載入您的團隊時發生錯誤",
    "Try again" : "再試試",
    "No teams yet" : "尚無團隊",
    "Create your first team to start collaborating." : "建立您的第一個團隊以開始協作。",
    "Create your first team" : "建立您的第一個團隊",
    "Your teams" : "您的團隊",
    "You have joined the team {circleName}." : "您已加入團隊 {circleName}。",
    "Loading" : "正在載入",
    "Invitation to the team" : "團隊邀請",
    "You are already a member of the team <b>{circleName}</b>." : "您已是 <b>{circleName}</b> 團隊的成員。",
    "Go to team page" : "前往團隊頁面",
    "You already requested to join the team <b>{circleName}</b>." : "您已要求加入團隊 <b>{circleName}</b>。",
    "Go back" : "返回",
    "Do you want to join the team <b>{circleName}</b>?" : "您真的想要加入團隊 <b>{circleName}</b> 嗎？",
    "Join" : "加入",
    "Invalid invitation link" : "無效的邀請連結",
    "This invitation link is not valid or has expired." : "此邀請連結無效或已過期。",
    "Team space unavailable" : "團隊空間無法使用",
    "Could not load the team space. Please try again later." : "無法載入團隊空間。請稍後再試。",
    "Could not load the team" : "無法載入團隊",
    "Team not found" : "找不到團隊",
    "This team may have been removed." : "此團隊可能已移除",
    "Failed to load teams" : "載入團隊失敗",
    "Join or create teams to see them here." : "加入或建立團隊即可在此檢視。",
    "Loading…" : "正在載入……",
    "More teams" : "更多團隊",
    "Link copied to the clipboard" : "連結已複製到剪貼簿",
    "Could not copy link to the clipboard" : "無法複製連結到剪貼簿",
    "Are you sure you want to leave {team}?" : "您確定您想要離開 {team} 嗎？",
    "You left \"{name}\"" : "您離開了「{name}」",
    "Could not leave the team" : "無法離開團隊",
    "Are you sure you want to delete {team}? This cannot be undone." : "您確定您想要刪除 {team} 嗎？此動作無法還原。",
    "Team deleted" : "已刪除團隊",
    "Could not delete the team" : "無法刪除團隊",
    "Join team" : "加入團隊",
    "You are about to leave {circle}.\nAre you sure?" : "您將要離開 {circle}。\n您確定嗎？",
    "Please confirm team leave" : "請確認您要離開團隊",
    "Could not leave the team {displayName}" : "無法離開團隊 {displayName}",
    "Unable to join the team" : "無法加入團隊",
    "You are about to delete {circle}.\nAre you sure?" : "您將要刪除 {circle}。\n您確定嗎？",
    "Please confirm team deletion" : "請確認您要刪除團隊",
    "Unable to delete the team" : "無法刪除這個團隊",
    "Could not copy link to the clipboard." : "無法複製連結至剪貼簿。",
    "All contacts" : "所有聯絡人",
    "Not grouped" : "未歸類",
    "Recently contacted" : "最近聯絡",
    "Organization chart" : "組織圖表",
    "Contacts settings" : "聯絡人設定",
    "Create your own teams for sharing. Add Nextcloud users, contacts, or anyone via email." : "建立您用來分享的團隊。新增 Nextcloud 使用者、聯絡人或透過電子郵件新增任何人。",
    "User" : "使用者",
    "Group" : "群組",
    "Email" : "電子郵件",
    "Invites" : "邀請",
    "Anyone can request membership" : "任何人都可以請求成員資格",
    "Members need to accept invitation" : "成員必須接受邀請",
    "Memberships must be confirmed/accepted by a Moderator (requires \"Anyone can request membership\")" : "成員資格必須由主持人確認／接受（必須為「任何人都可以請求成員資格」）",
    "Members can also invite" : "成員也可以邀請",
    "Invitation links" : "邀請連結",
    "Membership" : "成員",
    "Prevent teams from being a member of another team" : "避免團隊成為其他團隊的成員",
    "Federation" : "聯邦",
    "Allow federated members" : "允許聯盟式成員",
    "Privacy" : "隱私",
    "Visible to everyone" : "對所有人可見",
    "users" : "使用者",
    "Users" : "使用者",
    "groups" : "群組",
    "Groups" : "群組",
    "federated users" : "聯盟使用者",
    "Federated users" : "聯盟使用者",
    "teams" : "團隊",
    "email addresses" : "電子郵件地址",
    "Email addresses" : "電子郵件地址",
    "contacts" : "聯絡人",
    "Contacts" : "聯絡人",
    "An error has occurred in team(s). Check the console for more details." : "團隊中出現錯誤。請檢查主控台以取得更多詳細資訊。",
    "Unable to create team {circleName}" : "無法建立團隊 {circleName}",
    "Unable to delete team {circleId}" : "無法刪除團隊 {circleId}",
    "No files in here" : "沒有檔案在這裡。",
    "No entries found in this folder" : "在此資料夾中沒有任何項目",
    "Name" : "名稱",
    "Size" : "大小",
    "Modified" : "已修改",
    "Circles App Initialization" : "初始化小圈圈應用程式"
},
"nplurals=1; plural=0;");
