OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "Asistente de Ejecución Inicial",
    "Add your profile information! For example your email is needed to receive notifications." : "Agrega tu información de perfil. Por ejemplo, se necesita tu correo electrónico para recibir notificaciones.",
    "Add your profile information! For example your email is needed to receive notifications and reset your password." : "Agrega tu información de perfil. Por ejemplo, se necesita tu correo electrónico para recibir notificaciones y restablecer tu contraseña.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "¡Agregua tu información de perfil! Establece una imagen de perfil y nombre completo para reconocerte más fácilmente entre todas las funcionalidades. ",
    "Add your profile information! Set a full name for easier recognition across all features." : "Agregua tu información de perfil! Establece tu nombre completo para reconocerte más fácilmente entre todas las funcionalidades. ",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Agrega tu información de perfil! Establece una imagen de perfil para reconocerte más fácilmente entre todas las funcionalidades. ",
    "Schedule work & meetings, synced with all your devices." : "Programar trabajo y reuniones, sincronizado con todos tus dispositivos.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Mantén a tus colegas y amigos en un solo lugar sin filtrar su información privada.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Aplicación de correo electrónico simple integrada con Archivos, Contactos y Calendario.",
    "App recommendation: Tasks" : "Recomendación de aplicación: Tareas",
    "Sync tasks from various devices with your Nextcloud and edit them online." : "Sincroniza tareas desde varios dispositivos con tu Nextcloud y edítalas en línea.",
    "App recommendation: Deck" : "Recomendación de aplicación: Deck",
    "Kanban style organization for personal planning and team projects." : "Organización estilo Kanban para planificación personal y proyectos de equipo.",
    "App recommendation: Forms" : "Recomendación de aplicación: Formularios",
    "Simple surveys and questionnaires, self-hosted" : "Encuestas y cuestionarios simples, alojados en tu propio servidor",
    "App recommendation: Recognize" : "Recomendación de aplicación: Recognize",
    "Smart media tagging for Nextcloud" : "Etiquetado inteligente de medios para Nextcloud",
    "App recommendation: Group folders" : "Recomendación de aplicación: Grupos de carpetas",
    "Admin-configured folders shared by everyone in a group." : "Carpetas configuradas por el administrador y compartidas por todos en un grupo.",
    "Connect your calendar" : "Conecta tu calendario",
    "Connect your contacts" : "Conecta tus contactos",
    "Access files via WebDAV" : "Accede tus archivos vía WebDAV",
    "Download macOS/iOS configuration profile" : "Descarga el perfil de configuración de macOS/iOS",
    "Desktop client" : "Cliente de escritorio",
    "Android app on Google Play Store" : "Aplicación para Android en Google Play Store",
    "Android app on F-Droid" : "Aplicación para Android en F-Droid",
    "iOS app" : "Aplicación iOS",
    "A welcome and introduction wizard for Nextcloud" : "Una bienvenida y guía de introducción para Nextcloud",
    "This application enables a pop-up window when a user first logs into Nextcloud. This window welcomes new users to Nextcloud, and contains links to the standard desktop client, Android app, and the iOS app. The window also shows a link for accessing Nextcloud via WebDAV. At any time, the first run wizard can be opened again via link \"About\" on settings menu.\nThe First run wizard can be customized to meet specific design goals, or to change links and messages. Create an appropriate theme following the Theming documentation, and changes to the look and feel of this Wizard are simple. More information is available in the first run wizard documentation, as well as the theming documentation." : "Esta aplicación muestra una ventana emergente cuando un usuario inicia sesión por primera vez en Nextcloud. Esta ventana da la bienvenida a los nuevos usuarios de Nextcloud y contiene enlaces al cliente de escritorio estándar, la aplicación de Android y la aplicación de iOS. La ventana también muestra un enlace para acceder a Nextcloud a través de WebDAV. En cualquier momento, se puede abrir nuevamente la guía de primera ejecución haciendo clic en el enlace \"Acerca de\" en el menú de configuración.\n      La guía de primera ejecución se puede personalizar para cumplir con objetivos de diseño específicos o cambiar enlaces y mensajes. Crea un tema adecuado siguiendo la documentación de Temas, y los cambios en la apariencia de esta guía son sencillos. Obtén más información en la documentación de la guía de primera ejecución y en la documentación de temas.",
    "Close" : "Cerrar",
    "Welcome to {cloudName}!" : "¡Bienvenido a {cloudName}!",
    "Community" : "Comunidad",
    "Share via email" : "Compartir por correo electrónico",
    "Get the apps to sync your files" : "Obten las aplicaciones para sincronizar tus archivos",
    "Server address" : "Dirección del servidor",
    "Use this link to connect your apps and desktop client to this server:" : "Utiliza este enlace para conectar tus aplicaciones y el cliente de escritorio a este servidor:",
    "What's new?" : "¿Qué hay de nuevo?",
    "Share on social media" : "Compartir en redes sociales"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
