OC.L10N.register(
    "files_external",
    {
    "You are not logged in" : "Você não está logado",
    "Permission denied" : "Permissão negada",
    "Storage with ID \"%d\" not found" : "Armazenamento com ID \"%d\" não encontrado",
    "Forbidden to manage local mounts" : "Proibido gerenciar montagens locais",
    "Invalid backend or authentication mechanism class" : "Parâmetros do mecanismo de autenticação inválidos",
    "Invalid mount point" : "Ponto de montagem inválido",
    "Objectstore forbidden" : "Objectstore proibido",
    "Invalid storage backend \"%s\"" : "Backend de armazenamento inválido \"%s\"",
    "Not permitted to use backend \"%s\"" : "Não é permitido utilizar a interface \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "Não é permitido utilizar o mecanismo de autenticação \"%s\"",
    "Unsatisfied backend parameters" : "Parâmetros backend insatisfeitos",
    "Unsatisfied authentication mechanism parameters" : "Parâmetros do mecanismo de autenticação inválidos",
    "Insufficient data: %s" : "Dados insuficientes: %s",
    "Access key ID" : "ID da chave de acesso",
    "Secret access key" : "Chave de acesso segreda",
    "Builtin" : "Integrado",
    "None" : "Nenhum",
    "OpenStack v2" : "OpenStack v2",
    "Login" : "Iniciar sessão",
    "Password" : "Palavra-passe",
    "Tenant name" : "Nome do locatário",
    "Identity endpoint URL" : "Identidade URL endpoint",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "Domínio",
    "Rackspace" : "Rackspace",
    "API key" : "Chave API",
    "Global credentials" : "Credenciais globais",
    "Log-in credentials, save in database" : "Credenciais de Log-in, guardar na base de dados",
    "Log-in credentials, save in session" : "Credenciais de início de sessão, guardar na sessão",
    "Global credentials, manually entered" : "Credenciais globais, inseridas manualmente",
    "Manually entered, store in database" : "Inseridos manualmente, armazenados no banco de dados",
    "RSA public key" : "Chave pública RSA",
    "Public key" : "Chave pública",
    "Private key" : "Chave privada",
    "Kerberos default realm, defaults to \"WORKGROUP\"" : "Reino padrão do Kerberos, o padrão é \"WORKGROUP\"",
    "Kerberos ticket Apache mode" : "Modo Apache de ticket Kerberos",
    "Kerberos ticket" : "Ticket Kerberos",
    "Bucket" : "Bucket",
    "Hostname" : "Nome do Anfitrião",
    "Port" : "Porta",
    "Proxy" : "Proxy",
    "Region" : "Região",
    "Use HTTPS" : "Usar HTTPS",
    "Use Path Style (https://example.com/bucket)" : "Usar estilo de caminho (https://example.com/bucket)",
    "Use Legacy S3 signing (v2)" : "Usar assinatura S3 legada (v2)",
    "Enable multipart copy" : "Habilitar cópia multiparte",
    "Enable Direct Downloads (presigned URLs)" : "Ativar downloads diretos (URLs pré-assinados)",
    "SSE-C encryption key" : "Chave de criptografia SSE-C",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Subpasta remota ",
    "Secure https://" : "https:// Seguro",
    "Host" : "Anfitrião",
    "Secure ftps://" : "ftps:// Seguro",
    "Location" : "Localização:",
    "Nextcloud (WebDAV)" : "Nextcloud (WebDAV)",
    "Root" : "Root",
    "SFTP with public key authentication" : "SFTP com autenticação por chave pública",
    "SMB/CIFS (Windows network share)" : "SMB/CIFS (Compartilhamento de rede do Windows)",
    "Share" : "Partilhar",
    "Show hidden files" : "Mostrar ficheiros ocultos",
    "Case sensitive file system" : "Sistema de arquivos diferenciando maiúsculas/minúsculas",
    "Disabling it will allow to use a case insensitive file system, but comes with a performance penalty" : "Desativar está opção permitirá usar um sistema de arquivos que não diferencia maiúsculas de minúsculas, mas acarretará uma penalidade de desempenho",
    "Verify ACL access when listing files" : "Verifique o acesso da ACL ao listar arquivos",
    "Check the ACL's of each file or folder inside a directory to filter out items where the account has no read permissions, comes with a performance penalty" : "Verificar as ACLs de cada arquivo ou pasta dentro de um diretório para filtrar itens onde a conta não tem permissões de leitura, tem uma penalidade de desempenho",
    "Timeout" : "Tempo limite",
    "Login as share" : "Faça login como compartilhamento",
    "OpenStack Swift Object Storage" : "Armazenamento de objetos OpenStack Swift",
    "Service name" : "Nome do serviço",
    "Request timeout (seconds)" : "Pedido expira (segundos)",
    "External storage" : "Armazenamento Externo",
    "External storage support" : "Suporte para armazenamento externo",
    "This application enables administrators to configure connections to external storage providers, such as FTP servers, S3 or SWIFT object stores, other Nextcloud servers, WebDAV servers, and more. Administration can choose which types of storage to enable and can mount these storage locations for an account, a group, or the entire system. Users will see a new folder appear in their root Nextcloud directory, which they can access and use like any other Nextcloud folder. External storage also allows people to share files stored in these external locations. In these cases, the credentials for the owner of the file are used when the recipient requests the file from external storage, thereby ensuring that the recipient can access the shared file.\n\nExternal storage can be configured using the GUI or at the command line. This second option provides the administration with more flexibility for configuring bulk external storage mounts and setting mount priorities. More information is available in the external storage GUI documentation and the external storage Configuration File documentation." : "Este aplicativo permite que os administradores configurem conexões com provedores de armazenamento externos, como servidores FTP, armazenamentos de objetos S3 ou SWIFT, outros servidores Nextcloud, servidores WebDAV e muito mais. A administração pode escolher quais tipos de armazenamento a serem ativados e pode montar estes locais de armazenamento para uma conta, um grupo ou todo o sistema. Os usuários verão uma nova pasta aparecer em seu diretório raiz Nextcloud, que eles podem acessar e usar como qualquer outra pasta do Nextcloud. O armazenamento externo também permite que as pessoas compartilhem arquivos armazenados nestes locais externos. Nesses casos, as credenciais do proprietário do arquivo são usadas quando o destinatário solicita o arquivo do armazenamento externo, garantindo assim que o destinatário possa acessar o arquivo compartilhado. \n\nO armazenamento externo pode ser configurado usando a GUI ou na linha de comando. Esta segunda opção fornece à administração mais flexibilidade para configurar montagens de armazenamento externo em massa e definir prioridades de montagem. Mais informações estão disponíveis na documentação da GUI de armazenamento externo e na documentação do arquivo de configuração de armazenamento externo.",
    "Edit storage" : "Editar armazenamento",
    "Add storage" : "Adicionar armazenamento",
    "Folder name" : "Nome da pasta",
    "Authentication" : "Autenticação",
    "Cancel" : "Cancelar",
    "Edit" : "Editar",
    "Create" : "Criar",
    "Never" : "Nunca",
    "Once every direct access" : "Uma vez em cada acesso direto",
    "Always" : "Sempre",
    "Mount options" : "Opções de montagem",
    "Read only" : "Apenas leitura",
    "Enable previews" : "Ativar pré-visualizações",
    "Enable sharing" : "Ativar partilha",
    "Enable encryption" : "Ativar encriptação",
    "Compatibility with Mac NFD encoding (slow)" : "Compatibilidade com a codificação NFD Mac (lenta)",
    "External storages" : "Armazenamento externo",
    "Status" : "Status",
    "Actions" : "Ações",
    "Checking …" : "Verificando …",
    "Recheck status" : "Reverificar status",
    "Delete" : "Eliminar",
    "Saved" : "Guardado",
    "Saved allowed backends" : "Back-ends permitidos salvos",
    "Failed to save allowed backends" : "Falha ao salvar os back-ends permitidos",
    "Advanced options for external storage mounts" : "Opções avançadas para montagens de armazenamento externo",
    "Error generating key pair" : "Erro ao gerar chave par",
    "Key size" : "Tamanho da chave",
    "Generate keys" : "Gerar chaves",
    "Confirm" : "Confirmar",
    "To access the storage, you need to provide the authentication credentials." : "Para acessar o armazenamento, você precisa fornecer as credenciais de autenticação.",
    "External storage enables you to mount external storage services and devices as secondary Nextcloud storage devices." : "O armazenamento externo permite que você monte serviços e dispositivos de armazenamento externo como dispositivos de armazenamento secundários do Nextcloud.",
    "You may also allow people to mount their own external storage services." : "Você também pode permitir que as pessoas montem seus próprios serviços de armazenamento externo.",
    "{module} is not installed." : "{module} não está instalado.",
    "Global credentials saved" : "Credenciais globais salvas",
    "Saving …" : "A guardar ...",
    "Save" : "Guardar",
    "Unable to update this external storage config. {statusMessage}" : "Não é possível atualizar esta configuração de armazenamento externo.  {statusMessage}",
    "New configuration successfully saved" : "Nova configuração salva com sucesso",
    "Enter missing credentials" : "Digite as credenciais ausentes",
    "Credentials successfully set" : "Credenciais definidas com sucesso",
    "Checking storage …" : "Verificando armazenamento …",
    "There was an error with this external storage." : "Ocorreu um erro com este armazenamento externo.",
    "We were unable to check the external storage {basename}" : "Não foi possível verificar o armazenamento externo {basename}",
    "Open in Files" : "Abrir em Arquivos",
    "External mount error" : "Erro de montagem externa",
    "There was an error with this external storage. Do you want to review this mount point config in the settings page?" : "Ocorreu um erro com este armazenamento externo. Deseja revisar esta configuração do ponto de montagem na página de configurações?",
    "Open settings" : "Abrir definições",
    "Ignore" : "Ignorar",
    "List of external storage." : "Lista de armazenamentos externos.",
    "There is no external storage configured and you don't have the permission to configure them." : "Não há armazenamento externo configurado e você não tem permissão para configurá-los.",
    "Storage type" : "Tipo de Armazenamento",
    "Unknown" : "Desconhecido",
    "Scope" : "Âmbito",
    "Personal" : "Pessoal",
    "System" : "Sistema",
    "Connected" : "Conectado",
    "Error" : "Erro",
    "Indeterminate" : "Indeterminado",
    "Incomplete configuration" : "Configuração incompleta",
    "Unauthorized" : "Não autorizado",
    "Network error" : "Erro de Rede",
    "Grant access" : "Conceder acesso",
    "Error configuring OAuth2" : "Erro ao configurar OAuth2",
    "%s" : "%s",
    "Access key" : "Chave de acesso",
    "Secret key" : "Código secreto",
    "OAuth2" : "OAuth2",
    "Client ID" : "Id. de Cliente",
    "Client secret" : "Segredo de cliente",
    "S3 Storage" : "Armazenamento S3",
    "Enable SSL" : "Ativar SSL",
    "Enable Path Style" : "Ativar Estilo do Caminho",
    "Legacy (v2) authentication" : "Autenticação obsoleta (v2)",
    "FTP" : "FTP",
    "Local" : "Local",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "SFTP with secret key login" : "SFTP com início de sessão por chave secreta",
    "SMB/CIFS" : "SMB/CIFS",
    "SMB/CIFS using OC login" : "SMB/CIFS usando login OC",
    "OpenStack Object Storage" : "Armazenamento de Objetos OpenStack",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "O suporte cURL em PHP não está ativo ou instalado. Não é possível montar %s. Por favor peça ao seu administrador de sistema que o instale.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "O suporteF TP em PHP não está ativo ou instalado. Não é possível montar %s. Por favor peça ao seu administrador de sistema que o instale.",
    "\"%1$s\" is not installed. Mounting of %2$s is not possible. Please ask your system administrator to install it." : "\"%1$s\" não está instalado. A montagem de %2$s não é possível. Peça ao administrador para instalá-lo.",
    "(Group)" : "(Grupo)",
    "Check for changes" : "Verificar se há alterações",
    "Disconnect" : "Desligado",
    "Admin defined" : "Administrador definido",
    "Automatic status checking is disabled due to the large number of configured storages, click to check status" : "A verificação automática de status está desabilitada devido ao grande número de armazenamentos configurados, clique para verificar o status",
    "Are you sure you want to disconnect this external storage?" : "Tem certeza de que deseja desconectar este armazenamento externo?",
    "It will make the storage unavailable in {instanceName} and will lead to a deletion of these files and folders on any sync client that is currently connected but will not delete any files and folders on the external storage itself." : "Isso tornará o armazenamento indisponível em {instanceName} e levará à exclusão destes arquivos e pastas em qualquer cliente de sincronização que esteja conectado no momento, mas não excluirá nenhum arquivo ou pasta no próprio armazenamento externo.",
    "Delete storage?" : "Apagar armazenamento?",
    "Click to recheck the configuration" : "Clique para rechecar a configuração",
    "Saving …" : "A guardar...",
    "Failed to save global credentials" : "Falha ao salvar as credenciais globais",
    "Failed to save global credentials: {message}" : "Falha ao salvar as credenciais globais: {message}",
    "No external storage configured or you don't have the permission to configure them" : "Sem armazenamento externo configurado ou você não tem permissão para configurá-los",
    "Open documentation" : "Abrir documentação",
    "External storage enables you to mount external storage services and devices as secondary Nextcloud storage devices. You may also allow people to mount their own external storage services." : "O armazenamento externo permite montar serviços e dispositivos de armazenamento externos como dispositivos de armazenamento Nextcloud secundários. Você também pode permitir que as pessoas montem seus próprios serviços de armazenamento externo.",
    "Configuration" : "Configuração",
    "Available for" : "Disponível para ",
    "Advanced settings" : "Definições avançadas",
    "Use presigned S3 url" : "Usar URL S3 pré-assinado"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
