OC.L10N.register(
    "appstore",
    {
    "Apps" : "Apps",
    "App name" : "App navn",
    "Version" : "Version",
    "Groups" : "Grupper",
    "Actions" : "Handlinger",
    "Show details" : "Vis detaljer",
    "Grid view" : "Gittervisning",
    "Cancel" : "Annullér",
    "Features" : "Funktioner",
    "Learn more" : "Lær mere",
    "Daemon" : "Systemtjeneste",
    "Deploy Daemon" : "Udrulnings systemtjeneste",
    "Type" : "Type",
    "Name" : "Navn",
    "Display Name" : "Vist navn",
    "GPUs support" : "GPUer understøttelse",
    "Compute device" : "Beregningsapparat",
    "Advanced deploy options" : "Avancerede udrulningsindstillinger",
    "Edit ExApp deploy options before installation" : "Redigér ExApp udrulningsindstillinger før installation",
    "Configured ExApp deploy options. Can be set only during installation" : "Konfigurerede ExApp udrulningsindstillinger. Kan kun indstilles under installationen",
    "Environment variables" : "Miljøvariabler",
    "ExApp container environment variables" : "ExApp container miljøvariabler",
    "No environment variables defined" : "Ingen miljøvariabler defineret",
    "Mounts" : "Monteringer",
    "Define host folder mounts to bind to the ExApp container" : "Definer værtsmappemonteringer for at binde til ExApp containeren",
    "Must exist on the Deploy daemon host prior to installing the ExApp" : "Skal eksistere på udrulnings systemtjeneste værten, før installation af ExApp",
    "Host path" : "Host stien",
    "Container path" : "Container sti",
    "Read-only" : "Skrivebeskyttet",
    "Remove mount" : "Fjern montering",
    "New mount" : "Ny montering",
    "Enter path to host folder" : "Indtast stien til host mappen",
    "Enter path to container folder" : "Indtast stien til containermappen",
    "Toggle read-only mode" : "Skift skrivebeskyttet tilstand",
    "Confirm adding new mount" : "Bekræft tilføjelse af ny montering",
    "Confirm" : "Bekræft",
    "Cancel adding mount" : "Annuller tilføjelse af montering",
    "Add mount" : "Tilføj montering",
    "ExApp container mounts" : "ExApp containermonteringer",
    "No mounts defined" : "Der er ikke defineret nogen monteringer",
    "Description" : "Beskrivelse",
    "View in store" : "Se i butik",
    "Visit website" : "Besøg hjemmeside",
    "Usage documentation" : "Anvendelsesdokumentation",
    "Admin documentation" : "Admin-dokumentation",
    "Developer documentation" : "Udvikler-dokumentation",
    "Details" : "Detaljer",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Dette program kan ikke installeres, da følgende afhængigheder ikke imødekommes:",
    "Latest updated" : "Sidst opdateret",
    "Author" : "Forfatter",
    "Categories" : "Kategorier",
    "Resources" : "Ressourcer",
    "Changelog" : "Ændringslog",
    "Supported" : "Understøttet",
    "Featured" : "Fremhævet",
    "This app is supported via your current Nextcloud subscription." : "Denne app understøttes via dit nuværende Nextcloud-abonnement.",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Udvalgte apps er udviklet af og inden for fællesskabet. De tilbyder central funktionalitet og er klar til produktionsbrug.",
    "Community rating: {score}/5" : "Fællesskabsbedømmelse: {score}/5",
    "Choose Deploy Daemon for {appName}" : "Vælg udrulnings systemtjeneste for {appName}",
    "No Deploy daemons configured" : "Ingen udrulnings systemtjenester konfigureret",
    "Register a custom one or setup from available templates" : "Registrer en brugerdefineret en eller opsæt fra tilgængelige skabeloner",
    "Manage Deploy daemons" : "Styr udrulnings systemtjenester",
    "Registered Deploy daemons list" : "Liste over registrerede udrulnings systemtjenester",
    "Default" : "Standard",
    "Carousel" : "Karrusel",
    "Previous slide" : "Forrige slide",
    "Next slide" : "Næste slide",
    "Choose slide to display" : "Vælg slide til visning",
    "{index} of {total}" : "{index} ud af {total}",
    "Limit to groups" : "Begræns til grupper",
    "Save" : "Gem",
    "Update all" : "Opdater alle",
    "Loading app list" : "Indlæser app liste",
    "Search everywhere" : "Søg overalt",
    "Download and enable all" : "Download og aktiver alle",
    "Could not load app discover section" : "App opdagelsessektionen kunne ikke indlæses",
    "Could not render element" : "Elementet kunne ikke gengives",
    "Nothing to show" : "Intet indhold",
    "Could not load section content from app store." : "Kunne ikke hente det valgte indhold fra app store.",
    "Loading" : "Indlæser",
    "Fetching the latest news…" : "Henter seneste nyt...",
    "Loading categories" : "Indlæser kategorier",
    "Version {version}, {license}-licensed" : "Version {version}, {license}-licenseret",
    "Version {version}" : "Version {version}",
    "Disable" : "Deaktiver",
    "Enable" : "Aktivér",
    "Download and enable" : "Download og aktiver",
    "Rate the app" : "Bedøm appen",
    "Report a bug" : "Rapporter en fejl",
    "Remove" : "Fjern",
    "Update to {version}" : "Opdatér til {version}",
    "Discover" : "Opdag",
    "Your apps" : "Dine apps",
    "Active apps" : "Aktive apps",
    "Disabled apps" : "Deaktiverede apps",
    "Updates" : "Opdateringer",
    "App bundles" : "App bundles",
    "Featured apps" : "Udvalgte apps",
    "Supported apps" : "Understøttede apps",
    "An error occurred during the request. Unable to proceed." : "Der opstod en fejl under anmodningen. Kan ikke fortsætte."
},
"nplurals=2; plural=(n != 1);");
