OC.L10N.register(
    "app_api",
    {
    "Daemon config not found" : "Taustateenuse seadistusi ei leidu",
    "Error starting install of ExApp" : "ExApp'i paigaldamise alustamisel tekkis viga",
    "Error adding Docker registry" : "Viga Dockeri registrikirje lisamisel",
    "Error removing Docker registry" : "Viga Dockeri registrikirje eemaldamisel",
    "Deploy daemons" : "Kasutuselevõtmise taustateenus",
    "Cancel" : "Tühista",
    "Delete" : "Kustuta",
    "Password confirmation failed" : "Salasõna kinnitamine ei õnnestunud",
    "Default" : "Vaikimisi",
    "Docker registries" : "Dockeri registrikirjed",
    "Edit" : "Redigeeri",
    "Unlimited" : "Piiramatult",
    "{size} GiB" : "{size} GiB",
    "{size} MiB" : "{size} MiB",
    "_{n} CPU_::_{n} CPUs_" : ["{n} protsessor","{n} protsessorit"],
    "Name" : "Nimi",
    "Protocol" : "Protokoll",
    "Host" : "Host",
    "Deploy options" : "Kasutuselevõtmise valikud",
    "Docker network" : "Dockeri võrk",
    "Nextcloud URL" : "Nextcloudi võrguaadress",
    "HaProxy password" : "HaProxy salasõna",
    "GPU support" : "Graafikaprotsessori tugi",
    "Memory limit" : "Mälukasutuse ülempiir",
    "CPU limit" : "Kasutatavate protsessorite arvu ülempiir",
    "Additional options" : "Täiendavad valikud",
    "Check connection" : "Kontrolli ühenduse toimimist",
    "Registered Deploy daemons list" : "Registreeritud kasutuselevõtmise taustateenuste loend",
    "No Deploy daemons are registered" : "Ühtegi kasutuselevõtmise taustateenust pole seadistatud",
    "Enabled" : "Sisse lülitatud",
    "More information" : "Lisateave",
    "This registry mapping already exists" : "See registrivastendus on juba olemas",
    "Error adding Docker registry mapping" : "Viga Dockeri registrivastenduse lisamisel",
    "Docker registry mapping removed" : "Dockeri registrivastendus on eemaldatud",
    "Error removing Docker registry mapping" : "Viga Dockeri registrivastenduse eemaldamisel",
    "Remove" : "Eemalda",
    "From" : "Saatja",
    "To" : "Saaja",
    "Add" : "Lisa",
    "Display name" : "Kuvatav nimi",
    "The password must be at least 12 characters long" : "Salasõna peab olema vähemalt 12 tähemärki pikk",
    "Set this daemon as the default one" : "Määra see taustateenus vaikimisi kasutatavaks",
    "Set as the default daemon" : "Määra vaikimisi taustateenuseks",
    "Enable HTTPS" : "Lülita HTTPS sisse",
    "Compute device" : "Arvutusseade",
    "Memory limit (in MiB)" : "Mälukasutuse ülempiir (MiB)",
    "Must be a positive integer" : "Peab olema positiivne täisarv",
    "Confirm" : "Kinnita",
    "Save" : "Salvesta",
    "Register" : "Registreeru",
    "{license}-licensed" : "{license} litsents",
    "Update to {version}" : "Uuendus versioonini {version}",
    "Delete data on remove" : "Eemaldamisel kustuta andmed",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Sellel rakendusel pole määratud minimaalset Nextcloudi versiooni. See põhjustab tulevikus veateateid.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Sellel rakendusel pole määratud maksimaalset Nextcloudi versiooni. See põhjustab tulevikus veateateid.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Seda rakendust ei saa paigaldada, sest järgmised sõltuvusel ei ole täidetud:",
    "View in store" : "Vaata poes",
    "Visit website" : "Külasta veebisaiti",
    "Report a bug" : "Teata veast",
    "User documentation" : "Kasutaja dokumentatsioon",
    "Admin documentation" : "Administraatori dokumentatsioon",
    "Developer documentation" : "Arendaja dokumentatsioon",
    "This app is supported via your current Nextcloud subscription." : "See rakendus on toetatud sinu praeguses Nextcloudi tellimuses. ",
    "Supported" : "Toetatud",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Esiletõstetud rakendusi arendatakse kogukonna poolt. Nad pakuvad võimalust kasutada olulist funktsionaalsust ning on sobilikud igapäevaseks kasutuseks.",
    "Featured" : "Esile tõstetud",
    "Update to {update}" : "Uuenda versioonini {update}",
    "Default Deploy daemon is not accessible" : "Kasutuselevõtmise taustateenus pole leitav",
    "Icon" : "Ikoon",
    "Version" : "Versioon",
    "Daemon" : "Taustateenus",
    "Level" : "Tase",
    "Actions" : "Tegevused",
    "Results from other categories" : "Tulemused muudest kategooriatest",
    "_Update_::_Update all_" : ["Uuenda","Uuenda kõik"],
    "Deploy Daemon" : "Kasutuselevõtmise taustateenus",
    "Type" : "Tüüp",
    "Display Name" : "Kuvatav nimi",
    "GPUs support" : "Graafikaprotsessori tugi",
    "Verify connection" : "Kontrolli ühendust",
    "No Deploy daemons configured" : "Ühtegi kasutuselevõtmise taustateenust pole seadistatud",
    "Register a custom one or setup from available templates" : "Registreeri enda eelistus või vali olemasolevate mallide seast",
    "URL should start with http:// or https://" : "Võrguaadressi alguses peab olema kas http:// või https://",
    "Network" : "Võrk",
    "Your apps" : "Sinu rakendused",
    "Documentation" : "Dokumentatsioon",
    "Details" : "Üksikasjad",
    "Changelog" : "Muudatuste logi",
    "Active apps" : "Aktiivsed rakendused",
    "Disabled apps" : "Keelatud rakendused",
    "Updates" : "Uuendused",
    "Featured apps" : "Esiletõstetud rakendused",
    "Supported apps" : "Toetatud rakendused",
    "Deploy and Enable" : "Võta kasutusele ja lülita sisse",
    "Enable" : "Lülita sisse",
    "Disable" : "Lülita välja",
    "Allow untested app" : "Luba testimata rakenduse kasutamine",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "See rakendus pole märgitud ühilduvaks sinu Nextcloudi serveri versiooniga. Kui jätkad, siis saad ta ikkagi paigaldada, aga palun arvesta, et ta ei pruugi toimida ootuspäraselt.",
    "An error occurred during the request. Unable to proceed." : "Päringu ajal tekkis viga. Jätkamine pole võimalik.",
    "The app has been enabled but needs to be updated." : "See rakendus on kasutusel, aga vajab uuendamist.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Viga: Kuna ta muudaks selle serveri mittetöökindlaks, siis seda rakendust ei saa sisse lülitada"
},
"nplurals=2; plural=(n != 1);");
