OC.L10N.register(
    "sharebymail",
    {
    "Shared with {email}" : "Bendrinama su {email}",
    "Shared with {email} by {actor}" : "{actor} pradėjo bendrinti su {email}",
    "Unshared from {email}" : "Nustota bendrinti su {email}",
    "Unshared from {email} by {actor}" : "{actor} nustojo bendrinti su {email}",
    "Password for mail share sent to {email}" : "Slaptažodis pasidalinimui per elektroninį paštą išsiųstas {email}",
    "Password for mail share sent to you" : "Slaptažodis nuorodos bendrinimui el. paštu išsiųstas jums",
    "You shared {file} with {email} by mail" : "El. paštu pradėjote bendrinti {file} su {email}",
    "{actor} shared {file} with {email} by mail" : "{actor} el. paštu pradėjo bendrinti {file} su {email}",
    "You unshared {file} from {email} by mail" : "Jūs nustojote el. paštu bendrinti {file} su {email}",
    "{actor} unshared {file} from {email} by mail" : "{actor} nebendrintas {file} iš {email} el. paštu",
    "Password to access {file} was sent to {email}" : "Slaptažodis, skirtas prieigai prie {file}, buvo išsiųstas į {email}",
    "Password to access {file} was sent to you" : "Jums buvo išsiųstas slaptažodis, skirtas prieigai prie {file}",
    "Share by mail" : "Bendrinimas el. paštu",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "%1$s bendrinimas nepavyko, nes šis elementas jau bendrinamas su %2$s paskyra",
    "We cannot send you the auto-generated password. Please set a valid email address in your personal settings and try again." : "Mes negalime išsiųsti jums automatiškai sugeneruoto slaptažodžio. Prašome asmeniniuose nustatymuose nurodyti galiojantį el. pašto adresą ir pabandyti dar kartą.",
    "Failed to send share by email. Got an invalid email address" : "Nepavyko išsiųsti nuorodos el. paštu. Nurodytas neteisingas el. pašto adresas",
    "Failed to send share by email" : "Nepavyko bendrinti el. paštu",
    "%1$s shared %2$s with you" : "%1$s pradėjo bendrinti su jumis %2$s",
    "Note:" : "Pastaba:",
    "This share is valid until %s at midnight" : "Šis pasiūlymas galioja iki %s vidurnakčio",
    "Expiration:" : "Galiojimo pabaiga:",
    "Open shared item" : "Atidaryti bendrinamą elementą",
    "%1$s via %2$s" : "%1$s per %2$s",
    "%1$s shared %2$s with you. You should have already received a separate mail with a link to access it." : "%1$s bendrino %2$s su jumis. Jau turėjote gauti atskirą el. laišką su nuoroda, kaip jį pasiekti.",
    "Password to access %1$s shared to you by %2$s" : "%2$s pasidalino slaptažodžiu, reikalingu atverti %1$s",
    "Password to access %s" : "Slaptažodis, skirtas prieigai prie %s",
    "It is protected with the following password:" : "Apsaugota šiuo slaptažodžiu:",
    "This password will expire at %s" : "Šis slaptažodis nustos galioti %s",
    "%1$s shared %2$s with you and wants to add:" : "%1$s pasidalino %2$s su jumis ir nori pridėti:",
    "%1$s shared %2$s with you and wants to add" : "%1$s pasidalino %2$s su jumis ir nori pridėti",
    "%s added a note to a file shared with you" : "%s parašė pastabą su jumis pasidalintam failui",
    "You just shared %1$s with %2$s. The share was already sent to the recipient. Due to the security policies defined by the administrator of %3$s each share needs to be protected by password and it is not allowed to send the password directly to the recipient. Therefore you need to forward the password manually to the recipient." : "Jūs ką tik pasidalijote %1$s su %2$s. Pasidalijimas jau buvo išsiųstas gavėjui. Dėl %3$sadministratoriaus nustatytų saugumo taisyklių kiekvienas pasidalijimas turi būti apsaugotas slaptažodžiu, o slaptažodžio tiesiogiai siųsti gavėjui neleidžiama. Todėl slaptažodį gavėjui turite perduoti rankiniu būdu.",
    "Password to access %1$s shared by you with %2$s" : "Slaptažodis, skirtas %1$s prieigai, kurią bendrinote su %2$s",
    "This is the password:" : "Štai yra slaptažodis:",
    "You can choose a different password at any time in the share dialog." : "Dalinimosi dialoge bet kuriuo metu galite pasirinkti kitą slaptažodį.",
    "Could not find share" : "Nepavyko rasti bendrinimo",
    "Share provider which allows you to share files by mail" : "Bendrinimo teikėjas, kuris leidžia bendrinti failus el. paštu",
    "Unable to update share by mail config" : "Nepavyko atnaujinti bendrinimo el. paštu konfigūracijos",
    "Allows people to share a personalized link to a file or folder by putting in an email address." : "Leidžia žmonėms bendrinti asmeninę nuorodą į failą ar aplanką, įvedus el. pašto adresą.",
    "Send password by mail" : "Siųsti slaptažodį el. paštu",
    "Reply to initiator" : "Atsakyti iniciatoriui"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
