OC.L10N.register(
    "survey_client",
    {
    "Last report sent on: {on}" : "Останній звіт відправлено: {on}",
    "An error occurred while sending your report." : "Під час надсилання звіту сталася помилка.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "Перелік застосунків <em>(для кожного застосунку: назва, версія, чи увімкнено)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Інформація про БД <em>(тип, версія, розмір бази даних)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Інформація про шифрування <em>(чи ввімкнено?, який модуль за замовчуванням)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Кількість спільних ресурсів <em>(за типом та налаштуванням дозволу)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "Інформація про PHP <em>(версія, ліміт пам'яті, максимальний час виконання, максимальний розмір файлу)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Докладна інформація про цей сервер хмари <em>(версія, використання кешу пам'яті, стан блокування/попереднього перегляду/аватарок)</em>",
    "Statistic <em>(number of files, users, storages per type, comments and tags)</em>" : "Статистика <em>(кількість файлів, користувачів, сховищ за типами, коментарів та тегів)</em>",
    "Usage survey" : "Огляд використання",
    "Help improve Nextcloud" : "Допоможіть покращити Nextcloud",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Бажаєте допомогти нам покращити Nextcloud, надавши анонімні дані про ваші налаштування та використання? Ви можете відключити цю функцію в будь-який час в налаштуваннях адміністратора.",
    "Send usage" : "Надіслати інформацію про використання",
    "Not now" : "Не зараз",
    "Never" : "Ніколи",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud." : "Надсилає анонімні дані до Nextcloud, щоб допомогти нам покращити Nextcloud.",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud. You\n\t\talways have full control over the content sent to Nextcloud and can disable\n\t\tit again at any time." : "Надсилає анонімні дані до Nextcloud, щоб допомогти нам покращити Nextcloud. Ви\n\t\tзавжди маєте повний контроль над контентом, що надсилається до Nextcloud, і можете вимкнути його\n\t\tйого в будь-який час.",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Ви можете допомогти покращити Nextcloud, надіславши нам деякі дані про ваші поточні налаштування та використання.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. To delete the stored usage data, upload an empty report by unchecking all of the boxes then sending a new report." : "Ми серйозно ставимося до вашої конфіденційності. Відправлення даних за замовчуванням вимкнено, і якщо ви вирішите увімкнути цю функцію, дані спочатку будуть анонімізовані, а вам буде надано можливість вибрати, які дані ви хочете поділитися. Після отримання звіту попередній звіт видаляється. Щоб видалити збережені дані про використання, завантажте порожній звіт, знявши всі прапорці, а потім надішліть новий звіт.",
    "Send new report now" : "Надіслати новий звіт зараз",
    "Send usage survey monthly" : "Щомісяця надсилати звіт про використання",
    "Data to send" : "Дані для надсилання",
    "Last report" : "Останній звіт",
    "Last report sent on: %s" : "Останній звіт відправлено: %s"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
