OC.L10N.register(
    "files_versions",
    {
    "No rule given" : "No rule given",
    "Versions" : "Versions",
    "This application automatically maintains older versions of files that are changed." : "This application automatically maintains older versions of files that are changed.",
    "This application automatically maintains older versions of files that are changed. When enabled, a hidden versions folder is provisioned in every user's directory and is used to store old file versions. A user can revert to an older version through the web interface at any time, with the replaced file becoming a version. The app automatically manages the versions folder to ensure the account does not run out of Quota because of versions.\n\t\tIn addition to the expiry of versions, the versions app makes certain never to use more than 50% of the account's currently available free space. If stored versions exceed this limit, the app will delete the oldest versions first until it meets this limit. More information is available in the Versions documentation." : "This application automatically maintains older versions of files that are changed. When enabled, a hidden versions folder is provisioned in every user's directory and is used to store old file versions. A user can revert to an older version through the web interface at any time, with the replaced file becoming a version. The app automatically manages the versions folder to ensure the account does not run out of Quota because of versions.\n\t\tIn addition to the expiry of versions, the versions app makes certain never to use more than 50% of the account's currently available free space. If stored versions exceed this limit, the app will delete the oldest versions first until it meets this limit. More information is available in the Versions documentation.",
    "Current version" : "Current version",
    "Initial version" : "Initial version",
    "You" : "You",
    "Actions for version from {versionHumanExplicitDate}" : "Actions for version from {versionHumanExplicitDate}",
    "Name this version" : "Name this version",
    "Edit version name" : "Edit version name",
    "Compare to current version" : "Compare to current version",
    "Restore version" : "Restore version",
    "Download version" : "Download version",
    "Delete version" : "Delete version",
    "Cancel" : "ຍົກເລີກ",
    "Remove version name" : "Remove version name",
    "Save version name" : "Save version name",
    "Version name" : "Version name",
    "Named versions are persisted, and excluded from automatic cleanups when your storage quota is full." : "Named versions are persisted, and excluded from automatic cleanups when your storage quota is full.",
    "Initial version restored" : "Initial version restored",
    "Version restored" : "Version restored",
    "Could not restore version" : "Could not restore version",
    "Could not set version label" : "Could not set version label",
    "Could not delete version" : "Could not delete version",
    "File versions" : "File versions"
},
"nplurals=1; plural=0;");
