.material-design-icon[data-v-53618902]{display:flex;align-self:center;justify-self:center;align-items:center;justify-content:center}.empty-content[data-v-53618902]{display:flex;align-items:center;flex-direction:column;justify-content:center;flex-grow:1;padding:var(--default-grid-baseline)}.modal-wrapper .empty-content[data-v-53618902]{margin-top:5vh;margin-bottom:5vh}.empty-content__icon[data-v-53618902]{display:flex;align-items:center;justify-content:center;width:64px;height:64px;margin:0 auto 15px;opacity:.4;background-repeat:no-repeat;background-position:center;background-size:64px}.empty-content__icon[data-v-53618902] svg{width:64px!important;height:64px!important;max-width:64px!important;max-height:64px!important}.empty-content__name[data-v-53618902]{margin-bottom:10px;text-align:center;font-weight:var(--font-weight-heading, bold);font-size:20px;line-height:30px}.empty-content__description[data-v-53618902]{color:var(--color-text-maxcontrast);text-align:center;text-wrap-style:balance}.empty-content__action[data-v-53618902]{margin-top:8px}.modal-wrapper .empty-content__action[data-v-53618902]{margin-top:20px;display:flex}
