OC.L10N.register(
    "nextcloud_announcements",
    {
    "Nextcloud announcements" : "Najave Nextcloud",
    "Nextcloud announcement" : "Najava Nextcloud",
    "Read more" : "Več o tem",
    "Disable announcements" : "Onemogoči najave",
    "(These announcements are only shown to administrators)" : "(Tovrstna obvestila in najave so prikazane le skrbnikom)",
    "Nextcloud announcements brings the latest news of Nextcloud into your notifications" : "Program omogoča prikaz zadnjih novic Nextcloud med obvestili."
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
