OC.L10N.register(
    "photos",
    {
    "Photos" : "Photos",
    "Favorites" : "Favoriti",
    "Shared with you" : "Shared with you",
    "Save" : "Spremi",
    "Shared by" : "Dijeli",
    "Favorite" : "Favorit",
    "Home" : "Početna stranica",
    "Remove from favorites" : "Remove from favorites",
    "Group" : "Grupa",
    "Cancel" : "Cancel"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
