OC.L10N.register(
    "serverinfo",
    {
    "System" : "Sistem",
    "Unknown" : "Necunoscut",
    "Monitoring" : "Monitorizare",
    "Background jobs" : "Proces de fundal",
    "Mode" : "Mod",
    "Never" : "Niciodată",
    "Database" : "Baza de date",
    "Type:" : "Tip:",
    "Size:" : "Mărime:",
    "Started" : "A început",
    "Duration" : "Durată",
    "Details" : "Detalii",
    "Failed" : "Eșuat",
    "Running" : "Alergat",
    "Authentication" : "Autentificare",
    "Hostname" : "Nume mașină",
    "PHP extensions" : "extensii PHP ",
    "seconds" : "secunde",
    "Shares" : "Partajări",
    "Warning" : "Atenție",
    "Copied!" : "S-a copiat!",
    "Not supported!" : "Nu este suportat!",
    "Press ⌘-C to copy." : "Apasă ⌘-C pentru copiere.",
    "Press Ctrl-C to copy." : "Apasă Ctrl-C pentru copiere.",
    "Copy" : "Copiază"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
