OC.L10N.register(
    "files_trashbin",
    {
    "restored" : "Gendannet",
    "Deleted files" : "Slettede filer",
    "Deleted files and folders in the trash bin (may expire during export if you are low on storage space)" : "Slettede filer og mapper i skraldespanden (kan udløbe under eksport, hvis du mangler lagerplads)",
    "This application enables people to restore files that were deleted from the system." : "Denne applikation gør det muligt for folk at gendanne filer, der blev slettet fra systemet.",
    "This application enables people to restore files that were deleted from the system. It displays a list of deleted files in the web interface, and has options to restore those deleted files back to the people file directories or remove them permanently from the system. Restoring a file also restores related file versions, if the versions application is enabled. When a file is deleted from a share, it can be restored in the same manner, though it is no longer shared. By default, these files remain in the trash bin for 30 days.\nTo prevent an account from running out of disk space, the Deleted files app will not utilize more than 50% of the currently available free quota for deleted files. If the deleted files exceed this limit, the app deletes the oldest files until it gets below this limit. More information is available in the Deleted Files documentation." : "Denne applikation gør det muligt for folk at gendanne filer, der blev slettet fra systemet. Den viser en liste over slettede filer i webgrænsefladen og har muligheder for at gendanne de slettede filer tilbage til personarkiverne eller fjerne dem permanent fra systemet. Gendannelse af en fil gendanner også relaterede filversioner, hvis versionsapplikationen er aktiveret. Når en fil slettes fra en share, kan den gendannes på samme måde, selvom den ikke længere deles. Som standard forbliver disse filer i papirkurven i 30 dage.\nFor at forhindre en konto i at løbe tør for diskplads, vil appen Slettede filer ikke bruge mere end 50 % af den aktuelt tilgængelige gratis kvote for slettede filer. Hvis de slettede filer overskrider denne grænse, sletter appen de ældste filer, indtil den kommer under denne grænse. Flere oplysninger findes i dokumentationen til slettede filer.",
    "Restore" : "Gendan",
    "Not enough free space to restore the file/folder" : "Ikke nok ledig plads til at genskabe fil/mappe",
    "Empty deleted files" : "Tøm slettede filer",
    "Confirm permanent deletion" : "Bekræft permanent sletning",
    "Are you sure you want to permanently delete all files and folders in the trash? This cannot be undone." : "Er du sikker på, at du vil slette alle filer og mapper i papirkurven permanent? Dette kan ikke fortrydes.",
    "Cancel" : "Annullér",
    "Original location" : "Oprindelig filplacering",
    "Deleted by" : "Slettet af ",
    "Deleted" : "Slettet",
    "few seconds ago" : "et par sekunder siden",
    "A long time ago" : "For lang tid siden",
    "Unknown" : "Ukendt",
    "All files" : "Alle filer",
    "You" : "Dig",
    "List of files that have been deleted." : "Liste med filer der er blevet slettet.",
    "No deleted files" : "Ingen slettede filer",
    "Files and folders you have deleted will show up here" : "Filer og mapper du har slettet, vil blive listet her",
    "All files have been permanently deleted" : "Alle filer er blevet slettet permanent",
    "Failed to empty deleted files" : "Kunne ikke tømme slettede filer"
},
"nplurals=2; plural=(n != 1);");
