OC.L10N.register(
    "suspicious_login",
    {
    "New login location detected" : "لم يُمكن تحديد الموقع الذي تمّ منه الدخول",
    "More info about the suspicious IP address available on %s" : "مزيد من المعلومات عن عنوان IP المشبوه تجدها في %s",
    "Open %s ↗" : "إفتَح %s ↗",
    "Suspicious Login" : "دخولٌ مشبوهٌ",
    "New login detected" : " لم يتم كشف أي دخول جديد",
    "Detect and warn about suspicious IPs logging into Nextcloud\n\t" : "أكتشف و بلّغ عن أي عناوين مشبوهة تتم منها محاولة الدخول إلى نكست كلاود\n\t",
    "A new login into your account was detected. The IP address %s was classified as suspicious. If this was you, you can ignore this message. Otherwise you should change your password." : "تمّ اكتشاف دخول جديد إلى حسابك. تمّ اعتبار العنوان %s مشبوهاً. إذا كنت أنت الداخل، يمكنك تجاهل هذه الرسالة؛ و إلّا يلزمك تغيير كلمة المرور."
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
