OC.L10N.register(
    "files_versions",
    {
    "No rule given" : "No hay una regla establecida",
    "Versions" : "Versiones",
    "This application automatically maintains older versions of files that are changed." : "Esta aplicación mantiene automáticamente versiones anteriores de archivos que fueron cambiados. ",
    "Current version" : "Versión actual",
    "Initial version" : "Versión inicial",
    "You" : "Usted",
    "Name this version" : "Nombrar esta versión",
    "Edit version name" : "Editar el nombre de la versión",
    "Compare to current version" : "Comparar con la versión actual",
    "Restore version" : "Restaurar versión",
    "Download version" : "Descargar versión",
    "Delete version" : "Eliminar versión",
    "Cancel" : "Cancelar",
    "Remove version name" : "Eliminar el nombre de la versión",
    "Save version name" : "Guardar el nombre de la versión",
    "Version name" : "Nombre de la versión",
    "Named versions are persisted, and excluded from automatic cleanups when your storage quota is full." : "Las versiones con nombre se conservan y se excluyen de las limpiezas automáticas cuando su cuota de almacenamiento alcanzó el límite.",
    "Initial version restored" : "Versión inicial restaurada",
    "Version restored" : "Versión restaurada",
    "Could not restore version" : "No se pudo restaurar la versión",
    "Could not set version label" : "No se pudo establecer la etiqueta de la versión",
    "Could not delete version" : "No se pudo eliminar la versión"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
