OC.L10N.register(
    "circles",
    {
    "You created the team {circle}" : "{circle} takımını oluşturdunuz",
    "{author} created the team {circle}" : "{author}, {circle} takımını oluşturdu",
    "You deleted {circle}" : "{circle} takımını sildiniz",
    "{author} deleted {circle}" : "{author}, {circle} takımını sildi",
    "You made {member} join {circle}" : "{member} üyesini {circle} takımına eklediniz",
    "{author} made {member} join {circle}" : "{author}, {member} üyesini {circle} takımına ekledi",
    "You added team {member} as member to {circle}" : "{member} üyesini {circle} takımına eklediniz",
    "{author} added team {member} as member to {circle}" : "{author}, {member} üyesini {circle} takımına ekledi",
    "You made {member} leave {circle}" : "{member} üyesini {circle} takımından çıkardınız",
    "{author} made {member} leave {circle}" : "{author}, {member} üyesini {circle} takımından çıkardı",
    "You removed {member} from {circle}" : "{member} üyesini {circle} takımından çıkardınız",
    "{author} removed {member} from {circle}" : "{author},  {member} üyesini {circle} takımından çıkardı",
    "You joined {circle}" : "{circle} takımına girdiniz",
    "{member} joined {circle}" : "{member}, {circle} takımına girdi",
    "You accepted the invitation to join {circle}" : "{circle} takımına girme davetini kabul ettiniz",
    "{member} accepted the invitation to join {circle}" : "{member}, {circle} takımına girme davetini kabul etti",
    "You added {member} as member to {circle}" : "{member} üyesini {circle} takımına eklediniz",
    "You have been added as member to {circle} by {author}" : "{author} tarafından {circle} takımına eklendiniz",
    "{member} has been added as member to {circle} by {author}" : "{member}, {author} tarafından {circle} takımına eklendi",
    "You added {external} to {circle}" : "{external} kullanıcısını {circle} takımına eklediniz",
    "{external} has been added to {circle} by {author}" : "{external}, {author} tarafından {circle} takımına eklendi",
    "You accepted {member}'s request to join {circle}" : "{member} üyesinin {circle} takımına girme isteğini kabul ettiniz",
    "Your request to join {circle} has been accepted by {author}" : "{circle} takımına girme isteğiniz {author} tarafından kabul edildi",
    "{member}'s request to join {circle} has been accepted by {author}" : "{member} üyesinin {circle} takımına girme isteği  {author} tarafından kabul edildi",
    "You left {circle}" : "{circle} takımından ayrıldınız",
    "{member} left {circle}" : "{member}, {circle} takımından ayrıldı",
    "You declined the invitation to join {circle}" : "{circle} takımına girme davetini geri çevirdiniz",
    "{member} declined an invitation to join {circle}" : "{member}, {circle} takımına girme davetini geri çevirdi",
    "You cancelled your request to join {circle}" : "{circle} takımına gönderdiğiniz girme isteğini iptal ettiniz",
    "{member} cancelled a request to join {circle}" : "{member}, {circle} takımına gönderdiği girme isteğini iptal etti",
    "You have been removed from {circle} by {author}" : "{author} tarafından {circle} takımından çıkarıldınız",
    "{member} has been removed from {circle} by {author}" : "{member}, {author} tarafından {circle} takımından çıkarıldı",
    "You removed {external} from {circle}" : "{external} kullanıcısını {circle} takımından çıkardınız",
    "{external} has been removed from {circle} by {author}" : "{external}, {author} tarafından {circle} takımından çıkarıldı",
    "You cancelled {member}'s invitation to join {circle}" : "{member} üyesine gönderilen {circle} takımına girme davetini iptal ettiniz",
    "Your invitation to join {circle} has been cancelled by {author}" : "{circle} takımına girmeniz için yapılan davet {author} tarafından iptal edildi",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author}, {member} üyesine gönderilen {circle} takımına girme davetini iptal etti",
    "You dismissed {member}'s request to join {circle}" : "{member} üyesinin {circle} takımına girme isteğini reddettiniz",
    "Your request to join {circle} has been dismissed by {author}" : "{circle} takımına girme isteğiniz {author} tarafından reddedildi",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{member} üyesinin {circle} takımına girme isteği  {author} tarafından reddedildi",
    "You invited {member} to join {circle}" : "{member} üyesini {circle} takımına girmeye davet ettiniz",
    "You have been invited to join {circle} by {author}" : "{author} tarafından {circle} takımına girmeye davet edildiniz",
    "{member} has been invited to join {circle} by {author}" : "{member}, {author} tarafından {circle} takımına girmeye davet edildi",
    "You changed {member}'s level in {circle} to %1$s" : "{member} üyesinin {circle} takımındaki düzeyini %1$s olarak değiştirdiniz",
    "{author} changed your level in {circle} to %1$s" : "{author}, circle} takımındaki düzeyinizi %1$s olarak değiştirdi",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author}, {member} üyesinin {circle} takımındaki düzeyini %1$s olarak değiştirdi",
    "You sent a request to join {circle}" : "{circle} takımına girme isteği gönderdiniz",
    "{member} sent a request to join {circle}" : "{member} üyesi {circle} takımına girme isteği gönderdi",
    "You are the new owner of {circle}" : "Artık {circle} takımının sahibisiniz",
    "{member} is the new owner of {circle}" : "{member}, artık {circle} takımının sahibi",
    "Teams" : "Takımlar",
    "On events happening in a <strong>team</strong> of which you are a member" : "Üyesi olduğunuz bir <strong>takımdaki</strong> olaylarda",
    "Any important event in a <strong>team</strong> you are moderating" : "Sorumlusu olduğunuz bir <strong>takımdaki</strong> önemli olaylarda",
    "On global events happening in any <strong>team</strong>" : "Herhangi bir <strong>takımdaki</strong> genel olaylarda",
    "Single" : "Tek",
    "Personal" : "Kişisel",
    "System" : "Sistem",
    "Visible" : "Görünür",
    "Open" : "Aç",
    "Invite" : "Davet et",
    "Join request" : "Girme isteği",
    "Friends" : "Arkadaşlar",
    "Password protected" : "Parola korumalı",
    "No Owner" : "Sahibi yok",
    "Hidden" : "Gizli",
    "Backend" : "Yönetim bölümü",
    "Local" : "Yerel",
    "Root" : "Kök",
    "Team invite" : "Takım daveti",
    "Federated" : "Birleşik",
    "Mount point" : "Bağlama noktası",
    "App" : "Uygulama",
    "SCIM" : "SCIM",
    "Nextcloud Account" : "Nextcloud hesabı",
    "Nextcloud Group" : "Nextcloud grubu",
    "Email address" : "E-posta adresi",
    "Contact" : "Kişi",
    "Team" : "Takım",
    "Nextcloud App" : "Nextcloud uygulaması",
    "Teams App" : "Takımlar uygulaması",
    "Admin Command Line" : "Yönetici komut satırı",
    "Member" : "Üye",
    "Moderator" : "Sorumlu",
    "Admin" : "Yönetici",
    "Owner" : "Sahip",
    "%s shared »%s« with you." : "%s sizinle »%s« ögesini paylaştı.",
    "%s shared »%s« with \"%s\"." : "%s,  »%s« dosyasını \"%s\" ile paylaştı.",
    "%s on %s" : "%s %s zamanında",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s sizinle »%2$s« ögesini paylaştı.\nErişim bağlantısını içeren başka bir e-posta daha almış olmalısınız.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s sizinle »%2$s« ögesini paylaştı. Erişim bağlantısını içeren başka bir e-posta daha almış olmalısınız.",
    "Password to access »%1$s« shared to you by %2$s" : "»%1$s« için sizin tarafınızdan %2$s üzerinden paylaşılan erişim parolası",
    "Password to access »%s«" : "»%s« erişim parolası",
    "It is protected with the following password:" : "Şu parola ile korunuyor:",
    "%1$s via %2$s" : "%1$s, %2$s aracılığıyla",
    "Click the button below to open it." : "Açmak için aşağıdaki düğmeye tıklayın.",
    "Open »%s«" : "»%s« aç",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s sizinle birkaç dosya paylaştı.\nErişim bağlantısını içeren başka bir e-posta daha almış olmalısınız.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s sizinle birkaç dosya paylaştı. Erişim bağlantısını içeren başka bir e-posta daha almış olmalısınız.",
    "Password to access files shared to you by %1$s" : "Sizin tarafınızdan %1$s üzerinde paylaşılan dosyalara erişim parolası",
    "Password to access files" : "Dosyalara erişim parolası",
    "%s shared multiple files with \"%s\"." : "%s, \"%s\" ile birkaç dosya paylaştı.",
    "%s shared multiple files with you." : "%s sizinle birkaç dosya paylaştı.",
    "Boot up" : "Başlatma",
    "Nextcloud Initialization" : "Nextcloud başlatılıyor",
    "Teams App Initialization" : "Takımlar uygulaması başlatılıyor",
    "Fresh installation status" : "Yeni kurulum durumu",
    "Building Local Database" : "Yerel veri tabanı oluşturuluyor",
    "Testing Basic Team Creation" : "Temel takım oluşturma sınanıyor",
    "Adding local users and moderators" : "Yerel kullanıcılar ve sorumlular ekleniyor",
    "Show all teams" : "Tüm takımları görüntüle",
    "Create a new team" : "Yeni bir takım oluştur",
    "Files" : "Dosyalar",
    "This feature is not available for personal teams" : "Bu özellik kişisel takımlarda kullanılamaz",
    "The team is not federated" : "Takım birleşik değil",
    "You cannot join this team" : "Bu takıma giremezsiniz",
    "This member is not a moderator" : "Bu üye bir sorumlu değil",
    "Insufficient privileges" : "İzinler yetersiz",
    "This member does not exist" : "Bu üye bulunamadı",
    "This member is the owner of the team" : "Bu üye takımın sahibi",
    "Level cannot be changed for this type of member" : "Bu üye türünün düzeyi değiştirilemez",
    "You are already a member of this team" : "Zaten bu takımın bir üyesisiniz",
    "You have been blocked from this team" : "Bu takımda engellenmişsiniz",
    "The account is already a member of this team" : "Hesap zaten bu takımın bir üyesi",
    "The account has already been invited into this team" : "Hesap zaten bu takıma katılması için davet edilmiş",
    "%s (Team owned by %s)" : "%s (Takım sahibi %s)",
    "You are now a member of the Team \"%2$s\"" : "Artık \"%2$s\" takımının üyesisiniz",
    "You have been invited by %1$s into the Team \"%2$s\"" : "%1$s tarafından \"%2$s\" takımına davet edildiniz",
    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$s, \"%2$s\" takımına üye olma isteğinde bulundu",
    "Accept" : "Kabul et",
    "Refuse" : "Reddet",
    "Leave the team" : "Takımdan çık",
    "No image file provided" : "Herhangi bir görsel dosyası belirtilmemiş",
    "Invalid file provided" : "Belirtilen dosya geçersiz",
    "File is too big" : "Dosya çok büyük",
    "Invalid image" : "Görsel geçersiz",
    "Unknown filetype" : "Dosya türü bilinmiyor",
    "%s" : "%s",
    "Personal team" : "Kişisel takım",
    "%s owned by %s" : "%s sahibi %s",
    "You have no permission to create a new team" : "Yeni bir takım oluşturma izniniz yok",
    "Insufficient permissions to perform this action" : "Bu işlemi yapma izniniz yok",
    "%s shared a file with \"%s\"." : "%s, \"%s\" ile bir dosya paylaştı.",
    "%s shared a file with you." : "%s sizinle bir dosya paylaştı.",
    "%1$s shared %2$s with %3$s" : "%1$s, %2$s ögesini %3$s ile paylaştı",
    "%1$s shared %2$s with \"%3$s\"" : "%1$s,  %2$s ögesini \"%3$s\" ile paylaştı",
    "Open %s" : "%s ögesini aç",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s sizinle bir içerik paylaştı.\nErişim bağlantısını içeren başka bir e-posta daha almış olmalısınız.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s sizinle bir içerik paylaştı. Erişim bağlantısını içeren başka bir e-posta daha almış olmalısınız.",
    "Password to access content shared with you by %1$s" : "%1$s tarafından sizinle paylaşılan içeriğe erişme parolası",
    "Password to access content" : "İçeriğe erişme parolası",
    "Federated Teams" : "Birleşik takımlar",
    "Team spaces" : "Takım alanları",
    "This item is already shared with this team" : "Bu öge zaten bu takım ile paylaşılmış",
    "Bring cloud-users closer together." : "Bulut kullanıcılarını bir araya getirir.",
    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Takımlar, kişilerin kendi kişi/iş arkadaşı/arkadaş gruplarını oluşturmasını sağlar.\nBu kişi grupları başka uygulamalar tarafından paylaşım amacıyla kullanılabilir.",
    "Unable to update federated teams config" : "Birleşik takımlar yapılandırması güncellenemedi",
    "Invalid URL format. Please provide a valid URL." : "Adres biçimi geçersiz. Lütfen geçerli bir adres yazın.",
    "Changed frontal cloud URL" : "Ön bulut adresi değiştirildi",
    "Federation allows you to share teams with other trusted servers and make them discoverable across instances." : "Birleşim, takımları diğer güvenilir sunucularla paylaşmanızı ve bunları sunucu kopyaları arasında bulabilmenizi sağlar.",
    "Enable federated teams" : "Birleşik takımları aç",
    "Frontal URL" : "Ön adres",
    "https://…" : "https://…",
    "The public URL used by other instances to discover and connect to your teams." : "Takımlarınızı keşfetmek ve bağlantı kurmak için diğer kopyalar tarafından kullanılacak herkese açık adres.",
    "Unlimited" : "Sınırsız",
    "Unable to update team space config" : "Takım alanı yapılandırması güncellenemedi",
    "Changed default team space quota" : "Varsayılan takım alanı kotası değiştirildi",
    "Quota must be a non-negative number." : "Kota değeri negatif bir sayı olamaz.",
    "Automatically create a shared team space when a new team is created. Requires the Team Folders app to be installed and enabled." : "Yeni bir takım oluşturulduğunda otomatik olarak paylaşılan bir takım alanı oluşturun. Takım klasörleri uygulamasının kurulmuş ve etkinleştirilmiş olması gerekir.",
    "Automatically create a team space" : "Takım alanları otomatik olarak oluşturulsun",
    "Default quota" : "Varsayılan kota",
    "Select default quota" : "Varsayılan kota değerini seçin",
    "Save" : "Kaydet",
    "Default storage quota applied to each auto-created team space. Use 0 for unlimited storage." : "Otomatik olarak oluşturulan her takım alanına uygulanacak varsayılan depolama kotası. Depolama alanının sınırsız olması için 0 yazın.",
    "Connect to OIDC provider" : "OIDC hizmeti sağlayıcısına bağlan",
    "Connect your account to an external OIDC provider to automatically sync your memberships with Nextcloud teams." : "Üyeliklerinizi Nextcloud takımları ile otomatik olarak eşitlemek için hesabınızı bir dış OIDC hizmeti sağlayıcısına bağlayın.",
    "Your account is connected." : "Hesabınız bağlandı.",
    "Reconnect" : "Yeniden bağlantı kur",
    "Connect" : "Bağlan",
    "New team" : "Yeni takım",
    "Search teams" : "Takım ara",
    "Overview" : "Özet",
    "No teams found" : "Herhangi bir takım bulunamadı",
    "Try a different search." : "Farklı bir arama deneyin.",
    "Create a team to get started." : "Başlamak için bir takım oluşturun.",
    "Members" : "Üyeler",
    "_%n resource_::_%n resources_" : ["%n kaynak","%n kaynak"],
    "Please enter a team name" : "Lütfen bir takım adı yazın",
    "Some members could not be added to the team" : "Bazı üyeler takıma eklenemedi",
    "Team created, but the initial members could not be added" : "Takım oluşturuldu, ancak ilk üyeler eklenemedi",
    "Team \"{name}\" created" : "\"{name}\" takımı oluşturuldu",
    "Could not create the team" : "Takım oluşturulamadı",
    "Cancel" : "İptal",
    "Next" : "Sonraki",
    "Back" : "Geri",
    "Create team" : "Takım oluştur",
    "Step {current} of {total}" : "{current} / {total} adım",
    "Name your team" : "Takımınıza bir ad verin",
    "Team name" : "Takım adı",
    "e.g. Design" : "Örnek: Tasarım",
    "Add initial members" : "İlk üyeleri ekle",
    "Search people, groups, teams…" : "Kişi, grup ve takım ara…",
    "Optional, you can also add members later" : "İsteğe bağlı. Üyeleri daha sonra da ekleyebilirsiniz",
    "Search for people to add" : "Eklenecek kişileri ara",
    "You can always add or remove members later from the team page." : "Üyeleri daha sonra takım sayfasından ekleyip kaldırabilirsiniz.",
    "Could not load folder contents" : "Klasör içeriği yüklenemedi",
    "Team space breadcrumbs" : "Takım alanı sayfa yolu",
    "Switch to list view" : "Liste görünümüne geç",
    "Switch to grid view" : "Izgara görünümüne geç",
    "Open folder in Files" : "Klasörü Dosyalar uygulamasında aç",
    "Folder contents unavailable" : "Klasör içeriği kullanılamıyor",
    "Empty folder" : "Klasör boş",
    "This team space is empty." : "Bu takım alanı boş.",
    "Folder contents" : "Klasör içeriği",
    "Preview of {name}" : "{name} ön izlemesi",
    "Folder" : "Klasör",
    "Team owner" : "Takım sahibi",
    "you" : "siz",
    "Team actions" : "Takım işlemleri",
    "Manage team" : "Takım yönetimi",
    "Copy link" : "Bağlantıyı kopyala",
    "Leave team" : "Takımdan çık",
    "Delete team" : "Takımı sil",
    "An error happened during the config change" : "Yapılandırma değiştirilirken bir sorun çıktı",
    "Confirm enabling federation" : "Birliği kullanılmasını onayla",
    "Enabling this will prevent {circle} from being a member of other teams.\nAre you sure?" : "Birlik kullanıldığında, {circle} diğer takımların üyesi olamayacak.\nEmin misiniz?",
    "Enable federation" : "Birlik kullanılsın",
    "Copied" : "Kopyalandı",
    "Could not copy" : "Kopyalanamadı",
    "Create link" : "Bağlantı oluştur",
    "This action will make it impossible to join the team using the current link. Do we really want to change the link?" : "Bu işlem, var olan bağlantıyı kullanarak takıma katılmayı engelleyecek. Bağlantıyı gerçekten değiştirmek istiyor musunuz?",
    "Reset link" : "Bağlantıyı sıfırla",
    "This action will make it impossible to join the team using the current link. Do we really want to delete the link?" : "Bu işlem, var olan bağlantıyı kullanarak takıma katılmayı engelleyecek. Bağlantıyı gerçekten silmek istiyor musunuz?",
    "Reject link" : "Bağlantıyı reddet",
    "Enforce password protection on files shared to this team" : "Bu takımla paylaşılan dosyalar için parola koruması zorunlu kılınsın",
    "Use a unique password for all shares to this team" : "Bu takımdaki tüm paylaşımlar için benzersiz bir parola kullanılsın",
    "Unique password …" : "Benzersiz parola…",
    "Change unique password" : "Benzersiz parolayı değiştir",
    "Failed to save password. Please try again later." : "Parola kaydedilemedi. Lütfen bir süre sonra yeniden deneyin.",
    "Close" : "Kapat",
    "Choose a team picture" : "Bir takım görseli seçin",
    "There is no description for this team" : "Bu takım için bir açıklama yok",
    "Enter a description for the team" : "Takım için bir açıklama yazın",
    "Team space" : "Takım alanı",
    "Create a shared team space for this team." : "Bu takım için paylaşılan bir takım alanı oluşturun.",
    "New folder" : "Yeni klasör",
    "Folder name" : "Klasör adı",
    "This will create a regular folder shared with the team." : "Bu işlem, takım ile paylaşılan normal bir klasör oluşturacak.",
    "Talk conversation" : "Konuş görüşmesi",
    "New Talk conversation" : "Yeni Konuş görüşmesi",
    "Conversation name" : "Görüşme adı",
    "Collective" : "Topluluk",
    "Calendar" : "Takvim",
    "New calendar" : "Yeni takvim",
    "Calendar name" : "Takvim adı",
    "Could not load team space" : "Takım alanı yüklenemedi",
    "Could not create the team space" : "Takım alanı oluşturulamadı",
    "Unknown resource type" : "Kaynak türü bilinmiyor",
    "Team calendar \"{resourceName}\" created and shared with team" : "\"{resourceName}\" takım takvimi oluşturuldu ve takımla paylaşıldı",
    "{resourceType} \"{resourceName}\" created and shared with team" : "{resourceType} \"{resourceName}\" oluşturuldu ve takımla paylaşıldı",
    "A calendar named \"{name}\" already exists. Please choose a different name." : "\"{name}\" adında bir takvim zaten var. Lütfen başka bir ad seçin.",
    "Failed to create {resourceType}: {error}" : "{resourceType} oluşturulamadı: {error}",
    "Please select a valid png or jpg file" : "Lütfen geçerli bir png ya da jpg dosyası seçin",
    "Error picking team picture" : "Takım görseli alınırken sorun çıktı",
    "Error cropping avatar picture" : "Avatar görseli kırpılırken sorun çıktı",
    "An error happened while saving {fields}" : "{fields}kaydedilirken bir sorun çıktı",
    "Description" : "Açıklama",
    "Upload team picture" : "Takım görseli yükle",
    "Choose from Nextcloud Files" : "Nextcloud Dosyalar üzerinden seçin",
    "Delete picture" : "Görseli sil",
    "Edit" : "Düzenle",
    "Request to join" : "Girme isteğinde bulun",
    "Create" : "Oluştur",
    "Show in Calendar" : "Takvimde görüntülensin",
    "Your request to join this team is pending approval" : "Bu takıma girme isteğiniz onaylanmayı bekliyor",
    "You are not a member of {circle}" : "{circle} takımının üyesi değilsiniz ",
    "Add" : "Ekle",
    "Edit team picture" : "Takım görselini düzenle",
    "Apply" : "Uygula",
    "Remove {type}" : "{type} sil",
    "Add to group" : "Gruba ekle",
    "Add members to group" : "Gruba üye ekle",
    "Search {types}" : "{types} ara",
    "Add guest" : "Konuk ekle",
    "Loading …" : "Yükleniyor…",
    "No results" : "Herhangi bir sonuç bulunamadı",
    "Add {type}" : "{type} ekle",
    "Promote as sole owner" : "Sahip olarak ata",
    "Promote to {level}" : "{level} düzeyine yükselt",
    "Demote to {level}" : "{level} düzeyine düşür",
    "Are you sure you want to leave this team? This action cannot be undone." : "Bu takımdan çıkmak istediğinize emin misiniz? Bu işlem geri alınamaz.",
    "Leave team failed." : "Takımdan çıkılamadı.",
    "Could not delete the member {displayName}" : "{displayName} üyesi silinemedi",
    "Could not change the member level to {level}" : "Üye düzeyi {level} olarak değiştirilemedi",
    "Could not accept membership request" : "Üyelik isteği kabul edilemedi",
    "Accept membership request" : "Üyelik isteğini kabul et",
    "Reject membership request" : "Üyelik isteğini reddet",
    "Manage level" : "Düzeyi değiştir",
    "Remove member" : "Üyeyi kaldır",
    "Pending" : "Bekliyor",
    "Unable to get the results" : "Sonuçlar alınamadı",
    "Some members could not be added" : "Bazı üyeler eklenemedi",
    "There was an issue adding members to the team" : "Üyeler takıma eklenirken bir sorun çıktı",
    "There was an error fetching the member list" : "Üye listesi alınırken bir sorun çıktı",
    "The list of members is only visible to members of this team" : "Üye listesi yalnızca bu takımdaki üyeler tarafından görülebilir",
    "Search among current members" : "Var olan üyelerde ara",
    "Role" : "Rol",
    "Filter by role" : "Role göre süz",
    "Loading members list …" : "Üye listesi yükleniyor…",
    "No members found matching your search" : "Aramanıza uyan bir üye bulunamadı",
    "You currently have no access to the member list" : "Şu anda üye listesine erişme izniniz yok ",
    "Add to {team}" : "{team} içine ekle",
    "Invite members to {team}" : "{team} takıma üyeler davet edin",
    "Your teams and everything shared with them across Nextcloud." : "Takımlarınız ve onlarla Nextcloud üzerinde paylaştığınız her şey.",
    "Could not load teams" : "Takımlar yüklenemedi",
    "Something went wrong while loading your teams." : "Takımlarınız yüklenirken bir sorun çıktı.",
    "Try again" : "Yeniden dene",
    "No teams yet" : "Henüz bir takım yok",
    "Create your first team to start collaborating." : "İş birliği yapmaya başlamak için ilk takımınızı oluşturun.",
    "Create your first team" : "İlk takımınızı oluşturun",
    "Your teams" : "Takımlarınız",
    "You have joined the team {circleName}." : "{circleName} takımına katıldınız",
    "Loading" : "Yükleniyor",
    "Invitation to the team" : "Takım daveti",
    "You are already a member of the team <b>{circleName}</b>." : "Zaten <b>{circleName}</b> takımının bir üyesisiniz.",
    "Go to team page" : "Takım sayfasına git",
    "You already requested to join the team <b>{circleName}</b>." : "Zaten <b>{circleName}</b> takımına katılma isteğinde bulunmuşsunuz.",
    "Go back" : "Geri dön",
    "Do you want to join the team <b>{circleName}</b>?" : "<b>{circleName}</b> takımına katılmak ister misiniz?",
    "Join" : "Katıl",
    "Invalid invitation link" : "Davet bağlantısı geçersiz",
    "This invitation link is not valid or has expired." : "Bu davet bağlantısı geçersiz ya da süresi geçmiş.",
    "Team space unavailable" : "Takım alanı kullanılamıyor",
    "Could not load the team space. Please try again later." : "Takım alanı yüklenemedi. Bir süre sonra yeniden deneyin.",
    "Could not load the team" : "Takım yüklenemedi",
    "Team not found" : "Takım bulunamadı",
    "This team may have been removed." : "Bu takım kaldırılmış olabilir.",
    "Failed to load teams" : "Takımlar yüklenemedi",
    "Join or create teams to see them here." : "Girdiğiniz ve oluşturduğunuz takımlar burada görüntülenir",
    "Loading…" : "Yükleniyor…",
    "More teams" : "Diğer takımlar",
    "Link copied to the clipboard" : "Bağlantı panoya kopyalandı",
    "Could not copy link to the clipboard" : "Bağlantı panoya kopyalanamadı",
    "Are you sure you want to leave {team}?" : "{team} takımından çıkmak istediğinize emin misiniz?",
    "You left \"{name}\"" : "\"{name}\" takımından ayrıldınız",
    "Could not leave the team" : "Takımdan çıkılamadı",
    "Are you sure you want to delete {team}? This cannot be undone." : "\"{team}\" takımını silmek istediğinize emin misiniz? Bu işlem geri alınamaz",
    "Team deleted" : "Takım silindi",
    "Could not delete the team" : "Takım silinemedi",
    "Join team" : "Takıma gir",
    "You are about to leave {circle}.\nAre you sure?" : "{circle} takımından çıkmak üzeresiniz.\nBunu yapmak istediğinize emin misiniz?",
    "Please confirm team leave" : "Lütfen takımdan çıkmak istediğinizi onaylayın",
    "Could not leave the team {displayName}" : "{displayName} takımından çıkılamadı",
    "Unable to join the team" : "Takıma girilemedi",
    "You are about to delete {circle}.\nAre you sure?" : "{circle} takımını silmek üzeresiniz.\nBunu yapmak istediğinize emin misiniz?",
    "Please confirm team deletion" : "Lütfen takımı silmek istediğinizi onaylayın",
    "Unable to delete the team" : "Takım silinemedi",
    "Could not copy link to the clipboard." : "Bağlantı panoya kopyalanamadı.",
    "All contacts" : "Tüm kişiler",
    "Not grouped" : "Gruplanmamış",
    "Recently contacted" : "Son görüşülenler",
    "Organization chart" : "Organizasyon şeması",
    "Contacts settings" : "Kişiler ayarları",
    "Create your own teams for sharing. Add Nextcloud users, contacts, or anyone via email." : "Paylaşmak için kendi takımlarınızı oluşturun. Nextcloud kullanıcılarını, kişilerini veya herhangi birini e-posta adresi ile ekleyin.",
    "User" : "Kullanıcı",
    "Group" : "Grup",
    "Email" : "E-posta",
    "Invites" : "Davetler",
    "Anyone can request membership" : "Herkes üyelik isteğinde bulunabilir",
    "Members need to accept invitation" : "Üyeler daveti kabul etmelidir",
    "Memberships must be confirmed/accepted by a Moderator (requires \"Anyone can request membership\")" : "Üyelikler bir sorumlu tarafından onaylanmalıdır (\"Herkes üyelik isteğinde bulunabilir\" seçeneği açık olmalıdır)",
    "Members can also invite" : "Üyeler de davet gönderebilir",
    "Invitation links" : "Davet bağlantıları",
    "Membership" : "Üyelik",
    "Prevent teams from being a member of another team" : "Bu takım başka bir takıma üye olarak eklenemesin",
    "Federation" : "Birlik",
    "Allow federated members" : "Birleşmiş üyeler kullanılabilsin",
    "Privacy" : "Gizlilik",
    "Visible to everyone" : "Herkes görebilir",
    "users" : "kullanıcı",
    "Users" : "Kullanıcılar",
    "groups" : "grup",
    "Groups" : "Gruplar",
    "federated users" : "birleşik kullanıcı",
    "Federated users" : "Birleşik kullanıcılar",
    "teams" : "takım",
    "email addresses" : "e-posta adresi",
    "Email addresses" : "E-posta adresleri",
    "contacts" : "kişi",
    "Contacts" : "Kişiler",
    "An error has occurred in team(s). Check the console for more details." : "Takımlarda bir sorun çıktı. Ayrıntılı bilgi almak için konsola bakabilirsiniz.",
    "Unable to create team {circleName}" : "{circleName} takımı oluşturulamadı",
    "Unable to delete team {circleId}" : "{circleId} takımı silinemedi",
    "No files in here" : "Burada herhangi bir dosya yok",
    "No entries found in this folder" : "Bu klasörde herhangi bir kayıt yok",
    "Name" : "Ad",
    "Size" : "Boyut",
    "Modified" : "Değiştirilme",
    "Circles App Initialization" : "Takımlar uygulaması başlatılıyor"
},
"nplurals=2; plural=(n > 1);");
