OC.L10N.register(
    "bruteforcesettings",
    {
    "Brute-force settings" : "Konfigurimet e brute-force",
    "Comment" : "Koment",
    "Add" : "Shto",
    "Save" : "Ruaje"
},
"nplurals=2; plural=(n != 1);");
