OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Довод личних активности корисника %s",
    "Your feed URL is invalid" : "УРЛ вашег довода није исправан",
    "Activity feed for %1$s" : "Niz aktivnosti %1$s\n ",
    "Activity feed" : "Niz aktivnosti",
    "Your settings have been updated." : "Ваше поставке су ажуриране.",
    "Settings have been updated." : "Поставке су ажуриране.",
    "Recent activity" : "Poslednja aktivnost",
    "No activities" : "Nema aktivnosti",
    "More activities" : "Još aktivnosti",
    "Daily activity summary for %s" : "Izveštaj dnevnih aktivnosti za %s",
    "All activities" : "Све активности",
    "By others" : "туђе",
    "By you" : "ваше",
    "Hello %s" : "Здраво %s",
    "Hello %s," : "Здраво %s,",
    "There was some activity at %s" : "Било је активности у %s ",
    "_and %n more _::_and %n more _" : ["и још %n","и још %n","и још %n"],
    "Mail" : "поштом",
    "Activity" : "Активност",
    "Notifications" : "Obaveštenja",
    "Today" : "данас",
    "Yesterday" : "јуче",
    "More" : "Ostalo",
    "You need to set up your email address before you can receive notification emails." : "Морате поставити адресу е-поште пре почетка пријема обавештења.",
    "Send activity emails" : "Шаљи е-пошту са активностима",
    "As soon as possible" : "Што је пре могуће",
    "Hourly" : "сваки сат",
    "Daily" : "дневно",
    "Weekly" : "недељно",
    "in {path}" : "у {path}",
    "Home" : "Почетна",
    "This stream will show events like additions, changes & shares" : "Овде ће се приказати догађаји попут додавања, измена или дељења",
    "No activity yet" : "Још нема активности",
    "Enable RSS feed" : "Укључи РСС довод",
    "RSS feed" : "РСС довод",
    "Default settings" : "Подразумеване поставке",
    "No more events to load" : "Нема више догађаја за приказ"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
