OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "Анхны ажиллуулалтын шидтэн",
    "Add your profile information! For example your email is needed to receive notifications." : "Профайлын мэдээллээ нэмээрэй! Жишээ нь мэдэгдэл хүлээн авахад таны имэйл шаардлагатай.",
    "Add your profile information! For example your email is needed to receive notifications and reset your password." : "Профайлын мэдээллээ нэмээрэй! Жишээ нь мэдэгдэл хүлээн авах болон нууц үг сэргээхэд таны имэйл шаардлагатай.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Профайлын мэдээллээ нэмээрэй! Бүх функцуудад хялбар таних боломжтой болгохын тулд профайл зураг болон бүтэн нэрээ тохируулна уу.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Профайлын мэдээллээ нэмээрэй! Бүх функцуудад хялбар таних боломжтой болгохын тулд бүтэн нэрээ тохируулна уу.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Профайлын мэдээллээ нэмээрэй! Бүх функцуудад хялбар таних боломжтой болгохын тулд профайл зургаа тохируулна уу.",
    "App recommendation: Calendar" : "Апп санал болгох: Календар",
    "Schedule work & meetings, synced with all your devices." : "Ажил, уулзалт товлох, бүх төхөөрөмжтэй синк хийх.",
    "App recommendation: Contacts" : "Апп санал болгох: Харилцагчид",
    "Keep your colleagues and friends in one place without leaking their private info." : "Хамтран ажиллагчид болон найзуудаа нэг дор байлгаж, тэдний хувийн мэдээллийг алдагдуулахгүй байна уу.",
    "App recommendation: Mail" : "Апп санал болгох: Имэйл",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Файл, Харилцагчид болон Календартай сайхан нэгтгэгдсэн энгийн имэйл програм.",
    "App recommendation: Tasks" : "Апп санал болгох: Даалгаврууд",
    "Sync tasks from various devices with your Nextcloud and edit them online." : "Төрөл бүрийн төхөөрөмжийн даалгавруудыг Nextcloud-тай синхрончилж, онлайнаар засварлана уу.",
    "App recommendation: Deck" : "Апп санал болгох: Deck",
    "Kanban style organization for personal planning and team projects." : "Хувийн төлөвлөлт болон багийн төслүүдэд зориулсан Kanban загварын зохион байгуулалт.",
    "App recommendation: Forms" : "Апп санал болгох: Маягтууд",
    "Simple surveys and questionnaires, self-hosted" : "Энгийн судалгаа ба асуулгууд, өөрийн сервертэй",
    "App recommendation: Recognize" : "Апп санал болгох: Танилт",
    "Smart media tagging for Nextcloud" : "Nextcloud-н ухаалаг медиа таглах",
    "App recommendation: Group folders" : "Апп санал болгох: Бүлгийн хавтсууд",
    "Admin-configured folders shared by everyone in a group." : "Бүлгийн бүх хүн хуваалцдаг админ тохируулсан хавтсууд.",
    "App recommendation: Whiteboard" : "Апп санал болгох: Цагаан самбар",
    "Create and share whiteboards with others and collaborate in real-time." : "Бусадтай цагаан самбар үүсгэж хуваалцаж, бодит цагт хамтран ажиллах.",
    "Connect your calendar" : "Календараа холбох",
    "Connect your contacts" : "Харилцагчдаа холбох",
    "Access files via WebDAV" : "WebDAV-аар файлуудад хандах",
    "Download macOS/iOS configuration profile" : "macOS/iOS тохиргооны профайл татах",
    "Desktop client" : "–∑–∞—Ö–∏–∞–ª–∞–≥—á–∏–π–Ω –¥—ç–ª–≥—ç—Ü",
    "Android app on Google Play Store" : "Google Play Store дээрх Android апп",
    "Android app on F-Droid" : "F-Droid дээрх Android апп",
    "iOS app" : "iOS апп",
    "About & What's new" : "Тухай ба Шинэ юу байна",
    "A welcome and introduction wizard for Nextcloud" : "Nextcloud-н угтах ба танилцуулах шидтэн",
    "This application enables a pop-up window when a user first logs into Nextcloud. This window welcomes new users to Nextcloud, and contains links to the standard desktop client, Android app, and the iOS app. The window also shows a link for accessing Nextcloud via WebDAV. At any time, the first run wizard can be opened again via link \"About\" on settings menu.\nThe First run wizard can be customized to meet specific design goals, or to change links and messages. Create an appropriate theme following the Theming documentation, and changes to the look and feel of this Wizard are simple. More information is available in the first run wizard documentation, as well as the theming documentation." : "Энэ апп нь хэрэглэгч Nextcloud-д анх удаа нэвтрэх үед гарч ирэх цонхыг идэвхжүүлнэ. Энэ цонх шинэ хэрэглэгчдийг Nextcloud-д тавтай морилно уу гэж угтаж, стандарт ширээний клиент, Android апп болон iOS аппын линкүүдийг агуулна. Мөн WebDAV-аар Nextcloud-д хандах линкийг харуулна. Тохиргооны цэсний \"Тухай\" линкээр дамжуулан анхны ажиллуулалтын шидтэнг хэзээ ч дахин нээх боломжтой.\nАнхны ажиллуулалтын шидтэнг тодорхой загварын зорилгод нийцүүлж эсвэл линк, мэдэгдлүүдийг өөрчлөхөөр тохируулж болно. Загварчлалын баримт бичгийг дагаж тохирох загвар үүсгэвэл энэ шидтэний харагдах байдлыг өөрчлөх нь хялбар юм. Нэмэлт мэдээллийг анхны ажиллуулалтын шидтэний баримт бичиг болон загварчлалын баримт бичгээс авах боломжтой.",
    "Download on Apple app store" : "Apple app store дээр татах",
    "Download on Google play store" : "Google play store дээр татах",
    "Go to previous page" : "Өмнөх хуудас руу очих",
    "Close" : "‚Äì‚Ä¢‚Äì‚àû‚Äì‚àû‚Äî√ñ",
    "More about Nextcloud" : "Nextcloud-н талаар дэлгэрэнгүй",
    "Extend the functionality of Nextcloud with hundreds of community-developed apps." : "Олон зуун нийгэмлэгийн боловсруулсан аппаар Nextcloud-ийн функцийг өргөжүүлээрэй.",
    "Be a part of the community that helps build, design, translate and promote Nextcloud!" : "Nextcloud-ийг бүтээж, дизайнлаж, орчуулж, сурталчлахад тусалдаг нийгэмлэгийн нэг хэсэг болоорой!",
    "Find out more about your Nextcloud setup with the admin, user or developer documentation." : "Администратор, хэрэглэгч эсвэл хөгжүүлэгчийн баримт бичгээс Nextcloud-ийн тохиргооны талаар дэлгэрэнгүй мэдээлэл аваарай.",
    "Get Nextcloud Enterprise for mission critical environments where advanced security and compliance are important." : "Ахисан түвшний аюулгүй байдал болон нийцэл чухал байдаг чухал орчинд зориулж Nextcloud Enterprise авна уу.",
    "Seamless integration with your devices." : "Төхөөрөмжүүдтэй саадгүй нэгтгэл.",
    "Sync your files across your devices with the desktop and mobile apps, and connect your calendar and contacts." : "Ширээний болон гар утасны аппуудаар файлуудаа төхөөрөмжүүд дээрээ синхрончилж, календарь болон харилцагчдаа холбоорой.",
    "Download For Windows, Mac OS and Linux." : "Windows, Mac OS болон Linux-д татах.",
    "Connect your calendar and contacts with your devices." : "Календар ба харилцагчдаа төхөөрөмжүүдтэйгээ холбоно уу.",
    "Welcome to {cloudName}!" : "{cloudName}-д тавтай морилно уу!",
    "Skip" : "–ê–ª–≥–∞—Å–∞—Ö",
    "This Nextcloud is on version {version}" : "Энэ Nextcloud {version} хувилбар дээр байна",
    "A collaboration platform that puts you in control" : "Таныг хянах эрх олгодог хамтын ажиллагааны платформ",
    "Privacy" : "Нууцлал",
    "Host your data and files where you decide." : "Өгөгдөл ба файлуудаа өөрийн шийдсэн газар байршуулах.",
    "Productivity" : "Бүтээмж",
    "Collaborate and communicate across any platform." : "Ямар ч платформ дээр хамтран ажиллаж харилцах.",
    "Interoperability" : "Уялдаа холбоо",
    "Import and export anything you want with open standards." : "Нээлттэй стандартаар хүссэн бүхнээ импорт экспорт хийх.",
    "Community" : "Нийгэмлэг",
    "Enjoy constant improvements from a thriving open-source community." : "Цэцэглэж буй нээлттэй эхийн нийгэмлэгийн байнгын сайжруулалтыг ашиглах.",
    "Nextcloud Hub {version} release" : "Nextcloud Hub {version} хувилбар",
    "Read more about it on the Nextcloud Hub {version} blog" : "Nextcloud Hub {version} блог дээр дэлгэрэнгүй унших",
    "Find out more on the blog" : "Блог дээр дэлгэрэнгүй үзэх",
    "Read the Nextcloud Hub {version} blog" : "Nextcloud Hub {version} блогийг унших",
    "Share your opinion about Nextcloud Hub {version}" : "Nextcloud Hub {version}-н талаарх санал бодлоо хуваалцах",
    "Share via email" : "–ò–º—ç–π–ª—ç—ç—Ä —Ö—É–≤–∞–∞–ª—Ü–∞—Ö",
    "Share on {socialMedia}" : "{socialMedia} дээр хуваалцах",
    "New in Nextcloud Hub {version}" : "Nextcloud Hub {version}-д шинэ",
    "Connect other apps to {productName}" : "Бусад апп-уудыг {productName}-тай холбох",
    "Besides the mobile apps and desktop client you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to {productName}." : "Гар утасны аппууд болон ширээний клиентээс гадна WebDAV/CalDAV/CardDAV протоколуудыг дэмждэг бусад аливаа програмыг {productName}-д холбож болно.",
    "Apps to connect to {productName}" : "{productName}-тай холбогдох апп-ууд",
    "Set up sync clients using an {linkStart}app password{linkEnd}. That way you can make sure you are able to revoke access in case you lose that device." : "{linkStart}аппын нууц үг{linkEnd} ашиглан синхрончлолын клиентүүдийг тохируулна уу. Ингэснээр төхөөрөмжөө алдсан тохиолдолд хандалтыг цуцлах боломжтой болно.",
    "Get the apps to sync your files" : "Файлуудаа синк хийх апп-уудыг авах",
    "{productName} gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "{productName} нь та хаана ч байсан файлуудад тань хандах боломж олгоно. Бидний ашиглахад хялбар ширээний болон гар утасны клиентүүд бүх томоохон платформд үнэгүй ашиглах боломжтой.",
    "App for syncing" : "Синк хийх апп",
    "URL copied" : "URL хуулагдсан",
    "Could not copy the URL, please copy manually" : "URL хуулж чадсангүй, гараар хуулна уу",
    "Server address" : "—Ö“Ø–ª—ç—ç–Ω –∞–≤–∞–≥—á–∏–π–Ω —Ö–∞—è–≥",
    "Use this link to connect your apps and desktop client to this server:" : "Апп болон ширээний клиентээ энэ сервертэй холбохын тулд энэ холбоосыг ашиглана уу:",
    "Experience the brand new Nextcloud Hub!" : "Шинэ Nextcloud Hub-г туршина уу!",
    "Get to know the new features of Hub {version}" : "Hub {version}-ийн шинэ функцуудтай танилцаарай",
    "What's new?" : "Шинэ юу байна?",
    "Nextcloud on all your devices" : "Бүх төхөөрөмж дээрх Nextcloud",
    "Nextcloud Hub {version}" : "Nextcloud Hub {version}",
    "Share on social media" : "Сошиал медиад хуваалцах",
    "Get started!" : "Эхэлцгээе!",
    "Global redesign and usability lift" : "Глобал дахин дизайн ба хэрэглээний сайжруулалт",
    "New Office UI: colors, tabs, bars" : "Шинэ Office UI: өнгөнүүд, табууд, баарууд",
    "Performance and stability boost" : "Гүйцэтгэл ба тогтвортой байдлын сайжруулалт",
    "New AI Agency tools unlocked" : "Шинэ AI Agency хэрэгслүүд нээгдлээ",
    "Talk threads & live transcription" : "Talk хэлэлцүүлгүүд ба шууд бичгэлэг",
    "Calendar: date poll for participants" : "Календар: оролцогчдын огноо санал асуулга",
    "Intuitive file search" : "Ойлгомжтой файл хайлт",
    "Teams 2.0 & quick Guest accounts" : "Teams 2.0 ба хурдан Зочин бүртгэлүүд",
    "Quick presets & many other admin updates" : "Хурдан урьдчилсан тохиргоонууд ба бусад админ шинэчлэлтүүд",
    "Vue3, WebSockets and more OpenAPI for devs" : "Хөгжүүлэгчдэд Vue3, WebSockets ба OpenAPI",
    "Growing sovereignty: new federation features, improved data export and import" : "Бүрэн эрхт байдлыг нэмэгдүүлэх: холбооны шинэ боломжууд, сайжруулсан өгөгдлийн экспорт ба импорт",
    "Nextcloud Talk: live translations, pinned messages, scheduling" : "Nextcloud Talk: шууд орчуулга, тогтоосон мессежүүд, цаг товлолт",
    "Office document comparison" : "Оффисын баримт бичгийг харьцуулах",
    "Whiteboard: comments, reactions, timers" : "Цагаан самбар: сэтгэгдэл, урвалууд, цагийн тоолуур",
    "Nextcloud Assistant performance upgrade and AI labeling" : "Nextcloud Assistant гүйцэтгэлийн сайжруулалт болон AI шошгололт",
    "Powerful E2EE in the web interface" : "Вэб интерфэйс дэх хүчирхэг E2EE",
    "Speed-up with ADA engine" : "ADA системээр хурдасгах"
},
"nplurals=2; plural=(n != 1);");
