OC.L10N.register(
    "settings",
    {
    "{actor} added you to group {group}" : "{actor} Вас је додао у групу {group}",
    "You added {user} to group {group}" : "Додали сте корисника {user} у групу {group}",
    "{actor} added {user} to group {group}" : "{actor} је додао корисника {user} у групу {group}",
    "An administrator added you to group {group}" : "Администратор Вас је додао у групу {group}",
    "An administrator added {user} to group {group}" : "Администратор је додао корисника {user} у групу {group}",
    "{actor} removed you from group {group}" : "{actor} Вас је уклонио из групе {group}",
    "You removed {user} from group {group}" : "Уклонили сте корисника {user} из групе {group}",
    "{actor} removed {user} from group {group}" : "{actor} је уклонио корисника {user} из групе {group}",
    "An administrator removed you from group {group}" : "Администратор Вас је уклонио из групе {group}",
    "An administrator removed {user} from group {group}" : "Администратор је уклонио корисника {user} из групе {group}",
    "Your <strong>group memberships</strong> were modified" : "Ваше <strong>чланство у групи</strong> је измењено",
    "{actor} changed your password" : "{actor} је променио Вашу лозинку",
    "You changed your password" : "Променили сте лозинку",
    "Your password was reset by an administrator" : "Администратор је ресетовао Вашу лозинку",
    "Your password was reset" : "Ваша лозинка је ресетована",
    "{actor} changed your email address" : "{actor} је изменио адресу Ваше е-поште",
    "You changed your email address" : "Променили сте адресу е-поште",
    "Your email address was changed by an administrator" : "Администратор је изменио адресу Ваше е-поште",
    "You created an app password for a session named \"{token}\"" : "Креирали сте лозинку апликације за сесију под називом „{token}",
    "An administrator created an app password for a session named \"{token}\"" : "Администратор је креирао лозинку апликације за сесију под називом „{token}”",
    "You deleted app password \"{token}\"" : "Обрисали сте апликативну лозинку „{token}“",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Преименовали сте апликативну лозинку „{token}“ у „{newToken}“",
    "You granted filesystem access to app password \"{token}\"" : "Апликативном токену „{token}“ сте одобрили приступ систему фајлова",
    "You revoked filesystem access from app password \"{token}\"" : "Апликативном токену „{token}“ сте укинули одобрење приступу систему фајлова",
    "Security" : "Безбедност",
    "You successfully logged in using two-factor authentication (%1$s)" : "Успешно сте се пријавили са двофакторском провером идентитета (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Пријава са двофакторском провером идентитета неуспела (%1$s)",
    "Remote wipe was started on %1$s" : "Удаљено брисање је започето %1$s",
    "Remote wipe has finished on %1$s" : "Удаљено брисање је завршено %1$s",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Ваша <strong>лозинка</strong> или <strong>адреса е-поште</strong> је измењена",
    "Wrong password" : "Погрешна лозинка",
    "Unable to change personal password" : "Лична лозинка не може да се промени",
    "Saved" : "Сачувано",
    "No Login supplied" : "Није наведено име за пријаву",
    "Unable to change password" : "Не могу да променим лозинку",
    "Unable to change password. Password too long." : "Лозинка не може да се промени. Сувише је дугачка.",
    "Authentication error" : "Грешка при провери идентитета",
    "Please provide an admin recovery password; otherwise, all account data will be lost." : "Молимо вас да наведете администраторску лозинку за опоравак; у супротном, нестаће сви подаци са налога.",
    "Wrong admin recovery password. Please check the password and try again." : "Погрешна администраторска лозинка опоравка. Проверите лозинку и покушајте поново.",
    "Backend does not support password change, but the encryption of the account key was updated." : "Позадински механизам не подржава промену лозинке, али је ажуриран кључ налога за шифрирање.",
    "Administrator documentation" : "Администраторска документација",
    "User documentation" : "Корисничка документација",
    "Nextcloud help overview" : "Преглед помоћи за Nextcloud ",
    "Invalid SMTP password." : "Неисправна SMTP лозинка.",
    "Email setting test" : "Тестирај поставке е-поште",
    "Well done, %s!" : "Свака част, %s!",
    "If you received this email, the email configuration seems to be correct." : "Ако добијате ову е-пошту, подешавања е-поште су вам исправна.",
    "Email could not be sent. Check your mail server log" : "Не могу да пошаљем Е-пошта. Погледајте записнике сервера е-поште",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Појавио се проблем приликом слања е-поште. Проверите ваше поставке. (Грешка: %s)",
    "You need to set your account email before being able to send test emails. Go to %s for that." : "Пре слања тест и-мејлова морате најпре да поставите и-мејл адресу вашег налога. Посетите %s и поставите је.",
    "Recently active" : "Недавно активно",
    "Disabled accounts" : "Искључени налози",
    "Settings" : "Поставке",
    "Invalid account" : "Неисправан налог",
    "Invalid mail address" : "Неисправна е-адреса",
    "Settings saved" : "Подешавања сачувана",
    "Unable to change full name" : "Не могу да променим пуно име",
    "Unable to change email address" : "Не могу да изменим адресу е-поште",
    "Unable to set invalid phone number" : "Не може да се постави неисправан број телефона",
    "Unable to set invalid website" : "Не може да се постави неисправни веб сајт",
    "Some account data was invalid" : "Неки подаци у налогу нису исправни",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Да бисте верификовали Ваш Твитер налог, окачите следећи твит (пазите само да не преламате редове у твиту):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Да бисте верификовали веб сајт, поставите следећи садржај у корени директоријум веб сајта на '.well-known/CloudIdVerificationCode.txt' (пазите само да је цео текст у једној линији):",
    "%1$s changed your password on %2$s." : "%1$s је изменио Вашу лозинку на %2$s.",
    "Your password on %s was changed." : "Ваша лозинка на %s је измењена.",
    "Your password on %s was reset by an administrator." : "Администратор на %s је ресетовао Вашу лозинку.",
    "Your password on %s was reset." : "Ваша лозинка са %s је ресетована.",
    "Password for %1$s changed on %2$s" : "Лозинка за %1$s промењена на %2$s",
    "Password changed for %s" : "Лозинка на %s промењена.",
    "If you did not request this, please contact an administrator." : "Ако нисте Ви ово захтевали, контактирајте администратора.",
    "Your email address on %s was changed." : "Адреса Ваше е-поште на %s је измењена.",
    "Your email address on %s was changed by an administrator." : "Администратор на %s је изменио адресу Ваше е-поште.",
    "Email address for %1$s changed on %2$s" : "Адреса е-поште за %1$s промењена на %2$s",
    "Email address changed for %s" : "Адреса е-поште на %s промењена",
    "The new email address is %s" : "Адреса е-поште је сад %s",
    "Appearance and accessibility" : "Изглед и приступачност",
    "Personal settings" : "Лична подешавања",
    "Administration settings" : "Административна подешавања",
    "Accounts" : "Налози",
    "Help & privacy" : "Помоћ и приватност",
    "Your %s account was created" : "Ваш %s налог је направљен",
    "Welcome aboard" : "Добродошли",
    "Welcome aboard %s" : "Добродошли %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Добродошли у Ваш %s налог, сада можете додавати, штитити и делити Ваше податке.",
    "Your Login is: %s" : "Ваше име за пријаву је: %s",
    "Set your password" : "Поставите лозинку",
    "Go to %s" : "Иди на %s",
    "Install Client" : "Инсталирајте клијенте",
    "Logged in account must be a sub admin" : "Пријављени налог мора бити под администратор",
    "Personal" : "Лично",
    "Administration" : "Администрација",
    "Users" : "Корисници",
    "Additional settings" : "Додатне поставке",
    "Assistant" : "Асистент",
    "Administration privileges" : "Привилегије за администрацију",
    "Groupware" : "Радни тимови",
    "Office" : "Канцеларија",
    "Overview" : "Преглед",
    "Quick presets" : "Сачуване поставке брзих подешавања",
    "Basic settings" : "Основне поставке",
    "Sharing" : "Дељење",
    "Availability" : "Доступност",
    "Calendar" : "Календар",
    "Personal info" : "Лични подаци",
    "Mobile & desktop" : "Мобилни и десктоп",
    "Artificial Intelligence" : "Вештачка интелигенција",
    "Email server" : "Сервер е-поште",
    "Mail Providers" : "Пружаоци услуге поште",
    "Mail provider enables sending emails directly through the user's personal email account. At present, this functionality is limited to calendar invitations. It requires Nextcloud Mail 4.1 and an email account in Nextcloud Mail that matches the user's email address in Nextcloud." : "Пружалац услуге поште омогућава директно слање и-мејлова кроз корисников лични и-мејл налог. Тренутно је ова функционалност ограничена на календарске позивнице. Захтева Nextcloud Mail 4.1 и и-мејл налог у Nextcloud Mail који се подудара са корисниковом и-мејл адресом у Nextcloud.",
    "Send emails using" : "Шаљи и-мејлове користећи",
    "User's email account" : "Корисников и-мејл налог",
    "System email account" : "Системски и-мејл налог",
    "Security & setup checks" : "Провере безбедности и поставки",
    "Settings presets" : "Сачуване поставке подешавања",
    "Background jobs" : "Послови у позадини",
    "Unlimited" : "Неограничено",
    "Verifying" : "Проверавам",
    "Verifying …" : "Проверавам …",
    "Verify" : "Провери",
    "Allowed admin IP ranges" : "Дозвољени админ IP опсези",
    "Admin IP filtering isn't applied." : "Није примењено филтрирање админ IP адреса.",
    "Configuration key \"%1$s\" expects an array (%2$s found). Admin IP range validation will not be applied." : "Конфигурациони кључ „%1$s” очекује вредност типа низ (пронађено је %2$s). Неће се применити валидација админ IP опсега.",
    "Configuration key \"%1$s\" contains invalid IP range(s): \"%2$s\"" : "Конфигурациони кључ „%1$s” садржи неисправни IP опсег (или више њих) „%2$s”",
    "Admin IP filtering is correctly configured." : "Филтрирање админ IP адреса је исправно подешено.",
    "App directories owner" : "Власник директоријума апликације",
    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:\n%s" : "Власник неких директоријума апликације није исти као власник веб сервера. Ово може да се деси ако су апликације инсталиране ручно. Проверите дозволе следећих директоријума апликације:\n%s",
    "App directories have the correct owner \"%s\"" : "Директоријуми апликације имају исправног власника „%s”",
    "Brute-force Throttle" : "Пригушивање напада грубом силом",
    "Your remote address could not be determined." : "Не може да се одреди ваша удаљена адреса.",
    "Your remote address was identified as \"%s\" and is brute-force throttled at the moment slowing down the performance of various requests. If the remote address is not your address this can be an indication that a proxy is not configured correctly." : "Ваша удаљена адреса је идентификована као „%s” и тренутно је пригушена због напада грубом силом чиме се успоравају перформансе разних захтева. Ако удаљена адреса није ваша, ово може бити знак да прокси није исправно подешен. ",
    "Your remote address \"%s\" is not brute-force throttled." : "Ваша удаљена адреса „%s” није пригушена због напада грубом силом.",
    "Old administration imported certificates" : "Стари сертификати које је увезла администрација",
    "A background job is pending that checks for administration imported SSL certificates. Please check back later." : "Позадински посао за проверу SSL сертификата које је увезла администрација је на чекању. Молимо вас да проверите касније.",
    "There are some administration imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Присутни су неки SSL сертификати које је увезла администрација и који се више не користе у Nextcloud 21. Могу да се увезу из командне линије извршавањем команде „occ security:certificates:import”. Њихове путање унутар директоријума са подацима су приказане испод.",
    "Code integrity" : "Интегритет кода",
    "Integrity checker has been disabled. Integrity cannot be verified." : "Провера интегритета је искључена. Интегритет не може да се потврди.",
    "No altered files" : "Нема измењених фајлова",
    "Some files have not passed the integrity check. {link1} {link2}" : "Неки фајлови нису прошли проверу интегритета. {link1} {link2}",
    "List of invalid files…" : "Листа неисправних фајлова…",
    "Rescan…" : "Поново скенирај",
    "Cron errors" : "Cron грешке",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:\n%s" : "Cron посао није могао да се изврши из CLI. Дошло је до следећих техничких грешака:\n%s",
    "The last cron job ran without errors." : "Последњи cron посао се извршио без грешака.",
    "Cron last run" : "Последње извршавање cron",
    "Last background job execution ran %s. Something seems wrong. {link}." : "Последње извршавање посла у позадини је трајало %s. Изгледа да нешто није у реду. {link}.",
    "Last background job execution ran %s." : "Последње извршавање позадинског посла је трајало %s.",
    "Data directory protected" : "Директоријум са подацима је заштићен",
    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Вашем директоријуму са подацима и фајловама вероватно може да се приступи са интернета. Фајл .htaccess не функционише. Изричито препоручујемо да свој веб сервер подесите тако да се забрани приступ директоријуму са подацима, или да да преместите ван кореног директоријума докумената вашег веб сервера.",
    "Could not check that the data directory is protected. Please check manually that your server does not allow access to the data directory." : "Није могло да се провери да ли је диреторијум са подацима заштићен. Молимо вас да ручно проверите да ли ваш сервер дозвољава приступ директоријуму са подацима.",
    "Database missing columns" : "У бази података недостају колоне",
    "Missing optional column \"%s\" in table \"%s\"." : "У табели „%s” недостаје необавезна колона „%s”.",
    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "У бази недостају неке опционе колоне. Пошто додавање колона на великим табелама може да потраје, нису додате аутоматски, а пошто су и опционе. Покретањем „occ db:add-missing-columns“ , додаћете ове колоне за време рада инстанце. Када се ове колоне додају, неке функционалности можда буду брже или употребљивије.",
    "Database missing indices" : "У бази података недостају индекси",
    "Missing indices:" : "Индекси који недостају:",
    "\"%s\" in table \"%s\"" : "„%s” у табели „%s”",
    "Detected some missing optional indices. Occasionally new indices are added (by Nextcloud or installed applications) to improve database performance. Adding indices can sometimes take awhile and temporarily hurt performance so this is not done automatically during upgrades. Once the indices are added, queries to those tables should be faster. Use the command `occ db:add-missing-indices` to add them." : "Откривено је да недостају неки индекси који нису обавезни. Да би се унапредиле перформансе базе података (сам Nextcloud или инсталиране апликације) повремено додају нове индексе. Понекад то може да потраје и привремено може да смањи перформансе тако да се не ради аутоматски током ажурирања. Једном када се индекси додају, упити над тим табелама би требало да се брже извршавају. Да бисте их додали, употребите команду `occ db:add-missing-indices`.",
    "Database missing primary keys" : "У бази података недостају примарни кључеви",
    "Missing primary key on table \"%s\"." : "У табели „%s” недостаје примарни кључ.",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "У бази података недостају неки примарни кључеви. Услед тога што операција додавања примарних кључева у велике табеле може да потраје, они нису додати аутоматски. Извршавањем команде „occ db:add-missing-primary-keys” би се ти примарни кључеви ручно додали док инстанца несментано ради.",
    "Database pending bigint migrations" : "У бази података су на чекањи bigint миграције",
    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline." : "Неке колоне у бази података нису претворене у big int тип. Пошто у великим табелама промена типа колоне може доста да потраје, оне нису аутоматски промењене. Извршавањем команде „occ db:convert-filecache-bigint” ће се применити ове преостале измене. Ова операција се мора урадити док инстанца не ради.",
    "Debug mode" : "Режим отклањања грешака",
    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "Ова инстанца се извршава у дибаг режиму. Укључите га само за локални развој, никако у продукционом окружењу.",
    "Debug mode is disabled." : "Режим отклањања грешака је искључен.",
    "Default phone region" : "Подразумевани телефонски позивни број",
    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective ISO 3166-1 code of the region to your config file." : "Ваша инсталација нема постављен подразумевани телефонски позивни број. Ово је неопходно за проверу бројева телефона у подешавањима профила без кода земље. Ако желите да дозволите бројеве без кода земље, молимо вас да у свој конфигурациони фајл додате „default_phone_region” са одговарајућим ISO 3166-1 кодом региона.",
    "Email test" : "Тест и-мејла",
    "Mail delivery is disabled by instance config \"%s\"." : "Испорука поште је искључена конфигурацијом инстанце „%s”.",
    "Email test was successfully sent" : "Успешно је послат тест и-мејл ",
    "You have not set or verified your email server configuration, yet. Please head over to the \"Basic settings\" in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "Још увек нисте поставили или потврдили своју конфигурацију е-поште. Молимо вас пређите на „Основна подешавања” да је поставите. Након тога, употребите дугме „Пошаљи имејл” испод форме и потврдите своја подешавања.",
    "Transactional File Locking" : "Трансакционо закључавање фајла",
    "Transactional File Locking is disabled. This is not a a supported configuraton. It may lead to difficult to isolate problems including file corruption. Please remove the `'filelocking.enabled' => false` configuration entry from your `config.php` to avoid these problems." : "Трансакционо закључавање фајла је искључено. Ова конфигурација се не подржава. Услед ње може бити отежано изоловање проблема као што је кварење фајла. Да бисте спречили ове проблеме, молимо вас да из свог `config.php` фајла уклоните ставку конфигурације `'filelocking.enabled' => false`.",
    "The database is used for transactional file locking. To enhance performance, please configure memcache, if available." : "База података се користи за трансакционо закључавање фајлова. Да бисте побољшали перформансе, молимо вас да конфигуришете memcache, ако је то могуће.",
    "Forwarded for headers" : "Прослеђено за заглавља",
    "Your \"trusted_proxies\" setting is not correctly set, it should be an array." : "Ваше trusted_proxies” подешавање није исправно постављено, требало би да буде низ.",
    "Your \"trusted_proxies\" setting is not correctly set, it should be an array of IP addresses - optionally with range in CIDR notation." : "Нисте исправно поставили „trusted_proxies” подешавање, требало би да буде низ IP адреса – са опсегом у CIDR нотацији који није обавезан.",
    "The reverse proxy header configuration is incorrect. This is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud." : "Конфигурација заглавља реверсног проксија није исправна. Ово је безбедносни проблем који нападачу може дозволити да лажира своју IP адресу у адресу  коју види Nextcloud.",
    "Your IP address was resolved as %s" : "Ваша IP адреса је разрешена као %s",
    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud." : "Или су подешавања заглавља реверсног проксија неисправна, или Nextcloud инстанци приступате кроз прокси којем се верује. Ако то није случај, ово је безбедносни проблем који нападачу може дозволити да лажира своју IP адресу у адресу коју види Nextcloud.",
    "HTTPS access and URLs" : "HTTPS приступ и URL адресе",
    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead. Without it some important web functionality like \"copy to clipboard\" or \"service workers\" will not work!" : "Сајту се небезбедно приступа преко HTTP протокола. Снажно се препоручује да свој сервер подесите тако да уместо њега захтева HTTPS протокол. Без њега неке битне веб функције, као што је „копирај у клипборд” или „сервисни радници” неће радити!",
    "Accessing site insecurely via HTTP." : "Сајту се приступа небезбедно преко HTTP.",
    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This likely means that your instance is behind a reverse proxy and the Nextcloud `overwrite*` config values are not set correctly." : "Вашој инстанци приступате преко безбедне везе, међутим, ова инстанца генерише небезбедне URL адресе. Ово највероватније значи да се ваша инстанца налази иза реверсног проксија и да вредности  `overwrite*` променљивих Nextcloud конфигурације нису исправно постављене.",
    "Your instance is generating insecure URLs. If you access your instance over HTTPS, this likely means that your instance is behind a reverse proxy and the Nextcloud `overwrite*` config values are not set correctly." : "Ваша инстанца генерише небезбедне URL адресе. Ако јој приступате преко HTTPS протокола, ово највероватније значи да се ваша инстанца налази иза реверсног проксија и да вредности `overwrite*` променљивих Nextcloud конфигурације нису исправно постављене.",
    "You are accessing your instance over a secure connection, and your instance is generating secure URLs." : "Вашој инстанци приступате преко безбедне везе и она генерише безбедне URL адресе. ",
    "Internet connectivity" : "Веза са интернетом",
    "Internet connectivity is disabled in configuration file." : "Веза са интернетом је искључена у конфигурационом фајлу.",
    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Овај сервер нема функционалну интернет конекцију: више крајњих тачака није доступно. Ово значи да неће радити неке могућности као што су качење спољних складишта, обавештења о ажурирањима или инсталација апликација треће стране. Приступање фајловима споља и слање обавештења е-поштом исто тако може да не ради. Ако желите да уживате у свим могућностима, обезбедите везу овог сервера са интернетом.",
    "JavaScript modules support" : "Подршка за JavaScript модуле",
    "Unable to run check for JavaScript support. Please remedy or confirm manually if your webserver serves `.mjs` files using the JavaScript MIME type." : "Није могла да се покрене провера JavaScript подршке. Молимо вас да исправите проблем или да ручно потврдите да ваш веб сервер сервира `.mjs` фајлове користећи JavaScript MIME тип.",
    "Your webserver does not serve `.mjs` files using the JavaScript MIME type. This will break some apps by preventing browsers from executing the JavaScript files. You should configure your webserver to serve `.mjs` files with either the `text/javascript` or `application/javascript` MIME type." : "Ваш веб сервер не служи `.mjs` фајлове користећи JavaScript MIME тип. Због тога неке апликације неће радитити јер ће веб прегледачи одбити да изврше JavaScript фајлове. Требало би да ваш веб сервер подесите тако да `.mjs` фајлове служи било са `text/javascript` или са `application/javascript` MIME типом.",
    "JavaScript source map support" : "Подршка за JavaScript мапе извора",
    "Your webserver is not set up to serve `.js.map` files. Without these files, JavaScript Source Maps won't function properly, making it more challenging to troubleshoot and debug any issues that may arise." : "Ваш веб сервер није подешен да сервира  `.js.map` фајлове. Без ових фајлова, JavaScript Мапе Извора неће функционисати како треба, па ће бити теже пронаћи грешке и исправити било какве проблеме који могу да се јаве.",
    "Old server-side-encryption" : "Старо шифровање на серверској страни",
    "Disabled" : "Искључено",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "Укључен је стари формат шифровања на серверској страни. Препоручујемо да га искључите.",
    "Logging level" : "Ниво бележења",
    "The %1$s configuration option must be a valid integer value." : "Опција конфигурације %1$s мора да буде исправна целобројна  вредност.",
    "The logging level is set to debug level. Use debug level only when you have a problem to diagnose, and then reset your log level to a less-verbose level as it outputs a lot of information, and can affect your server performance." : "Ниво бележења је постављен на дибаг ниво. Дибаг ниво би требало да користите само током испитивања проблема, па да га онда вратите на неки мање детаљни ниво, јер он исписује много информација и то може негативно да утиче на перформансе вашег сервера.",
    "Logging level configured correctly." : "Ниво бележења је исправно подешен.",
    "Maintenance window start" : "Почетак перода за одржавање",
    "Server has no maintenance window start time configured. This means resource intensive daily background jobs will also be executed during your main usage time. We recommend to set it to a time of low usage, so users are less impacted by the load caused from these heavy tasks." : "Није подешено време почетка периода за одржавање сервера. То значи да ће се током времена уобичајене употребе такође извршавати и дневни позадински послови који захтевају доста ресурса. Препоручујемо вам да га подесите у време када се систем не користи интензивно, тако да оптерећење које изазивају ови обимни задаци има мањи утицај на кориснике.",
    "Maintenance window to execute heavy background jobs is between {start}:00 UTC and {end}:00 UTC" : "Период одржавања за извршавање захтевних позадинских послова је између {start}:00 UTC и {end}:00 UTC",
    "Memcache" : "Memcache",
    "Memcached is configured as distributed cache, but the wrong PHP module (\"memcache\") is installed. Please install the PHP module \"memcached\"." : "Memcached је подешен као дистрибуирани кеш, али је инсталиран погрешан PHP модул („memcache”). Молимо вас да инсталирате PHP модул „memcached”.",
    "Memcached is configured as distributed cache, but the PHP module \"memcached\" is not installed. Please install the PHP module \"memcached\"." : "Memcached је подешен као дистрибуирани кеш, али није инсталиран PHP модул „memcached”. Молимо вас да инсталирате PHP модул „memcached”.",
    "No memory cache has been configured. To enhance performance, please configure a memcache, if available." : "Није подешено никакво кеширање у меморији. Да бисте побољшали перформансе, молимо вас да конфигуришете memcache, ако је то могуће.",
    "Failed to write and read a value from local cache." : "Није успело читање и упис вредности из локалног кеша.",
    "Failed to write and read a value from distributed cache." : "Није успело читање и упис вредности из дистрибуираног кеша.",
    "Configured" : "подешено",
    "Mimetype migrations available" : "Доступне mimetype миграције",
    "One or more mimetype migrations are available. Occasionally new mimetypes are added to better handle certain file types. Migrating the mimetypes take a long time on larger instances so this is not done automatically during upgrades. Use the command `occ maintenance:repair --include-expensive` to perform the migrations." : "Доступна је једна или више mimetype миграција. Повремено се додају нови mime типови да би се боље обрађивали одрећени типови фајлова. Миграција mime типова дуже траје на већим инстанцама, тако да се током ажурирања то не ради аутоматски. Да бисте извршили миграцијем употребите команду `occ maintenance:repair --include-expensive`.",
    "MySQL row format" : "MySQL формат реда",
    "You are not using MySQL" : "Не користите MySQL",
    "None of your tables use ROW_FORMAT=Compressed" : "Ниједна од ваших табела не користи ROW_FORMAT=Compressed",
    "Incorrect row format found in your database. ROW_FORMAT=Dynamic offers the best database performances for Nextcloud. Please update row format on the following list: %s." : "У вашој бази података је пронађен неисправан формат реда. ROW_FORMAT=Dynamic обезбеђује најбоље перформансе базе података за Nextcloud. Молимо вас да у следећој листи ажурирате формат реда: %s.",
    "MySQL Unicode support" : "MySQL Уникод подршка",
    "MySQL is used as database and does support 4-byte characters" : "MySQL се користи као база података и не подржава карактере дужине 4 бајта",
    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL." : "Као база података се користи MySQL, али не подржава карактере дужине 4 бајта. Препоручује се да у MySQL укључите подршку за карактере дужине 4 бајта да би се у именима фајлова и коментарима, на пример, без проблема обрадили карактери дужине 4 бајта (као што су емођи).",
    "OCS provider resolving" : "Разрешавање пружаоца OCS услуге",
    "Could not check if your web server properly resolves the OCM and OCS provider URLs." : "Не може да се провери да ли ваш веб сервер исправно разрешава URL адресе пружаоца OCM и OCS услуге.",
    "Your web server is not properly set up to resolve %1$s.\nThis is most likely related to a web server configuration that was not updated to deliver this folder directly.\nPlease compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx.\nOn Nginx those are typically the lines starting with \"location ~\" that need an update." : "Ваш веб сервер није исправно подешен да разреши %1$s.\nОво је највероватније везано за конфигурацију веб сервера која није ажурирана тако да директно достави овај фолдер.\nМолимо вас да упоредите своју конфигурацију са оном испорученом уз програм и поново испишите правила у „.htaccess” за Apache, или приложену у документацији за Nginx.\nНа Nginx су обично линије које почињу са „location ~” оне које треба да се преправе.",
    "Overwrite CLI URL" : "Overwrite cli URL",
    "The \"overwrite.cli.url\" option in your config.php is correctly set to \"%s\"." : "„overwrite.cli.url” опција у вашем config.php је исправно постављена на „%s”.",
    "The \"overwrite.cli.url\" option in your config.php is set to \"%s\" which is a correct URL. Suggested URL is \"%s\"." : "„overwrite.cli.url” опција у вашем config.php је исправно постављена на „%s” и то је исправни URL. Препоручени URL. је „%s”.",
    "Please make sure to set the \"overwrite.cli.url\" option in your config.php file to the URL that your users mainly use to access this Nextcloud. Suggestion: \"%s\". Otherwise there might be problems with the URL generation via cron. (It is possible though that the suggested URL is not the URL that your users mainly use to access this Nextcloud. Best is to double check this in any case.)" : "Молимо вас да обезбедите да је опција „overwrite.cli.url” у config.php фајлу постављена на URL који ваши корисници углавном користе за приступ овој Nextcloud инстанци. Предлог: „%s”. У супротном може доћи до проблема са генерисањем URL преко cron. (Мада је могуће да предложени URL није URL који ваши корисници углавном користе да приступе овој Nextcloud инстанци. У сваком случају је најбоље да се ово провери.)",
    "PHP APCu configuration" : "PHP APCu конфигурација",
    "Your APCu cache has been running full, consider increasing the apc.shm_size php setting." : "Ваш APCu кеш је пун, покушајте да увећате вредност apc.shm_size php подешавања.",
    "Your APCu cache is almost full at %s%%, consider increasing the apc.shm_size php setting." : "Ваш APCu кеш је скоро пун на %s%%, покушајте да увећате apc.shm_size php подешавање.",
    "PHP default charset" : "Подразумевани PHP скуп знакова",
    "PHP configuration option \"default_charset\" should be UTF-8" : "PHP кофигурациона опција „default_charset би требало да има вредност UTF-8",
    "PHP set_time_limit" : "PHP set_time_limit",
    "The function is available." : "Функција је доступна.",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "PHP функција „set_time_limit“ није доступна. Ово може да узрокује да се скрипте закоче у сред извршавања, и тако покваре инсталацију. Препоручује се да омогућите ову функцију.",
    "Freetype" : "Freetype",
    "Supported" : "Подржана",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Ваша PHP инсталација нема подршку за FreeType. Ово ће довести до неисправних профилних слика и неисправног интерфејса за подешавања.",
    "PHP getenv" : "PHP getenv",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP изгледа није исправно подешен да дохвата променљиве окружења. Тест са getenv(\"PATH\") враћа празну листу као одговор.",
    "PHP file size upload limit" : "PHP ограничење величине фајла који се отпрема",
    "The PHP upload_max_filesize is too low. A size of at least %1$s is recommended. Current value: %2$s." : "PHP вредност upload_max_filesize је сувише мала. Препоручује се барем %1$s. Тренутна вредност: %2$s.",
    "The PHP post_max_size is too low. A size of at least %1$s is recommended. Current value: %2$s." : "PHP вредност post_max_size је сувише мала. Препоручује се барем %1$s. Тренутна вредност: %2$s.",
    "The PHP max_input_time is too low. A time of at least %1$s is recommended. Current value: %2$s." : "PHP вредност max_input_time је сувише мала. Препоручује се барем %1$s. Тренутна вредност: %2$s.",
    "The PHP max_execution_time is too low. A time of at least %1$s is recommended. Current value: %2$s." : "PHP вредност max_execution_time је сувише мала. Препоручује се барем %1$s. Тренутна вредност: %2$s.",
    "PHP memory limit" : "Ограничење PHP меморије",
    "The PHP memory limit is below the recommended value of %s. Some features or apps - including the Updater - may not function properly." : "Ограничење PHP меморије је испод препоручене вредности од %s. Неке функције или апликације - укључујући и апликацију за ажурирање - можда неће радити како треба.",
    "PHP modules" : "PHP модули",
    "increases language translation performance and fixes sorting of non-ASCII characters" : "Побољшава перформансе превођења језика и исправља сортирање карактера који нису ASCII",
    "required for SFTP storage and recommended for WebAuthn performance" : "неопходно за SFTP складиште и препоручено за WebAuthn перформансе",
    "for picture rotation in server and metadata extraction in the Photos app" : "за ротирање слике на серверу и издвајање метаподатака у апликацији Слике",
    "This instance is missing some required PHP modules. It is required to install them: %s." : "Овој инстанци недостају неки неопходни PHP модули. Потребно је да се инсталирају: %s.",
    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them:\n%s" : "Овој инстанци недостају неки препоручени PHP модули. Препоручује се да их инсталирате због побољшања перформанси и за бољу компатибилност:\n%s",
    "PHP opcache" : "PHP opcache",
    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "PHP модул OPcache није учитан. Да би се постигле боље перформансе, препоручује се да га учитате у своју PHP инсталацију.",
    "OPcache is disabled. For better performance, it is recommended to apply \"opcache.enable=1\" to your PHP configuration." : "OPcache је искључен. Да би се постигле боље перформансе, препоручује се да у своју PHP конфигурацију поставите „opcache.enable=1”.",
    "The shared memory based OPcache is disabled. For better performance, it is recommended to apply \"opcache.file_cache_only=0\" to your PHP configuration and use the file cache as second level cache only." : "OPcache заснован на дељеној меморији је искључен. Да би се постигле боље перформансе, препоручује се да у вашој PHP конфигурацији поставите „opcache.file_cache_only=0” и фајл кеш користите само као кеш другог нивоа.",
    "OPcache is not working as it should, opcache_get_status() returns false, please check configuration." : "OPcache не функционише како би требало, функција opcache_get_status() враћа false, молимо вас да проверите конфигурацију.",
    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be kept in the cache, it is recommended to apply \"opcache.max_accelerated_files\" to your PHP configuration with a value higher than \"%s\"." : "Максимални број OPcache кључева ће ускоро бити премашен. Да би се обезбедило да се све скрипте налазе у кешу, препоручује са да у вашој PHP конфигурацији поставите „opcache.max_accelerated_files” на вредност већу од „%s”.",
    "The OPcache buffer is nearly full. To assure that all scripts can be hold in cache, it is recommended to apply \"opcache.memory_consumption\" to your PHP configuration with a value higher than \"%s\"." : "OPcache бафер је скоро испуњен. Да би се обезбедило да се све скрипте чувају у кешу, препоручује се да у вашој PHP конфигурацији поставите „opcache.memory_consumption” на вредност већу од „%s”.",
    "The OPcache interned strings buffer is nearly full. To assure that repeating strings can be effectively cached, it is recommended to apply \"opcache.interned_strings_buffer\" to your PHP configuration with a value higher than \"%s\"." : "OPcache бафер притворених стрингова је скоро испуњен. Да би се обезбедило ефективно кеширање стрингова који се понављају, препоручује се да у вашој PHP конфигурацији поставите „opcache.interned_strings_buffer” на вредност већу од „%s”.",
    "OPcache is configured to remove code comments. With OPcache enabled, \"opcache.save_comments=1\" must be set for Nextcloud to function." : "OPcache је подешен тако да уклања коментаре у коду. Да би Nextcloud функционисао, уз укључени OPcache мора да се постави и „opcache.save_comments=1”.",
    "Nextcloud is not allowed to use the OPcache API. With OPcache enabled, it is highly recommended to include all Nextcloud directories with \"opcache.restrict_api\" or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Забрањено је да Nextcloud користи OPcache API. Уз укључен OPcache, снажно се препоручује да се у „opcache.restrict_api” укључе сви Nextcloud  директоријуми, или да се ово подешавање искључи, како би се уклонила ограничења за OPcache API. Тиме се спречавају грешке током ажурирања основног Nextcloud кода или апликација.",
    "Checking from CLI, OPcache checks have been skipped." : "Проверава се из CLI, прескочене су OPcache провере.",
    "The PHP OPcache module is not properly configured. %s." : "PHP модул OPcache није исправно подешен. %s.",
    "Correctly configured" : "Исправно подешен",
    "PHP version" : "PHP верзија",
    "You are currently running PHP %1$s. PHP %2$s is deprecated since Nextcloud %3$s. Nextcloud %4$s may require at least PHP %5$s. Please upgrade to one of the officially supported PHP versions provided by the PHP Group as soon as possible." : "Тренутно се извршава PHP %1$s. PHP %2$s је застарео почевши од Nextcloud %3$s. Nextcloud %4$s може да захтева барем PHP %5$s. Молимо вас да што је пре могуће извршите ажурирање на једну од званично подржаних PHP верзија које обезбеђује PHP Група.",
    "You are currently running PHP %s." : "Тренутно се извршава PHP %s.",
    "PHP \"output_buffering\" option" : "PHP опција „output_buffering”",
    "PHP configuration option \"output_buffering\" must be disabled" : "PHP конфигурациона опција output_buffering” мора бити искључена",
    "Push service" : "Сервис за брза обавештења",
    "Valid enterprise license" : "Важећа лиценца за предузећа",
    "Free push service" : "Бесплатни сервис за брза обавештења",
    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications are limited to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at {link}." : "Ово је Nextcloud који је изградила заједница и није подржан. Узевши у обзир величину инстанце, перформансе, поузданост и скалабилност не могу да се гарантују. Брза обавештења су ограничена да би се спречило загушење нашег бесплатног сервиса. Сазнајте више о предностима Nextcloud Enterprise на {link}.",
    "Random generator" : "Генератор случајних бројева",
    "No suitable source for randomness found by PHP which is highly discouraged for security reasons." : "PHP није пронашао погодни извор случајности, а из разлога безбедности то никако није пожељно.",
    "Secure" : "Безбедно",
    "Configuration file access rights" : "Права приступа конфигурационом фајлу",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Омогућена је конфигурација само за читање. То спречава постављање неке конфигурације преко веб-интерфејса. Осим тога, фајлу мора бити ручно омогућено уписивање код сваког освежавања.",
    "Nextcloud configuration file is writable" : "Могућ је упис у Nextcloud конфигурациони фајл",
    "Scheduling objects table size" : "Величина табеле за распоред објеката",
    "You have more than %s rows in the scheduling objects table. Please run the expensive repair jobs via occ maintenance:repair --include-expensive." : "У табели за распоред објеката имате више од %s редова. Молимо вас да покренете скупе послове поправке са occ maintenance:repair --include-expensive",
    "Scheduling objects table size is within acceptable range." : "Величина табеле за распоред објеката је унутар прихватљивог опсега.",
    "HTTP headers" : "HTTP заглавља",
    "- The `%1$s` HTTP header is not set to `%2$s`. Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "- HTTP заглавље `%1$s` није подешено на `%2$s`. Неке функције можда неће радити исправно, па се препоручује да га поставите на одговарајућу вредност.",
    "- The `%1$s` HTTP header is not set to `%2$s`. This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "- HTTP заглавље `%1$s` није подешено на `%2$s`. Ово је потенцијални безбедносни ризик или може да угрози приватност, па се препоручује да га поставите на одговарајућу вредност.",
    "- The `%1$s` HTTP header is not set to `%2$s`, `%3$s`, `%4$s`, `%5$s` or `%6$s`. This can leak referer information. See the {w3c-recommendation}." : "- HTTP заглавље  `%1$s` није постављено на `%2$s`, `%3$s`, `%4$s`, `%5$s` или `%6$s`. Услед тога могу процурити информације у упућивачу. Погледајте {w3c-recommendation}.",
    "- The `Strict-Transport-Security` HTTP header is not set to at least `%d` seconds (current value: `%d`). For enhanced security, it is recommended to use a long HSTS policy." : "- HTTP заглавље `Strict-Transport-Security` није постављено на барем `%d` секунди (тренутна вредност је: `%d`). Препорука за унапређену безбедност је да се користи дуготрајна HSTS полиса.",
    "- The `Strict-Transport-Security` HTTP header is malformed: `%s`. For enhanced security, it is recommended to enable HSTS." : "- HTTP заглавље `Strict-Transport-Security` није исправно постављено: `%s`. Препорука за унапређену безбедност је да укључите HSTS.",
    "- The `Strict-Transport-Security` HTTP header is not set (should be at least `%d` seconds). For enhanced security, it is recommended to enable HSTS." : "- HTTP заглавље `Strict-Transport-Security` није постављено (требало би да буде барем `%d` секунди). Препорука за унапређену безбедност је да укључите HSTS.",
    "Some headers are not set correctly on your instance" : "Нека заглавља на вашој инстанци нису исправно подешена",
    "Could not check that your web server serves security headers correctly. Please check manually." : "Није могло да се провери да ли ваш веб сервер исправно сервира безбедносна заглавља. Молимо вас да проверите ручно.",
    "Could not check that your web server serves security headers correctly, unable to query `%s`" : "Није могло да се провери да ли ваш веб сервер исправно сервира безбедносна заглавља, није успео упит `%s`",
    "Your server is correctly configured to send security headers." : "Ваш сервер је исправно подешен за слање безбедносних заглавља.",
    "Configuration server ID" : "ИД сервера за конфигурацију ",
    "Database version" : "Верзија базе података",
    "MariaDB version \"%1$s\" detected. MariaDB >=%2$s and <=%3$s is suggested for best performance, stability and functionality with this version of Nextcloud." : "Детектована је MariaDB верзија „%1$s”. За најбоље перформансе, стабилност и функционалност са овом Nextcloud верзијом, препоручује се MariaDB >=%2$s и <=%3$s.",
    "MySQL version \"%1$s\" detected. MySQL >=%2$s and <=%3$s is suggested for best performance, stability and functionality with this version of Nextcloud." : "Детектована је MySQL верзија „%1$s”. За најбоље перформансе, стабилност и функционалност са овом Nextcloud верзијом, препоручује се MySQL >=%2$s и <=%3$s.",
    "PostgreSQL version \"%1$s\" detected. PostgreSQL >=%2$s and <=%3$s is suggested for best performance, stability and functionality with this version of Nextcloud." : "Детектована је PostgreSQL верзија „%1$s”. За најбоље перформансе, стабилност и функционалност са овом Nextcloud верзијом, препоручује се PostgreSQL >=%2$s и <=%3$s.",
    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend. This is particularly recommended when using the desktop client for file synchronisation. To migrate to another database use the command line tool: \"occ db:convert-type\"." : "Тренутно се као база података позадинског механизма користи SQLite. У случају већих инсталација, препоручујемо вам да пређете на неки други позадински механизам базе података. Ово се посебно препоручује када се за синхронизацију фајлова користи десктоп клијент. За миграцију на другу базу података, употребите алат из командне линије: „occ db:convert-type”.",
    "Unknown database platform" : "Непозната платформа базе података",
    "Architecture" : "Архитектура",
    "64-bit" : "64-бита",
    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit!" : "Изгледа да покрећете 32-битну PHP верзију. За правилно извршавање Nextcloud захтева 64-битну верзију. Молимо вас да ажурирате свој оперативни систем и PHP на 64-бита!",
    "Task Processing pickup speed" : "Брзина прихватања Обраде задатака",
    "_No scheduled tasks in the last day._::_No scheduled tasks in the last %n days._" : ["Нема заказаних задатака током последњег дана.","Нема заказаних задатака током последња %n дана.","Нема заказаних задатака током последњих %n дана."],
    "_The task pickup speed has been ok in the last day._::_The task pickup speed has been ok in the last %n days._" : ["Брзина прихватања задатака је била у реду током последњег дана.","Брзина прихватања задатака је била у реду током последња %n дана.","Брзина прихватања задатака је била у реду током последњих %n дана."],
    "_The task pickup speed has been slow in the last day. Many tasks took longer than 4 minutes to be picked up. Consider setting up a worker to process tasks in the background._::_The task pickup speed has been slow in the last %n days. Many tasks took longer than 4 minutes to be picked up. Consider setting up a worker to process tasks in the background._" : ["Брзина прихватања задатака је била спора током последњег дана. Многим задацима је требало више од 4 минута да се прихвате. Размотрите могућност да подесите радника за обраду задатака у позадини.","Брзина прихватања задатака је била спора током последња %n дана. Многим задацима је требало више од 4 минута да се прихвате. Размотрите могућност да подесите радника за обраду задатака у позадини.","Брзина прихватања задатака је била спора током последњих %n дана. Многим задацима је требало више од 4 минута да се прихвате. Размотрите могућност да подесите радника за обраду задатака у позадини."],
    "_A lot of tasks failed in the last day. Consider checking the nextcloud log for errors and investigating whether the AI provider apps have been set up correctly._::_A lot of tasks failed in the last %n days. Consider checking the nextcloud log for errors and investigating whether the AI provider apps have been set up correctly._" : ["Многи задаци нису успели да се изврше током претходног дана. Проверите Nextcloud дневник и истражите да ли су исправно подешене апликације за пружање AI услуге.","Многи задаци нису успели да се изврше током претходна %n дана. Проверите Nextcloud дневник и истражите да ли су исправно подешене апликације за пружање AI услуге.","Многи задаци нису успели да се изврше током претходних %n дана. Проверите Nextcloud дневник и истражите да ли су исправно подешене апликације за пружање AI услуге."],
    "Temporary space available" : "Доступан привремени простор",
    "Error while checking the temporary PHP path - it was not properly set to a directory. Returned value: %s" : "Грешка приликом провере привремене PHP путање - није била исправно постављена на директоријум. Враћена вредност је: %s",
    "The PHP function \"disk_free_space\" is disabled, which prevents the check for enough space in the temporary directories." : "Искључена је PHP функција „disk_free_space”, па не може да се провери довољна количина слободног простора у привременим директоријумима.",
    "Error while checking the available disk space of temporary PHP path or no free disk space returned. Temporary path: %s" : "Грешка приликом провере доступног простора на диску за привремену PHP путању или уопште није враћен слободан простор на диску. Привремена путања: %s",
    "- %.1f GiB available in %s (PHP temporary directory)" : "- %.1f GiB је доступно у %s (PHP привремени директоријум)",
    "- %.1f GiB available in %s (Nextcloud temporary directory)" : "- %.1f GiB је доступно у %s (Nextcloud привремени директоријум)",
    "Temporary directory is correctly configured:\n%s" : "Привремени директоријум је исправно подешен:\n%s",
    "This instance uses an S3 based object store as primary storage, and has enough space in the temporary directory.\n%s" : "Ова инстанца као основно складиште користи складиште објеката засновано на S3 сервису и има довољно простора у привременом директоријуму.\n%s",
    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GiB of free space available in the temp directory of PHP. To improve this please change the temporary directory in the php.ini or make more space available in that path. \nChecking the available space in the temporary path resulted in %.1f GiB instead of the recommended 50 GiB. Path: %s" : "Ова инстанца као основно складиште користи складиште објеката засновано на S3 сервису. Отпремљени фајлови се привремено чувају на серверу и препоручује се да имате доступно бар 50 GiB слободног простора у PHP привременом директоријуму. Да бисте ово побољшали, измените привремени директоријум у php.ini фајлу или направите више слободног места на тренутној путањи.\nРезултат провере слободног простора на привременој путањи је %.1f GiB уместо препоручених 50 GiB. Путања: %s",
    "Database transaction isolation level" : "Ниво изолације трансакција у бази података",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "База података није покренута са „READ COMMITTED“ нивоом изолације трансакција. Ово може изазвати проблеме ако се више различитих акција изврши у паралели.",
    "Was not able to get transaction isolation level: %s" : "Није успело преузимање нивоа изолације: %s",
    ".well-known URLs" : ".well-known URL адресе",
    "`check_for_working_wellknown_setup` is set to false in your configuration, so this check was skipped." : "`check_for_working_wellknown_setup` је  у вашим подешавањима постављено на false, тако да је ова провера прескочена.",
    "Could not check that your web server serves `.well-known` correctly. Please check manually." : "Није могло да се провери да ли ваш веб сервер исправно сервира `.well-known`. Молимо вас да проверите ручно.",
    "Your web server is not properly set up to resolve `.well-known` URLs, failed on:\n`%s`" : "Ваш веб сервер није исправно подешен и не може да разрешава `.well-known` URL адресе, није успео на адреси:\n`%s`",
    "Your server is correctly configured to serve `.well-known` URLs." : "Ваш сервер је исправно подешен за сервирање `.well-known` URL адреса.",
    "Font file loading" : "Фајл фонта се учитава",
    "Could not check for {extension} loading support. Please check manually if your webserver serves `.{extension}` files." : "Није могла да се провери подршка за учитавање {extension} фајлова. Молимо вас да ручно проверите да ли ваш веб сервер сервира `.{extension}` фајлове.",
    "Your web server is not properly set up to deliver .{extension} files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustment to also deliver .{extension} files. Compare your Nginx configuration to the recommended configuration in our documentation." : "Ваш веб сервер није исправно подешен да испоручи .{extension} фајлове. Ово је обично проблем са Nginx конфигурацијом. За Nextcloud 15 је неопходно да се направе измене у конфигурацији како би могли да се испоруче и .{extension} фајлови. Упоредите своју Nginx конфигурацију са препорученом конфигурацијом у нашој документацији.",
    "Profile information" : "Информације о профилу",
    "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Слика профила, пуно име, и-мејл, број телефона, адреса, веб сајт, Tweeter, организација, улога, насловна линија, биографија и то да ли је ваш профил укључен",
    "Nextcloud settings" : "Nextcloud подешавања",
    "Generate text" : "Генериши текст",
    "Unified task processing" : "Обједињена обрада задатака",
    "AI tasks can be implemented by different apps. Here you can set which app should be used for which task." : "AI  задатке могу да имплементирају разне апликације. Овде можете да подесите која ће се користити за који задатак.",
    "Allow AI usage for guest users" : "Дозволи да корисници гости користе AI",
    "Provider for Task types" : "Пружалац услуге за Типове задатака",
    "Enable" : "Укључи",
    "None of your currently installed apps provide Task processing functionality" : "Ниједна од ваших тренутно инсталираних апликација не пружа функционалност обраде задатака",
    "Machine translation can be implemented by different apps. Here you can define the precedence of the machine translation apps you have installed at the moment." : "Машинско превођење могу да имплементирају разне апликације. Овде можете да дефинишете приоритет апликација машинског превођења које сте тренутно инсталирали.",
    "Image generation can be implemented by different apps. Here you can set which app should be used." : "Генерисање слике могу да имплементирају разне апликације. Овде можете да подесите која ће се користити.",
    "None of your currently installed apps provide image generation functionality" : "Ниједна од ваших тренутно инсталираних апликација не пружа функционалност генерисања слике",
    "Text processing tasks can be implemented by different apps. Here you can set which app should be used for which task." : "Задатке обраде текста могу да имплементирају разне апликације. Овде можете да подесите која ће се користити за који задатак.",
    "Task:" : "Задатак:",
    "None of your currently installed apps provide text processing functionality using the Text Processing API." : "Ниједна од ваших тренутно инсталираних апликација не пружа функционалност обраде текста употребом API за обраду текста.",
    "Here you can decide which group can access certain sections of the administration settings." : "Овде можете да одлучите која група може да приступи одређеним деловима административних подешавања.",
    "Unable to modify setting" : "Подешавање не може да се измени",
    "None" : "Ништа",
    "Changed disclaimer text" : "Промењен је текст ограђивања",
    "Deleted disclaimer text" : "Обрисан је текст ограђивања",
    "Could not set disclaimer text" : "Није могао да се постави текст ограђивања",
    "Allow apps to use the Share API" : "Дозволи апликацијама да користе АПИ дељења",
    "Allow resharing" : "Дозволи дељење даље",
    "Allow sharing with groups" : "Дозволи дељење са групама",
    "Restrict users to only share with users in their groups" : "Ограничи кориснике да могу да деле само унутар групе",
    "Ignore the following groups when checking group membership" : "Игнориши следеће групе када се проверава припадност групи",
    "Allow users to preview files even if download is disabled" : "Дозволи корисницима да прегледају фајлове чак и када је забрањено преузимање",
    "Users will still be able to screenshot or record the screen. This does not provide any definitive protection." : "Корисници ће ипак моћи да направе слику екрана или да сниме екран. Ово не представља дефинитивну заштиту.",
    "Allow users to share via link and emails" : "Дозволи корисницима да деле путем линка и и-мејлова",
    "Allow public uploads" : "Дозволи јавна отпремања",
    "Allow public shares to be added to other clouds by federation." : "Дозволи да се јавна дељења здруживањем додају на остале облаке.",
    "This will add share permissions to all newly created link shares." : "Ово ће додати дозволе дељења свим новокреираним дељењима линком.",
    "Always ask for a password" : "Увек питај за лозинку",
    "Enforce password protection" : "Захтевај заштиту лозинком",
    "Exclude groups from password requirements" : "Изузми групе из захтева за лозинком",
    "Exclude groups from creating link shares" : "Изузми групе из креирања дељења путем линка",
    "Allow users to set custom share link tokens" : "Дозволи да корисници поставе произвољне жетоне линка за дељење",
    "Shares with custom tokens will continue to be accessible after this setting has been disabled" : "Приступ дељењима са произвољним жетонима ће се наставити када се ово подешавање искључи",
    "Shares with guessable tokens may be accessed easily" : "Дељењима са жетонима који могу да се лако погоде може једноставно да се приступи",
    "Limit sharing based on groups" : "Ограничи дељење по групама",
    "Allow sharing for everyone (default)" : "Дозволи дељење свима (подразумевано)",
    "Groups allowed to share" : "Групе које смеју да деле",
    "Groups excluded from sharing" : "Групе изузете од дељења",
    "Not allowed groups will still be able to receive shares, but not to initiate them." : "Забрањеним групама ће моћи да се дели, али оне не могу да иницирају дељење.",
    "Set default expiration date for internal shares" : "Постави подразумевано време истека за интерна дељења",
    "Enforce expiration date" : "Захтевај датум истека",
    "Default expiration time of new shares in days" : "Подразумевано време трајања нових дељења у данима",
    "Expire shares after x days" : "Нека дељења истекну након х дана",
    "Set default expiration date for shares to other servers" : "Постави подразумевани датум истека за дељења са осталим серверима",
    "Enforce expiration date for remote shares" : "Форсирај датум истека за удаљена дељења",
    "Default expiration time of remote shares in days" : "Подразумевано време трајања удаљених дељења у данима",
    "Expire remote shares after x days" : "Нека удаљена дељења истекну након х дана",
    "Set default expiration date for shares via link or mail" : "Постави подразумевано време истека за дељења путем линка или мејла",
    "Enforce expiration date for link or mail shares" : "Форсирај датум истека за дељења линком или мејлом",
    "Default expiration time of shares in days" : "Подразумевано време трајања дељења у данима",
    "Privacy settings for sharing" : "Поставке приватности за дељење",
    "Allow account name autocompletion in share dialog and allow access to the system address book" : "Омогући аутоматско довршавање имена налога у дијалогу дељења и дозволи приступ системском адресару",
    "Sharing autocompletion restrictions" : "Дељење ограничења аутодовршавања",
    "If autocompletion restrictions for both \"same group\" and \"phonebook integration\" are enabled, a match in either is enough to show the user." : "Ако су укључена ограничења аутодовршавања и за „иста група” и за „интеграција броја телефона”, подударање у било којој од њих ће бити довољно да се прикаже кориснику.",
    "Restrict account name autocompletion and system address book access to users within the same groups" : "Ограничи ауто-довршавање имена налога и приступ системском адресару само на кориснике из истих група",
    "Restrict account name autocompletion to users based on their phonebook" : "Ограничи аутоматско довршавање имена налога на кориснике добијене на основу њиховог телефонског именика.",
    "Allow autocompletion to full match when entering the full name (ignoring restrictions like group membership or missing phonebook match)" : "Дозволи аутодовршавање на потпуно подударање када се уноси пуно име (уз игнорисање ограничења као што су припадност групи или недостатак подударања у телефонском именику)",
    "Full match autocompletion restrictions" : "Ограничења аутодовршавања на пуно подударање",
    "Also allow autocompletion on full match of the user ID" : "Дозволи такође и аутодовршавање на пуно подударање ИД корисника",
    "Also allow autocompletion on full match of the user email" : "Дозволи такође и аутодовршавање на пуно подударање корисникове и-мејл адресе",
    "Do not use second user displayname for full match" : "Не користи име за приказ другог корисника за пуно подударање",
    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Прикажи текст о ограђивању на јавној страни за отпремање (приказан је само када је сакривена листа фајлова)",
    "Disclaimer text" : "Текст ограђивања",
    "This text will be shown on the public link upload page when the file list is hidden." : "Овај текст ће бити приказан на јавној страни отпремања када је скривен листа фајлова.",
    "Default share permissions" : "Подразумеване дозволе за дељење",
    "Two-Factor Authentication" : "Двофакторска провера идентитета",
    "Two-factor authentication can be enforced for all accounts and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Двофакторска провера идентитета се може захтевати за све налоге и за одређене групе. Ако немају већ подешеног пружаоца услуге другог фактора, неће моћи да се пријаве на систем.",
    "Enforce two-factor authentication" : "Захтевај двофакторску проверу идентитета",
    "Limit to groups" : "Ограничи на групе",
    "Enforcement of two-factor authentication can be set for certain groups only." : "Двофакторска провера идентитета се може захтевати за само поједине групе.",
    "Two-factor authentication is enforced for all members of the following groups." : "Двофакторска провера идентитета се захтева за све чланове следећих група.",
    "Enforced groups" : "Групе којима се захтева",
    "Two-factor authentication is not enforced for members of the following groups." : "Двофакторска провера идентитета се не захтева за чланове следећих група.",
    "Excluded groups" : "Искључене групе",
    "When groups are selected/excluded, they use the following logic to determine if an account has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If an account is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Када се групе означе/искључе, користи се следећа логика да се закључи да ли се за налог захтева 2FA: ако није одабрана ниједна група, 2FA је укључен свима осим члановима искључених група. Ако има одабраних група, 2FA је укључен само њиховим члановима. Ако је налог у исто време у одабраној и у искљученој групи, одабрана група има предност и 2FA се захтева.",
    "Save changes" : "Сними измене",
    "Failed to load groups" : "Није успело учитавање група",
    "Failed to create group" : "Није успело креирање групе",
    "List of groups. This list is not fully populated for performance reasons. The groups will be loaded as you navigate or search through the list." : "Листа група. Ова листа није у потпуности приказана из разлога перформанси. Групе ће се приказивати како се крећете кроз листу.",
    "Groups" : "Групе",
    "Creating group…" : "Креира се група…",
    "Create group" : "Креирај групу",
    "Group name" : "Назив групе",
    "Please enter a valid group name" : "Молимо вас да унесете исправно име групе",
    "Loading groups…" : "Учитавање група...",
    "Google Chrome for Android" : "Google Chrome за Андроид",
    "{productName} iOS app" : "{productName} iOS апликација",
    "{productName} Android app" : "{productName} Android апликација",
    "{productName} Talk for iOS" : "{productName} Talk за iOS",
    "{productName} Talk for Android" : "{productName} Talk за Android",
    "Sync client" : "Клијент за синхронизовање",
    "This session" : "Ова сесија",
    "{client} - {version} ({system})" : "{client} - {version} ({system})",
    "{client} - {version}" : "{client} - {version}",
    "Confirm wipe" : "Потврда брисања",
    "Do you really want to wipe your data from this device?" : "Да ли стварно желите да обришете податке са овог уређаја?",
    "Wipe device" : "Очисти уређај",
    "Cancel" : "Откажи",
    "Device name" : "Назив уређаја",
    "Cancel renaming" : "Откажи промену имена",
    "Save new name" : "Сачувај ново име",
    "Marked for remote wipe" : "Означено за удаљено брисање",
    "Device settings" : "Подешавања уређаја",
    "Allow filesystem access" : "Дозволи приступ фајловима",
    "Rename" : "Преименуј",
    "Revoke" : "Повуци",
    "Revoking this token might prevent the wiping of your device if it has not started the wipe yet." : "Опозив овог жетона може да спречи брисање вашег уређаја у случају да брисање још увек није започето.",
    "Device" : "Уређај",
    "Last activity" : "Последња активност",
    "Actions" : "Радње",
    "Devices & sessions" : "Уређаји & сесије",
    "Web, desktop and mobile clients currently logged in to your account." : "Веб, рачунарски и мобилни клијенти тренутно пријављени на Ваш налог.",
    "Error while creating device token" : "Грешка при прављењу токена на уређају",
    "App name" : "Назив апликације",
    "Create new app password" : "Направите нову лозинку апликације",
    "App password copied!" : "Копирана је лозинка апликације!",
    "Copy app password" : "Копирај лозинку апликације",
    "Login name copied!" : "Копирано име за пријаву!",
    "Copy login name" : "Копирај име за пријаву",
    "Could not copy app password. Please copy it manually." : "Не могу да копирам апликативну лозинку. Копирајте је ручно.",
    "Could not copy login name. Please copy it manually." : "Није могло да се копира име за лозинку. Молимо вас да је копирате ручно.",
    "New app password" : "Нова лозинка апликације",
    "Use the credentials below to configure your app or device. For security reasons this password will only be shown once." : "Употребите акредититиве наведене испод да конфигуришете двоју апликацију или уређај. Због безбедносних разлога, ова лозинка ће се приказати само једном.",
    "Login" : "Пријава",
    "Password" : "Лозинка",
    "Show QR code for mobile apps" : "Прикажи QR код за мобилне апликације",
    "Use system cron service to call the cron.php file every 5 minutes." : "Користите системски крон сервис за позивање cron.php фајла сваких 5 минута.",
    "The cron.php needs to be executed by the system account \"{user}\"." : "cron.php треба да извршава системски налог „{user}”.",
    "The PHP POSIX extension is required. See {linkstart}PHP documentation{linkend} for more details." : "Потребна је PHP POSIX екстензија. Погледајте {linkstart}PHP документацију{linkend} за више детаља.",
    "Unable to update background job mode" : "Режим позадинског посла не може да се ажурира",
    "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information." : "Да би сервер исправно радио, важно је да се правилно подесе позадински послови. Cron је препоручено подешавање. За још информација, молимо вас да погледате документацију.",
    "Last job execution ran {time}. Something seems wrong." : "Последњи посао се извршавао {time}. Изгледа да нешто није у реду.",
    "Last job ran {relativeTime}." : "Последњи посао се извршавао {relativeTime}.",
    "Background job did not run yet!" : "Позадински посао се још увек није покренуо!",
    "AJAX" : "AJAX",
    "Execute one task with each page loaded. Use case: Single account instance." : "Извршава један задатак за сваку учитану страницу. Случај употребе: инстанца са једним налогом.",
    "Webcron" : "Webcron",
    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 accounts depending on the usage)." : "cron.php се региструје у webcron сервис тако да се cron.php позива преко HTTP сваких 5 минута. Случај употребе: врло мала инстанца (1–5 налога, у зависности од употребе).",
    "Cron (Recommended)" : "Cron (Препоручено)",
    "Unable to update profile default setting" : "Подразумевано подешавање профила не може да се ажурира",
    "Profile" : "Профил",
    "Enable or disable profile by default for new accounts." : "Профил нових налога се подразумевано укључује или искључује.",
    "Password confirmation is required" : "Потребна је потврда лозинке",
    "Failed to save setting" : "Није успело чување подешавања",
    "{app}'s declarative setting field: {name}" : "поље декларативног подешавања апликације {app}: {name}",
    "Unable to update server side encryption config" : "Конфигурација енкрипције на страни сервера не може да се ажурира",
    "Server-side encryption" : "Шифровање на серверској страни",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Шифровање на страни сервера омогућава да фајлови који се стављају на овај сервер буду шифровани. То се може одразити на перформансе па ово укључите само ако вам је потребно.",
    "To encrypt all existing files run this OCC command:" : "Да шифрујете све постојеће фајлове, извршите следећу OCC команду:",
    "Enable server-side encryption" : "Укључи шифровање на серверској страни",
    "Disabling server side encryption is only possible using OCC, please refer to the documentation." : "Искључивање шифровања на страни сервера је могуће само помоћу OCC, молимо вас да погледате документацију.",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Шифрарски модул није учитан. Укључите га у менију апликација",
    "Select default encryption module:" : "Изаберите подразумевани модул за шифровање:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}" : "Морате да мигрирате своје кључеве за шифрирање са старог начина шифирирања (ownCloud <= 8.0) на нови. Молимо вас да укључите „Подразумевани модул за шифрирање” и извршите {command}",
    "Cancel encryption" : "Откажи шифровање",
    "Enable encryption" : "Укључи шифровање",
    "Confirm enabling encryption" : "Потврди укључивање шифровања",
    "Please read carefully before activating server-side encryption:" : "Молимо вас да пажљиво прочитате пре активирања енкрипције на страни сервера:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Једном кад се шифровање укључи, сви фајлови окачени на сервер од тог тренутка ће бити шифровани на серверу. Једини начин да искључите шифровање касније је да активни шифрарски модул то подржава и сви остали услови су задовољени (нпр. постављање кључа за опоравак).",
    "By default a master key for the whole instance will be generated. Please check if that level of access is compliant with your needs." : "Подразумевано е се генерисати мастер кључ за целу инстанцу. Молимо вас да проверите да ли тај ниво приступа задовољава ваше потребе.",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Шифровање само по себи не гарантује безбедност система. Погледајте документацију за више информација како шифровање ради и подржане начине коришћења.",
    "Be aware that encryption always increases the file size." : "Водите рачуна и да шифровање повећава величину фајлова.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Увек је паметно да правите редовне резервне копије података. У случају када су подаци шифровани, онда поред њих и резервне копије кључева за шифровања.",
    "Refer to the admin documentation on how to manually also encrypt existing files." : "Погледајте админ документацију у вези са ручним шифровањем постојећих фајлова.",
    "This is the final warning: Do you really want to enable encryption?" : "Ово је последње упозорење: Да ли стварно желите да укључите шифровање?",
    "Failed to delete group \"{group}\"" : "Није успело брисање групе „{group}”",
    "Please confirm the group removal" : "Молимо вас да потврдите уклањање групе",
    "You are about to delete the group \"{group}\". The accounts will NOT be deleted." : "Управо ћете обрисати групу „{group}”. Налози се НЕЋЕ обрисати.",
    "Confirm" : "Потврди",
    "Submit" : "Пошаљи",
    "Rename group" : "Промени име групе",
    "Delete group" : "Брисање групе",
    "Current password" : "Тренутна лозинка",
    "New password" : "Нова лозинка",
    "Change password" : "Измени лозинку",
    "Choose your profile picture" : "Изаберите слику за свој профил",
    "Please select a valid png or jpg file" : "Молимо вас изаберите исправан png или jpg фајл",
    "Error setting profile picture" : "Грешка приликом постављања слике профила",
    "Error cropping profile picture" : "Грешка приликом опсецања слике профила",
    "Error saving profile picture" : "Грешка приликом чувања слике профила",
    "Error removing profile picture" : "Грешка приликом уклањања слике профила",
    "Your profile picture" : "Ваша слика профила",
    "Upload profile picture" : "Отпреми слику профила",
    "Choose profile picture from Files" : "Изабери слику профила из Фајлова",
    "Remove profile picture" : "Уклони слику профила",
    "The file must be a PNG or JPG" : "Фајл мора да буде PNG или JPG",
    "Picture provided by original account" : "Слика оригиналног налога",
    "Set as profile picture" : "Постави као слику профила",
    "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "Молимо вас да имате на уму да може проћи до 24 часа док се слика вашег профила не ажурира на свим местима.",
    "Your biography. Markdown is supported." : "Ваша биографија. Подржава се употреба Markdown означавања.",
    "Unable to update date of birth" : "Није успело ажурирање датума рођења",
    "Enter your date of birth" : "Унесите датум свог рођења",
    "Bluesky handle" : "Bluesky ручка",
    "You are using {s}{usage}{/s}" : "Користите {s}{usage}{/s}",
    "You are using {s}{usage}{/s} of {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})" : "Користите {s}{usage}{/s} од {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})",
    "Details" : "Детаљи",
    "You are a member of the following groups:" : "Члан сте следећих група:",
    "Your full name" : "Ваше пуно име",
    "Unable to update primary email address" : "Примарна и-мејл адреса није могла да се ажурира",
    "Unable to delete additional email address" : "Додатна и-мејл адреса не може да се обрише",
    "No email address set" : "Није постављена адреса е-поште",
    "Email options" : "Опције за и-мејл",
    "Options for additional email address {index}" : "Опције за додатну и-мејл адресу {index}",
    "Remove primary email" : "Уклони примарни и-мејл",
    "Delete email" : "Обриши и-мејл",
    "This address is not confirmed" : "Ова адреса није потврђена",
    "Unset as primary email" : "Постави да није примарни и-мејл",
    "Set as primary email" : "Постави као примарни и-мејл",
    "Additional email address {index}" : "Додатна и-мејл адреса {index}",
    "Unable to delete primary email address" : "Примарна и-мејл адреса не може да се обрише",
    "Unable to add additional email address" : "Не може да се дода додатна и-мејл адреса",
    "Unable to update additional email address" : "Додатна и-мејл адреса није могла да се ажурира",
    "Primary email for password reset and notifications" : "Примарни и-мејл за ресетовање лозинке и обавештења",
    "Your handle" : "Ваша ручка",
    "Derived from your locale ({weekDayName})" : "Закључено из вашег локале подешавања ({weekDayName})",
    "Unable to update first day of week" : "Није успело ажурирање првог дана недеље",
    "Day to use as the first day of week" : "Дан који се користи као први дан недеље",
    "Your headline" : "Ваша насловна линија",
    "No language set" : "Ниједан језик није постављен",
    "Unable to update language" : "Језик није могао да се ажурира",
    "Languages" : "Језици",
    "Help translate" : " Помозите у превођењу",
    "No locale set" : "Није постављен локалитет",
    "Unable to update locale" : "Локалитет није могао да се ажурира",
    "Locales" : "Локалитети",
    "Week starts on {firstDayOfWeek}" : "Недеља почиње у {firstDayOfWeek}",
    "Your city" : "Ваш град",
    "Your organisation" : "Ваша организација",
    "Your phone number" : "Ваш број телефона",
    "Edit your Profile visibility" : "Уредите видљивост вашег профила",
    "Unable to update profile enabled state" : "Није могло да се ажурира стање профила",
    "Enable profile" : "Укључи профил",
    "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "На вашем провилу се поштује рестриктивније подешавање било видљивости, било опсега важења. На пример, ако је видљивост постављена на „Прикажи свима”, а опсег важења на „Приватан”, поштује се „Приватан”.",
    "Unable to update visibility of {displayId}" : "Није успело ажурирање видљивости {displayId}",
    "she/her" : "она/њен",
    "he/him" : "он/њему",
    "they/them" : "они/њима",
    "Your pronouns. E.g. {pronounsExample}" : "Ваше заменице. Нпр. {pronounsExample}",
    "Your role" : "Ваша улога",
    "Timezone" : "Временска зона",
    "Your X (formerly Twitter) handle" : "Ваша X (бивши Twitter) ручка",
    "Your website" : "Ваш веб сајт",
    "Invalid value" : "Неисправна вредност",
    "Unable to update {property}" : "Није успело ажурирање {property}",
    "No {property} set" : "{property} није постављено",
    "Change scope level of {property}, current scope is {scope}" : "Измена опсега важења {property}, тренутни опсег важења је {scope}",
    "Unable to update federation scope of the primary {property}" : "Није успело ажурирање опсега важења федерације примарне {property}",
    "Unable to update federation scope of additional {property}" : "Није успело ажурирање опсега важења федерације додатне {property}",
    "Add additional email" : "Додај додатни и-мејл",
    "Add" : "Додај",
    "Create" : "Креирање",
    "Change" : "Измени",
    "Delete" : "Избриши",
    "Reshare" : "Дели даље",
    "Default config values" : "Подразумеване вредности конфигурације",
    "Applications config" : "Конфигурација апликација",
    "User config" : "Корисничка конфигурација",
    "Bundled applications" : "Испоручене апликације",
    "Enabled applications" : "Укључене апликације",
    "Disabled applications" : "Искључене апликације",
    "Large organization" : "Масивна организација",
    "Big organization" : "Велика организација",
    "Small organization" : "Мала организација",
    "Hosting company" : "Хостинг компанија",
    "University" : "Универзитет",
    "School" : "Школа",
    "Club or association" : "Клуб или удружење",
    "Family" : "Породица",
    "Personal use" : "Лична употреба",
    "Default" : "Подразумевано",
    "Setup errors" : "Грешка у вези са подешавањима",
    "Setup warnings" : "Упозорење у вези са подешавањима",
    "Setup recommendations" : "Препоруке о подешавањима",
    "Default language" : "Подразумевани језик",
    "Common languages" : "Најкоришћенији језици",
    "Other languages" : "Остали језици",
    "Password change is disabled because the master key is disabled" : "Промена лозинке је искључена пошто је главни кључ искључен",
    "No accounts" : "Нема налога",
    "Loading accounts …" : "Учитавају се налози ",
    "List of accounts. This list is not fully rendered for performance reasons. The accounts will be rendered as you navigate through the list." : "Листа налога. Услед разлога везаних за перформансе, ова листа се не приказује у потпуности. Налози ће се приказивати како се будете кретали кроз листу.",
    "Account name" : "Име рачуна",
    "Account updated" : "Налог је ажуриран",
    "Edit account" : "Измени налог",
    "Saving …" : "Чувам …",
    "Save" : "Сачувај",
    "Account name will be autogenerated" : "Име налога ће бити генерисано аутоматски",
    "Account name (required)" : "Име налога (обавезно)",
    "Password (required)" : "Лозинка (обавезно)",
    "Email (required)" : "И-мејл (обавезно)",
    "Email" : "Е-пошта",
    "New account" : "Нови налог",
    "Add new account" : "Додај нови налог",
    "Display name" : "Име за приказ",
    "Either password or email is required" : "Неопходна је или лозинка или и-мејл",
    "Member of the following groups (required)" : "Члан следећих група (неопходно)",
    "Member of the following groups" : "Члан следећих група",
    "Failed to search groups" : "Није успело претраживање група",
    "Set account groups" : "Постави групе налога",
    "Admin of the following groups" : "Админ следећих група",
    "Set account as admin for …" : "Постави налог као админ за ",
    "Language" : "Језик",
    "Set default language" : "Постави подразумевани језик",
    "Manager" : "Менаџер",
    "Quota" : "Квота",
    "Set account quota" : "Постави квоту за налог",
    "_{userCount} account …_::_{userCount} accounts …_" : ["{userCount} налог …","{userCount} налога …","{userCount} налога …"],
    "_{userCount} account_::_{userCount} accounts_" : ["{userCount} налог","{userCount} налога","{userCount} налога"],
    "Total rows summary" : "Резиме укупног броја редова",
    "Scroll to load more rows" : "Скролујте да се учита још редова",
    "Avatar" : "Аватар",
    "Group admin for" : "Администратор групе за",
    "Account backend" : "Позадински механизам за налоге",
    "Storage location" : "Локација складишта",
    "First login" : "Прва пријава",
    "Last login" : "Последња пријава",
    "Account actions" : "Акције налога",
    "Unknown" : "Непознато",
    "Never" : "Никад",
    "{size} used" : "{size} искоришћено",
    "Delete account" : "Обриши рачун",
    "Disconnect all devices and delete local data" : "Раскини везу са свим уређајима и обриши локалне податке",
    "Disable account" : "Искључи налог",
    "Enable account" : "Укључи налог",
    "Resend welcome email" : "Поново пошаљи е-пошту добродошлице",
    "In case of lost device or exiting the organization, this can remotely wipe the {productName} data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "У случају изгубљеног уређаја или напуштања организације, овим се могу удаљено обрисати {productName} подаци са свих уређаја повезаних са налогом {userid}. Ради само ако је уређај повезан на интернет.",
    "Remote wipe of devices" : "Удаљено брисање уређаја",
    "Wipe {userid}'s devices" : "Обриши уређај од корисника {userid}",
    "Wiped {userid}'s devices" : "Обрисани уређаји корисника {userid}",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "Комплетно брисање уређаја са налога корисника {userid} укључујући све личне фајлове, апликативне податке, итд.",
    "Account deletion" : "Брисање налога",
    "Delete {userid}'s account" : "Обриши налог корисника {userid}",
    "Welcome mail sent!" : "Е-пошта добродошлице послата!",
    "Loading account …" : "Налог се учитава …",
    "Toggle account actions menu" : "Укључи/искључи мени са акцијама налога",
    "Edit" : "Измени",
    "Account management settings" : "Подешавања управљања налозима",
    "Visibility" : "Видљивост",
    "Show language" : "Прикажи језик",
    "Show account backend" : "Прикажи позадински механизам за налоге",
    "Show storage path" : "Прикажи путању до складишта",
    "Show first login" : "Прикажи прву пријаву",
    "Show last login" : "Прикажи последњу пријаву",
    "Sorting" : "Сортирање",
    "The system config enforces sorting the groups by name. This also disables showing the member count." : "Конфигурација система форсира сортирање група по имену. Ово такође искључује приказ броја чланова.",
    "Group list sorting" : "Сортирање листе група",
    "Sorting only applies to the currently loaded groups for performance reasons. Groups will be loaded as you navigate or search through the list." : "Из разлога перформанси, сортирање се примењује само на тренутно учитане групе. Групе ће се учитавати како се крећете кроз листу.",
    "By member count" : "По броју чланова",
    "By name" : "По имену",
    "Send email" : "Пошаљи е-пошту",
    "Send welcome email to new accounts" : "Пошаљи и-мејл добродошлице новим налозима",
    "Defaults" : "Пордазумеване",
    "Default quota" : "Подразумевана квота",
    "Select default quota" : "Одаберите подразумевану квоту",
    "Search" : "Претрага",
    "Help" : "Помоћ",
    "Show those shortcuts" : "Прикажи те пречице",
    "Server error while trying to complete WebAuthn device registration" : "Серверска грешка при завршетку регистрације WebAuthn уређаја",
    "Passwordless authentication requires a secure connection." : "Пријављивање без лозинке захтева безбедну конекцију.",
    "Add WebAuthn device" : "Додајте WebAuthn уређај",
    "Please authorize your WebAuthn device." : "Ауторизујте Ваш WebAuthn уређај.",
    "Adding your device …" : "Додајем Ваш уређај …",
    "Unnamed device" : "Неименовани уређај",
    "Passwordless Authentication" : "Провера идентитета без лозинке",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "Подесите налог за пријављивање без лозинке користећи FIDO2 стандард.",
    "No devices configured." : "Ниједан уређај није подешен.",
    "The following devices are configured for your account:" : "Следећи уређаји су подешени за Ваш налог:",
    "Your browser does not support WebAuthn." : "Ваш веб читач не подржава WebAuthn.",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Важно је да подесите сервер тако да може да шаље е-пошту када нпр. треба послати ресетовање лозинке или нека обавештења.",
    "Send mode" : "Режим слања",
    "Encryption" : "Шифровање",
    "Sendmail mode" : "Sendmail режим",
    "Disable certificate verification (insecure)" : "Искључи проверу сертификата (небезбедно)",
    "From address" : "Са адресе",
    "Domain" : "Домен",
    "Server address" : "Адреса сервера",
    "Host" : "Домаћин",
    "Port" : "Порт",
    "Authentication" : "Провера идентитета",
    "Authentication required" : "Неопходна провера идентитета",
    "Saving…" : "Снимам…",
    "Save settings" : "Сачувај поставке",
    "Please double check the {linkStartInstallationGuides}installation guides{linkEnd}, and check for any errors or warnings in the {linkStartLog}log{linkEnd}." : "Добро погледајте {linkStartInstallationGuides}инсталациону документацију {linkEnd} и проверите за било какве грешке или упозорења у {linkEnd}записнику{linkStartLog}.",
    "Check the security of your {productName} over {linkStart}our security scan{linkEnd}." : "Проверите безбедност своје {productName} инстанце {linkStart}кроз наше безбедоносно скенирање{linkEnd}.",
    "Security & setup warnings" : "Упозорења за безбедност и поставке",
    "It is important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Ради безбедности и перформанси ваше инстанце, важно је да је све подешено исправно. Да бисмо вам помогли у томе, извршићемо неке аутоматске провере. За више информација, погледајте линк на документацију.",
    "Checking your server …" : "Ваш сервер се проверава…",
    "Failed to run setup checks" : "Није успело покретање провера поставки",
    "Try again" : "Покушајте поново",
    "All checks passed." : "Све провере успешно прошле.",
    "There are some errors regarding your setup." : "Постоје неке грешке у вези са Вашом инсталацијом.",
    "There are some warnings regarding your setup." : "Постоје нека упозорења у вези са Вашом инсталацијом.",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Као администратор, можете фино подешавати понашања дељења. Погледајте документацију за више информација.",
    "You need to enable the File sharing App." : "Морате да укључите Апликацију за дељење фајла",
    "Failed to save selected preset." : "Није успело чување изабраног скупа поставки",
    "Select a configuration preset for easy setup." : "За лакше подешавање, изаберите сачувану поставку конфигурације.",
    "Apply" : "Примени",
    "All accounts" : "Сви налози",
    "Admins" : "Администратори",
    "Account group: {group}" : "Група налога: {group}",
    "Account management" : "Управљање налозима",
    "For performance reasons, when you enable encryption on a {productName} server only new and changed files are encrypted." : "Из разлога перформанси, када укључите шифровање само на {productName} серверу, шифрују се нови и измењени фајлови.",
    "Location" : "Локација",
    "Profile picture" : "Слика профила",
    "About" : "О програму",
    "Date of birth" : "Датум рођења",
    "Full name" : "Пуно име",
    "Additional email" : "Додатни и-мејл",
    "Fediverse (e.g. Mastodon)" : "Fediverse (нпр. Mastodon)",
    "Headline" : "Наслов",
    "Organisation" : "Организација",
    "Phone number" : "Број телефона",
    "Pronouns" : "Заменице",
    "Role" : "Улога",
    "X (formerly Twitter)" : "X (бивши Twitter)",
    "Bluesky" : "Bluesky",
    "Website" : "Веб сајт",
    "Profile visibility" : "Видљивост профила",
    "Locale" : "Локалитет",
    "First day of week" : "Први дан недеље",
    "timezone" : "временска зона",
    "Private" : "Приватно",
    "Only visible to people matched via phone number integration through Talk on mobile" : "Видљиво је само људима који су пронађени интеграцијом броја телефона кроз Разговор на мобилном",
    "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Није доступно јер је ова особина потребна за основну функционалност укључујући дељење фајла и позивнице календара",
    "Local" : "Локално",
    "Only visible to people on this instance and guests" : "Видљиво је само људима на овој инстанци и гостима",
    "Federated" : "Здружено",
    "Only synchronize to trusted servers" : "Само синхронизује са серверима од поверења",
    "Not available as federation has been disabled for your account, contact your system administration if you have any questions" : "Није доступно јер је за ваш налог искључена федерација, обратите се администрацији система ако имате било каквих питања",
    "Published" : "Објављено",
    "Synchronize to trusted servers and the global and public address book" : "Синхронизуј на сервере од поверења и глобалне и јавне адресаре",
    "Not available as publishing account specific data to the lookup server is not allowed, contact your system administration if you have any questions" : "Није доступно јер је забрањено објављивање података о налогу на сервер за претрагу, обратите се администрацији система ако имате било каквих питања",
    "Discover" : "Откриј",
    "Your apps" : "Ваше апликације",
    "Active apps" : "Активне апликације",
    "Disabled apps" : "Искључене апликације",
    "Updates" : "Ажурирања",
    "App bundles" : "Пакети апликација",
    "Featured apps" : "Препоручене апликације",
    "Supported apps" : "Подржане апликације",
    "Show to everyone" : "Прикажи свима",
    "Show to logged in accounts only" : "Прикажи само пријављеним налозима",
    "Hide" : "Сакриј",
    "Could not register device: Network error" : "Не може да се региструје уређај: мрежна грешка",
    "Could not register device: Probably already registered" : "Не може да се региструје уређај: вероватно је већ регистрован",
    "Could not register device" : "Уређај не може да се региструје ",
    "Could not delete the app token" : "Није могао да се обрише жетон апликације",
    "Error while wiping the device with the token" : "Грешка приликом удаљеног брисања уређаја са овим токеном",
    "Error while updating device token name" : "Грешка при ажурирању имена токена уређаја",
    "Error while updating device token scope" : "Грешка при ажурирању домета токена уређаја",
    "An error occurred during the request. Unable to proceed." : "Током захтева је дошло до грешке. Не може да се настави.",
    "Could not set group sorting" : "Није могло да се постави соритирање групе",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Са ваше мреже долази превише захтева. Покушајте поново касније или контактирајте администратора уколико је ово нека грешка.",
    "Error" : "Грешка",
    "Account documentation" : "Документација налога",
    "Administration documentation" : "Администраторска документација",
    "Documentation" : "Документација",
    "Forum" : "Форум",
    "Nextcloud help & privacy resources" : "Nextcloud ресурси помоћи и приватности",
    "General documentation" : "Општа документација",
    "Legal notice" : "Правно обавештење",
    "Privacy policy" : "Смернице приватности",
    "Version" : "Верзија",
    "Reasons to use Nextcloud in your organization" : "Разлози да користите Некстклауд у Вашој организацији",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Развијено од стране {communityopen}Некстклауд заједнице{linkclose}, {githubopen}изворни код{linkclose} је под {licenseopen}AGPL{linkclose} лиценцом.",
    "Like our Facebook page" : "Лајкујте нашу Фејсбук страну",
    "Follow us on Bluesky" : "Пратите нас на Bluesky",
    "Follow us on Mastodon" : "Запратите нас на Мастадонту",
    "Check out our blog" : "Баците поглед на наш блог",
    "Subscribe to our newsletter" : "Пријавите се на наше новине",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Ово Некстклауд издање заједнице није подржано и инстант обавештења нису доступна.",
    "Open documentation" : "Отвори документацију",
    "Use a second factor besides your password to increase security for your account." : "Поред лозинке, користите и други фактор да повећате безбедност Вашег налога.",
    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Ако за повезивање са Nextcloud користите апликације треће стране, обезбедите да се лозинка сваке апликације креира и подеси пре него што се укључи двофакторска аутентификација.",
    "Very weak password" : "Веома слаба лозинка",
    "Weak password" : "Слаба лозинка",
    "So-so password" : "Осредња лозинка",
    "Good password" : "Добра лозинка",
    "Strong password" : "Јака лозинка",
    "Group list is empty" : "Списак група је празан",
    "Unable to retrieve the group list" : "Не могу да добавим списак група",
    "Could not remove app." : "Апликација не може да се уклони.",
    "Could not update app." : "Апликација не може да се ажурира.",
    "Apps" : "Апликације",
    "for Argon2 for password hashing" : "за Argon2 за хеширање лозинке",
    "MariaDB version 10.3 detected, this version is end-of-life and only supported as part of Ubuntu 20.04. MariaDB >=%1$s and <=%2$s is suggested for best performance, stability and functionality with this version of Nextcloud." : "Детектована је MariaDB верзија 10.3, ова верзија је на крају животног века и подржава се само као део Ubuntu 20.04 оперативног система. За најбоље перформансе, стабилност и функционалност са овом Nextcloud верзијом, препоручује се MariaDB >=%1$s и <=%2$s.",
    "_Most tasks were successful in the last day._::_Most tasks were successful in the last %n days._" : ["Већина задатака је била успешна тококм последњег дана.","Већина задатака је била успешна тококм последња %n дана.","Већина задатака је била успешна тококм последњих %n дана."],
    "Machine translation" : "Машинско превођење",
    "Image generation" : "Генерисање слике",
    "Text processing" : "Обрада текста",
    "Exclude some groups from sharing" : "Изузми неке групе из дељења",
    "Limit sharing to some groups" : "Ограничи дељење на одређене групе",
    "Also allow autocompletion on full match of the user id" : "Дозволи такође и аутодовршавање на пуно подударање ид корисника",
    "Choose Deploy Daemon for {appName}" : "Изабери Даемон за постављање за {appName}",
    "Registered Deploy daemons list" : "Листа регистрованих Даемона за постављање",
    "No Deploy daemons configured" : "Није подешен ниједан Даемон за постављање",
    "Register a custom one or setup from available templates" : "Региструјте произвољни или подесите неки према доступном шаблону",
    "Manage Deploy daemons" : "Управљај Даемонима за постављање",
    "Show details for {appName} app" : "Прикажи детаље апликације {appName}",
    "Update to {update}" : "Ажурирај на {update}",
    "Remove" : "Уклони",
    "Featured" : "Препоручене",
    "This app is supported via your current Nextcloud subscription." : "Ова апликација је подржана са Вашом тренутном Некстклауд претплатом.",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Препоручене апликације су развијене за и од стране заједнице. Нуде главне функционалности и спремне су за продукциону употребу.",
    "Community rating: {score}/5" : "Рејтинг заједнице: {score}/5",
    "Disable all" : "Искључи све",
    "Download and enable all" : "Преузми и укључи све",
    "All apps are up-to-date." : "Све апликације су најновије.",
    "Icon" : "Икона",
    "Name" : "Име",
    "Level" : "Ниво",
    "Results from other categories" : "Резултати из других категорија",
    "No apps found for your version" : "Нема апликација за вашу верзију",
    "_%n app has an update available_::_%n apps have an update available_" : ["%n апликација има доступно ажурирање","%n апликације имају доступна ажурирања","%n апликација имају доступна ажурирања"],
    "_Update_::_Update all_" : ["Ажурирај","Ажурирај све","Ажурирај све"],
    "Search groups…" : "Претражи групе…",
    "Could not load app discover section" : "Не може да се учита одељак откривања апликација",
    "Could not render element" : "Не може да се исцрта елемент",
    "Nothing to show" : "Овде нема шта да се прикаже",
    "Could not load section content from app store." : "Не може да се учита садржај одељка из продавнице апликација.",
    "Loading" : "Учитавам",
    "Fetching the latest news…" : "Преузимање најновијих вести",
    "Carousel" : "Карусел",
    "Previous slide" : "Претходни слајд",
    "Next slide" : "Наредни слајд",
    "Choose slide to display" : "Изаберите слајд за приказ",
    "{index} of {total}" : "{index} од {total}",
    "Daemon" : "Сервис",
    "Deploy Daemon" : "Даемон за постављање",
    "Type" : "Тип",
    "Display Name" : "Име за приказ",
    "GPUs support" : "Подршка за GPU",
    "Compute device" : "Рачунарски уређај",
    "Advanced deploy options" : "Напредне опције постављања",
    "Edit ExApp deploy options before installation" : "Уреди ExApp опције постављања пре инсталације",
    "Configured ExApp deploy options. Can be set only during installation" : "Конфигурисане су ExApp опције постављања. Може да се постави само током инсталације",
    "Learn more" : "Сазнајте више",
    "Environment variables" : "Променљиве окружења",
    "ExApp container environment variables" : "Променљиве окружења ExApp контејнера",
    "No environment variables defined" : "Није дефинисана ниједна променљиве окружења",
    "Mounts" : "Монтирања",
    "Define host folder mounts to bind to the ExApp container" : "Дефинише монтирања фолдера на хосту која се везују са ExApp контејнером",
    "Must exist on the Deploy daemon host prior to installing the ExApp" : "Мора да постоји на хосту даемона постављања пре него што се инсталира ExApp",
    "Host path" : "Путања на хосту",
    "Container path" : "Путања контејнера",
    "Read-only" : "Само-за-читање",
    "Remove mount" : "Уклони монтирање",
    "New mount" : "Ново монтирање",
    "Enter path to host folder" : "Унесите путању до фолдера на хосту",
    "Enter path to container folder" : "Унесите путању до фолдера са контејнером",
    "Toggle read-only mode" : "Укључи/искључи режим само-за-читање",
    "Confirm adding new mount" : "Потврди додавање новог монтирања",
    "Cancel adding mount" : "Откажи додавање монтирања",
    "Add mount" : "Додај монтирање",
    "ExApp container mounts" : "Монтирања ExApp контејнера",
    "No mounts defined" : "Није дефинисано ниједно монтирање",
    "Description" : "Опис",
    "View in store" : "Погледај у продавници",
    "Visit website" : "Посети веб сајт",
    "Usage documentation" : "Документација о употреби",
    "Admin documentation" : "Администраторска документација",
    "Developer documentation" : "Програмерска документација",
    "All" : "Све",
    "Limit app usage to groups" : "Ограничи коришћење апликације на групе",
    "No results" : "Нема резултата",
    "Update to {version}" : "Ажурирај на верзију {version}",
    "Deploy options" : "Опције постављања",
    "Default Deploy daemon is not accessible" : "Није доступан подразумевани даемон за постављање ",
    "Delete data on remove" : "Обриши податке приликом уклањања",
    "This app has no minimum {productName} version assigned. This will be an error in the future." : "Ова апликација нема дефинисану минималну верзију {productName} на којој ради. Ово ће у будућности постати грешка.",
    "This app has no maximum {productName} version assigned. This will be an error in the future." : "Ова апликација нема дефинисану максималну верзију {productName} на којој ради. Ово ће у будућности постати грешка.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Апликација се не може инсталирати јер следеће зависности нису испуњене:",
    "Latest updated" : "Последњи пут ажурирано",
    "Author" : "Аутор",
    "Categories" : "Категорије",
    "Resources" : "Ресурси",
    "Interact" : "Остварите узајамно деловање",
    "Report a bug" : "Пријави грешку",
    "Request feature" : "Затражи функционалност",
    "Ask questions or discuss" : "Питајте питање или дискутујте",
    "Rate the app" : "Оцените апликацију",
    "Rate" : "Оцени",
    "Changelog" : "Дневник измена",
    "Loading accounts …" : "Учитавање налога",
    "Set line manager" : "Избор надређеног менаџера",
    "Set account as admin for …" : "Постави налог као администратора за",
    "_{userCount} account …_::_{userCount} accounts …_" : ["{userCount} налог…","{userCount} налога…","{userCount} налога…"],
    "Password or insufficient permissions message" : "Порука о лозинки или недовољним дозволама",
    "Failed to load groups with details" : "Није успело учитавање група са детаљима",
    "Failed to load sub admin groups with details" : "Није успело учитавање под админ група са детаљима",
    "Failed to update line manager" : "Није успело ажурирање надређеног менаџера",
    "Display name was successfully changed" : "Име за приказ је успешно промењено",
    "Password can't be empty" : "Лозинка не може да буде празна",
    "Password was successfully changed" : "Лозинка је усшешно промењена",
    "Email can't be empty" : "И-мејл не може да буде празан",
    "Email was successfully changed" : "И-мејл је успешно промењен",
    "Loading account …" : "Налог се учитава…",
    "Change display name" : "Промени име за приказ",
    "Set new password" : "Постави нову лозинку",
    "You do not have permissions to see the details of this account" : "Немате дозволе да видите детаље о овом налогу",
    "Set new email address" : "Постави нову адресу е-поште",
    "Add account to group" : "Додај налог у групу",
    "Set account as admin for" : "Постави налог као администратора за",
    "Select account quota" : "Одаберите квоту за налог",
    "Set the language" : "Постави језик",
    "Done" : "Завршено",
    "Adding your device …" : "Додајем Ваш уређај…",
    "App Store" : "Продавница апликације",
    "Loading app list" : "Листа апликација се учитава",
    "Loading categories" : "Учитавају се категорије",
    "Version {version}, {license}-licensed" : "Верзија {version}, {license}-лиценцирано",
    "Version {version}" : "Верзија {version}",
    "Sending…" : "Шаљем…",
    "Email sent" : "Порука је послата",
    "Manually installed apps cannot be updated" : "Ручно инсталиране апликације не могу да се ажурирају",
    "{progress}% Deploying …" : "{progress}% Поставља се",
    "{progress}% Initializing …" : "{progress}% Иницијализује се…",
    "Health checking" : "Провера здравља",
    "Deploy and Enable" : "Постави и укључи",
    "Download and enable" : "Скини и укључи",
    "Disable" : "Искључи",
    "Allow untested app" : "Дозволи нетестиране апликације",
    "The app will be downloaded from the App Store" : "Апликација ће се преузети са Продавнице апликација",
    "This app is not marked as compatible with your {productName} version." : "Ова апликација није означена као компатибилна са вашом {productName} верзијом.",
    "If you continue you will still be able to install the app. Note that the app might not work as expected." : "Ако наставите, моћи ћете свеједно да инсталирате апликацију. Врло је могуће да апликација неће радити како је планирано.",
    "The app has been enabled but needs to be updated." : "Апликација је уљкучена, али је потребно да се ажурира.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Грешка: Ова апликација не може да се обрише јер ће сервер постати нестабилан",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Апликација је укључена, али треба да се ажурира. Бићете преусмерени на страну са ажурирањем за 5 секунди.",
    "None/STARTTLS" : "Ништа/STARTTLS",
    "SSL" : "ССЛ",
    "Credentials" : "Акредитиви",
    "SMTP Login" : "SMTP име за пријаву",
    "SMTP Password" : "SMTP лозинка",
    "Test and verify email settings" : "Тестирај и потврди подешавања и-мејла",
    "{progress}% Deploying …" : "{progress}% Поставља се ",
    "{progress}% Initializing …" : "{progress}% Иницијализује се …"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
