OC.L10N.register(
    "appstore",
    {
    "Apps" : "Aplikacije",
    "App name" : "Naziv aplikacije",
    "Version" : "Verzija",
    "Groups" : "Grupe",
    "Actions" : "Radnje",
    "Show details" : "Prikaži detalje",
    "Grid view" : "Prikaz rešetke",
    "Cancel" : "Otkaži",
    "Office suite switching is managed through the Nextcloud All-in-One interface." : "Prebacivanjem uredskih paketa upravlja se putem sučelja Nextcloud All-in-One.",
    "Please use the AIO interface to switch between office suites." : "Za prebacivanje između uredskih paketa koristite AIO sučelje.",
    "Disable office suites" : "Onemogući uredske pakete",
    "installed" : "instalirano",
    "Features" : "Značajke",
    "Learn more" : "Saznajte više",
    "Daemon" : "Daemon",
    "Deploy Daemon" : "Deploy daemon",
    "Type" : "Vrsta",
    "Name" : "Naziv",
    "Display Name" : "Naziv za prikaz",
    "GPUs support" : "Podrška za GPU-ove",
    "Compute device" : "Uređaj za izračun",
    "Advanced deploy options" : "Napredne opcije implementacije",
    "Edit ExApp deploy options before installation" : "Uredi opcije implementacije ExApp prije instalacije",
    "Configured ExApp deploy options. Can be set only during installation" : "Konfigurirane opcije implementacije ExApp. Mogu se postaviti samo tijekom instalacije",
    "Environment variables" : "Varijable okruženja",
    "ExApp container environment variables" : "Varijable okruženja spremnika ExApp",
    "No environment variables defined" : "Nema definiranih varijabli okruženja",
    "Mounts" : "Točke montiranja",
    "Define host folder mounts to bind to the ExApp container" : "Definirajte montiranja mapa s hosta za povezivanje sa spremnikom ExApp",
    "Must exist on the Deploy daemon host prior to installing the ExApp" : "Mora postojati na hostu Deploy daemona prije instalacije ExApp-a",
    "Host path" : "Putanja na hostu",
    "Container path" : "Putanja u spremniku",
    "Read-only" : "Samo za čitanje",
    "Remove mount" : "Ukloni montiranje",
    "New mount" : "Novo montiranje",
    "Enter path to host folder" : "Unesite putanju do mape na hostu",
    "Enter path to container folder" : "Unesite putanju do mape u spremniku",
    "Toggle read-only mode" : "Uključi/isključi način rada samo za čitanje",
    "Confirm adding new mount" : "Potvrdite dodavanje novog montiranja",
    "Confirm" : "Potvrdi",
    "Cancel adding mount" : "Odustani od dodavanja montiranja",
    "Add mount" : "Dodaj montiranje",
    "ExApp container mounts" : "Montiranja spremnika ExApp",
    "No mounts defined" : "Nema definiranih montiranja",
    "Description" : "Opis",
    "View in store" : "Prikaži u trgovini",
    "Visit website" : "Posjeti web-stranicu",
    "Usage documentation" : "Dokumentacija o korištenju",
    "Admin documentation" : "Administratorska dokumentacija",
    "Developer documentation" : "Dokumentacija za programere",
    "Details" : "Pojedinosti",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Ovu aplikaciju nije moguće instalirati jer sljedeće ovisnosti nisu zadovoljene:",
    "Latest updated" : "Najnovije ažurirano",
    "Author" : "Autor",
    "Categories" : "Kategorije",
    "Resources" : "Resursi",
    "Changelog" : "Zapisnik promjena",
    "Supported" : "Podržano",
    "Featured" : "Istaknuto",
    "This app is supported via your current Nextcloud subscription." : "Ova aplikacija je podržana putem vaše trenutne pretplate na Nextcloud.",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Istaknute aplikacije razvija zajednica. Nude ključnu funkcionalnost i spremne su za produkcijsku upotrebu.",
    "Community rating: {score}/5" : "Ocjena zajednice: {score}/5",
    "Choose Deploy Daemon for {appName}" : "Odaberite Deploy Daemon za {appName}",
    "No Deploy daemons configured" : "Nema konfiguriranih Deploy daemona",
    "Register a custom one or setup from available templates" : "Registrirajte prilagođeni ili postavite iz dostupnih predložaka",
    "Manage Deploy daemons" : "Upravljaj Deploy daemonima",
    "Registered Deploy daemons list" : "Popis registriranih demona za postavljanje",
    "Default" : "Zadano",
    "Carousel" : "Vrtuljak",
    "Previous slide" : "Prethodni slajd",
    "Next slide" : "Sljedeći slajd",
    "Choose slide to display" : "Odaberite slajd za prikaz",
    "{index} of {total}" : "{index} od {total}",
    "Limit to groups" : "Ograniči na grupe",
    "Save" : "Spremi",
    "Update all" : "Ažuriraj sve",
    "Loading app list" : "Učitavanje popisa aplikacija",
    "Search everywhere" : "Traži svugdje",
    "Download and enable all" : "Preuzmi i omogući sve",
    "Could not load app discover section" : "Nije moguće učitati odjeljak otkrivanja aplikacija",
    "Could not render element" : "Nije moguće prikazati element",
    "Nothing to show" : "Nema ničega za prikaz",
    "Could not load section content from app store." : "Nije moguće učitati sadržaj odjeljka iz trgovine aplikacija.",
    "Loading" : "Učitavanje",
    "Fetching the latest news…" : "Dohvaćam najnovije vijesti…",
    "Loading categories" : "Učitavanje kategorija",
    "Version {version}, {license}-licensed" : "Verzija {version}, licencirano pod {license}",
    "Version {version}" : "Verzija {version}",
    "Disable" : "Onemogući",
    "Enable" : "Omogući",
    "Download and enable" : "Preuzmi i omogući",
    "Rate the app" : "Ocijeni aplikaciju",
    "Report a bug" : "Prijavi grešku",
    "Remove" : "Ukloni",
    "Update to {version}" : "Ažuriraj na {version}",
    "Discover" : "Otkrijte",
    "Your apps" : "Vaše aplikacije",
    "Active apps" : "Aktivne aplikacije",
    "Disabled apps" : "Onemogućene aplikacije",
    "Updates" : "Ažuriranja",
    "App bundles" : "Paketi aplikacija",
    "Featured apps" : "Istaknute aplikacije",
    "Supported apps" : "Podržane aplikacije",
    "Good Nextcloud integration" : "Dobra integracija s Nextcloudom",
    "Open source" : "Otvoreni kod",
    "Best performance" : "Najbolje performanse",
    "Limited ODF compatibility" : "Ograničena ODF kompatibilnost",
    "Best Microsoft compatibility" : "Najbolja kompatibilnost s Microsoftom",
    "Best Nextcloud integration" : "Najbolja integracija s Nextcloudom",
    "Good performance" : "Dobre performanse",
    "Best security: documents never leave your server" : "Najbolja sigurnost: dokumenti nikad ne napuštaju vaš poslužitelj",
    "Best ODF compatibility" : "Najbolja ODF kompatibilnost",
    "Best support for legacy files" : "Najbolja podrška za starije datoteke",
    "An error occurred during the request. Unable to proceed." : "Došlo je do pogreške tijekom zahtjeva. Nije moguće nastaviti."
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
