OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "Caducou o contrasinal, use o método de contrasinal esquecido para restabelecelo",
    "Password must not have been used recently before." : "O contrasinal non debe ter sido empregado recentemente.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "O contrasinal está entre o 1.000.000 máis común. Escolla un diferente.",
    "Password is present in compromised password list. Please choose a different password." : "O contrasinal atopase nunha lista de contrasinais comprometidos. Escolla un contrasinal diferente.",
    "Password needs to be at least %s characters long." : "O contrasinal precisa ser polo menos de %s caracteres de lonxitude.",
    "Password needs to contain at least one numeric character." : "O contrasinal precisa conter polo menos un caracter numérico.",
    "Password needs to contain at least one special character." : "O contrasinal precisa conter polo menos un caracter especial.",
    "Password needs to contain at least one lower and one upper case character." : "O contrasinal precisa conter polo menos un caracter en minúsculas e un en maiúsculas.",
    "Password policy" : "Directiva de contrasinais",
    "Allows admins to configure a password policy" : "Permítelle aos administradores  configurar unha directiva de contrasinais",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Permítelle aos administradores definir certas precondicións para os contrasinais, p. ex., facer obrigatorio unha lonxitude mínima",
    "General password policies" : "Directiva xeral sobre contrasinais",
    "Add policy set" : "Engadir un grupo de directivas",
    "Login policies" : "Directivas de acceso",
    "Password history size" : "Tamaño do historial do contrasinal",
    "Number of passwords to keep (securely hashed) to prevent users from reusing previously used passwords." : "Número de contrasinais a manter (en forma de resumo criptográfico seguro) para evitar que os usuarios reutilizen contrasinais usados ​​anteriormente.",
    "Maximum login attempts" : "Número máximo de intentos de acceso",
    "Number of login attempts before the user account will be disabled until manual action is taken. (0 for no limit)" : "Número de intentos de acceso antes de que a conta de usuario se desactive ata que se realice unha acción manual. (0 para sen límite)",
    "Please note, this option is meant to protect attacked accounts. Disabled accounts have to be re-enabled manually by administration. Attackers that try to guess passwords of accounts will have their IP address blocked by the bruteforce protection independent from this setting." : "Teña en conta que esta opción está destinada a protexer as contas atacadas. As contas desactivadas teñen que ser reactivadas manualmente pola administración. Os atacantes que intenten adiviñar os contrasinais das contas terán o seu enderezo IP bloqueado pola protección de forza bruta independentemente deste axuste.",
    "Number of days until user password expires" : "Número de días ata que caduque o contrasinal do usuario",
    "Password expiration" : "Caducidade do contrasinal",
    "Warning: enabling password expiration is nowadays considered a security risk by several security agencies." : "Advertencia: activar a caducidade do contrasinal está considerado hoxe en día un risco de seguridade por varias axencias de seguridade.",
    "Remove policy" : "Retirar a directiva",
    "Minimum password length" : "Lonxitude mínima do contrasinal",
    "Forbid common passwords" : "Prohibir contrasinais comúns",
    "Enforce upper and lower case characters" : "Facer obrigatorios os caracteres en maiúsculas e minúsculas",
    "Enforce numeric characters" : "Facer obrigatorios os caracteres numéricos",
    "Enforce special characters" : "Facer obrigatorios os caracteres especiais",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Comprobar o contrasinal contra a lista de contrasinais comprometidos de haveibeenpwned.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Esta comprobación crea un resumo criptográfico dos contrasinais e envía os 5 primeiros caracteres deste resumo criptográfico á API de haveibeenpwned.com para recuperar unha lista de todos os resumo criptográfico que comezan desa forma. Após comprobase na instancia de Nextcloud se o resumo criptográfico do contrasinal está no conxunto de resultados.",
    "Account password policies" : "Directiva de contrasinais de contas",
    "Share password policies" : "Directiva de contrasinais de comparticións"
},
"nplurals=2; plural=(n != 1);");
