OC.L10N.register(
    "comments",
    {
    "Comments" : "Comentários",
    "You commented" : "Você comentou",
    "{author} commented" : "{author} comentou",
    "You commented on %1$s" : "Você comentou em %1$s",
    "You commented on {file}" : "Você comentou sobre {file}",
    "%1$s commented on %2$s" : "%1$s comentaram em %2$s",
    "{author} commented on {file}" : "{author} comentou em {file}",
    "<strong>Comments</strong> for files" : "<strong>Comentários</strong> para arquivos",
    "Files" : "Arquivos",
    "You were mentioned on \"{file}\", in a comment by an account that has since been deleted" : "Você foi mencionado em \"{file}\", em um comentário de uma conta que já foi excluída",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} mencionou você em um comentário sobre \"{file}\"",
    "Go to file" : "Ir para o arquivo",
    "Files app plugin to add comments to files" : "Complemento do aplicativo Files para adicionar comentários",
    "Edit comment" : "Editar comentário",
    "Delete comment" : "Excluir comentário",
    "Cancel edit" : "Cancelar edição",
    "New comment" : "Novo comentário",
    "Write a comment …" : "Escreva um comentário …",
    "Post comment" : "Postar comentário",
    "@ for mentions, : for emoji, / for smart picker" : "@ para menções, : para emoji, / para seletor inteligente",
    "Could not reload comments" : "Não foi possível recarregar comentários",
    "Failed to mark comments as read" : "Falha ao marcar comentários como lidos",
    "Unable to load the comments list" : "Não foi possível carregar a lista de comentários",
    "No comments yet, start the conversation!" : "Nenhum comentário ainda, inicie uma conversa!",
    "No more messages" : "Sem mais mensagens",
    "Retry" : "Tentar novamente",
    "_1 new comment_::_{unread} new comments_" : ["1 novo comentário","{unread} novos comentários","{unread} novos comentários"],
    "Comment" : "Comentar",
    "An error occurred while trying to edit the comment" : "Ocorreu um erro ao tentar editar o comentário",
    "Comment deleted" : "Comentário excluído",
    "An error occurred while trying to delete the comment" : "Ocorreu um erro ao tentar excluir o comentário",
    "An error occurred while trying to create the comment" : "Ocorreu um erro ao tentar criar o comentário",
    "Write a comment …" : "Escreva um comentário …"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
