OC.L10N.register(
    "office",
    {
    "Office" : "Birojs",
    "Create new" : "Izveidot jaunu",
    "Search {category}" : "Meklēt {category}",
    "Search" : "Meklēt",
    "All" : "Visi",
    "Filename" : "Datnes nosaukums",
    "Filename cannot be empty" : "Datnes nosaukums nevar būt tukšs"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
