<?php
/**
 * SPDX-FileCopyrightText: 2016 Nextcloud GmbH and Nextcloud contributors
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */
return array (
  'welcomeelquehacequeelcorazonyore_21' => true,
  'thamires123456789123456789123456789' => true,
  'nguyenthuyvannguyenngoctuongvy12345' => true,
  'mercedessatthucokhuonmattretho_tung' => true,
  'kateznhkbillhutsweetsexything_4ever' => true,
  'justinconloctinhyeu_lovestorm852004' => true,
  'evadcyjwwxvhbdu2uvxsray9xhmmfp8rvuy' => true,
  'dtz4yc4ytntyajaxmoknpn46x8x6amkyia5' => true,
  'mahalwalangiwananpangako09334053656' => true,
  '5fi8f4oi4598f04fh7547f2222222222222' => true,
  '2273019023540390255doouglaassaaiid.' => true,
  '12233344446564564563456356546363563' => true,
);