OC.L10N.register(
    "recommendations",
    {
    "Recommended files" : "推荐文件",
    "Recommendations" : "推荐",
    "Shows recommended files" : "显示推荐的文件",
    "Shows recommended files for quick access of files and folders with recent activity" : "显示推荐的文件，以便快速访问最近活动的文件和文件夹",
    "No recommendations yet" : "暂无推荐",
    "Last updated {timeAgo}" : "最后更新于 {timeAgo}",
    "Shared with you {timeAgo}" : "与您共享于 {timeAgo}",
    "Last commented on {timeAgo}" : "最后评论于 {timeAgo}",
    "Path name {path}" : "路径名称 {path}",
    "Show recommendations" : "显示推荐"
},
"nplurals=1; plural=0;");
