OC.L10N.register(
    "files_lock",
    {
    "File is currently locked by %s" : "Soubor je v tuto chvíli uzamčen uživatelem %s",
    "File is not locked" : "Soubor není uzamčen",
    "File can only be locked with update permissions." : "Soubor je možné uzamknout pouze s aktualizovanými oprávněními.",
    "File can only be unlocked by providing a valid owner lock token" : "Soubor je možné odemknout pouze zadáním platného tokenu zámku vlastníka",
    "File can only be unlocked by the owner of the lock" : "Soubor může být odemčen pouze vlastníkem zámku",
    "Desktop client" : "Klient pro počítač",
    "iOS client" : "iOS klient",
    "Android client" : "Android klient",
    "Temporary files lock" : "Dočasný zámek souborů",
    "Temporary lock your files" : "Dočasně zamykejte své soubory",
    "Allow your users to temporary lock their files to avoid conflicts while working on shared files." : "Umožňuje vašim uživatelům dočasně uzamykat své soubory a vyhýbat se tak konfliktům při práci na sdílených souborech.",
    "Manually locked by {user}" : "Ručně uzamkl(a) {user}",
    "Locked by editing online in {app}" : "Uzamčeno upravováním online v {app}",
    "Automatically locked by {user}" : "Automaticky uzamkl(a) {user}",
    "Unlock file" : "Odemknout soubor",
    "Lock file" : "Zamknout soubor",
    "This file has been locked automatically by a client. Removing the lock may lead to a conflict saving the file." : "Tento soubor byl automaticky uzamčen klientem. Odebrání zámku může vést ke konfliktu při ukládání souboru.",
    "Keep lock" : "Ponechat zámek",
    "Force unlock" : "Vynutit odemknutí"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
