OC.L10N.register(
    "files_trashbin",
    {
    "restored" : "visszaállítva",
    "Deleted files" : "Törölt fájlok",
    "Deleted files and folders in the trash bin (may expire during export if you are low on storage space)" : "A kukában lévő törölt fájlok és mappák (exportálás során lejárhatnak, ha nincs elég tárhely)",
    "This application enables people to restore files that were deleted from the system." : "Ez az alkalmazás lehetővé teszi a rendszerből már törölt fájlok helyreállítását.",
    "This application enables people to restore files that were deleted from the system. It displays a list of deleted files in the web interface, and has options to restore those deleted files back to the people file directories or remove them permanently from the system. Restoring a file also restores related file versions, if the versions application is enabled. When a file is deleted from a share, it can be restored in the same manner, though it is no longer shared. By default, these files remain in the trash bin for 30 days.\nTo prevent an account from running out of disk space, the Deleted files app will not utilize more than 50% of the currently available free quota for deleted files. If the deleted files exceed this limit, the app deletes the oldest files until it gets below this limit. More information is available in the Deleted Files documentation." : "Ez az alkalmazás lehetővé teszi a rendszerből már törölt fájlok helyreállítását. Webes felületen sorolja fel a törölt fájlokat, és azok visszahelyezhetők a könyvtárakba, vagy véglegesen törölhetők. Egy fájllal együtt annak korábbi verzióit is helyreállítja, amennyiben ez be van kapcsolva a rendszerben. Ha egy megosztásból lett törölve a fájl, ugyanígy helyreállítható, de már nem lesz megosztva. Ezek a fájlok alapértelmezetten 30 napig maradnak a kukában.\nHogy a fiók ne fusson ki az elérhető tárhelyből, a Törölt fájlok alkalmazás legfeljebb az elérhető terület 50%-át használja tárolásra. Ha ennél több fájl kerül bele, az alkalmazás törli a legrégebbi fájlokat, amíg a határértéken belülre nem kerül. További információ a Törölt fájlok dokumentációjában található.",
    "Restore" : "Visszaállítás",
    "Not enough free space to restore the file/folder" : "Nincs elég szabad hely a fájl/mappa helyreállításához",
    "Empty deleted files" : "Törölt fájlok ürítése",
    "Confirm permanent deletion" : "Végleges törlés megerősítése",
    "Are you sure you want to permanently delete all files and folders in the trash? This cannot be undone." : "Biztos, hogy végleg törli az összes fájlt és mappát a kukából? Ez nem vonható vissza.",
    "Cancel" : "Mégse",
    "Original location" : "Eredeti hely",
    "Deleted by" : "Törölte:",
    "Deleted" : "Törölve",
    "few seconds ago" : "néhány másodperce",
    "A long time ago" : "Réges régen",
    "Unknown" : "Ismeretlen",
    "All files" : "Összes fájl",
    "You" : "Ön",
    "List of files that have been deleted." : "A törölt fájlok listája.",
    "No deleted files" : "Nincs törölt fájl",
    "Files and folders you have deleted will show up here" : "A törölt fájlok és mappák itt jelennek meg",
    "All files have been permanently deleted" : "Az összes fájl véglegesen törölve",
    "Failed to empty deleted files" : "A törölt fájlok ürítése sikertelen"
},
"nplurals=2; plural=(n != 1);");
