OC.L10N.register(
    "files_downloadlimit",
    {
    "Files download limit" : "ファイルのダウンロード制限",
    "File link share download limit" : "リンク共有ファイルのダウンロード制限",
    "This app allows limiting the number of downloads for external link shares." : "このアプリでは、外部リンク共有のダウンロード数を制限できるようにします",
    "The minimum limit is 1" : "制限の最小値は1です",
    "Failed to set download limit" : "ダウンロード制限の設定に失敗しました",
    "Failed to remove download limit" : "ダウンロード制限の削除に失敗しました",
    "Limit downloads" : "ダウンロードを制限",
    "Set download limit" : "ダウンロード制限を設定",
    "Setting a new limit will reset the download count" : "新しい制限を設定すると、ダウンロード数がリセットされます",
    "_1 remaining download allowed_::_{count} remaining downloads allowed_" : ["ダウンロードできる回数は残り {count} 回です"],
    "Download limit" : "ダウンロード制限",
    "Configure the default download limit for external shares." : "外部共有のデフォルトのダウンロード制限を設定します。",
    "Default download limit for external shares" : "外部共有のデフォルトのダウンロード制限",
    "Set default download limit" : "デフォルトのダウンロード制限の設定",
    "You have reached the maximum amount of downloads allowed" : "許可されているダウンロードの上限に達しました",
    "This share has a limited number of downloads. Are you sure you want to trigger a new download?" : "この共有のダウンロード数には制限があります。新しいダウンロードを開始してもよろしいですか?",
    "Failed to set default download limit" : "デフォルトのダウンロード制限の設定に失敗しました",
    "Failed to remove default download limit" : "デフォルトのダウンロード制限を削除できませんでした"
},
"nplurals=1; plural=0;");
