OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Pannellu de controllu",
    "Dashboard app" : "Aplicatzione de su pannellu de controllu",
    "Weather" : "Tempus",
    "Status" : "Istadu",
    "Good morning" : "Bona die",
    "Good morning, {name}" : "Bona die, {name}",
    "Good afternoon" : "Salude",
    "Good afternoon, {name}" : "Salude, {name}",
    "Good evening" : "Salude",
    "Good evening, {name}" : "Salude, {name}",
    "Hello" : "Salude",
    "Hello, {name}" : "Salude, {name}",
    "Customize" : "Personaliza",
    "Edit widgets" : "Modìfica ordìngios",
    "Get more widgets from the App Store" : "Otene àteros trastos dae sa butega de is aplicatziones",
    "Weather service" : "Servìtziu de su tempus",
    "Weather data from Met.no" : "Datos de su tempus dae Met.no",
    "geocoding with Nominatim" : "geocodìfica cun Nominatim",
    "elevation data from OpenTopoData" : "datos de elevada dae OpenTopoData"
},
"nplurals=2; plural=(n != 1);");
