OC.L10N.register(
    "files_sharing",
    {
    "File shares" : "ھۆججەت ئورتاقلىشىش",
    "Downloaded via public link" : "ئاممىۋى ئۇلىنىش ئارقىلىق چۈشۈرۈلدى",
    "Downloaded by {email}" : "{email} ئارقىلىق چۈشۈرۈلدى",
    "{file} downloaded via public link" : "{file} public ئاممىۋى ئۇلىنىش ئارقىلىق چۈشۈرۈلدى",
    "{email} downloaded {file}" : "{email} چۈشۈرۈلگەن {file}",
    "Shared with group {group}" : "گۇرۇپپا {group} بىلەن ئورتاقلاشتى",
    "Removed share for group {group}" : "گۇرۇپپا {group} ئۈچۈن ھەمبەھىر چىقىرىۋېتىلدى",
    "{actor} shared with group {group}" : "{actor} group گۇرۇپپا {group} بىلەن ئورتاقلاشتى",
    "{actor} removed share for group {group}" : "{actor} group گۇرۇپپا {group} ئۈلۈشىنى ئېلىۋەتتى",
    "Share for group {group} expired" : "گۇرۇپپا {group} ئۈچۈن ئورتاقلىشىش ۋاقتى توشتى",
    "You shared {file} with group {group}" : "سىز {file} نى گۇرۇپپا {group} بىلەن ئورتاقلاشتىڭىز",
    "You removed group {group} from {file}" : "گۇرۇپپا {group} نى {file} ئۆچۈردىڭىز",
    "{actor} shared {file} with group {group}" : "{actor} گۇرۇپپا {file} بىلەن ئورتاقلاشقان {group}",
    "{actor} removed group {group} from {file}" : "{actor} گۇرۇپپا {group} {file} چىقىرىۋېتىلدى",
    "Share for file {file} with group {group} expired" : "گۇرۇپپا {file} بىلەن ھۆججەت {group} نى ئورتاقلىشىش ۋاقتى توشتى",
    "Shared as public link" : "ئاممىۋى ئۇلىنىش سۈپىتىدە ئورتاقلاشتى",
    "Removed public link" : "ئاممىۋى ئۇلىنىش ئۆچۈرۈلدى",
    "Public link expired" : "ئاممىۋى ئۇلىنىش ۋاقتى توشتى",
    "{actor} shared as public link" : "{actor} public ئاممىۋى ئۇلىنىش سۈپىتىدە ھەمبەھىرلەندى",
    "{actor} removed public link" : "{actor} public ئاممىۋى ئۇلىنىشنى ئۆچۈردى",
    "Public link of {actor} expired" : "{actor} نىڭ ئاممىۋى ئۇلىنىشى ۋاقتى توشتى",
    "You shared {file} as public link" : "ئاممىۋى ھۆججەت سۈپىتىدە {file} نى ئورتاقلاشتىڭىز",
    "You removed public link for {file}" : "{file} ئۈچۈن ئاممىۋى ئۇلىنىشنى ئۆچۈردىڭىز",
    "Public link expired for {file}" : "ئاممىۋى ئۇلىنىش {file} نىڭ ۋاقتى توشتى",
    "{actor} shared {file} as public link" : "{actor} ئورتاقلاشقان {file} public ئاممىۋى ئۇلىنىش سۈپىتىدە",
    "{actor} removed public link for {file}" : "{actor} {file} ئاممىۋى ئۇلىنىشىنى ئۆچۈردى",
    "Public link of {actor} for {file} expired" : "{actor} for ئۈچۈن {file} نىڭ ئاممىۋى ئۇلىنىشى ۋاقتى توشتى",
    "{user} accepted the remote share" : "{user} يىراقتىن ئورتاقلىشىشنى قوبۇل قىلدى",
    "{user} declined the remote share" : "{user} يىراقتىن ھەمبەھىرلىنىشنى رەت قىلدى",
    "You received a new remote share {file} from {user}" : "{file} دىن يېڭى يىراقتىن ئورتاقلىشىش {user} تاپشۇرۇۋالدىڭىز",
    "{user} accepted the remote share of {file}" : "{user} {file} يىراقتىن ھەمبەھىرلىنىشىنى قوبۇل قىلدى",
    "{user} declined the remote share of {file}" : "{user} {file} يىراقتىن ھەمبەھىرلىنىشىنى رەت قىلدى",
    "{user} unshared {file} from you" : "{user} ئورتاقلاشمىغان {file} سىزدىن",
    "Shared with {user}" : "{user} بىلەن ئورتاقلاشتى",
    "Removed share for {user}" : "{user} for ئۈچۈن ھەمبەھىر چىقىرىۋېتىلدى",
    "You removed yourself" : "ئۆزىڭىزنى ئېلىۋەتتىڭىز",
    "{actor} removed themselves" : "{actor} ئۆزىنى ئۆچۈرۈۋەتتى",
    "{actor} shared with {user}" : "{actor} {user} بىلەن ئورتاقلاشتى",
    "{actor} removed share for {user}" : "{actor} {user} ئۈچۈن ھەمبەھىرلەنگەن",
    "Shared by {actor}" : "ھەمبەھىرلەنگەن {actor}",
    "{actor} removed share" : "{actor} ھەمبەھىرلەنگەن",
    "Share for {user} expired" : "{user} ئۈچۈن ئورتاقلىشىش ۋاقتى توشتى",
    "Share expired" : "ھەمبەھىرلىنىش ۋاقتى توشتى",
    "You shared {file} with {user}" : "{file} بىلەن {user} نى ئورتاقلاشتىڭىز",
    "You removed {user} from {file}" : "سىز {user} نى {file} ئۆچۈردىڭىز",
    "You removed yourself from {file}" : "ئۆزىڭىزنى {file} دىن ئۆچۈردىڭىز",
    "{actor} removed themselves from {file}" : "{actor} ئۆزىنى {file} ئۆچۈرۈۋەتتى",
    "{actor} shared {file} with {user}" : "{actor} ئىشلەتكۈچى {file} ئورتاقلاشقان {user}",
    "{actor} removed {user} from {file}" : "{actor} {file} {user} چىقىرىۋېتىلدى",
    "{actor} shared {file} with you" : "{actor} ئورتاقلاشقان {file} سىز بىلەن",
    "{actor} removed you from the share named {file}" : "{actor} سىزنى {file} named دېگەن ئورتاقلىشىشتىن ئۆچۈردى",
    "Share for file {file} with {user} expired" : "ھۆججەت {file} بىلەن ئورتاقلىشىش {user} ۋاقتى توشتى",
    "Share for file {file} expired" : "ھۆججەتكە ئورتاقلىشىش {file} ۋاقتى توشتى",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "خەت ياكى ئاممىۋى ئۇلىنىش ئارقىلىق ھەمبەھىرلەنگەن ھۆججەت ياكى ھۆججەت قىسقۇچ <strong> چۈشۈرۈلدى </strong>",
    "Files have been <strong>uploaded</strong> to a folder shared by mail or by public link" : "ھۆججەتلەر ئېلېكترونلۇق خەت ياكى ئاممىۋى ئۇلىنىش ئارقىلىق ھەمبەھىرلىنىدىغان ھۆججەت قىسقۇچقا <strong> يۈكلەندى</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "ھۆججەت ياكى ھۆججەت قىسقۇچ <strong> باشقا مۇلازىمېتىر </strong> دىن ئورتاقلاشتى",
    "Sharing" : "ھەمبەھىر",
    "A file or folder has been <strong>shared</strong>" : "ھۆججەت ياكى ھۆججەت قىسقۇچ <strong> ئورتاقلاشتى </strong>",
    "Shared link" : "ئورتاق ئۇلىنىش",
    "Wrong share ID, share does not exist" : "خاتا ئورتاقلىشىش كىملىكى ، ئورتاقلىشىش مەۋجۇت ئەمەس",
    "Could not delete share" : "ھەمبەھىرنى ئۆچۈرەلمىدى",
    "Please specify a file or folder path" : "ھۆججەت ياكى ھۆججەت قىسقۇچ يولىنى بەلگىلىۈڭ",
    "Wrong path, file/folder does not exist" : "خاتا يول ، ھۆججەت / ھۆججەت قىسقۇچ مەۋجۇت ئەمەس",
    "Could not create share" : "ئورتاقلىشالمىدى",
    "Please specify a valid account to share with" : "ئورتاقلىشىدىغان ئۈنۈملۈك ھېساباتنى بەلگىلىۈڭ",
    "Please specify a valid group" : "ئىناۋەتلىك گۇرۇپپىنى بەلگىلىۈڭ",
    "Please specify a valid email address" : "ئىناۋەتلىك ئېلېكترونلۇق خەت ئادرېسىنى بەلگىلىۈڭ",
    "Sharing %s sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "Nextcloud Talk ئارقىلىق پارول ئەۋەتىش %s نى ئورتاقلىشىش مەغلۇب بولدى ، چۈنكى Nextcloud Talk قوزغىتىلمىدى",
    "Please specify a valid federated account ID" : "ئىناۋەتلىك فېدېراتسىيە ھېسابات كىملىكىنى بەلگىلىۈڭ",
    "Please specify a valid federated group ID" : "ئىناۋەتلىك فېدېراتسىيە گۇرۇپپا كىملىكىنى بەلگىلىۈڭ",
    "You cannot share to a Team if the app is not enabled" : "ئەگەر بۇ دېتال قوزغىتىلمىغان بولسا ، بىر گۇرۇپپىغا ئورتاقلىشالمايسىز",
    "Please specify a valid team" : "ئىناۋەتلىك گۇرۇپپا بەلگىلەڭ",
    "Sharing %s failed because the back end does not support room shares" : "%s نى ئورتاقلىشىش مەغلۇب بولدى ، چۈنكى ئارقا تەرىپى ئۆي ئۈلۈشىنى قوللىمايدۇ",
    "Unknown share type" : "نامەلۇم ئورتاقلىشىش تىپى",
    "Not a directory" : "مۇندەرىجە ئەمەس",
    "Could not lock node" : "تۈگۈننى قۇلۇپلىيالمىدى",
    "Public upload is only possible for publicly shared folders" : "ئاشكارا يوللاش پەقەت ئاممىۋى ئورتاقلاشقان ھۆججەت قىسقۇچلار ئۈچۈنلا بولىدۇ",
    "Share must at least have READ or CREATE permissions" : "ھەمبەھىرلىنىشتە ھېچ بولمىغاندا ئوقۇش ياكى ئىجاد قىلىش ھوقۇقى بولۇشى كېرەك",
    "Share must have READ permission if UPDATE or DELETE permission is set" : "UPDATE ياكى DELETE ئىجازىتى تەڭشەلگەن بولسا ، ئورتاقلىشىش چوقۇم ئوقۇش رۇخسىتى بولۇشى كېرەك",
    "Could not lock path" : "يولنى قۇلۇپلىيالمىدى",
    "no sharing rights on this item" : "بۇ تۈردە ئورتاقلىشىش ھوقۇقى يوق",
    "You are not allowed to edit incoming shares" : "كەلگەن پايلارنى تەھرىرلىشىڭىزگە رۇخسەت قىلىنمايدۇ",
    "Wrong or no update parameter given" : "يېڭىلاش پارامېتىرى خاتا ياكى يوق",
    "\"Sending the password by Nextcloud Talk\" for sharing a file or folder failed because Nextcloud Talk is not enabled." : "Nextcloud Talk قوزغىتىلمىغانلىقتىن ھۆججەت ياكى ھۆججەت قىسقۇچنى ئورتاقلىشىش ئۈچۈن «Nextcloud Talk ئارقىلىق پارول ئەۋەتىش» مەغلۇپ بولدى.",
    "Custom share link tokens have been disabled by the administrator" : "باشقۇرغۇچى تەرىپىدىن خاسلاشتۇرۇلغان ئورتاقلىشىش ئۇلىنىشى بەلگىلىرى چەكلەندى",
    "Invalid date. Format must be YYYY-MM-DD" : "ئىناۋەتسىز ۋاقىت. فورماتى چوقۇم YYYY-MM-DD بولۇشى كېرەك",
    "No sharing rights on this item" : "بۇ تۈردە ئورتاقلىشىش ھوقۇقى يوق",
    "Invalid share attributes provided: \"%s\"" : "تەمىنلەنگەن ئىناۋەتسىز ئورتاقلىشىش خاسلىقى: \"%s\"",
    "You are not allowed to send mail notifications" : "خەت ئۇقتۇرۇشى ئەۋەتىشىڭىزگە رۇخسەت قىلىنمايدۇ",
    "No mail notification configured for this share type" : "بۇ ئورتاقلىشىش تىپىغا ھېچقانداق خەت ئۇقتۇرۇشى سەپلەنمىگەن",
    "Wrong password" : "پارول خاتا",
    "Error while sending mail notification" : "خەت ئۇقتۇرۇشى ئەۋەتكەندە خاتالىق",
    "Failed to generate a unique token" : "ئۆزگىچە نۇمۇر ھاسىل قىلىش مەغلۇپ بولدى",
    "This share does not exist or is no longer available" : "بۇ ئۈلۈش مەۋجۇت ئەمەس ياكى ئەمدى ئىشلەتكىلى بولمايدۇ",
    "shared by %s" : "%s بىلەن ئورتاقلاشتى",
    "Download" : "چۈشۈر",
    "Add to your %s" : "%s گە قوشۇڭ",
    "Direct link" : "بىۋاسىتە ئۇلىنىش",
    "Share API is disabled" : "ھەمبەھىر API چەكلەنگەن",
    "File sharing" : "ھۆججەت ئورتاقلىشىش",
    "Share will expire tomorrow" : "ھەمبەھىرلىنىش ئەتە توشىدۇ",
    "Your share of {node} will expire tomorrow" : "سىزنىڭ {node} دىكى ئۈلۈشىڭىز ئەتە توشىدۇ",
    "You received {share} as a share by {user}" : "سىز {share} تەرىپىدىن ئورتاقلىشىش سۈپىتىدە {user} نى تاپشۇرۇۋالدىڭىز",
    "You received {share} to group {group} as a share by {user}" : "{share} نىڭ ئورتاق بەھرىلىنىشى سۈپىتىدە گۇرۇپپا {group} {user} نى تاپشۇرۇۋالدىڭىز",
    "Accept" : "قوبۇل قىلىڭ",
    "Decline" : "رەت قىلىش",
    "Remember to upload the files to %s" : "ھۆججەتلەرنى %s غا يوللاشنى ئۇنتۇپ قالماڭ",
    "We would like to kindly remind you that you have not yet uploaded any files to the shared folder." : "ئورتاق ھۆججەت قىسقۇچقا تېخى ھۆججەت يوللىمىغانلىقىڭىزنى سەمىمىيلىك بىلەن ئەسكەرتىمىز.",
    "Open \"%s\"" : "\"%s\" نى ئېچىڭ",
    "This application enables people to share files within Nextcloud. If enabled, the admin can choose which groups can share files. The applicable people can then share files and folders with other accounts and groups within Nextcloud. In addition, if the admin enables the share link feature, an external link can be used to share files with other people outside of Nextcloud. Admins can also enforce passwords, expirations dates, and enable server to server sharing via share links, as well as sharing from mobile devices.\nTurning the feature off removes shared files and folders on the server for all share recipients, and also on the sync clients and mobile apps. More information is available in the Nextcloud Documentation." : "بۇ پروگرامما كىشىلەرنى Nextcloud ئىچىدىكى ھۆججەتلەرنى ئورتاقلىشالايدۇ. ئەگەر قوزغىتىلسا ، باشقۇرغۇچى قايسى گۇرۇپپىلارنىڭ ھۆججەتلەرنى ئورتاقلىشالايدىغانلىقىنى تاللىيالايدۇ. قوللىنىشچان كىشىلەر ئاندىن Nextcloud ئىچىدىكى ھۆججەت ۋە ھۆججەت قىسقۇچلارنى باشقا ھېسابات ۋە گۇرۇپپىلار بىلەن ئورتاقلىشالايدۇ. بۇنىڭدىن باشقا ، ئەگەر باشقۇرغۇچى ئورتاقلىشىش ئۇلىنىش ئىقتىدارىنى قوزغىتالىسا ، سىرتقى ئۇلىنىش ئارقىلىق Nextcloud نىڭ سىرتىدىكى باشقا كىشىلەر بىلەن ھۆججەتلەرنى ئورتاقلىشالايدۇ. باشقۇرغۇچى يەنە مەخپىي نومۇر ، مۇددىتى توشۇش ۋاقتىنى ئىجرا قىلالايدۇ ھەمدە مۇلازىمېتىرنى ھەمبەھىر ئۇلىنىش ئارقىلىق كۆچمە ئۈسكۈنىلەردىن ئورتاقلىشالايدۇ.\nبۇ ئىقتىدارنى تاقاش بارلىق ھەمبەھىر تاپشۇرۇۋالغۇچىلار ئۈچۈن مۇلازىمېتىردىكى ھەمبەھىر ھۆججەت ۋە ھۆججەت قىسقۇچلارنى ، شۇنداقلا ماس قەدەملىك خېرىدارلار ۋە كۆچمە ئەپلەرنى ئۆچۈرۈۋېتىدۇ. Nextcloud ھۆججىتىدە تېخىمۇ كۆپ ئۇچۇرلار بار.",
    "Filter accounts" : "ھېساباتنى سۈزۈڭ",
    "you" : "سىز",
    "The request will expire on {date} at midnight and will be password protected." : "بۇ تەلەپ {date} يېرىم كېچىدە توشىدۇ ھەمدە مەخپىي نومۇر قوغدىلىدۇ.",
    "The request will expire on {date} at midnight." : "بۇ تەلەپ يېرىم كېچىدە {date} توشىدۇ.",
    "The request will be password protected." : "تەلەپ مەخپىي نومۇر بىلەن قوغدىلىدۇ.",
    "When should the request expire?" : "تەلەپنىڭ ۋاقتى قاچان بولۇشى كېرەك؟",
    "Set a submission expiration date" : "تاپشۇرۇش ۋاقتى توشىدۇ",
    "Expiration date" : "مۇددىتى توشقان ۋاقىت",
    "Select a date" : "چېسلانى تاللاڭ",
    "Your administrator has enforced a {count} days expiration policy." : "باشقۇرغۇچىڭىز {count} كۈننىڭ مۇددىتى توشۇش سىياسىتىنى يولغا قويدى.",
    "What password should be used for the request?" : "تەلەپ ئۈچۈن قايسى پارولنى ئىشلىتىش كېرەك؟",
    "Set a password" : "پارول بەلگىلەڭ",
    "Password" : "پارول",
    "Enter a valid password" : "ئىناۋەتلىك پارول كىرگۈزۈڭ",
    "Generate a new password" : "يېڭى پارول ھاسىل قىلىڭ",
    "Your administrator has enforced a password protection." : "باشقۇرغۇچىڭىز مەخپىي نومۇر قوغداشنى يولغا قويدى.",
    "Automatically copying failed, please copy the share link manually" : "ئاپتوماتىك كۆچۈرۈش مەغلۇب بولدى ، ئورتاقلىشىش ئۇلانمىسىنى قولدا كۆچۈرۈڭ",
    "Link copied" : "ئۇلىنىش كۆچۈرۈلدى",
    "Email already added" : "ئېلېكترونلۇق خەت قوشۇلدى",
    "Invalid email address" : "ئىناۋەتسىز ئېلخەت ئادرېسى",
    "_The following email address is not valid: {emails}_::_The following email addresses are not valid: {emails}_" : ["تۆۋەندىكى ئېلخەت ئادىرسى ئىناۋەتلىك ئەمەس: {emails}","تۆۋەندىكى ئېلخەت ئادىرسى ئىناۋەتلىك ئەمەس: {emails}"],
    "_{count} email address already added_::_{count} email addresses already added_" : ["{count} ئېلخەت ئادىرسلىرى ئاللىبۇرۇن قوشۇلدى","{count} ئېلخەت ئادىرسلىرى ئاللىبۇرۇن قوشۇلدى"],
    "_{count} email address added_::_{count} email addresses added_" : ["{count} ئېلخەت ئادىرسلىرى قوشۇلدى","{count} ئېلخەت ئادىرسلىرى قوشۇلدى"],
    "You can now share the link below to allow people to upload files to your directory." : "سىز تۆۋەندىكى ئۇلىنىشنى ھەمبەھىرلەپ ، كىشىلەرنىڭ مۇندەرىجىڭىزگە ھۆججەت يوللىشىغا يول قويالايسىز.",
    "Share link" : "ئۇلىنىش ھەمبەھىرلە",
    "Copy" : "كۆچۈر",
    "Send link via email" : "ئېلېكترونلۇق خەت ئارقىلىق ئۇلىنىش ئەۋەتىڭ",
    "Enter an email address or paste a list" : "ئېلېكترونلۇق خەت ئادرېسىنى كىرگۈزۈڭ ياكى تىزىملىك چاپلاڭ",
    "Remove email" : "ئېلېكترونلۇق خەتنى ئۆچۈرۈڭ",
    "Select a destination" : "مەنزىلنى تاللاڭ",
    "Select" : "تاللاڭ",
    "What are you requesting?" : "نېمە تەلەپ قىلىسىز؟",
    "Request subject" : "تېما تەلەپ قىلىش",
    "Birthday party photos, History assignment…" : "تۇغۇلغان كۈن سۈرىتى ، تارىخ تاپشۇرۇق…",
    "Where should these files go?" : "بۇ ھۆججەتلەر نەگە بېرىشى كېرەك؟",
    "Upload destination" : "نىشاننى يۈكلەڭ",
    "Revert to default" : "سۈكۈتكە قايتىڭ",
    "The uploaded files are visible only to you unless you choose to share them." : "يۈكلەنگەن ھۆججەتلەرنى ئورتاقلىشىشنى تاللىمىسىڭىزلا كۆرۈنىدۇ.",
    "Add a note" : "خاتىرە قوشۇڭ",
    "Note for recipient" : "تاپشۇرۇۋالغۇچىغا دىققەت قىلىڭ",
    "Add a note to help people understand what you are requesting." : "كىشىلەرگە نېمە تەلەپ قىلىۋاتقانلىقىڭىزنى چۈشىنىشى ئۈچۈن خاتىرە قوشۇڭ.",
    "You can add links, date or any other information that will help the recipient understand what you are requesting." : "ئۇلىنىش ، چېسلا ياكى باشقا ئۇچۇرلارنى قوشالايسىز ، تاپشۇرۇۋالغۇچىنىڭ سىز تەلەپ قىلغان نەرسىنى چۈشىنىشىگە ياردەم بېرىدۇ.",
    "Close" : "ياپ",
    "_Send email and close_::_Send {count} emails and close_" : ["ئېلخەت يوللا ھەمدە ياپ","{count} ئېلخەت يوللا ھەمدە ياپ"],
    "Please select a folder, you cannot share the root directory." : "ھۆججەت قىسقۇچنى تاللاڭ ، يىلتىز مۇندەرىجىسىنى ئورتاقلىشالمايسىز.",
    "File request created" : "ھۆججەت تەلىپى قۇرۇلدى",
    "_File request created and email sent_::_File request created and {count} emails sent_" : ["ھۆججەت تەلىپى قۇرۇلدى ھەمدە ئېلخەت يوللاندى","ھۆججەت تەلىپى قۇرۇلدى ھەمدە {count} ئېلخەت يوللاندى"],
    "Error creating the share: {errorMessage}" : "ھەمبەھىرلەشتە خاتالىق: {errorMessage}",
    "Error creating the share" : "ھەمبەھىرلەشتە خاتالىق",
    "Error sending emails: {errorMessage}" : "ئېلېكترونلۇق خەت ئەۋەتىشتە خاتالىق: {errorMessage}",
    "Error sending emails" : "ئېلېكترونلۇق خەت ئەۋەتىشتە خاتالىق",
    "Create a file request" : "ھۆججەت تەلەپ قىلىڭ",
    "Collect files from others even if they do not have an account." : "ھېساباتى بولمىسىمۇ باشقىلاردىن ھۆججەت توپلاڭ.",
    "To ensure you can receive files, verify you have enough storage available." : "ھۆججەتلەرنى قوبۇل قىلىشىڭىزغا كاپالەتلىك قىلىش ئۈچۈن ، يېتەرلىك ساقلاش بوشلۇقى بار-يوقلۇقىنى تەكشۈرۈڭ.",
    "File request" : "ھۆججەت تەلىپى",
    "Previous step" : "ئالدىنقى قەدەم",
    "Cancel" : "ۋاز كەچ",
    "Cancel the file request creation" : "ھۆججەت تەلىپىنى قۇرۇشنى ئەمەلدىن قالدۇرۇڭ",
    "Close without sending emails" : "ئېلېكترونلۇق خەت ئەۋەتمەيلا تاقاڭ",
    "Continue" : "داۋاملاشتۇر",
    "Error while toggling options" : "تاللانمىلارنى ئالماشتۇرغاندا خاتالىق",
    "Accept shares from other accounts and groups by default" : "سۈكۈتتىكى باشقا ھېسابات ۋە گۇرۇپپىلاردىن پاينى قوبۇل قىلىڭ",
    "Choose a default folder for accepted shares" : "قوبۇل قىلىنغان پايلار ئۈچۈن سۈكۈتتىكى ھۆججەت قىسقۇچنى تاللاڭ",
    "Invalid path selected" : "ئىناۋەتسىز يول تاللانغان",
    "Unknown error" : "يوچۇن خاتالىق",
    "Set default folder for accepted shares" : "قوبۇل قىلىنغان پايلار ئۈچۈن سۈكۈتتىكى ھۆججەت قىسقۇچ بەلگىلەڭ",
    "Reset" : "ئەسلىگە قايتۇرۇش",
    "Reset folder to system default" : "ھۆججەت قىسقۇچنى سىستېمىنىڭ سۈكۈتتىكى ھالىتىگە قايتۇرۇڭ",
    "Share expiration: {date}" : "ھەمبەھىر ۋاقتى ئۆتتى: {date}",
    "Share Expiration" : "ھەمبەھىر مۇددىتى توشۇش",
    "group" : "گۇرۇپپا",
    "conversation" : "سۆھبەت",
    "remote" : "يىراق",
    "remote group" : "يىراق گۇرۇپپا",
    "guest" : "مېھمان",
    "by {initiator}" : "{initiator} تەرىپىدىن",
    "Shared with the group {user} by {owner}" : "{user} گۇرۇپپىسى {owner} گۇرۇپپىسى بىلەن ئورتاقلاشتى",
    "Shared with the conversation {user} by {owner}" : "پاراڭ {user} تەرىپىدىن {owner} بىلەن ئورتاقلاشتى",
    "Shared with {user} by {owner}" : "{user} بىلەن {owner} بىلەن ئورتاقلاشتى",
    "Open Sharing Details" : "ئورتاقلىشىش تەپسىلاتلىرىنى ئېچىڭ",
    "Added by {initiator}" : "{initiator} by قوشۇلدى",
    "Via “{folder}”" : "«{folder}» ئارقىلىق",
    "Unshare" : "ھەمبەھىرلىمە",
    "Cannot copy, please copy the link manually" : "كۆچۈرگىلى بولمايدۇ ، ئۇلىنىشنى قولدا كۆچۈرۈڭ",
    "Copy internal link" : "ئىچكى ئۇلىنىشنى كۆچۈرۈڭ",
    "For people who already have access" : "ئاللىبۇرۇن كىرەلەيدىغان ئادەملەر ئۈچۈن",
    "Internal link" : "ئىچكى ئۇلىنىش",
    "{shareWith} by {initiator}" : "{shareWith} تەرىپىدىن {initiator}",
    "Shared via link by {initiator}" : "{initiator} by ئۇلىنىش ئارقىلىق ھەمبەھىرلەندى",
    "File request ({label})" : "ھۆججەت تەلىپى ({label})",
    "Mail share ({label})" : "خەت ئورتاقلىشىش ({label})",
    "Share link ({label})" : "ئورتاقلىشىش ئۇلىنىشى ({label})",
    "Mail share" : "خەت ئورتاقلىشىش",
    "Share link ({index})" : "ئورتاقلىشىش ئۇلىنىشى ({index})",
    "Create public link" : "ئاممىۋى ئۇلىنىش قۇر",
    "Actions for \"{title}\"" : "\"{title}\" نىڭ ھەرىكەتلىرى",
    "Copy public link of \"{title}\"" : "\"{title}\" نىڭ ئاممىۋى ئۇلىنىشىنى كۆچۈر",
    "Error, please enter proper password and/or expiration date" : "خاتالىق ، مۇۋاپىق پارول ۋە / ياكى مۇددىتى توشقان ۋاقىتنى كىرگۈزۈڭ",
    "Link share created" : "ئۇلىنىش ئۈلۈشى قۇرۇلدى",
    "Error while creating the share" : "ھەمبەھىرلەشتە خاتالىق",
    "Your browser does not support copying, please copy the link manually:" : "تور كۆرگۈچىڭىز كۆچۈرۈشنى قوللىمايدۇ، ئۇلىنىشنى قولدا كۆچۈرۈڭ:",
    "Successfully copied public link" : "ئاممىۋى ئۇلىنىش مۇۋاپىقىيەتلىك كۆچۈرۈلدى",
    "Please enter the following required information before creating the share" : "ئورتاقلىشىشتىن بۇرۇن تۆۋەندىكى زۆرۈر ئۇچۇرلارنى كىرگۈزۈڭ",
    "Password protection (enforced)" : "پارولنى قوغداش (ئىجرا قىلىنىدۇ)",
    "Password protection" : "پارول قوغداش",
    "Enter a password" : "بىر پارول كىرگۈزۈڭ",
    "Enable link expiration (enforced)" : "ئۇلىنىش ۋاقتى ئۆتۈشنى قوزغات (مەجبۇرىي)",
    "Enable link expiration" : "ئۇلىنىش ۋاقتى ئۆتۈشنى قوزغات",
    "Enter expiration date (enforced)" : "ۋاقتى ئۆتۈش ۋاقتى (مەجبۇرىي)",
    "Enter expiration date" : "ۋاقتى ئۆتۈش ۋاقتىنى كىرگۈز",
    "Create share" : "ئورتاقلىشىش",
    "Customize link" : "ئۇلىنىشنى خاسلاشتۇرۇڭ",
    "Generate QR code" : "QR كودى ھاسىل قىلىڭ",
    "Add another link" : "باشقا ئۇلىنىش قوشۇڭ",
    "Create a new share link" : "يېڭى ئورتاقلىشىش ئۇلىنىشى قۇر",
    "Quick share options, the current selected is \"{selectedOption}\"" : "تېز ھەمبەھىرلىنىش تاللانمىلىرى ، نۆۋەتتىكى تاللانغانلار \"{selectedOption}\"",
    "View only" : "پەقەت كۆرۈش",
    "Can edit" : "تەھرىرلىيەلەيدۇ",
    "Custom permissions" : "ئىختىيارى ئىجازەت",
    "Resharing is not allowed" : "قايتا تەقسىم قىلىشقا بولمايدۇ",
    "Name or email …" : "ئىسىم ياكى ئېلخەت  ...",
    "Name, email, or Federated Cloud ID …" : "ئىسمى، ئېلخەت، ياكى فېدراتسىيەلىك بۇلۇت ID  ...",
    "Searching …" : "ئىزدەۋاتىدۇ ",
    "No elements found." : "ھېچقانداق ئېلېمېنت تېپىلمىدى.",
    "Search everywhere" : "ھەممە يەردىن ئىزدەڭ",
    "Guest" : "مېھمان",
    "Group" : "گۇرۇپپا",
    "Email" : "تورخەت",
    "Team" : "ئەتىرەت",
    "Talk conversation" : "پاراڭلىشىش",
    "Deck board" : "پالۋان تاختىسى",
    "ScienceMesh" : "ScienceMesh",
    "on {server}" : "{server}",
    "Enter external recipients" : "سىرتقى تاپشۇرۋالغۇچىنى كىرگۈز",
    "Search for internal recipients" : "ئىچكى تاپشۇرۋالغۇچىنى كىرگۈز",
    "Note from" : "دىققەت قىلىڭ",
    "Note:" : "ئەسكەرتىش:",
    "File drop" : "ھۆججەت چۈشۈرۈش",
    "Upload files to {foldername}." : "ھۆججەتلەرنى {foldername} نامىغا يۈكلەڭ.",
    "By uploading files, you agree to the terms of service." : "ھۆججەتلەرنى يوللاش ئارقىلىق مۇلازىمەت شەرتلىرىگە قوشۇلىسىز.",
    "Successfully uploaded files" : "ھۆججەتلەر مۇۋاپىقىيەتلىك چىقىرىلدى",
    "View terms of service" : "مۇلازىمەت شەرتلىرىنى كۆرۈش",
    "Terms of service" : "مۇلازىمەت شەرتلىرى",
    "Share with {user}" : "{user} بىلەن ھەمبەھىرلە",
    "Share with email {email}" : "ئېلېكترونلۇق خەت {email} خەت",
    "Share with group" : "گۇرۇپپا بىلەن ئورتاقلىشىش",
    "Share in conversation" : "سۆھبەتتە ئورتاقلىشىڭ",
    "Share with {user} on remote server {server}" : "يىراقتىكى مۇلازىمېتىردا {user} بىلەن ئورتاقلىشىش {server}",
    "Share with remote group" : "يىراق گۇرۇپپا بىلەن ئورتاقلىشىڭ",
    "Share with guest" : "مېھمان بىلەن ئورتاقلىشىڭ",
    "Update share" : "ھەمبەھىرنى يېڭىلاش",
    "Save share" : "ئورتاقلىشىشنى ساقلاڭ",
    "Read" : "ئوقۇ",
    "Create" : "قۇر",
    "Edit" : "تەھرىر",
    "Share" : "ھەمبەھىر",
    "Delete" : "ئۆچۈر",
    "Password field cannot be empty" : "پارول ئورنى قۇرۇق بولسا بولمايدۇ",
    "Replace current password" : "نۆۋەتتىكى پارولنى ئالماشتۇرۇڭ",
    "Failed to generate a new token" : "يېڭى نۇمۇر ھاسىل قىلىش مەغلۇپ بولدى",
    "Allow upload and editing" : "يوللاش ۋە تەھرىرلەشكە يول قويۇڭ",
    "Allow editing" : "تەھرىرلەشكە يول قويۇڭ",
    "Upload only" : "پەقەت يۈكلەڭ",
    "Advanced settings" : "ئىلغار تەڭشەكلەر",
    "Share label" : "ئورتاقلىشىش بەلگىسى",
    "Share link token" : "ئۇلىنىش نۇمۇرىنى ھەمبەھىرلە",
    "Set the public share link token to something easy to remember or generate a new token. It is not recommended to use a guessable token for shares which contain sensitive information." : "ئاممىۋى ئورتاقلىشىش ئۇلىنىش بەلگىسىنى ئاسان ئېسىدە ساقلىنىدىغان قىلىپ تەڭشەڭ ياكى يېڭى بەلگە ھاسىل قىلىڭ. مەخپىي ئۇچۇرلارنى ئۆز ئىچىگە ئالغان ئورتاقلىشىشلار ئۈچۈن پەرەز قىلغىلى بولىدىغان بەلگە ئىشلىتىش تەۋسىيە قىلىنمايدۇ.",
    "Generating…" : "ياساۋاتىدۇ...",
    "Generate new token" : "يېڭى نۇمۇر ياساۋاتىدۇ",
    "Set password" : "پارول بەلگىلەڭ",
    "Password expires {passwordExpirationTime}" : "پارولنىڭ ۋاقتى توشىدۇ {passwordExpirationTime}",
    "Password expired" : "پارولنىڭ ۋاقتى توشتى",
    "Video verification" : "سىن دەلىللەش",
    "Expiration date (enforced)" : "مۇددىتى توشقان (ئىجرا قىلىنغان)",
    "Set expiration date" : "ۋاقتى توشىدۇ",
    "Hide download" : "چۈشۈرۈشنى يوشۇرۇش",
    "Allow download and sync" : "چۈشۈرۈش ۋە ماسقەدەملەشكە يول قويۇڭ",
    "Note to recipient" : "تاپشۇرۇۋالغۇچىغا دىققەت قىلىڭ",
    "Enter a note for the share recipient" : "ھەمبەھىر تاپشۇرۇۋالغۇچىغا خاتىرە يېزىڭ",
    "Show files in grid view" : "تورسىمان كۆرۈنۈشتە كۆرسەت",
    "Delete share" : "ھەمبەھىرنى ئۆچۈرۈڭ",
    "Others with access" : "باشقىلار بار",
    "No other accounts with access found" : "باشقا ھېساباتلار تېپىلمىدى",
    "Toggle list of others with access to this directory" : "بۇ مۇندەرىجىگە ئېرىشەلەيدىغان باشقىلارنىڭ تىزىملىكىنى ئالماشتۇرۇڭ",
    "Toggle list of others with access to this file" : "بۇ ھۆججەتنى زىيارەت قىلالايدىغان باشقىلارنىڭ تىزىملىكىنى ئالماشتۇرۇڭ",
    "Unable to fetch inherited shares" : "مىراس قالغان پايلارنى ئالالمىدى",
    "Link shares" : "ئۇلىنىش پايلىرى",
    "Shares" : "ھەمبەھىرلەر",
    "Share files within your organization. Recipients who can already view the file can also use this link for easy access." : "ھۆججەتلەرنى تەشكىلاتىڭىز ئىچىدە ئورتاقلىشىڭ. ھۆججەتنى كۆرەلەيدىغان قوبۇل قىلغۇچىلارمۇ ئاسان ئېرىشىش ئۈچۈن بۇ ئۇلىنىشنى ئىشلىتەلەيدۇ.",
    "Share files with others outside your organization via public links and email addresses. You can also share to {productName} accounts on other instances using their federated cloud ID." : "ئاممىۋى ئۇلىنىشلار ۋە ئېلخەت ئادرېسلىرى ئارقىلىق تەشكىلاتىڭىز سىرتىدىكى باشقىلار بىلەن ھۆججەتلەرنى ئورتاقلىشىڭ. سىز يەنە باشقا ئەھۋاللاردا {productName} ھېساباتلىرى بىلەن ئۇلارنىڭ بىرلەشمە بۇلۇت كىملىكىنى ئىشلىتىپ ئورتاقلىشالايسىز.",
    "Shares from apps or other sources which are not included in internal or external shares." : "ئىچكى ياكى تاشقى ئورتاقلىشىشقا كىرمەيدىغان ئەپلەر ياكى باشقا مەنبەلەردىن ئېلىنغان ئورتاقلىشىشلار.",
    "Type names, teams, federated cloud IDs" : "ئىسىم، ئەتىرەت، فېدراتسىيەلىك بۇلۇت ID لىرىنى كىرگۈز",
    "Type names or teams" : "ئىسىم ياكى ئەتىرەت كىرگۈز",
    "Type a federated cloud ID" : "بىر فېدراتسىيەلىك بۇلۇت ID كىرگۈز",
    "Type an email" : "بىر ئېلخەت كىرگۈز",
    "Type an email or federated cloud ID" : "بىر ئېلخەت ياكى فېدراتسىيەلىك بۇلۇت ID كىرگۈز",
    "Unable to load the shares list" : "پاي تىزىملىكىنى يۈكلىيەلمىدى",
    "Expires {relativetime}" : "ۋاقتى {relativetime} ۋاقىت",
    "this share just expired." : "بۇ ئۈلۈشنىڭ ۋاقتى توشتى.",
    "Shared with you by {owner}" : "{owner} سىز بىلەن ئورتاقلاشتى",
    "Internal shares" : "ئىچكى ھەمبەھىر",
    "Internal shares explanation" : "ئىچكى ھەمبەھىر چۈشەندۈرۈشلەر",
    "External shares" : "سىرتقى ھەمبەھىر",
    "External shares explanation" : "سىرتقى ھەمبەھىر چۈشەندۈرۈشلەر",
    "Additional shares" : "قۇشۇمچە ھەمبەھىر",
    "Additional shares explanation" : "قوشۇمچە ھەمبەھىر چۈشەندۈرۈشلەر",
    "Link to a file" : "ھۆججەتكە ئۇلىنىش",
    "_Accept share_::_Accept shares_" : ["ھەمبەھىرنى قۇبۇللا","ھەمبەھىرنى قۇبۇللا"],
    "Open in Files" : "ھۆججەتلەرنى ئېچىڭ",
    "_Reject share_::_Reject shares_" : ["ھەمبەھىرنى رەت قىل","ھەمبەھىرنى رەت قىل"],
    "_Restore share_::_Restore shares_" : ["ھەمبەھىرنى ئەسلىگە قايتۇر","ھەمبەھىرنى ئەسلىگە قايتۇر"],
    "Shared" : "ئورتاقلاشتى",
    "Shared by {ownerDisplayName}" : "{ownerDisplayName} بىلەن ئورتاقلاشتى",
    "Shared multiple times with different people" : "ئوخشىمىغان كىشىلەر بىلەن كۆپ قېتىم ئورتاقلاشتى",
    "Sharing options" : "ھەمبەھىر تاللانمىلىرى",
    "Shared with others" : "باشقىلار بىلەن ئورتاقلاشتى",
    "You do not have enough permissions to share this file." : "سىزنىڭ بۇ ھۆججەتنى ھەمبەھىرلىگۈدەك يىتەرلىك ھوقوقىڭىز يوق.",
    "People" : "كىشىلەر",
    "Create file request" : "ھۆججەت تەلەپ قىلىش",
    "Upload files to {foldername}" : "ھۆججەتلەرنى {foldername} نامىغا يۈكلەڭ",
    "Public file share" : "ئاممىۋى ھۆججەت ئورتاقلىشىش",
    "Publicly shared file." : "ئاشكارا ھۆججەت.",
    "No file" : "ھۆججەت يوق",
    "The file shared with you will show up here" : "سىز بىلەن ئورتاقلاشقان ھۆججەت بۇ يەردە كۆرۈنىدۇ",
    "Public share" : "جامائەت ئۈلۈشى",
    "Publicly shared files." : "ئورتاق بەھرىلىنىدىغان ھۆججەتلەر.",
    "No files" : "ھۆججەت يوق",
    "Files and folders shared with you will show up here" : "سىز بىلەن ئورتاقلاشقان ھۆججەت ۋە ھۆججەت قىسقۇچلار بۇ يەردە كۆرۈنىدۇ",
    "Overview of shared files." : "ئورتاق ھۆججەتلەرنىڭ ئومۇمىي ئەھۋالى.",
    "No shares" : "پاي يوق",
    "Files and folders you shared or have been shared with you will show up here" : "سىز ئورتاقلاشقان ياكى سىز بىلەن ئورتاقلاشقان ھۆججەت ۋە ھۆججەت قىسقۇچلار بۇ يەردە كۆرۈنىدۇ",
    "Shared with you" : "سىز بىلەن ھەمبەھىرلىدى",
    "List of files that are shared with you." : "سىز بىلەن ئورتاقلاشقان ھۆججەتلەرنىڭ تىزىملىكى.",
    "Nothing shared with you yet" : "ھازىرچە ھېچنېمە ھەمبەھىرلەنمىدى",
    "Files and folders others shared with you will show up here" : "باشقىلار سىز بىلەن ئورتاقلاشقان ھۆججەت ۋە ھۆججەت قىسقۇچلار بۇ يەردە كۆرۈنىدۇ",
    "List of files that you shared with others." : "باشقىلار بىلەن ئورتاقلاشقان ھۆججەتلەرنىڭ تىزىملىكى.",
    "Nothing shared yet" : "ھازىرچە ھېچقانداق نەرسە ئورتاقلاشمىدى",
    "Files and folders you shared will show up here" : "سىز ئورتاقلاشقان ھۆججەت ۋە ھۆججەت قىسقۇچلار بۇ يەردە كۆرۈنىدۇ",
    "Shared by link" : "ئۇلىنىش ئارقىلىق ئورتاقلاشتى",
    "List of files that are shared by link." : "ئۇلىنىش ئارقىلىق ھەمبەھىرلىنىدىغان ھۆججەتلەرنىڭ تىزىملىكى.",
    "No shared links" : "ئورتاق ئۇلىنىش يوق",
    "Files and folders you shared by link will show up here" : "ئۇلىنىش ئارقىلىق ئورتاقلاشقان ھۆججەت ۋە ھۆججەت قىسقۇچلار بۇ يەردە كۆرۈنىدۇ",
    "File requests" : "ھۆججەت تەلەپلىرى",
    "List of file requests." : "ھۆججەت تەلەپلىرى تىزىملىكى.",
    "No file requests" : "ھۆججەت تەلەپ قىلمايدۇ",
    "File requests you have created will show up here" : "سىز قۇرغان ھۆججەت تەلەپلىرى بۇ يەردە كۆرۈنىدۇ",
    "Deleted shares" : "ئۆچۈرۈلگەن پايلار",
    "List of shares you left." : "سىز قالدۇرغان پاي تىزىملىكى.",
    "No deleted shares" : "ئۆچۈرۈلگەن پاي يوق",
    "Shares you have left will show up here" : "سىز قالدۇرغان پايلار بۇ يەردە كۆرۈنىدۇ",
    "Pending shares" : "ساقلىنىۋاتقان پايلار",
    "List of unapproved shares." : "تەستىقتىن ئۆتمىگەن پاي تىزىملىكى.",
    "No pending shares" : "ساقلىنىۋاتقان پاي يوق",
    "Shares you have received but not approved will show up here" : "تاپشۇرۇۋالغان ، ئەمما تەستىقلانمىغان پايلار بۇ يەردە كۆرۈنىدۇ",
    "Error deleting the share" : "ھەمبەھىرنى ئۆچۈرۈش خاتالىقى",
    "Error updating the share" : "ھەمبەھىرنى يېڭىلاشتا خاتالىق",
    "File \"{path}\" has been unshared" : "ھۆججەت \"{path}\" ھەمبەھىرلەنمىدى",
    "Folder \"{path}\" has been unshared" : "ھۆججەت قىسقۇچ \"{path}\" ئورتاقلاشمىدى",
    "Could not update share" : "ھەمبەھىرنى يېڭىلىيالمىدى",
    "Share saved" : "ھەمبەھىرلەندى",
    "Share expiry date saved" : "ئورتاقلىشىش ۋاقتى ساقلاندى",
    "Share hide-download state saved" : "ھەمبەھىرلەش-چۈشۈرۈش ھالىتى ئورتاقلاشتى",
    "Share label saved" : "ئورتاقلىشىش بەلگىسى ساقلاندى",
    "Share note for recipient saved" : "تاپشۇرۇۋالغۇچى ئۈچۈن خاتىرە قالدۇرۇڭ",
    "Share password saved" : "پارولنى ئورتاقلاشتى",
    "Share permissions saved" : "ئورتاقلىشىش ئىجازەتلىرى ساقلاندى",
    "To upload files to {folder}, you need to provide your name first." : "{folder} غا ھۆججەت چىقىرىش ئۈچۈن، ئىسمىڭىزنى تەمىنلىشىڭىز كېرەك.",
    "Upload files to {folder}" : "ھۆججەتلەرنى {folder} يۈكلەڭ",
    "Please confirm your name to upload files to {folder}" : "{folder} غا ھۆججەت چىقىرىش ئۈچۈن ئىسمىڭىزنى جەزىملەشتۈرۈڭ",
    "{ownerDisplayName} shared a folder with you." : "{ownerDisplayName} ھۆججەت قىسقۇچنى سىز بىلەن ئورتاقلاشتى.",
    "Names must not be empty." : "ئىسىم قۇرۇق بولسا بولمايدۇ.",
    "Names must not start with a dot." : "ئىسىم چىكىت بىلەن باشلانمايدۇ",
    "\"{char}\" is not allowed inside a name." : "\"{char}\" ئىسىمنىڭ ئىچىدە بولسا بولمايدۇ.",
    "\"{segment}\" is a reserved name and not allowed." : "\"{segment}\" ئالاھىدە ئىسىم ھەمدە يول قۇيۇلمايدۇ.",
    "\"{extension}\" is not an allowed name." : "\"{extension}\" يول قۇيۇلغان ئىسىم ئەمەس.",
    "Names must not end with \"{extension}\"." : "ئىسىم \"{extension}\" بىلەن ئاخىرلاشمايدۇ.",
    "Invalid name." : "ئىناۋەتسىز ئىسىم.",
    "Password created successfully" : "پارول مۇۋەپپەقىيەتلىك قۇرۇلدى",
    "Error generating password from password policy" : "پارول سىياسىتىدىن پارول ھاسىل قىلىشتا خاتالىق",
    "Shared with you and the group {group} by {owner}" : "سىز ۋە گۇرۇپپا {group} بىلەن ئورتاقلاشتى {owner}",
    "Shared with you and {circle} by {owner}" : "سىز بىلەن ھەمبەھىرلەنگەن {circle} {owner}",
    "Shared with you and the conversation {conversation} by {owner}" : "سىز بىلەن ھەمبەھىرلەنگەن سۆھبەت {conversation} {owner} تەرىپىدىن",
    "Shared with you in a conversation by {owner}" : "{owner} نىڭ سۆھبىتىدە سىز بىلەن ئورتاقلاشتى",
    "Share not found" : "ھەمبەھىر تېپىلمىدى",
    "Back to %s" : "%s گە قايتىش",
    "Add to your Nextcloud" : "Nextcloud غا قوشۇڭ",
    "Group sharing is disabled by the administrator" : "گۇرۇپپا ئورتاقلىشىش باشقۇرغۇچى تەرىپىدىن چەكلەنگەن",
    "Public link sharing is disabled by the administrator" : "ئاممىۋى ئۇلىنىشنى ھەمبەھىرلەش باشقۇرغۇچى تەرىپىدىن چەكلەنگەن",
    "Sharing %1$s failed because the back end does not allow shares from type %2$s" : "%1$s نى ئورتاقلىشىش مەغلۇب بولدى ، چۈنكى ئارقا تەرىپى %2$s دىن پاي چېكىگە يول قويمايدۇ",
    "Sharing %s failed because the back end does not support ScienceMesh shares" : "%s نى ئورتاقلىشىش مەغلۇب بولدى ، چۈنكى ئارقا تەرىپى ScienceMesh نىڭ پاي چېكىنى قوللىمايدۇ",
    "Public upload disabled by the administrator" : "باشقۇرغۇچى تەرىپىدىن ئاممىۋى يوللاش چەكلەنگەن",
    "Tokens must contain at least 1 character and may only contain letters, numbers, or a hyphen" : "بەلگىلەر كەم دېگەندە 1 ھەرپتىن تەركىب تاپقان بولۇشى كېرەك، پەقەت ھەرپلەر، سانلار ياكى سىزىقچە بولۇشى مۇمكىن.",
    "Name or email …" : "ئىسىم ياكى ئېلخەت…",
    "Name, email, or Federated Cloud ID …" : "ئىسمى ، ئېلېكترونلۇق خەت ياكى فېدېراتسىيە بۇلۇت كىملىكى…",
    "Searching …" : "ئىزدەش…"
},
"nplurals=2; plural=(n != 1);");
