OC.L10N.register(
    "files",
    {
    "Added to favorites" : "ياقتۇرىدىغانلارغا قوشۇلدى",
    "Removed from favorites" : "ياقتۇرىدىغانلاردىن ئۆچۈرۈلدى",
    "You added {file} to your favorites" : "ياقتۇرىدىغانلىرىڭىزغا {file} قوشتىڭىز",
    "You removed {file} from your favorites" : "ياقتۇرىدىغانلىرىڭىزدىن {file} نى ئۆچۈردىڭىز",
    "Favorites" : "يىغقۇچ",
    "File changes" : "ھۆججەت ئۆزگەرتىش",
    "Created by {user}" : "{user} قۇرغان",
    "Changed by {user}" : "{user} تەرىپىدىن ئۆزگەرتىلدى",
    "Deleted by {user}" : "{user} by تەرىپىدىن ئۆچۈرۈلدى",
    "Restored by {user}" : "{user} تەرىپىدىن ئەسلىگە كەلتۈرۈلدى",
    "Renamed by {user}" : "{user} تەرىپىدىن ئۆزگەرتىلدى",
    "Moved by {user}" : "{user} تەرىپىدىن يۆتكەلدى",
    "\"remote account\"" : "\"يىراقتىكى ھېسابات\"",
    "You created {file}" : "سىز {file} قۇردىڭىز",
    "You created an encrypted file in {file}" : "سىز {file} دە شىفىرلانغان ھۆججەت قۇردىڭىز",
    "{user} created {file}" : "{user} قۇرغان {file}",
    "{user} created an encrypted file in {file}" : "{user} {file} شىفىرلانغان ھۆججەت قۇردى",
    "{file} was created in a public folder" : "{file} public ئاممىۋى ھۆججەت قىسقۇچتا قۇرۇلدى",
    "You changed {file}" : "{file} ئۆزگەرتتىڭىز",
    "You changed an encrypted file in {file}" : "سىز شىفىرلانغان ھۆججەتنى {file} گە ئۆزگەرتتىڭىز",
    "{user} changed {file}" : "{user} ئۆزگەرتىلگەن {file}",
    "{user} changed an encrypted file in {file}" : "{user} شىفىرلانغان ھۆججەتنى {file} گە ئۆزگەرتتى",
    "You deleted {file}" : "{file} ئۆچۈردىڭىز",
    "You deleted an encrypted file in {file}" : "سىز {file} دىكى شىفىرلانغان ھۆججەتنى ئۆچۈردىڭىز",
    "{user} deleted {file}" : "{user} ئۆچۈرۈلگەن {file}",
    "{user} deleted an encrypted file in {file}" : "{user} شىفىرلانغان ھۆججەتنى {file} ئۆچۈردى",
    "You restored {file}" : "{file} ئەسلىگە كەلتۈردىڭىز",
    "{user} restored {file}" : "{user} ئەسلىگە كەلتۈرۈلگەن {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "سىز {oldfile} (يوشۇرۇن) نى {newfile} (يوشۇرۇن) غا ئۆزگەرتتىڭىز",
    "You renamed {oldfile} (hidden) to {newfile}" : "سىز {oldfile} (يوشۇرۇن) نى {newfile} غا ئۆزگەرتتىڭىز",
    "You renamed {oldfile} to {newfile} (hidden)" : "سىز {oldfile} غا {newfile} (يوشۇرۇن) دەپ ئىسىم قويدىڭىز",
    "You renamed {oldfile} to {newfile}" : "سىز {oldfile} غا {newfile} غا ئۆزگەرتتىڭىز",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} ئۆزگەرتىلگەن {oldfile} (يوشۇرۇن) {newfile} (يوشۇرۇن)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} ئۆزگەرتىلگەن {oldfile} (يوشۇرۇن) {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} ئۆزگەرتىلگەن {oldfile} دىن {newfile} (يوشۇرۇن)",
    "{user} renamed {oldfile} to {newfile}" : "{user} ئۆزگەرتىلگەن {oldfile} دىن {newfile}",
    "You moved {oldfile} to {newfile}" : "سىز {oldfile} نى {newfile} غا يۆتكىدىڭىز",
    "{user} moved {oldfile} to {newfile}" : "{user} {oldfile} نى {newfile} غا يۆتكىدى",
    "A file has been added to or removed from your <strong>favorites</strong>" : "ھۆججەتلىرىڭىز <strong> ياقتۇرىدىغان </strong> غا قوشۇلدى ياكى ئۆچۈرۈلدى",
    "Files" : "ھۆججەتلەر",
    "A file or folder has been <strong>changed</strong>" : "ھۆججەت ياكى ھۆججەت قىسقۇچ <strong> ئۆزگەرتىلدى </strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "ياقتۇرىدىغان ھۆججەت ياكى ھۆججەت قىسقۇچ <strong> ئۆزگەرتىلدى </strong>",
    "Failed to authorize" : "ھوقۇق بېرىش مەغلۇب بولدى",
    "Invalid folder path" : "ھۆججەت قىسقۇچ يولى ئىناۋەتسىز",
    "Folder not found" : "ھۆججەت قىسقۇچ تېپىلمىدى",
    "The file cannot be found" : "ھۆججەتنى تاپقىلى بولمىدى",
    "The destination path does not exist: %1$s" : "نىشان يول مەۋجۇت ئەمەس: %1$s",
    "You do not have permission to create a file at the specified location" : "سىزنىڭ بەلگىلەنگەن ئورۇندا ھۆججەت قۇرۇش ھوقوقىڭىز يوق",
    "The file could not be converted." : "ھۆججەتنى ئايلاندۇرغىلى بولمىدى",
    "Could not get relative path to converted file" : "ئايلاندۇرغان ھۆججەتنىڭ نىسپىي يولىغا ئېرىشكىلى بولمىدى",
    "Limit must be a positive integer." : "چەك چوقۇم مۇسبەت سان بولىشى كېرەك",
    "The replacement character may only be a single character." : "ئالماشتۇرۇش ھەرىپى چوقۇم تاق ھەرىپ بولىشى كېرەك",
    "Filename sanitization already started." : "ھۆججەت نامىنى دىزىنفىكسىيەلەش باشلاندى.",
    "No filename sanitization in progress." : "ھۆججەت نامىنى دىزىنفىكسىيەلەش داۋاملىشىۋاتىدۇ",
    "Favorite files" : "ياقتۇردىغان ھۆججەتلەر",
    "No favorites" : "ياقتۇردىغان يوق",
    "More favorites" : "كۆپ ياقتۇردىغان",
    "Accept" : "قوبۇل قىلىڭ",
    "Reject" : "رەت قىلىش",
    "Incoming ownership transfer from {user}" : "{user} دىن كەلگەن ئىگىدارلىق ھوقۇقىنى يۆتكەش",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "{path} نى قوبۇل قىلامسىز؟\n\nئەسكەرتىش: قوبۇل قىلغاندىن كېيىن يۆتكىلىش جەريانى 1 سائەتكە يېتىشى مۇمكىن.",
    "Ownership transfer denied" : "ئىگىدارلىق ھوقۇقىنى يۆتكەش رەت قىلىندى",
    "Your ownership transfer of {path} was denied by {user}." : "{path} نىڭ ئىگىدارلىق ھوقۇقىڭىزنى {user} رەت قىلدى.",
    "Ownership transfer failed" : "ئىگىدارلىق ھوقۇقىنى يۆتكەش مەغلۇب بولدى",
    "Your ownership transfer of {path} to {user} failed." : "ئىگىدارلىق ھوقۇقىڭىز {path} دىن {user} غا يۆتكەلدى.",
    "The ownership transfer of {path} from {user} failed." : "{path} نىڭ {user} دىن ئىگىدارلىق ھوقۇقىنى يۆتكەش مەغلۇب بولدى.",
    "Ownership transfer done" : "ئىگىدارلىق ھوقۇقىنى يۆتكەش ئېلىپ بېرىلدى",
    "Your ownership transfer of {path} to {user} has completed." : "ئىگىدارلىق ھوقۇقىڭىزنى {path} دىن {user} غا يۆتكەش تاماملاندى.",
    "The ownership transfer of {path} from {user} has completed." : "{path} نىڭ {user} دىن ئىگىدارلىق ھوقۇقىنى يۆتكەش تاماملاندى.",
    "in %s" : "%s دە",
    "Transferred from %1$s on %2$s" : "%2$s دا %1$s دىن يۆتكەلدى",
    "Delete files" : "ھۆججەتلەرنى ئۆچۈرۈڭ",
    "Show files in grid view" : "تورسىمان كۆرۈنۈشتە كۆرسەت",
    "File" : "ھۆججەت",
    "File Management" : "ھۆججەت باشقۇرۇش",
    "Home" : "ئۆي",
    "Target folder does not exist any more" : "نىشان ھۆججەت قىسقۇچ ئەمدى مەۋجۇت ئەمەس",
    "Reload current directory" : "نۆۋەتتىكى مۇندەرىجىنى قايتا يۈكلەڭ",
    "Go to the \"{dir}\" directory" : "\"{dir}\" مۇندەرىجىسىگە كىرىڭ",
    "Current directory path" : "نۆۋەتتىكى مۇندەرىجە يولى",
    "Share" : "ھەمبەھىرلەش",
    "Your have used your space quota and cannot upload files anymore" : "بوشلۇق نورمىسىنى ئىشلىتىپ ، ھۆججەتلەرنى ئەمدى يۈكلىيەلمەيسىز",
    "You do not have permission to upload or create files here." : "بۇ يەرگە ھۆججەت يوللاش ياكى قۇرۇش ھوقۇقىڭىز يوق.",
    "Drag and drop files here to upload" : "ھۆججەتلەرنى بۇ يەرگە سۆرەپ تاشلاڭ",
    "Favorite" : "يىغقۇچ",
    "Back" : "قايتىش",
    "Toggle selection for file \"{displayName}\"" : "«{displayName}» ھۆججىتىنى تاللاڭ.",
    "Toggle selection for folder \"{displayName}\"" : "ھۆججەت قىسقۇچنى تاللاش \"{displayName}\"",
    "File is loading" : "ھۆججەت يۈكلىنىۋاتىدۇ",
    "Folder is loading" : "ھۆججەت قىسقۇچ يۈكلىنىۋاتىدۇ",
    "Filename" : "ھۆججەت ئىسمى",
    "Folder name" : "قىسقۇچ ئاتى",
    "Another entry with the same name already exists." : "ئوخشاش ئىسىمدىكى يەنە بىر تۈر بار.",
    "Invalid filename." : "ئىناۋەتسىز ھۆججەت ئىسمى.",
    "Rename file" : "ھۆججەتنىڭ نامىنى ئۆزگەرتىش",
    "Folder" : "قىسقۇچ",
    "Unknown file type" : "نامەلۇم ھۆججەت تىپى",
    "{ext} image" : "{ext} سۈرەت",
    "{ext} video" : "{ext} سىن",
    "{ext} audio" : "{ext} ئاۋاز",
    "{ext} text" : "{ext} تېكىست",
    "Pending" : "كۈتۈۋاتىدۇ",
    "Unknown date" : "نامەلۇم چېسلا",
    "Active filters" : "ئاكتىپ سۈزگۈچ",
    "Remove filter" : "سۈزگۈچنى ئۆچۈرۈڭ",
    "Today" : "بۈگۈن",
    "Last 7 days" : "ئاخىرقى 7 كۈن",
    "Last 30 days" : "ئاخىرقى 30 كۈن",
    "This year ({year})" : "بۇ يىل ({year})",
    "Last year ({year})" : "ئۆتكەن يىلى ({year})",
    "Custom date range" : "ئىختىيارى چېسلا دائىرىسى",
    "Search everywhere" : "ھەممە يەردىن ئىزدەڭ",
    "Documents" : "ھۆججەتلەر",
    "Spreadsheets" : "ئېلېكترونلۇق جەدۋەل",
    "Presentations" : "لېكسىيە",
    "PDFs" : "PDF",
    "Folders" : "ھۆججەت قىسقۇچ",
    "Audio" : "ئاۋاز",
    "Images" : "سۈرەتلەر",
    "Videos" : "سىنلار",
    "Filters" : "سۈزگۈچ",
    "Appearance" : "كۆرۈنۈش",
    "Show hidden files" : "يوشۇرۇن ھۆججەتلەرنى كۆرسەت",
    "Show file type column" : "ھۆججەت تىپى قاتارىنى كۆرسەت",
    "Show file extensions" : "ھۆججەت كېڭەيتمىسىنى كۆرسەت",
    "Crop image previews" : "رەسىمنى ئالدىن كۆرۈش",
    "General" : "ئۇمۇمىي",
    "Sort favorites first" : "ياقتۇرىدىغانلارنى رەتلەڭ",
    "Sort folders before files" : "ھۆججەتلەرنى ھۆججەتتىن بۇرۇن تەرتىپلەڭ",
    "Enable folder tree view" : "قىسقۇچ شاخسىمان كۆرۈنۈشىنى قوزغات",
    "Default view" : "كۆڭۈلدىكى كۆرۈنۈش",
    "All files" : "بارلىق ھۆججەتلەر",
    "Personal files" : "شەخسىي ھۆججەتلەر",
    "Additional settings" : "قوشۇمچە تەڭشەكلەر",
    "Actions" : "مەشغۇلاتلار",
    "File actions" : "ھۆججەت ھەرىكىتى",
    "Selection" : "تاللاش",
    "Select all files" : "ھەممە ھۆججەتلەرنى تاللا",
    "Deselect all" : "ھەممىنى تاللاڭ",
    "Select or deselect" : "تاللا ياكى تاللىما",
    "Select a range" : "بىر دائىرىنى تاللا",
    "Navigation" : "يول باشلاش",
    "Go to parent folder" : "باش قىسقۇچقا بار",
    "Go to file above" : "ئۈستىدىكى ھۆججەتكە بار",
    "Go to file below" : "ئاستىدىكى ھۆججەتكە بار",
    "Go left in grid" : "سولغا بار",
    "Go right in grid" : "ئوڭغا بار",
    "View" : "كۆرۈنۈش",
    "Toggle grid view" : "تورسىمان كۆرۈنۈشنى قوزغات",
    "Show those shortcuts" : "ئۇ قىسقايولنى كۆرسەت",
    "Warnings" : "ئاگاھلاندۇرۇش",
    "Warn before changing a file extension" : "بىر ھۆججەت كېڭەيتىلمىسىنى ئۆزگەرتىشتىن بۇرۇن ئاگاھلاندۇر",
    "Warn before deleting a file" : "بىر ھۆججەتنى ئۆچۈرۈشتىن بۇرۇن ئاگاھلاندۇر",
    "WebDAV URL" : "WebDAV URL",
    "Create an app password" : "بىر ئەپ پارولى قۇر",
    "Required for WebDAV authentication because Two-Factor Authentication is enabled for this account." : "بۇ ھېسابات ئۈچۈن ئىككى ئامىللىق دەلىللەش قوزغىتىلغان بولغاچقا، WebDAV دەلىللەش ئۈچۈن تەلەپ قىلىنىدۇ.",
    "How to access files using WebDAV" : "WebDAV ئارقىلىق ھۆججەتلەرگە قانداق كىرىش كېرەك",
    "Total rows summary" : "ئومۇمىي قۇر خۇلاسىسى",
    "Toggle selection for all files and folders" : "بارلىق ھۆججەت ۋە ھۆججەت قىسقۇچلارنى تاللاڭ",
    "Name" : "ئاتى",
    "File type" : "ھۆججەت تىپى",
    "Size" : "چوڭلۇقى",
    "Modified" : "ئۆزگەرتكەن",
    "{displayName}: failed on some elements" : "{displayName}: بەزى ئېلېمېنتلاردا مەغلۇپ بولدى ",
    "{displayName}: done" : "{displayName}: پۈتتى",
    "{displayName}: failed" : "{displayName}: مەغلۇپ بولدى",
    "(selected)" : "(تاللانغان)",
    "List of files and folders." : "ھۆججەت ۋە ھۆججەت قىسقۇچلارنىڭ تىزىملىكى.",
    "You have used your space quota and cannot upload files anymore." : "بوشلۇق كۋوتىڭىزنى ئىشلەتتىڭىز، ئەمدى ھۆججەتلەرنى يۈكلىيەلمەيسىز.",
    "Column headers with buttons are sortable." : "كۇنۇپكىلار بار ئىستون ماۋزۇلىرى تەرتىپلىك.",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "بۇ تىزىملىك ئىقتىدار سەۋەبىدىن تولۇق كۆرسىتىلمىگەن. ھۆججەتلەر تىزىملىكتىن ئۆتكەندە كۆرسىتىلىدۇ.",
    "File not found" : "ھۆججەت تېپىلمىدى",
    "_{count} selected_::_{count} selected_" : ["{count} تاللاندى","{count} تاللاندى"],
    "Views" : "كۆرۈنۈشلەر",
    "Search everywhere …" : "ھەممە يەردە ئىزدە  ...",
    "Search here …" : "بۇ يەردە ئىزدە  ...",
    "Search scope options" : "ئىزدەش دائىرە تاللانمىسى",
    "Search here" : "بۇ يەردە ئىزدە",
    "Owner" : "ئىگىسى",
    "{usedQuotaByte} used" : "{usedQuotaByte} ئىشلىتىلگەن",
    "{used} of {quota} used" : "{used} {quota} ئىشلىتىلگەن",
    "{relative}% used" : "{relative}% ئىشلىتىلگەن",
    "Could not refresh storage stats" : "ساقلاش سانلىق مەلۇماتلىرىنى يېڭىلىيالمىدى",
    "Your storage is full, files can not be updated or synced anymore!" : "ساقلاش بوشلۇقىڭىز تولۇق ، ھۆججەتلەرنى يېڭىلاشقا ياكى ماسقەدەملەشكە بولمايدۇ!",
    "Storage information" : "ساقلاش ئۇچۇرى",
    "Storage quota" : "ساقلاش نورمىسى",
    "New folder" : "يېڭى قىسقۇچ",
    "Create new folder" : "يېڭى ھۆججەت قىسقۇچ قۇر",
    "This name is already in use." : "بۇ ئىسىم ئاللىقاچان ئىشلىتىلىۋاتىدۇ.",
    "Create" : "قۇر",
    "Files starting with a dot are hidden by default" : "نۇقتا بىلەن باشلانغان ھۆججەتلەر ئۆزلۈكىدىن يوشۇرۇنغان بولىدۇ",
    "Failed to start filename sanitization." : "ھۆججەت نامىنى تازىلاشنى باشلاش مەغلۇب بولدى.",
    "Failed to refresh filename sanitization status." : "ھۆججەت نامىنى تازىلاش ھالىتىنى يېڭىلاش مەغلۇب بولدى.",
    "Filename sanitization in progress." : "ھۆججەت نامىنى تازىلاش داۋاملىشىۋاتىدۇ.",
    "Currently {processedUsers} of {totalUsers} accounts are already processed." : "ھازىر {totalUsers} ھېساباتنىڭ {processedUsers} سانى بىر تەرەپ قىلىندى.",
    "Preparing …" : "تەييارلاۋاتىدۇ  ...",
    "Refresh" : "يېڭىلاش",
    "All files have been santized for Windows filename support." : "بارلىق ھۆججەتلەر Windows ھۆججەت نامىنى قوللاش ئۈچۈن تازىلىنىدۇ.",
    "Some files could not be sanitized, please check your logs." : "بەزى ھۆججەتلەرنى تازىلىغىلى بولمىدى، خاتىرىلىرىڭىزنى تەكشۈرۈپ بېقىڭ.",
    "Sanitization errors" : "تازىلاش خاتالىقى",
    "Not sanitized filenames" : "تازىلانمىغان ھۆججەت نامى قالمىدى",
    "Windows filename support has been enabled." : "Windows ھۆججەت نامىنى قوللاش ئىقتىدارى قوزغىتىلدى.",
    "While this blocks users from creating new files with unsupported filenames, existing files are not yet renamed and thus still may break sync on Windows." : "بۇ ئىشلەتكۈچىلەرنىڭ قوللىمايدىغان ھۆججەت ئىسمى بىلەن يېڭى ھۆججەتلەرنى قۇرۇشىنى توسسىمۇ، مەۋجۇت ھۆججەتلەرنىڭ ئىسمى ئۆزگەرتىلمىگەن، شۇڭا Windows سىستېمىسىدا يەنىلا ماسلىشىشنى بۇزۇلۇشى مۇمكىن.",
    "You can trigger a rename of files with invalid filenames, this will be done in the background and may take some time." : "سىز خاتا ئىسىملىق ھۆججەتلەرنىڭ ئىسمىنى ئۆزگەرتەلەيسىز، بۇ ئارقا كۆرۈنۈشتە ئېلىپ بېرىلىدۇ ھەمدە بىر ئاز ۋاقىت كېتىشى مۇمكىن.",
    "Please note that this may cause high workload on the sync clients." : "بۇنىڭ سىنخرونلاشتۇرۇش خېرىدارلىرىغا يۇقىرى يۈك ئېلىپ كېلىشى مۇمكىنلىكىنى ئۇنۇتماڭ.",
    "Limit" : "چەك",
    "This allows to configure how many users should be processed in one background job run." : "بۇ ئارقىلىق بىر قېتىم ئارقا كۆرۈنۈش خىزمىتى ئىجرا قىلىنىۋاتقاندا قانچە ئىشلەتكۈچىنىڭ بىر تەرەپ قىلىنىشى كېرەكلىكىنى تەڭشەشكە بولىدۇ.",
    "Sanitize filenames" : "ھۆججەت نامىنى تازىلا",
    "(starting)" : "(باشلىندۇ)",
    "Fill template fields" : "قېلىپ بۆلەكلىرىنى تولدۇرۇڭ",
    "Submitting fields …" : "ئورۇنلارنى تاپشۇرۋاتىدۇ  ...",
    "Submit" : "يوللاڭ",
    "Choose a file or folder to transfer" : "يۆتكەش ئۈچۈن ھۆججەت ياكى ھۆججەت قىسقۇچنى تاللاڭ",
    "Transfer" : "يۆتكەش",
    "Transfer {path} to {userid}" : "{path} نى {userid} غا يۆتكەڭ",
    "Error while searching for users" : "ئىشلەتكۈچى ئىزدەۋاتقاندا خاتالىق",
    "Ownership transfer request sent" : "ئىگىدارلىق ھوقۇقىنى يۆتكەش ئىلتىماسى ئەۋەتىلدى",
    "Cannot transfer ownership of a file or folder you do not own" : "سىز ئىگە بولمىغان ھۆججەت ياكى ھۆججەت قىسقۇچنىڭ ئىگىدارلىق ھوقۇقىنى يۆتكىگىلى بولمايدۇ",
    "Transfer ownership of a file or folder" : "ھۆججەت ياكى ھۆججەت قىسقۇچنىڭ ئىگىدارلىق ھوقۇقىنى يۆتكەڭ",
    "New owner" : "يېڭى خوجايىن",
    "Keep {old}" : "{old} ساقلا",
    "Keep without extension" : "كېڭەيتىلمىسىز ساقلا",
    "Use {new}" : "{new} نى ئىشلەت",
    "Remove extension" : "كېڭەيتىلمىنى ئۆچۈر",
    "Change file extension" : "ھۆججەت كېڭەيتىلمىسىنى ئۆزگەرت",
    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "ھۆججەت كېڭەيتىلمىسىنى «{old}» دىن «{new}» غا ئۆزگەرتسىڭىز، ھۆججەتنى ئوقۇغىلى بولمايدىغان ھالغا كەلتۈرۈشى مۇمكىن.",
    "Removing the file extension \"{old}\" may render the file unreadable." : "«{old}» ھۆججەت كېڭەيتىلمىسىنى ئۆچۈرۈۋەتسىڭىز، ھۆججەتنى ئوقۇغىلى بولمايدىغان ھالغا كەلتۈرۈشى مۇمكىن.",
    "Adding the file extension \"{new}\" may render the file unreadable." : "«{new}» ھۆججەت كېڭەيتىلمىسىنى قوشسىڭىز، ھۆججەتنى ئوقۇغىلى بولمايدىغان ھالغا كەلتۈرۈشى مۇمكىن.",
    "Do not show this dialog again." : "بۇ دىئالوگنى قايتا كۆرسەتمە.",
    "Cancel" : "ۋاز كەچ",
    "Rename" : "ئات ئۆزگەرت",
    "Select file or folder to link to" : "ئۇلىنىدىغان ھۆججەت ياكى ھۆججەت قىسقۇچنى تاللاڭ",
    "Choose {file}" : "{file} نى تاللاڭ",
    "Files settings" : "ھۆججەت تەڭشىكى",
    "Switch to list view" : "تىزىملىك كۆرۈنۈشىگە ئالماشتۇرۇڭ",
    "Switch to grid view" : "كاتەكچە كۆرۈنۈشكە ئالماشتۇرۇڭ",
    "The file could not be found" : "بۇ ھۆججەت تېپىلمىدى",
    "Upload was cancelled by user" : "ئىشلەتكۈچى يوللاش ئەمەلدىن قالدۇرۇلدى",
    "Not enough free space" : "يېتەرلىك بوشلۇق يوق",
    "Operation is blocked by access control" : "زىيارەتنى كونترول قىلىش ئارقىلىق مەشغۇلات توسۇلۇپ قالىدۇ",
    "Error during upload: {message}" : "يوللاشتىكى خاتالىق: {message}",
    "Error during upload, status code {status}" : "يوللاش جەريانىدا خاتالىق ، ھالەت كودى {status}",
    "Unknown error during upload" : "يوللاش جەريانىدا نامەلۇم خاتالىق",
    "Loading current folder" : "نۆۋەتتىكى ھۆججەت قىسقۇچنى يۈكلەۋاتىدۇ",
    "Retry" : "قايتا سىناڭ",
    "No files in here" : "بۇ يەردە ھۆججەت يوق",
    "Upload some content or sync with your devices!" : "بەزى مەزمۇنلارنى يۈكلەڭ ياكى ئۈسكۈنىڭىز بىلەن ماسقەدەملەڭ!",
    "Go back" : "قايتىڭ",
    "Loading …" : "يۈكلەۋاتىدۇ ...",
    "Your files" : "ھۆججەتلىرىڭىز",
    "Open in files" : "ھۆججەتلەرنى ئېچىڭ",
    "File cannot be accessed" : "ھۆججەتنى زىيارەت قىلغىلى بولمايدۇ",
    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "ھۆججەت تېپىلمىدى ياكى ئۇنى كۆرۈش ھوقۇقىڭىز يوق. ئەۋەتكۈچىدىن ئورتاقلىشىشنى سوراڭ.",
    "No search results for “{query}”" : "\"{query}\" نىڭ ئىزدەش نەتىنجىسى يوق",
    "Search for files" : "ھۆججەتلەرنى ئىزدە",
    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "ھۆججەت نامىنى چەكلەشكە يول قويۇڭ ، ھۆججەتلەرنىڭ بارلىق خېرىدارلار بىلەن ماسقەدەملىنىشىگە كاپالەتلىك قىلىڭ. سۈكۈتتىكى ھالەتتە POSIX (ئىناۋەتلىك Linux ياكى macOS) دىكى بارلىق ھۆججەت ئىسمى رۇخسەت قىلىنىدۇ.",
    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Windows بىلەن ماس كېلىدىغان ھۆججەت ئىسىملىرىنى قوزغىتقاندىن كېيىن، مەۋجۇت ھۆججەتلەرنى ئۆزگەرتكىلى بولمايدۇ، لېكىن ئۇلارنىڭ ئىگىسى ئۇلارنى كۈچكە ئىگە يېڭى ئىسىملار بىلەن ئۆزگەرتەلەيدۇ.",
    "Failed to toggle Windows filename support" : "Windows ھۆججەت نامىنى قوللاش ئىقتىدارىنى ئالماشتۇرۇش مەغلۇب بولدى",
    "Files compatibility" : "ھۆججەتلەرنىڭ ماسلىشىشچانلىقى",
    "Enforce Windows compatibility" : "Windows ماسلىشىشچانلىقىنى كۈچەيتىڭ",
    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "بۇ Windows سىستېمىسىدا كۈچكە ئىگە بولمىغان ھۆججەت نامىنى چەكلەيدۇ ، مەسىلەن زاپاس ئىسىم ياكى ئالاھىدە ھەرپلەرنى ئىشلىتىش دېگەندەك. ئەمما بۇ ئەھۋال سەزگۈرلۈكىنىڭ ماسلىشىشچانلىقىنى ئىجرا قىلمايدۇ.",
    "Blank" : "ئوچۇق",
    "Unable to create new file from template" : "قېلىپتىن يېڭى ھۆججەت قۇرالمىدى",
    "Pick a template for {name}" : "{name} for نىڭ قېلىپىنى تاللاڭ",
    "Create a new file with the selected template" : "تاللانغان قېلىپ بىلەن يېڭى ھۆججەت قۇر",
    "Creating file" : "ھۆججەت قۇرۇش",
    "Save as {displayName}" : "{displayName} سۈپىتىدە ساقلا",
    "Save as …" : "سۈپىتىدە ساقلا  ...",
    "Converting files …" : "ھۆججەتلەرنى ئايلاندۇرۋاتىدۇ  ...",
    "Failed to convert files: {message}" : "ھۆججەتنى ئايلاندۇرۇش مەغلۇپ بولدى: {message}",
    "All files failed to be converted" : "ھەممە ھۆججەتنى ئايلاندۇرۇش مەغلۇپ بولدى",
    "One file could not be converted: {message}" : "بىر ھۆججەتنى ئايلاندۇرغىلى بولمىدى: {message}",
    "_%n file could not be converted_::_%n files could not be converted_" : ["%n ھۆججەتنى ئايلاندۇرغىلى بولمىدى","%n ھۆججەتنى ئايلاندۇرغىلى بولمىدى"],
    "_%n file converted_::_%n files converted_" : ["%nھۆججەت ئايلاندۇرۇلدى","%n ئايلاندۇرۇلدى"],
    "Files converted" : "ھۆججەتلەر ئايلاندۇرۇلدى",
    "Failed to convert files" : "ھۆججەتلەرنى ئايلاندۇرۇش مەغلۇب بولدى",
    "Converting file …" : "ھۆججەتنى ئايلاندۇرۋاتىدۇ  ...",
    "File successfully converted" : "ھۆججەت مۇۋاپىقىيەتلىك ئايلاندۇرۇلدى",
    "Failed to convert file: {message}" : "ھۆججەتنى ئايلاندۇرۇش مەغلۇپ بولدى: {message}",
    "Failed to convert file" : "ھۆججەتنى ئايلاندۇرۇش مەغلۇپ بولدى",
    "Delete" : "ئۆچۈر",
    "Leave this share" : "بۇ ئۈلۈشنى قالدۇرۇڭ",
    "Leave these shares" : "بۇ پايلارنى قالدۇرۇڭ",
    "Disconnect storage" : "ساقلاشنى ئۈزۈڭ",
    "Disconnect storages" : "دۇكانلارنى ئۈزۈڭ",
    "Delete permanently" : "مەڭگۈلۈك ئۆچۈر",
    "Delete and unshare" : "ئۆچۈرۈش ۋە ئورتاقلىشىش",
    "Delete file" : "ھۆججەتنى ئۆچۈرۈڭ",
    "Delete folder" : "ھۆججەت قىسقۇچنى ئۆچۈرۈڭ",
    "Delete folders" : "ھۆججەت قىسقۇچلارنى ئۆچۈرۈڭ",
    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["سىز {count} تارماقنى مەڭگۈلۈك ئۆچۈرمەكچى بولىۋاتىسىز","سىز {count} تارماقنى مەڭگۈلۈك ئۆچۈرمەكچى بولىۋاتىسىز"],
    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["سىز {count} تارماقنى ئۆچۈرمەكچى بولىۋاتىسىز","سىز {count} تارماقنى ئۆچۈرمەكچى بولىۋاتىسىز"],
    "Confirm deletion" : "ئۆچۈرۈشنى جەزملەشتۈرۈڭ",
    "Download" : "چۈشۈر",
    "The requested file is not available." : "تەلەپ قىلىنغان ھۆججەت مەۋجۇت ئەمەس.",
    "The requested files are not available." : "تەلەپ قىلىنغان ھۆججەتلەر مەۋجۇت ئەمەس.",
    "Add to favorites" : "ياقتۇردىغانغا قوش",
    "Remove from favorites" : "ياقتۇردىغاندىن چىقىرۋەت",
    "Add or remove favorite" : "ياقتۇردىغانغا قوش ياكى ئۆچۈر",
    "Move" : "يۆتكە",
    "Copy" : "كۆچۈرۈڭ",
    "Move or copy" : "يۆتكەش ياكى كۆچۈرۈش",
    "Destination is not a folder" : "نىشان بىر قىسقۇچ ئەمەس",
    "This file/folder is already in that directory" : "بۇ ھۆججەت/قىسقۇچ ئۇ مۇندەرىجىدە مەۋجۇت",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "ھۆججەت ياكى ھۆججەت قىسقۇچنى ئۆزىڭىزگە ياكى تارماق قىسقۇچقا يۆتكىيەلمەيسىز",
    "A file or folder with that name already exists in this folder" : "بۇ ھۆججەت قىسقۇچتا بۇ ئىسىم بار ھۆججەت ياكى ھۆججەت قىسقۇچ بار",
    "The files are locked" : "ھۆججەتلەر قۇلۇپلاندى",
    "The file does not exist anymore" : "بۇ ھۆججەت ئەمدى مەۋجۇت ئەمەس",
    "Moving \"{source}\" to \"{destination}\" …" : "\"{source}\" نى \" {destination}\" غا يۆتكەۋاتىدۇ  ...",
    "Copying \"{source}\" to \"{destination}\" …" : "\"{source}\" نى \" {destination}\" غا كۆچۈرۋاتىدۇ  ...",
    "Choose destination" : "مەنزىلنى تاللاڭ",
    "Copy to {target}" : "{target} غا كۆچۈرۈڭ",
    "Move to {target}" : "{target} يۆتكەڭ",
    "Move or copy operation failed" : "يۆتكەش ياكى كۆچۈرۈش مەشغۇلاتى مەغلۇپ بولدى",
    "Open folder" : "ھۆججەت قىسقۇچنى ئېچىڭ",
    "Open folder {displayName}" : "ھۆججەت قىسقۇچ {displayName}",
    "Open in Files" : "ھۆججەتلەرنى ئېچىڭ",
    "Open locally" : "يەرلىكتە ئېچىڭ",
    "Failed to redirect to client" : "خېرىدارغا قايتا نىشانلاش مەغلۇپ بولدى",
    "Open file locally" : "ھۆججەتنى يەرلىكتە ئېچىڭ",
    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "ھۆججەت ھازىر ئۈسكۈنىڭىزدە ئېچىلىشى كېرەك. ئەگەر ئېچىلمىسا، ئۈستەل يۈزى ئەپىڭىزنىڭ ئورنىتىلغانلىقىنى تەكشۈرۈڭ.",
    "Retry and close" : "قايتا سىناپ بېقىڭ ۋە تاقاپ قويۇڭ",
    "Open online" : "توردا ئاچ",
    "Details" : "تەپسىلاتى",
    "Unfavorite" : "ياقتۇرمايدىغان",
    "View in folder" : "قىسقۇچتا كۆرۈش",
    "Type" : "تىپ",
    "Created new folder \"{name}\"" : "يېڭى ھۆججەت قىسقۇچ \"{name}\" قۇرۇلدى",
    "Unable to initialize the templates directory" : "قېلىپ مۇندەرىجىسىنى قوزغىتالمىدى",
    "Create templates folder" : "قېلىپ ھۆججەت قىسقۇچى قۇرۇش",
    "Templates" : "قېلىپلار",
    "New template folder" : "يېڭى قېلىپ ھۆججەت قىسقۇچى",
    "In folder" : "ھۆججەت قىسقۇچتا",
    "Search in all files" : "ئۇ ھۆججەتلەرنىڭ ھەممىسىدە ئىزدە",
    "Search in folder: {folder}" : "ھۆججەت قىسقۇچتىن ئىزدەش: {folder} قىسقۇچ",
    "One of the dropped files could not be processed" : "تاشلانغان ھۆججەتلەرنىڭ بىرىنى بىر تەرەپ قىلالمىدى",
    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "توركۆرگۈڭىز Filesystem API نى قوللىمايدۇ. مۇندەرىجە يۈكلەنمەيدۇ",
    "No files to upload" : "يۈكلەيدىغان ھۆججەت يوق",
    "Unable to create the directory {directory}" : "مۇندەرىجە {directory} قۇرالمىدى",
    "Some files could not be uploaded" : "بەزى ھۆججەتلەرنى يۈكلەشكە بولمىدى",
    "Files uploaded successfully" : "ھۆججەتلەر مۇۋەپپەقىيەتلىك يۈكلەندى",
    "No files to process" : "بىر تەرەپ قىلىدىغان ھۆججەت يوق",
    "Files copied successfully" : "ھۆججەتلەر مۇۋەپپەقىيەتلىك كۆچۈرۈلدى",
    "Files moved successfully" : "ھۆججەتلەر مۇۋەپپەقىيەتلىك يۆتكەلدى",
    "Some files could not be copied" : "بەزى ھۆججەتلەرنى كۆچۈرگىلى بولمىدى",
    "Some files could not be moved" : "بەزى ھۆججەتلەرنى يۆتكىگىلى بولمىدى",
    "Conflicts resolution skipped" : "زىددىيەتنىڭ ھەل قىلىنىشى ئاتلاپ كەتتى",
    "Upload cancelled" : "يۈكلەش ئەمەلدىن قالدۇرۇلدى",
    "Could not rename \"{oldName}\", it does not exist any more" : "\"{oldName}\" نىڭ نامىنى ئۆزگەرتەلمىدى ، ئۇ ئەمدى مەۋجۇت ئەمەس",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "\"{dir}\" ھۆججەت قىسقۇچىدا \"{newName}\" ئىسمى ئاللىبۇرۇن ئىشلىتىلگەن. باشقا ئىسىمنى تاللاڭ.",
    "Could not rename \"{oldName}\"" : "\"{oldName}\" نىڭ نامىنى ئۆزگەرتەلمىدى",
    "This operation is forbidden" : "بۇ مەشغۇلات مەنئى قىلىنىدۇ",
    "This folder is unavailable, please try again later or contact the administration" : "بۇ قىسقۇچ ئىشلىتىلمەيدۇ، كېيىن قايتا سىناپ بېقىڭ ياكى باشقۇرۇش بىلەن ئالاقىلىشىڭ.",
    "Storage is temporarily not available" : "ساقلاش ۋاقتىنى ۋاقىتلىق ئىشلەتكىلى بولمايدۇ",
    "Unexpected error: {error}" : "ئويلىمىغان خاتالىق: {error}",
    "Unknown error" : "يوچۇن خاتالىق",
    "_%n file_::_%n files_" : ["%n ھۆججەت","%n ھۆججەتلەر"],
    "_%n folder_::_%n folders_" : ["%n قىسقۇچ","%n قىسقۇچلار"],
    "_%n hidden_::_%n hidden_" : ["يۇشۇرۇن %n","يۇشۇرۇن %n"],
    "Filename must not be empty." : "ھۆججەت ئىسمى بوش بولماسلىقى كېرەك.",
    "\"{char}\" is not allowed inside a filename." : "ھۆججەت نامىدا \"{char}\" رۇخسەت قىلىنمايدۇ.",
    "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" زاپاس ئىسىم بولۇپ ، ھۆججەت نامىغا رۇخسەت قىلىنمايدۇ.",
    "\"{extension}\" is not an allowed filetype." : "\"{extension}\" رۇخسەت قىلىنغان ھۆججەت تىپى ئەمەس.",
    "Filenames must not end with \"{extension}\"." : "ھۆججەت ئىسمى «{extension}» بىلەن ئاخىرلاشماسلىقى كېرەك.",
    "List of favorite files and folders." : "ياقتۇرىدىغان ھۆججەت ۋە ھۆججەت قىسقۇچلارنىڭ تىزىملىكى.",
    "No favorites yet" : "ياقتۇرىدىغانلار تېخى يوق",
    "Files and folders you mark as favorite will show up here" : "سىز ياقتۇرىدىغان ھۆججەت ۋە ھۆججەت قىسقۇچلار بۇ يەردە كۆرۈنىدۇ",
    "List of your files and folders." : "ھۆججەت ۋە ھۆججەت قىسقۇچلىرىڭىزنىڭ تىزىملىكى.",
    "Folder tree" : "قىسقۇچ شېخى",
    "List of your files and folders that are not shared." : "ئورتاقلاشمىغان ھۆججەت ۋە ھۆججەت قىسقۇچلىرىڭىزنىڭ تىزىملىكى.",
    "No personal files found" : "شەخسىي ھۆججەت تېپىلمىدى",
    "Files that are not shared will show up here." : "ئورتاقلاشمىغان ھۆججەتلەر بۇ يەردە كۆرۈنىدۇ.",
    "Recent" : "يېقىنقى",
    "List of recently modified files and folders." : "يېقىندا ئۆزگەرتىلگەن ھۆججەت ۋە ھۆججەت قىسقۇچلارنىڭ تىزىملىكى.",
    "No recently modified files" : "يېقىندا ئۆزگەرتىلگەن ھۆججەت يوق",
    "Files and folders you recently modified will show up here." : "سىز يېقىندا ئۆزگەرتكەن ھۆججەت ۋە ھۆججەت قىسقۇچلار بۇ يەردە كۆرۈنىدۇ.",
    "Search" : "ئىزدەش",
    "Search results within your files." : "ھۆججەتلىرىڭىزدىكى ئىزدەش نەتىنجىسى",
    "This node is unavailable" : "بۇ تۈگۈننى ئىشلەتكىلى بولمايدۇ",
    "Renamed \"{oldName}\" to \"{newName}\"" : "\"{oldName}\" غا \"{newName}\" غا ئۆزگەرتىلدى",
    "Clear filter" : "سۈزگۈچنى تازىلاش",
    "Open file sidebar" : "ھۆججەت يانبالداقنى ئاچ",
    "Search everywhere …" : "ھەممە يەردىن ئىزدە ...",
    "Search here …" : "بۇ يەردە ئىزدە ...",
    "Preparing …" : "تەييارلىنۋاتىدۇ ...",
    "Submitting fields …" : "ئورۇنلارنى تاپشۇرۋاتىدۇ ...",
    "Invalid path selected" : "ئىناۋەتسىز يول تاللانغان",
    "Choose file or folder to transfer" : "يۆتكەش ئۈچۈن ھۆججەت ياكى ھۆججەت قىسقۇچنى تاللاڭ",
    "Change" : "ئۆزگەرتىش",
    "Shared by link" : "ئۇلىنىش ئارقىلىق ئورتاقلاشتى",
    "Shared" : "ئورتاقلاشتى",
    "You" : "سەن",
    "Shared multiple times with different people" : "ئوخشىمىغان كىشىلەر بىلەن كۆپ قېتىم ئورتاقلاشتى",
    "Unable to change the favorite state of the file" : "بۇ ھۆججەتنىڭ ياقتۇردىغان ھالىنىنى ئۆزگەتكىلى بولمىدى",
    "Error while loading the file data" : "ھۆججەت سانلىق مەلۇماتلىرىنى يۈكلەۋاتقاندا خاتالىق",
    "Tags" : "بەلگەلەر",
    "Save as …" : "سۈپىتىدە ساقلا ...",
    "Converting files …" : "ھۆججەتنى ئايلاندۇرۋاتىدۇ ...",
    "Converting file …" : "ھۆججەتنى ئايلاندۇرۋاتىدۇ ...",
    "No entries found in this folder" : "بۇ ھۆججەت قىسقۇچتا ھېچقانداق مەزمۇن تېپىلمىدى",
    "Select all" : "ھەممىنى تاللاڭ",
    "Upload too large" : "يۈكلەندىغىنى بەك چوڭ",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "سىز يۈكلىمەكچى بولغان ھۆججەتلەر بۇ مۇلازىمېتىردا ھۆججەت يوللاشنىڭ ئەڭ چوڭ چوڭلۇقىدىن ئېشىپ كەتتى."
},
"nplurals=2; plural=(n != 1);");
