OC.L10N.register(
    "files",
    {
    "Added to favorites" : "Pridané do obľúbených",
    "Removed from favorites" : "Odstránené z obľúbených",
    "You added {file} to your favorites" : "Pridali ste {file} do vašich obľúbených",
    "You removed {file} from your favorites" : "Odstránili ste {file} z vašich obľúbených",
    "Favorites" : "Obľúbené",
    "File changes" : "Zmeny v súboroch",
    "Created by {user}" : "Vytvorené užívateľom {user}",
    "Changed by {user}" : "Zmenené užívateľom {user}",
    "Deleted by {user}" : "Zmazané užívateľom {user}",
    "Restored by {user}" : "Obnovené užívateľom {user}",
    "Renamed by {user}" : "Premenované užívateľom {user}",
    "Moved by {user}" : "Presunuté užívateľom {user}",
    "\"remote account\"" : "\"vzdialený účet\"",
    "You created {file}" : "Vytvorili ste súbor {file}",
    "You created an encrypted file in {file}" : "Vytvorili ste zašifrovaný súbor  {file}",
    "{user} created {file}" : "{user} vytvoril súbor {file}",
    "{user} created an encrypted file in {file}" : "{user} vytvoril šifrovaný súbor {file}",
    "{file} was created in a public folder" : "{file} bol vytvorený vo verejnom priečinku",
    "You changed {file}" : "Zmenili ste {file}",
    "You changed an encrypted file in {file}" : "Zmenili ste šifrovaný súbor {file}",
    "{user} changed {file}" : "{user} zmenil {file}",
    "{user} changed an encrypted file in {file}" : "{user} zmenil šifrovaný súbor {file}",
    "You deleted {file}" : "Odstránili ste {file}",
    "You deleted an encrypted file in {file}" : "Odstránili ste šifrovaný súbor {file}",
    "{user} deleted {file}" : "{user} zmazal {file}",
    "{user} deleted an encrypted file in {file}" : "{user} zmazal šifrovaný súbor {file}",
    "You restored {file}" : "Obnovili ste {file}",
    "{user} restored {file}" : "{user} obnovil {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Premenovali ste {oldfile} (skryté) na {newfile} (skryté)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Premenovali ste {oldfile} (skryté) na {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Premenovali ste {oldfile} na {newfile} (skryté)",
    "You renamed {oldfile} to {newfile}" : "Premenovali ste {oldfile} na {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} premenoval {oldfile} (skryté) na {newfile} (skryté)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} premenoval {oldfile} (skryté) na {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} premenoval {oldfile} na {newfile} (skryté)",
    "{user} renamed {oldfile} to {newfile}" : "{user} premenoval {oldfile} na {newfile}",
    "You moved {oldfile} to {newfile}" : "Presunuli ste {oldfile} do {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} presunul {oldfile} do {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Súbor bol pridaný alebo odstránený z vašich <strong>obľúbených</strong>",
    "Files" : "Súbory",
    "A file or folder has been <strong>changed</strong>" : "Súbor alebo priečinok bol <strong>zmenený</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "Obľúbený súbor alebo priečinok bol <strong>zmenený</strong>",
    "Failed to authorize" : "Autorizácia zlyhala",
    "Invalid folder path" : "Neplatná cesta k priečinku",
    "Folder not found" : "Priečinok nebol nájdený",
    "The file cannot be found" : "Súbor sa nepodarilo nájsť",
    "The destination path does not exist: %1$s" : "Cieľová cesta neexistuje: %1$s",
    "You do not have permission to create a file at the specified location" : "Nemáte oprávnenie vytvoriť súbor v zadanom umiestnení",
    "The file could not be converted." : "Súbor nemohol byť skonvertovaný.",
    "Could not get relative path to converted file" : "Nepodarilo sa získať relatícnu cestu ku skonvertovanému súboru",
    "Limit must be a positive integer." : "Limit musí byť kladné celé číslo.",
    "The replacement character may only be a single character." : "Zástupný znak môže byť iba jeden znak.",
    "Filename sanitization already started." : "Sanitizácia názvu súboru bola už zahájená.",
    "No filename sanitization in progress." : "Žiadna sanitácia názvu súboru neprebieha.",
    "Favorite files" : "Obľúbené súbory",
    "No favorites" : "Žiadne obľúbené",
    "More favorites" : "Viac obľúbených",
    "Accept" : "Prijať",
    "Reject" : "Odmietnuť",
    "Incoming ownership transfer from {user}" : "Prichádzajúci prevod vlastníctva od {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Chcete prijať {path}?\n\nPozn.: Proces pre prijatie môže trvať až hodinu.",
    "Ownership transfer denied" : "Prevod vlastníctva bol odmietnutý",
    "Your ownership transfer of {path} was denied by {user}." : "{user} odmietol prevod vlastníctva {path}.",
    "Ownership transfer failed" : "Prevod vlastníctva zlyhal",
    "Your ownership transfer of {path} to {user} failed." : "Prevod vlastníctva {path} od vás na {user} zlyhal.",
    "The ownership transfer of {path} from {user} failed." : "Prevod vlastníctva {path} od {user} zlyhal.",
    "Ownership transfer done" : "Prevod vlastníctva dokončený",
    "Your ownership transfer of {path} to {user} has completed." : "Prevod vami vlastnenej položky {path} na {user} bol dokončený.",
    "The ownership transfer of {path} from {user} has completed." : "Prevod vlastníctva položky {path} od {user} bol dokončený.",
    "in %s" : "v %s",
    "Transferred from %1$s on %2$s" : "Prevedené z %1$s na %2$s",
    "Delete files" : "Zmazať súbory",
    "Show files in grid view" : "Zobraziť zobrazenie súborov v mriežke",
    "File" : "Súbor",
    "File Management" : "Správa súborov",
    "Home" : "Domov",
    "Target folder does not exist any more" : "Cieľový priečinok už neexistuje",
    "Reload current directory" : "Znova načítať súčasný adresár",
    "Go to the \"{dir}\" directory" : "Ísť do \"{dir}\" adresára",
    "Current directory path" : "Aktuálna cesta k adresáru",
    "Share" : "Zdieľať",
    "Reload content" : "Znovu načítať obsah",
    "Your have used your space quota and cannot upload files anymore" : "Dosiahli ste limit vášho priestoru a už viac nemôžete nahrávať súbory",
    "You do not have permission to upload or create files here." : "Nemáte oprávnenie sem nahrávať alebo vytvárať súbory.",
    "Drag and drop files here to upload" : "Pre nahratie presuňte do tohto priestoru súbory ťahaním",
    "Favorite" : "Obľúbené",
    "Back" : "Späť",
    "Toggle selection for file \"{displayName}\"" : "Prepnúť výber pre súbor \"{displayName}\"",
    "Toggle selection for folder \"{displayName}\"" : "Prepnúť výber pre adresár \"{displayName}\"",
    "File is loading" : "Súbor sa nahráva",
    "Folder is loading" : "Adresár sa nahráva",
    "Filename" : "Názov súboru",
    "Folder name" : "Názov priečinka",
    "Another entry with the same name already exists." : "Iná položka s rovnakým menom už existuje.",
    "Invalid filename." : "Chybný názov súboru.",
    "Rename file" : "Premenovať súbor",
    "Recently created" : "Nedávno vytvorené",
    "Folder" : "Priečinok",
    "Unknown file type" : "Neznámy typ súboru",
    "{ext} image" : "{ext} obrázok",
    "{ext} video" : "{ext} video",
    "{ext} audio" : "{ext} zvuk",
    "{ext} text" : "{ext} text",
    "Pending" : "Čaká",
    "Unknown date" : "Neznámy dátum",
    "Active filters" : "Aktívne filtre",
    "Remove filter" : "Odstrániť filter",
    "Today" : "Dnes",
    "Last 7 days" : "Posledných 7 dní",
    "Last 30 days" : "Posledných 30 dní",
    "This year ({year})" : "Tento rok ({year})",
    "Last year ({year})" : "Minulý rok ({year})",
    "Custom range" : "Vlastný rozsah",
    "Custom date range" : "Vlastné rozpätie dátumov",
    "Search everywhere" : "Hľadať všade",
    "Documents" : "Dokumenty",
    "Spreadsheets" : "Tabuľky",
    "Presentations" : "Prezentácie",
    "PDFs" : "PDFká",
    "Folders" : "Priečinky",
    "Audio" : "Zvuk",
    "Images" : "Obrázky",
    "Videos" : "Videá",
    "Filters" : "Filtre",
    "Back to filters" : "Späť k filtrom",
    "Appearance" : "Vzhľad",
    "Show hidden files" : "Zobraziť skryté súbory",
    "Show file type column" : "Zobraziť stĺpec typu súboru",
    "Show file extensions" : "Zobraziť prípony súborov",
    "Crop image previews" : "Orezať náhľady obrázkov",
    "General" : "Všeobecné",
    "Sort favorites first" : "Zoradiť od najobľúbenejších",
    "Sort folders before files" : "Zoradiť adresáre pred súbormi",
    "Enable folder tree view" : "Povoliť zobrazenie stromu priečinkov",
    "Default view" : "Predvolené zobrazenie",
    "All files" : "Všetky súbory",
    "Personal files" : "Osobné súbory",
    "Additional settings" : "Ďalšie nastavenia",
    "Actions" : "Akcie",
    "File actions" : "Akcie súboru",
    "Selection" : "Výber",
    "Select all files" : "Vybrať všetky súbory",
    "Deselect all" : "Odznačiť všetko",
    "Select or deselect" : "Vybrať alebo zrušiť výber",
    "Select a range" : "Vybrať rozsah",
    "Navigation" : "Navigácia",
    "Go to parent folder" : "Prejsť do nadriadeného priečinka",
    "Go to file above" : "Prejsť na súbor vyššie",
    "Go to file below" : "Prejsť na súbor nižšie",
    "Go left in grid" : "Prejsť doľava v mriežke",
    "Go right in grid" : "Prejsť doprava v mriežke",
    "View" : "Zobraziť",
    "Toggle grid view" : "Prepnúť zobrazenie mriežky",
    "Show those shortcuts" : "Zobraziť klávesové skratky",
    "Warnings" : "Upozornenia",
    "Warn before changing a file extension" : "Upozorniť pred zmenou prípony súboru",
    "Warn before deleting a file" : "Upozorniť pred vymazaním súboru",
    "WebDAV URL" : "WebDAV URL",
    "Create an app password" : "Vytvoriť heslo pre aplikáciu",
    "Required for WebDAV authentication because Two-Factor Authentication is enabled for this account." : "Vyžaduje sa pre autentifikáciu WebDAV, pretože pre tento účet je povolená dvojfaktorová autentifikácia.",
    "How to access files using WebDAV" : "Ako získať prístup k súborom pomocou WebDAV",
    "Total rows summary" : "Súčet všetkých riadkov",
    "Toggle selection for all files and folders" : "Prepnúť výber pre všetky súbory a adresáre",
    "Name" : "Názov",
    "File type" : "Typ súboru",
    "Size" : "Veľkosť",
    "Modified" : "Upravené",
    "{displayName}: failed on some elements" : "{displayName}: zlyhalo na niektorých prvkoch",
    "{displayName}: done" : "{displayName}: hotovo",
    "{displayName}: failed" : "{displayName}: zlyhalo",
    "(selected)" : "(vybrané)",
    "List of files and folders." : "Zoznam súborov a priečinkov.",
    "You have used your space quota and cannot upload files anymore." : "Už ste využili kapacitu úložného priestoru a nie je možné nahrávať ďalšie súbory.",
    "Column headers with buttons are sortable." : "Stĺpce hlavičiek s tlačidlami sú triediteľné.",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Tento zoznam nie je úplne vykreslený z dôvodov výkonu. Súbory budú vykreslené, keď budete prechádzať zoznamom.",
    "File not found" : "Súbor nenájdený",
    "_{count} selected_::_{count} selected_" : ["{count} vybraný","{count} vybrané","{count} vybraných","{count} vybraných"],
    "Views" : "Zobrazenia",
    "Search everywhere …" : "Hľadať všade ...",
    "Search here …" : "Hľadať tu …",
    "Search scope options" : "Možnosti rozsahu vyhľadávania",
    "Search here" : "Hľadať tu",
    "Owner" : "Vlastník",
    "{usedQuotaByte} used" : "{usedQuotaByte} použitých",
    "{used} of {quota} used" : "použitých {used} z {quota}",
    "{relative}% used" : "{relative}% použitých",
    "Could not refresh storage stats" : "Nebolo možné obnoviť úložiskové štatistiky",
    "Your storage is full, files can not be updated or synced anymore!" : "Vaše úložisko je plné. Súbory nemožno aktualizovať ani synchronizovať!",
    "Storage information" : "Informácie o úložisku",
    "Storage quota" : "Kvóta pre úložisko",
    "New folder" : "Nový priečinok",
    "Create new folder" : "Vytvoriť nový priečinok",
    "This name is already in use." : "Toto meno je už používané.",
    "Create" : "Vytvoriť",
    "Files starting with a dot are hidden by default" : "Súbory, ktoré začínajú bodkou, sú predvolene skryté.",
    "Failed to start filename sanitization." : "Nezískalo sa spustenie sanitizácie názvu súboru.",
    "Failed to refresh filename sanitization status." : "Nepodarilo sa obnoviť stav sanitácie názvu súboru.",
    "Filename sanitization in progress." : "Prebieha sanitácia názvu súboru.",
    "Currently {processedUsers} of {totalUsers} accounts are already processed." : "Aktuálne je spracovaných {processedUsers} z {totalUsers} účtov.",
    "Preparing …" : "Pripravuje sa …",
    "Refresh" : "Obnoviť",
    "All files have been santized for Windows filename support." : "Všetky súbory boli upravené na podporu názvov súborov vo Windows.",
    "Some files could not be sanitized, please check your logs." : "Niektoré súbory nebolo možné upravené, prosím, skontrolujte svoje protokoly.",
    "Sanitization errors" : "Chyby v sanitizácii",
    "Not sanitized filenames" : "Nezabezpečené názvy súborov",
    "Windows filename support has been enabled." : "Podpora názvov súborov vo Windows bola povolená.",
    "While this blocks users from creating new files with unsupported filenames, existing files are not yet renamed and thus still may break sync on Windows." : "Kým toto blokuje používateľov v tvorbe nových súborov s nepodporovanými názvami, existujúce súbory ešte neboli premenované a teda môžu stále spôsobiť problémy so synchronizáciou na Windows.",
    "You can trigger a rename of files with invalid filenames, this will be done in the background and may take some time." : "Môžete spustiť premenovanie súborov s neplatnými názvami, tento proces sa vykoná na pozadí a môže trvať nejaký čas.",
    "Please note that this may cause high workload on the sync clients." : "Upozorňujeme, že to môže spôsobiť vysokú záťaž pre klientov synchronizácie.",
    "Limit" : "Limit",
    "This allows to configure how many users should be processed in one background job run." : "Toto umožňuje nastaviť, koľko používateľov by malo byť spracovaných v jednom spustení úlohy na pozadí.",
    "Sanitize filenames" : "Vyčistiť názvy súborov",
    "(starting)" : "(začína sa)",
    "Fill template fields" : "Vyplňte položky šablóny",
    "Submitting fields …" : "Odosielanie polí …",
    "Submit" : "Odoslať",
    "Choose a file or folder to transfer" : "Vyberte súbor alebo priečinok na prevod",
    "Transfer" : "Prevod",
    "Transfer {path} to {userid}" : "Previesť {path} na {userid}",
    "Error while searching for users" : "Chyba pri vyhľadávaní užívateľov",
    "Ownership transfer request sent" : "Žiadosť o prevod vlastníctva bola odoslaná",
    "Cannot transfer ownership of a file or folder you do not own" : "Nie je možné preniesť vlastníctvo súboru alebo priečinka, ktorý nevlastníte",
    "Transfer ownership of a file or folder" : "Prevod vlastníctva súboru alebo priečinka",
    "New owner" : "Nový vlastník",
    "Keep {old}" : "Ponechať {old}",
    "Keep without extension" : "Ponechať bez prípony",
    "Use {new}" : "Použiť {new}",
    "Remove extension" : "Odstrániť príponu",
    "Change file extension" : "Zmeniť príponu súboru",
    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "Zmena prípony súboru z „{old}“ na „{new}“ môže spôsobiť, že súbor bude nečitateľný.",
    "Removing the file extension \"{old}\" may render the file unreadable." : "Odstránenie prípony súboru „{old}“ môže spôsobiť, že súbor bude nečitateľný.",
    "Adding the file extension \"{new}\" may render the file unreadable." : "Pridanie prípony súboru „{new}“ môže spôsobiť, že súbor bude nečitateľný.",
    "Do not show this dialog again." : "Toto dialógové okno už nezobrazovať.",
    "Rename file to hidden" : "Premenovať súbor na skrytie",
    "Prefixing a filename with a dot may render the file hidden." : "Predpona názvu súboru bodkou môže spôsobiť, že súbor bude skrytý.",
    "Are you sure you want to rename the file to \"{filename}\"?" : "Ste si istí, že chcete premenovať súbor na \"{filename}\"?",
    "Cancel" : "Zrušiť",
    "Rename" : "Premenovať",
    "Select file or folder to link to" : "Vyberte súbor alebo priečinok na ktorý odkazovať",
    "Choose {file}" : "Vyberte {file}",
    "Files settings" : "Nastavenia súborov",
    "Switch to list view" : "Prepnúť na zobrazenie v zozname",
    "Switch to grid view" : "Prepnúť na zobrazenie v mriežke",
    "The file could not be found" : "Súbor nebol nájdený",
    "Upload was cancelled by user" : "Nahrávanie bolo zrušené užívateľom",
    "Not enough free space" : "Nedostatok voľného miesta",
    "Operation is blocked by access control" : "Činnosť je blokovaná kontrolou prístupu",
    "Error during upload: {message}" : "Chyba počas nahrávania: {message}",
    "Error during upload, status code {status}" : "Chyba počas nahrávania, chybový kód {status}",
    "Unknown error during upload" : "Neznáma chyba počas nahrávania",
    "File list is reloading" : "Zoznam súborov sa znova načítava",
    "Loading current folder" : "Načítavanie súčasného priečinka",
    "Retry" : "Zopakovať",
    "No files in here" : "Nie sú tu žiadne súbory",
    "Upload some content or sync with your devices!" : "Nahrajte nejaký obsah alebo synchronizujte dáta so svojimi zariadeniami!",
    "Go back" : "Ísť späť",
    "Loading …" : "Načítava sa …",
    "Your files" : "Vaše súbory",
    "Open in files" : "Otvoriť v súboroch",
    "File cannot be accessed" : "Súbor nie je možné sprístupniť",
    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Súbor sa nenašiel alebo nemáte oprávnenie na jeho zobrazenie. Požiadajte odosielateľa, aby ho sprístupnil.",
    "No search results for “{query}”" : "Žiadne výsledky vyhľadávania pre „{query}“",
    "Search for files" : "Vyhľadať súbory",
    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Povoliť obmedzenie názvov súborov, aby sa zabezpečila synchronizácia súborov so všetkými klientmi. V predvolenom nastavení sú povolené všetky názvy súborov platné pre POSIX (napr. Linux alebo macOS).",
    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Po povolení kompatibilných názvov súborov pre Windows už nie je možné upravovať existujúce súbory, ale ich vlastník ich môže premenovať na platné nové názvy.",
    "Failed to toggle Windows filename support" : "Nepodarilo sa prepnúť podporu názvov súborov systému Windows",
    "Files compatibility" : "Kompatibilita súborov",
    "Enforce Windows compatibility" : "Vynútiť kompatibilitu s Windows",
    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Tým sa zablokujú názvy súborov, ktoré nie sú platné v systémoch Windows, ako napríklad používanie vyhradených názvov alebo špeciálnych znakov. To však nevynúti kompatibilitu rozlišovania malých a veľkých písmen.",
    "Blank" : "Prázdne",
    "Unable to create new file from template" : "Nemôžem vytvoriť nový súbor zo šablóny",
    "Pick a template for {name}" : "Vyberte šablónu pre {name}",
    "Create a new file with the selected template" : "Vytvoriť nový súbor pomocou vybranej šablóny",
    "Creating file" : "Vytvára sa súbor",
    "Save as {displayName}" : "Uložiť ako {displayName}",
    "Save as …" : "Uložiť ako ...",
    "Converting files …" : "Konverzia súborov ...",
    "Failed to convert files: {message}" : "Nepodarilo sa skonvertovať súbory: {message}",
    "All files failed to be converted" : "Nepodarilo sa skonvertovať žiadne súbory",
    "One file could not be converted: {message}" : "Jeden súbor sa nepodarilo skonvertovať: {message}",
    "_%n file could not be converted_::_%n files could not be converted_" : ["%n súbor sa nepodarilo skonvertovať","%n súbory sa nepodarilo skonvertovať","%n súborov sa nepodarilo skonvertovať","%n súborov sa nepodarilo skonvertovať"],
    "_%n file converted_::_%n files converted_" : ["%n prevedený súbor","%n prevedených súborov","%n prevedených súborov","%n prevedené súbory"],
    "Files converted" : "Súbory boli konvertované",
    "Failed to convert files" : "Konverzia súborov zlyhala",
    "Converting file …" : "Konverzia súborov ...",
    "File successfully converted" : "Súbor bol úspešne skonvertovaný",
    "Failed to convert file: {message}" : "Nepodarilo sa skonvertovať súbor: {message}",
    "Failed to convert file" : "Konverzia súboru zlyhala",
    "Delete" : "Zmazať",
    "Leave this share" : "Opustiť toto zdieľanie.",
    "Leave these shares" : "Opustiť tieto zdieľania.",
    "Disconnect storage" : "Odpojiť úložisko",
    "Disconnect storages" : "Odpojiť úložiská",
    "Delete permanently" : "Zmazať  natrvalo",
    "Delete and unshare" : "Vymazať a zrušiť zdieľanie",
    "Delete file" : "Zmazať súbor",
    "Delete folder" : "Zmazať priečinok",
    "Delete folders" : "Zmazať priečinky",
    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Chystáte sa permanentne vymazať {count} položku","Chystáte sa permanentne vymazať {count} položky","Chystáte sa permanentne vymazať {count} položiek","Chystáte sa permanentne vymazať {count} položiek"],
    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Chystáte sa vymazať {count} položku","Chystáte sa vymazať {count} položky","Chystáte sa vymazať {count} položiek","Chystáte sa vymazať {count} položiek"],
    "Confirm deletion" : "Potvrdiť vymazanie",
    "Download" : "Stiahnuť",
    "The requested file is not available." : "Požadovaný súbor nie je k dispozícii.",
    "The requested files are not available." : "Požadované súbory nie sú k dispozícii.",
    "Add to favorites" : "Pridať do obľúbených",
    "Remove from favorites" : "Odstrániť z obľúbených",
    "Add or remove favorite" : "Pridať alebo odstrániť obľúbené",
    "Move" : "Presunúť",
    "Copy" : "Kopírovať",
    "Move or copy" : "Presunúť alebo kopírovať",
    "Destination is not a folder" : "Cieľ nie je priečinok",
    "This file/folder is already in that directory" : "Tento súbor/priečinok sa už v danom adresári nachádza",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "Nemôžete presunúť súbor/priečinok do seba alebo do jeho podpriečinka.",
    "A file or folder with that name already exists in this folder" : "Súbor alebo priečinok s týmto názvom už existuje v tomto priečinku",
    "The files are locked" : "Súbory sú uzamknuté.",
    "The file does not exist anymore" : "Súbor už neexistuje",
    "Moving \"{source}\" to \"{destination}\" …" : "Presúvanie \"{source}\" do \"{destination}\" …",
    "Copying \"{source}\" to \"{destination}\" …" : "Kopírovanie \"{source}\" do \"{destination}\" …",
    "Choose destination" : "Vyberte cieľ",
    "Copy to {target}" : "Kopírovať do {target}",
    "Move to {target}" : "Presunúť do {target}",
    "Move or copy operation failed" : "Operácia presunu alebo kopírovania zlyhala",
    "Open folder" : "Otvoriť priečinok",
    "Open folder {displayName}" : "Otvoriť priečinok {displayName}",
    "Open in Files" : "Otvoriť v súboroch",
    "Open locally" : "Otvoriť lokálne",
    "Failed to redirect to client" : "Nepodarilo sa presmerovať na klienta",
    "Open file locally" : "Otvoriť súbor lokálne",
    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Súbor by sa mal teraz otvoriť v zariadení. Ak sa tak nestane, skontrolujte, či máte nainštalovanú aplikáciu pre počítače.",
    "Retry and close" : "Skúsiť znova a zatvoriť",
    "Open online" : "Otvoriť online",
    "Details" : "Podrobnosti",
    "Open the details sidebar" : "Otvoriť bočný panel s podrobnosťami",
    "Unfavorite" : "Odobrať z obľúbených",
    "View in folder" : "Zobraziť v priečinku",
    "Type" : "Typ",
    "Created new folder \"{name}\"" : "Vytvorený nový priečinok \"{name}\"",
    "Unable to initialize the templates directory" : "Nemôžem inicializovať priečinok so šablónami",
    "Create templates folder" : "Vytvoriť adresár pre šablóny",
    "Templates" : "Šablóny",
    "New template folder" : "Nový adresár šablóny",
    "In folder" : "V adresári",
    "Pick folder to search in" : "Vybrať priečinok na vyhľadávanie",
    "Search in all files" : "Hľadať vo všetkých súboroch",
    "Search in folder: {folder}" : "Hľadať v adresári: {folder}",
    "One of the dropped files could not be processed" : "Jeden z vložených súborov nemohol byť spracovaný.",
    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Váš prehliadač nepodporuje Filesystem API. Adresáre nebudú nahrané",
    "No files to upload" : "Žiadne súbory pre nahratie",
    "Unable to create the directory {directory}" : "Nie je možné vytvoriť adresár {directory}",
    "Some files could not be uploaded" : "Niektoré súbory nebolo možné nahrať.",
    "Files uploaded successfully" : "Súbory boli úspešne nahrané.",
    "No files to process" : "Žiadne súbory pre spracovanie",
    "Files copied successfully" : "Súbory boli úspešne skopírované",
    "Files moved successfully" : "Súbory boli úspešne presunuté",
    "Some files could not be copied" : "Niektoré súbory nebolo možné skopírovať",
    "Some files could not be moved" : "Niektoré súbory nebolo možné presunúť",
    "Conflicts resolution skipped" : "Riešenie konfliktov bolo preskočené",
    "Upload cancelled" : "Odosielanie bolo zrušené",
    "Could not rename \"{oldName}\", it does not exist any more" : "Nebolo možné premenovať  \"{oldName}\". Položka už neexistuje.",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Názov \"{newName}\" sa už používa v priečinku \"{dir}\". Vyberte prosím iný názov.",
    "Could not rename \"{oldName}\"" : "Nebolo možné premenovať \"{oldName}\"",
    "This operation is forbidden" : "Táto operácia je zakázaná",
    "This folder is unavailable, please try again later or contact the administration" : "Táto zložka nie je k dispozícii, skúste to prosím neskôr alebo kontaktujte správu.",
    "Storage is temporarily not available" : "Úložisko je dočasne nedostupné",
    "Unexpected error: {error}" : "Neočakávaná chyba: {error}",
    "Unknown error" : "Neznáma chyba",
    "_%n file_::_%n files_" : ["%n súbor","%n súbory","%n súborov","%n súborov"],
    "_%n folder_::_%n folders_" : ["%n priečinok","%n priečinky","%n priečinkov","%n priečinkov"],
    "_%n hidden_::_%n hidden_" : ["%n skrytý","%n skrytých","%n skrytých","%n sktyré"],
    "Filename must not be empty." : "Názov súboru nesmie byť prázdny.",
    "\"{char}\" is not allowed inside a filename." : "Znak \"{char}\" nie je povolený v názve súboru.",
    "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" je rezervované slovo a nie je možné ho použiť v názvoch súborov.",
    "\"{extension}\" is not an allowed filetype." : "\"{extension}\" nie je povolená prípona súboru.",
    "Filenames must not end with \"{extension}\"." : "Názvy súborov nesmú končiť s \"{extension}\"",
    "List of favorite files and folders." : "Zoznam obľúbených súborov a priečinkov.",
    "No favorites yet" : "Zatiaľ žiadne obľúbené",
    "Files and folders you mark as favorite will show up here" : "Súbory a priečinky označené ako obľúbené budú zobrazené tu",
    "List of your files and folders." : "Zoznam vašich súborov a priečinkov.",
    "Folder tree" : "Strom priečinkov",
    "List of your files and folders that are not shared." : "Zoznam vašich súborov a priečinkov, ktoré nie sú zdieľané.",
    "No personal files found" : "Žiadne osobné súbory nenájdené",
    "Files that are not shared will show up here." : "Súbory, ktoré nie sú zdieľané, sa tu nezobrazia.",
    "Recent" : "Nedávne",
    "List of recently modified files and folders." : "Zoznam nedávno upravených súborov a priečinkov.",
    "No recently modified files" : "Žiadne nedávno upravené súbory",
    "Files and folders you recently modified will show up here." : "Súbory a priečinky, ktoré ste nedávno upravili sa zobrazia tu",
    "Search" : "Hľadať",
    "Search results within your files." : "Výsledky vyhľadávania vo vašich súboroch.",
    "This node is unavailable" : "Uzol nie je k dispozícií",
    "Renamed \"{oldName}\" to \"{newName}\"" : "Premenované z \"{oldName}\" na \"{newName}\"",
    "Clear filter" : "Vyčistiť filter",
    "Open file sidebar" : "Otvoriť bočný panel súboru",
    "Search everywhere …" : "Hľadať všade ...",
    "Search here …" : "Hľadať tu …",
    "Preparing …" : "Pripravuje sa …",
    "Submitting fields …" : "Položky sa odosielajú ...",
    "Invalid path selected" : "Bola vybraná neplatná cesta",
    "Choose file or folder to transfer" : "Vyberte súbor alebo priečinok na prevod",
    "Change" : "Zmeniť",
    "Shared by link" : "Sprístupnené odkazom",
    "Shared" : "Sprístupnené",
    "You" : "Vy",
    "Shared multiple times with different people" : "Zdieľané viackrát rôznymi ľuďmi",
    "Unable to change the favorite state of the file" : "Nie je možné zmeniť stav „obľúbené“ súboru",
    "Error while loading the file data" : "Chyba pri načítaní údajov súboru",
    "Tags" : "Štítky",
    "Save as …" : "Uložiť ako ...",
    "Converting files …" : "Konverzia súborov ...",
    "Converting file …" : "Konverzia súborov ...",
    "No entries found in this folder" : "V tomto priečinku nebolo nič nájdené",
    "Select all" : "Vybrať všetko",
    "Upload too large" : "Nahrávanie je príliš veľké",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Súbory, ktoré sa snažíte nahrať, presahujú maximálnu veľkosť pre nahratie súborov na tento server."
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
