OC.L10N.register(
    "recommendations",
    {
    "Recommended files" : "Anbefalte filer",
    "Recommendations" : "Anbefalinger",
    "Shows recommended files" : "Vis anbefalte filer",
    "Shows recommended files for quick access of files and folders with recent activity" : "Viser anbefalte filer for rask tilgang til filer og mapper med nylig aktivitet",
    "No recommendations yet" : "Ingen anbefalinger ennå",
    "Path name {path}" : "Stinavn {path}",
    "Show recommendations" : "Vis anbefalinger"
},
"nplurals=2; plural=(n != 1);");
