OC.L10N.register(
    "provisioning_api",
    {
    "Logged in account must be an administrator or have authorization to edit this setting." : "حساب وارد شده باید مدیر باشد یا مجوز ویرایش این تنظیم را داشته باشد",
    "Could not create non-existing user ID" : "امکان ایجاد شناسه کاربری غیرموجود وجود ندارد",
    "User already exists" : "کاربر از قبل وجود دارد",
    "Group %1$s does not exist" : "گروه %1$s وجود ندارد",
    "Insufficient privileges for group %1$s" : "دسترسی‌های ناکافی برای گروه %1$s",
    "No group specified (required for sub-admins)" : "گروهی مشخص نشده است (برای زیرمدیران الزامی است)",
    "Sub-admin group does not exist" : "گروه زیرمدیر وجود ندارد",
    "Cannot create sub-admins for admin group" : "امکان ایجاد زیرمدیر برای گروه مدیر وجود ندارد",
    "No permissions to promote sub-admins" : "مجوز ارتقا به زیرمدیر وجود ندارد",
    "Invalid password value" : "مقدار رمز عبور نامعتبر است",
    "An email address is required, to send a password link to the user." : "برای ارسال لینک رمز عبور به کاربر، آدرس ایمیل الزامی است",
    "Required email address was not provided" : "آدرس ایمیل مورد نیاز ارائه نشده است",
    "User creation failed" : "ایجاد کاربر ناموفق بود",
    "Cannot change display name for this user" : "امکان تغییر نام نمایشی برای این کاربر وجود ندارد",
    "Invalid email address" : "آدرس ایمیل نامعتبر است",
    "Language change is not allowed on this instance" : "تغییر زبان در این نمونه مجاز نیست",
    "Invalid language" : "زبان نامعتبر است",
    "Insufficient permissions to change quota" : "دسترسی کافی برای تغییر سهمیه وجود ندارد",
    "Insufficient permissions to change groups" : "دسترسی کافی برای تغییر گروه‌ها وجود ندارد",
    "Group %s does not exist" : "گروه %s وجود ندارد",
    "Insufficient permissions to change sub-admin groups" : "دسترسی کافی برای تغییر گروه‌های زیرمدیر وجود ندارد",
    "Insufficient permissions to change manager" : "دسترسی کافی برای تغییر مدیر وجود ندارد",
    "Invalid quota value: %1$s" : "مقدار سهمیه نامعتبر: %1$s",
    "Invalid quota value. %1$s is exceeding the maximum quota" : "مقدار سهمیه نامعتبر است. %1$s از حداکثر سهمیه فراتر می‌رود",
    "Unlimited quota is forbidden on this instance" : "سهمیه نامحدود در این نمونه ممنوع است",
    "Setting the password is not supported by the users backend" : "تنظیم رمز عبور توسط پشتیبان کاربران پشتیبانی نمی‌شود",
    "Invalid locale" : "محلی نامعتبر است",
    "Invalid timezone" : "منطقه زمانی نامعتبر است",
    "Invalid first day of week" : "اولین روز هفته نامعتبر است",
    "Cannot remove yourself from the admin group" : "امکان حذف خود از گروه مدیر وجود ندارد",
    "Cannot remove yourself from this group as you are a sub-admin" : "به دلیل زیرمدیر بودن، امکان حذف خود از این گروه وجود ندارد",
    "Not viable to remove user from the last group you are sub-admin of" : "حذف کاربر از آخرین گروهی که زیرمدیر آن هستید امکان‌پذیر نیست",
    "User does not exist" : "کاربر وجود ندارد",
    "Group does not exist" : "گروه وجود ندارد",
    "User is not a sub-admin of this group" : "کاربر زیرمدیر این گروه نیست",
    "Email address not available" : "آدرس ایمیل در دسترس نیست",
    "Sending email failed" : "ارسال ایمیل ناموفق بود",
    "Logged in account is not mail address owner" : "حساب وارد شده مالک آدرس ایمیل نیست",
    "Email confirmation" : "تأیید ایمیل",
    "To enable the email address %s please click the button below." : "برای فعال‌سازی آدرس ایمیل %s لطفاً روی دکمه زیر کلیک کنید.",
    "Confirm" : "تأیید",
    "Email was already removed from account and cannot be confirmed anymore." : "ایمیل قبلاً از حساب حذف شده و دیگر قابل تأیید نیست.",
    "Could not verify mail because the token is expired." : "تأیید ایمیل به دلیل منقضی شدن توکن امکان‌پذیر نیست.",
    "Could not verify mail because the token is invalid." : "تأیید ایمیل به دلیل نامعتبر بودن توکن امکان‌پذیر نیست.",
    "An unexpected error occurred. Please contact your admin." : "خطای غیرمنتظره‌ای رخ داد. لطفاً با مدیر خود تماس بگیرید.",
    "Email confirmation successful" : "تأیید ایمیل با موفقیت انجام شد",
    "Provisioning API" : "API تأمین",
    "This application enables a set of APIs that external systems can use to manage accounts, groups and apps." : "این برنامه مجموعه‌ای از APIها را فعال می‌کند که سیستم‌های خارجی می‌توانند برای مدیریت حساب‌ها، گروه‌ها و برنامه‌ها استفاده کنند.",
    "This application enables a set of APIs that external systems can use to create, edit, delete and query account\n\t\tattributes, query, set and remove groups, set quota and query total storage used in Nextcloud. Group admin accounts\n\t\tcan also query Nextcloud and perform the same functions as an admin for groups they manage. The API also enables\n\t\tan admin to query for active Nextcloud applications, application info, and to enable or disable an app remotely.\n\t\tOnce the app is enabled, HTTP requests can be used via a Basic Auth header to perform any of the functions\n\t\tlisted above. More information is available in the Provisioning API documentation, including example calls\n\t\tand server responses." : "این برنامه مجموعه‌ای از APIها را فعال می‌کند که سیستم‌های خارجی می‌توانند برای ایجاد، ویرایش، حذف و جستجوی ویژگی‌های حساب، جستجو، تنظیم و حذف گروه‌ها، تنظیم سهمیه و جستجوی فضای ذخیره‌سازی کل استفاده شده در نکست‌کلود استفاده کنند. حساب‌های مدیر گروه نیز می‌توانند نکست‌کلود را جستجو کرده و همان وظایف یک مدیر را برای گروه‌هایی که مدیریت می‌کنند انجام دهند. API همچنین به مدیر امکان می‌دهد برنامه‌های فعال نکست‌کلود، اطلاعات برنامه‌ها را جستجو کرده و یک برنامه را از راه دور فعال یا غیرفعال کند. پس از فعال شدن برنامه، می‌توان از درخواست‌های HTTP با هدر Basic Auth برای انجام هر یک از وظایف ذکر شده در بالا استفاده کرد. اطلاعات بیشتر در مستندات API تأمین، شامل نمونه فراخوانی‌ها و پاسخ‌های سرور، موجود است."
},
"nplurals=2; plural=(n > 1);");
