OC.L10N.register(
    "app_api",
    {
    "Daemon config not found" : "Nie znaleziono konfiguracji demona",
    "Error starting install of ExApp" : "Błąd podczas uruchamiania instalacji ExApp",
    "ExApp failed to register, check the NC logs" : "Nie udało się zarejestrować ExApp, sprawdź logi NC",
    "ExApp not found, failed to get status" : "Nie znaleziono ExApp, nie udało się uzyskać statusu",
    "Error adding Docker registry" : "Błąd podczas dodawania rejestru Dockera",
    "Error removing Docker registry" : "Błąd podczas usuwania rejestru Dockera",
    "This app is not installed from the AppStore. No extra information available. Only enable/disable and remove actions are allowed." : "Ta aplikacja nie została zainstalowana ze Sklepu Aplikacji. Brak dodatkowych informacji. Dozwolone są tylko akcje włączania/wyłączania i usuwania.",
    "Could not perform installation of ExApp" : "Nie udało się przeprowadzić instalacji ExApp",
    "Failed to enable ExApp" : "Nie udało się włączyć ExApp",
    "Failed to disable ExApp" : "Nie udało się wyłączyć ExApp",
    "Could not update ExApp" : "Nie udało się zaktualizować ExApp",
    "Error starting update of ExApp" : "Błąd podczas uruchamiania aktualizacji ExApp",
    "Could not perform update of ExApp" : "Nie udało się przeprowadzić aktualizacji ExApp",
    "ExApp not found, failed to get logs" : "Nie znaleziono ExApp, nie udało się pobrać logów",
    "Failed to get container logs. Note: Downloading Docker container works only for containers with the json-file or journald logging driver. Error: %s" : "Nie udało się pobrać logów kontenera. Uwaga: Pobieranie kontenera Dockera działa tylko dla kontenerów z włączonym sterownikiem logowania json-file lub journald. Błąd: %s",
    "ExApp not found, failed to get deploy options" : "Nie znaleziono ExApp, nie udało się pobrać opcji wdrożenia",
    "AppAPI authentication failed" : "Uwierzytelnienie AppAPI nie powiodło się",
    "AppAPI ExApp notifier" : "Powiadomienie AppAPI ExApp",
    "AppAPI" : "AppAPI",
    "AI Integration Team" : "Zespół integracji AI",
    "ExApps Settings" : "Ustawienia ExApps",
    "AppAPI deploy daemon" : "Demon wdrożeniowy AppAPI",
    "AppAPI default deploy daemon is not set. Please register a default deploy daemon in the settings to install External Apps (Ex-Apps)." : "Domyślny demon wdrożeniowy AppAPI nie jest ustawiony. Zarejestruj domyślny demon wdrożeniowy w ustawieniach, aby zainstalować aplikacje zewnętrzne (Ex-Apps).",
    "AppAPI default deploy daemon \"%s\" is not accessible. Please check the daemon configuration." : "Domyślny demon wdrożeniowy AppAPI \"%s\" jest niedostępny. Sprawdź konfigurację demona.",
    "The AppAPI default deploy daemon is not using HaRP. Please consider switching to HaRP for better performance." : "Domyślny demon wdrożeniowy AppAPI nie używa HaRP. Rozważ przełączenie na HaRP w celu uzyskania lepszej wydajności.",
    "AppAPI HaRP version check" : "Sprawdzenie wersji HaRP AppAPI",
    "Could not retrieve HaRP version from daemon \"%s\"" : "Nie można pobrać wersji HaRP z demona \"%s\"",
    "HaRP version for daemon \"%s\" is \"%s\", which is too old. The minimum required version is \"%s\". Please update the daemon to the latest version." : "Wersja HaRP dla demona \"%s\" to \"%s\" i jest zbyt stara. Minimalna wymagana wersja to \"%s\". Zaktualizuj demona do najnowszej wersji.",
    "Failed to check HaRP version for daemon \"%s\": %s" : "Nie udało się sprawdzić wersji HaRP dla demona \"%s\":%s",
    "Nextcloud AppAPI" : "AppAPI Nextcloud",
    "### What is AppAPI?\n\nAppAPI is the Nextcloud component that enables **External Apps (ExApps)**.\nExApps are apps whose backend runs **outside** the Nextcloud PHP process (usually as a Docker container), while still integrating with your Nextcloud users, permissions and web UI.\n\n### Do I need it?\n\nNo. If you do not plan to install External Apps, you can disable AppAPI.\n\nIf AppAPI is enabled without a configured Deploy Daemon, Nextcloud will show the info message:\n\n> \"AppAPI default deploy daemon is not set …\"\n\nThat warning means: \"External Apps are not configured yet\".\n\nYou can either disable AppAPI, or configure a Deploy Daemon (see below).\n\n### How do External Apps get deployed?\n\nA **Deploy Daemon** is the service Nextcloud talks to in order to install, start, stop and reach ExApps.\n\nTwo options are available:\n\n- **HaRP** (recommended for Nextcloud 32+) — a high-performance reverse proxy with FRP tunneling\n- **Docker Socket Proxy** (legacy) — scheduled for removal in Nextcloud 35\n\nSee the [admin documentation](https://docs.nextcloud.com/server/latest/admin_manual/exapps_management/DeployConfigurations.html) for setup instructions." : "### Czym jest AppAPI?\n\nAppAPI to komponent Nextcloud umożliwiający Aplikacje zewnętrzne (ExApps). ExApps to aplikacje, których backend działa poza procesem PHP Nextcloud (zwykle w kontenerze Docker), przy jednoczesnej integracji z użytkownikami, uprawnieniami i interfejsem webowym Nextcloud.\n\n### Czy jest mi to potrzebne?\n\nNie. Jeśli nie planujesz instalować Aplikacji zewnętrznych, możesz wyłączyć AppAPI. \n\nJeśli AppAPI jest włączone bez skonfigurowanego demona wdrożeniowego, Nextcloud wyświetli komunikat informacyjny:\n\n„Domyślny demon wdrożeniowy AppAPI nie jest ustawiony...”\n\nOstrzeżenie oznacza to, że : „Aplikacje zewnętrzne nie są skonfigurowane.”\n\nMożesz wyłączyć AppAPI lub skonfigurować demona wdrożeniowego (patrz poniżej).\n\n### Jak wdrażane są Aplikacje zewnętrzne?\n\n**Demon wdrożeniowy** to usługa, z którą Nextcloud komunikuje się w celu instalowania, uruchamiania, zatrzymywania i obsługi ExApps. \n\nDostępne są dwie opcje:\n\n- **HaRP** (zalecany dla Nextcloud 32+) — wysokowydajny reverse proxy z tunelowaniem FRP\n- **Docker Socket Proxy** (starszy) — planowany do usunięcia w Nextcloud 35\n\nInstrukcje konfiguracji znajdziesz w dokumentacji administratora (https://docs.nextcloud.com/server/latest/admin_manual/exapps_management/DeployConfigurations.html)",
    "External Apps management" : "Zarządzanie aplikacjami zewnętrznymi",
    "Admin options saved" : "Opcje administracyjne zostały zapisane",
    "Failed to save admin options" : "Nie udało się zapisać opcji administratora",
    "The AppAPI Project is an exciting initiative that aims to revolutionize the way applications are developed for Nextcloud through the use of docker containers. Allowing for greater programming language choice and allowing computationally expensive tasks to be offloaded to a different server." : "Projekt AppAPI to ekscytująca inicjatywa, której celem jest zrewolucjonizowanie sposobu, w jaki aplikacje są rozwijane dla Nextcloud poprzez wykorzystanie kontenerów Dockera.\nPozwala to na większy wybór języków programowania oraz przeniesienie kosztownych obliczeniowo zadań na inny serwer.",
    "Deploy daemons" : "Demony wdrożeniowe",
    "A deploy daemon (DaemonConfig) is an ExApps orchestration daemon." : "Demon wdrożeniowy (DaemonConfig) to demon orkiestracji ExApps.",
    "Deploy daemons. A deploy daemon (DaemonConfig) is an ExApps orchestration daemon." : "Demony wdrożeniowe. Demon wdrożeniowy (DaemonConfig) to demon orkiestracji ExApps.",
    "Default deploy daemon is not accessible. Please check its configuration" : "Domyślny demon wdrożeniowy jest niedostępny. Sprawdź jego konfigurację.",
    "ExApp init timeout (minutes)" : "Limit czasu inicjalizacji ExApp (w minutach)",
    "ExApp initialization process timeout after which AppAPI will mark it as failed" : "Upłynął limit czasu procesu inicjalizacji ExApp, po którym AppAPI oznaczy go jako zakończony niepowodzeniem",
    "ExApp init timeout" : "Limit czasu inicjalizacji ExApp",
    "ExApp container restart policy" : "Polityka ponownego uruchamiania kontenera ExApp",
    "Choose the container restart policy, e.g. 'always' to ensure ExApps will be running after a daemon server reboot" : "Wybierz politykę restartu kontenera, np. „always”, aby zapewnić działanie ExApps po ponownym uruchomieniu serwera demona.",
    "This settings changes are effective only for newly created containers" : "Zmiany tych ustawień obowiązują tylko dla nowo tworzonych kontenerów.",
    "Deploy daemon deletion confirmation" : "Potwierdzenie usunięcia demona wdrożeniowego",
    "Are you sure you want delete the \"{name}\" deploy daemon?" : "Czy na pewno chcesz usunąć demona wdrożeniowego \"{name}\"?",
    "Remove all ExApps installed on this daemon" : "Usuń wszystkie ExApps zainstalowane na tym demonie",
    "Cancel" : "Anuluj",
    "Delete" : "Usuń",
    "A \"manual-install\" deploy daemon cannot be set as default" : "Demon wdrożeniowy \"manual-install\" nie może być ustawiony jako domyślny",
    "Failed to save admin settings. Check the logs" : "Nie udało się zapisać ustawień administratora. Sprawdź logi",
    "Password confirmation failed" : "Potwierdzenie hasła nie powiodło się",
    "Default" : "Domyślny",
    "Set as default" : "Ustaw jako domyślny",
    "Test deploy" : "Testowe wdrożenie",
    "Docker registries" : "Rejestry Dockera",
    "Edit" : "Edycja",
    "Daemon connection successful" : "Połączenie z demonem powiodło się",
    "Failed to connect to the daemon. Check the logs" : "Nie udało się połączyć z demonem. Sprawdź logi",
    "Failed to check connection to the daemon. Check the logs" : "Nie udało się sprawdzić połączenia z demonem. Sprawdź logi",
    "Unlimited" : "Bez limitu",
    "{size} GiB" : "{size} GiB",
    "{size} MiB" : "{size} MiB",
    "_{n} CPU_::_{n} CPUs_" : ["{n} CPU","{n} CPUs","{n} CPUs","{n} CPUs"],
    "Deploy daemon configuration" : "Konfiguracja demona wdrożeniowego",
    "Deploy daemon configuration details" : "Szczegóły konfiguracji demona wdrożeniowego",
    "Deploy daemon" : "Demon wdrożeniowy",
    "Default daemon. ExApps will be installed on it" : "Demon domyślny. ExAppy będą na nim instalowane",
    "The \"Manual install\" daemon is usually used for development. It cannot be set as the default daemon." : "Demon \"Manual install\" jest zwykle używany do celów deweloperskich. Nie może być ustawiony jako domyślny demon.",
    "ExApps installed" : "ExAppy zainstalowane",
    "Name" : "Nazwa",
    "Protocol" : "Protokół",
    "Host" : "Host",
    "ExApp direct communication (FRP disabled)" : "Bezpośrednia komunikacja ExApp (FRP wyłączona)",
    "Deploy options" : "Opcje wdrażania",
    "Docker network" : "Sieć Dockera",
    "Nextcloud URL" : "Adres URL Nextcloud",
    "HaProxy password" : "Hasło HaProxy",
    "GPU support" : "Wsparcie GPU",
    "Computation device" : "Urządzenie obliczeniowe",
    "Memory limit" : "Limit pamięci",
    "CPU limit" : "Limit CPU ",
    "Additional options" : "Dodatkowe opcje",
    "Check connection" : "Sprawdź połączenie",
    "Registered Deploy daemons list" : "Lista zarejestrowanych demonów wdrożeniowych",
    "No Deploy daemons are registered" : "Nie zarejestrowano żadnych demonów wdrożeniowych",
    "Register a custom one or configure one from the available templates" : "Zarejestruj własny lub skonfiguruj jeden z dostępnych szablonów",
    "Register daemon" : "Zarejestruj demona",
    "Register ExApp in Nextcloud" : "Zarejestruj ExApp w Nextcloud",
    "Check if the ExApp is registered in Nextcloud before deployment" : "Sprawdź, czy ExApp jest zarejestrowany w Nextcloud przed wdrożeniem",
    "Image pull" : "Pobieranie obrazu",
    "Check if the image is successfully pulled" : "Sprawdź, czy obraz został pomyślnie pobrany",
    "Container started" : "Kontener uruchomiony",
    "Check if the image successfully pulled and container is created and started" : "Sprawdź, czy obraz został pomyślnie pobrany oraz czy kontener został utworzony i uruchomiony",
    "Heartbeat" : "Sygnał kontrolny (Heartbeat)",
    "Check for the heartbeat is finished and healthy" : "Sprawdź, czy sygnał kontrolny został zakończony i jest prawidłowy",
    "Init step" : "Krok inicjalizacji",
    "Wait for initialization step to finish" : "Czekaj na zakończenie kroku inicjalizacji",
    "Enabled" : "Włączone",
    "Check if ExApp successfully handled the enabled event and registered all stuff properly" : "Sprawdź, czy ExApp pomyślnie obsłużył zdarzenie „enabled” i poprawnie zarejestrował wszystkie elementy",
    "Only if ExApp container is preset" : "Tylko jeśli kontener ExApp jest wstępnie ustawiony",
    "Deploy test passed successfully!" : "Test wdrożenia zakończony pomyślnie!",
    "Deploy test failed at step \"{step}\"" : "Test wdrożenia nie powiódł się na kroku \"{step}\"",
    "AppAPI will try to install small skeleton ExApp to check that the daemon is configured correctly and the deployment steps are successful." : "AppAPI spróbuje zainstalować małą przykładową ExApp, aby sprawdzić, czy demon jest poprawnie skonfigurowany i czy kroki wdrożenia zakończyły się powodzeniem.",
    "The following deploy test checks must succeed:" : "Następujące kontrole testu wdrożenia muszą zakończyć się sukcesem:",
    "More information" : "Więcej informacji",
    "Download ExApp logs" : "Pobierz logi ExApp",
    "Remove the test ExApp" : "Usuń testową ExApp",
    "Start the deploy test" : "Rozpocznij test wdrożenia",
    "Stop the deploy test" : "Zatrzymaj test wdrożenia",
    "The test ExApp is unregistered and its container is removed on \"Stop the deploy test\"" : "Testowa ExApp zostanie wyrejestrowana, a jej kontener usunięty po wybraniu \"Zatrzymaj test wdrożenia\"",
    "Please enter a registry domain" : "Proszę wprowadzić domenę rejestru",
    "\"From\" cannot be \"local\"" : "\"From\" nie może mieć wartości \"local\"",
    "This registry mapping already exists" : "To mapowanie rejestru już istnieje",
    "\"From\" and \"To\" cannot be the same" : "\"From\" i \"To\" nie mogą być takie same",
    "Docker registry mapping added" : "Mapowanie rejestru Dockera zostało dodane",
    "Error adding Docker registry mapping" : "Błąd podczas dodawania mapowania rejestru Dockera",
    "Docker registry mapping removed" : "Mapowanie rejestru Dockera zostało usunięte",
    "Error removing Docker registry mapping" : "Błąd podczas usuwania mapowania rejestru Dockera",
    "Override Docker registries" : "Nadpisz rejestry Dockera",
    "Configure Docker registry override mappings for the selected daemon." : "Skonfiguruj nadpisania mapowań rejestru Docker dla wybranego demona.",
    "The matching source registry in ExApp info.xml will be overwritten during deployment (image pull step)." : "Odpowiadający rejestr źródłowy w pliku ExApp info.xml zostanie nadpisany podczas wdrożenia (etap pobierania obrazu).",
    "This is useful if you want to use a custom Docker registry, for example, to use a private Docker registry, or to use a different Docker registry for testing." : "To jest przydatne, jeśli chcesz użyć własnego rejestru Dockera, np. prywatnego rejestru Dockera lub innego rejestru Dockera do testów.",
    "Image pull will be skipped" : "Pobieranie obrazu zostanie pominięte",
    "Remove" : "Usuń",
    "No custom Docker registries are registered" : "Nie zarejestrowano żadnych niestandardowych rejestrów Docker",
    "Add registry override mapping" : "Dodaj mapowanie nadpisania rejestru",
    "From" : "Od",
    "registry URL (e.g. ghcr.io)" : "Adres URL rejestru (np. ghcr.io)",
    "To" : "Do",
    "registry URL (e.g. docker.io)" : "Adres URL rejestru (np. docker.io)",
    "Add" : "Dodaj",
    "Hostname used by Nextcloud to access the ExApps" : "Nazwa hosta używana przez Nextcloud do uzyskiwania dostępu do ExApps",
    "The hostname (and port) at which the {name} is available. This does not need to be a public host, just a host accessible by the Nextcloud server, e.g. {host}." : "Nazwa hosta (i port), pod którym {name} jest dostępny. Nie musi to być host publiczny, wystarczy host dostępny dla serwera Nextcloud, np. {host}.",
    "The hostname (and port) or path at which the {name} is available. This does not need to be a public host, just a host accessible by the Nextcloud server. It can also be the path to the Docker socket. (e.g. nextcloud-appapi-dsp:2375, /var/run/docker.sock)" : "Nazwa hosta (i port) lub ścieżka, pod którą {name} jest dostępny. Nie musi to być host publiczny, wystarczy host dostępny dla serwera Nextcloud. Może to być także ścieżka do gniazda Docker (np. nextcloud-appapi-dsp:2375, /var/run/docker.sock)",
    "A daemon with this name already exists" : "Demon o tej nazwie już istnieje",
    "The secret key for the HaRP container communication (HP_SHARED_KEY)." : "Klucz tajny do komunikacji kontenerów HaRP (HP_SHARED_KEY).",
    "AppAPI Docker Socket Proxy authentication password" : "Hasło uwierzytelniające AppAPI Docker Socket Proxy",
    "Changes are only effective for newly installed ExApps. For existing ExApps, the Docker containers should be recreated to apply the new settings values." : "Zmiany obowiązują tylko dla nowo zainstalowanych ExApps. W przypadku istniejących ExApps kontenery Docker powinny zostać odtworzone, aby zastosować nowe wartości ustawień.",
    "The Docker network that the deployed ExApps will use." : "Sieć Docker, z której będą korzystać wdrożone ExApps.",
    "The URL should start with http:// or https://" : "Adres URL powinien zaczynać się od http:// lub https://",
    "For a HTTPS daemon, the Nextcloud URL should be HTTPS" : "Dla demona HTTPS adres URL Nextcloud powinien używać HTTPS",
    "All available GPU devices on the daemon host need to be enabled in ExApp containers by Docker." : "Wszystkie dostępne urządzenia GPU na hoście demona muszą być włączone w kontenerach ExApp przez Docker.",
    "DaemonConfig successfully registered" : "DaemonConfig został pomyślnie zarejestrowany",
    "Failed to register DaemonConfig. Check the logs" : "Nie udało się zarejestrować DaemonConfig. Sprawdź logi",
    "DaemonConfig successfully updated" : "DaemonConfig został pomyślnie zaktualizowany",
    "Failed to update DaemonConfig. Check the logs" : "Nie udało się zaktualizować DaemonConfig. Sprawdź logi",
    "Failed to connect to Daemon. Check the logs" : "Nie udało się połączyć z demonem. Sprawdź logi",
    "Failed to check connection to Daemon. Check the logs" : "Nie udało się sprawdzić połączenia z demonem. Sprawdź logi",
    "Edit the deploy daemon" : "Edytuj demona wdrożeniowego",
    "Register a new deploy daemon" : "Zarejestruj nowego demona wdrożeniowego",
    "Daemon configuration template" : "Szablon konfiguracji Daemon",
    "Select a daemon configuration template" : "Wybierz szablon konfiguracji demona",
    "Daemon registration form" : "Formularz rejestracji Daemon",
    "Unique deploy daemon name" : "Unikalna nazwa demona wdrożeniowego",
    "Unique deploy Daemon name" : "Unikalna nazwa Demona wdrożeniowego",
    "Display name" : "Wyświetlana nazwa",
    "Deployment method" : "Metoda wdrażania",
    "Select the daemon deploy method" : "Wybierz metodę wdrożenia demona",
    "HaRP host" : "Host HaRP",
    "Daemon host" : "Host Daemon",
    "HaRP shared key" : "Klucz współdzielony HaRP",
    "The password must be at least 12 characters long" : "Hasło musi mieć co najmniej 12 znaków",
    "Set this daemon as the default one" : "Ustaw tego demona jako domyślnego",
    "Set as the default daemon" : "Ustaw jako domyślnego demona",
    "Enable HTTPS" : "Włącz HTTPS",
    "Show deploy options" : "Pokaż opcje wdrożenia",
    "Hide deploy options" : "Ukryj opcje wdrożenia",
    "Enable HaRP" : "Włącz HaRP",
    "FRP server address" : "Adres serwera FRP",
    "The address (host:port) of the FRP server that should be reachable by the ExApp in the network defined in the 'Docker network' section." : "Adres (host:port) serwera FRP, który powinien być osiągalny dla ExApp w sieci zdefiniowanej w sekcji „Sieć Docker”.",
    "Docker socket proxy port" : "Port proxy gniazda Dockera",
    "The port in HaRP which the Docker socket proxy connects to. This should be exposed but for the in-built one, it is not required to be exposed or changed." : "Port w HaRP, do którego łączy się proxy gniazda Docker. Powinien być wystawiony, ale w przypadku wbudowanego nie jest wymagane jego wystawianie ani zmiana.",
    "Disable FRP" : "Wyłącz FRP",
    "FRP is always disabled for the All-in-One setup." : "FRP jest zawsze wyłączone w konfiguracji All-in-One.",
    "Flag for advanced setups only. Disables the FRP tunnel between ExApps and HaRP." : "Flaga tylko dla zaawansowanych konfiguracji. Wyłącza tunel FRP między ExApps a HaRP.",
    "Docker network for ex-app deployment must be defined" : "Sieć Dockera dla wdrożenia ex-app musi być zdefiniowana",
    "Compute device" : "Urządzenie obliczeniowe",
    "Memory limit (in MiB)" : "Limit pamięci (w MB)",
    "Must be a positive integer" : "Musi być liczbą całkowitą dodatnią",
    "Maximum amount of memory that the ExApp container can use in mebibytes" : "Maksymalna ilość pamięci, jaką kontener ExApp może używać (w mebibajtach).",
    "CPU limit as decimal value" : "Limit CPU jako wartość dziesiętna",
    "Must be a positive number" : "Musi być liczbą dodatnią",
    "Maximum number of CPU cores that the ExApp container can use (e.g. 0.5 for half a core, 2 for two cores)" : "Maksymalna liczba rdzeni CPU, których może używać kontener ExApp (np. 0,5 dla połowy rdzenia, 2 dla dwóch rdzeni).",
    "Add additional option" : "Dodaj dodatkową opcję",
    "Option key (unique)" : "Klucz opcji (unikalny)",
    "Option key (unique, e.g. my_key)" : "Klucz opcji (unikalny, np. my_key)",
    "Option key is required" : "Wymagany jest klucz opcji",
    "Option value" : "Wartość opcji",
    "Option value is required" : "Wymagana jest wartość opcji",
    "Confirm" : "Potwierdź",
    "Save" : "Zapisz",
    "Register" : "Zarejestruj się",
    "External Apps" : "Aplikacje zewnętrzne",
    "### Boost your Nextcloud with AppAPI and its specially designed applications.\n\n\nThe AppAPI is a project within the Nextcloud ecosystem designed to streamline and enhance the process of\napplication development, deployment, and management.\n\nIt introduces a new methodology that allows developers to create\napplications using a variety of programming languages, not limited to PHP, which was traditionally used in Nextcloud development.\n\n### Bundled App\n\n**Starting with Nextcloud 30.0.1, this application is included in the default Nextcloud package.**\n\n### Support\n\nWe appreciate any support for this project:\n\n- ⭐ Star our work on GitHub\n- ❗ Create an Issue or feature request\n- 💁 Resolve an Issue and create a Pull Request\n- 🧑‍💻 Develop your own application using AppAPI\n\nWe are genuinely excited about the future of the AppAPI project and its potential to transform\nthe way applications are developed and experienced within Nextcloud.\n\nAs we embark on this journey, we warmly invite you - developers, thinkers, creators, and visionaries -\nto join us in shaping a more versatile, stable, and secure app landscape.\n\n*Your insights, suggestions, and contributions are invaluable to us.*" : "### Wzmocnij swojego Nextclouda dzięki AppAPI i jego specjalnie zaprojektowanym aplikacjom. \n\n\nProjekt AppAPI w ekosystemie Nextcloud został zaprojektowany, aby usprawnić i ulepszyć proces \ntworzenia, wdrażania i zarządzania aplikacjami. \n\nWprowadza nową metodologię, która pozwala deweloperom tworzyć aplikacje w różnych językach programowania, nie tylko w PHP, które tradycyjnie było używane w Nextcloudzie.\n\n### Dołączona aplikacja\n\n**Począwszy od Nextcloud 30.0.1, aplikacja ta jest zawarta w domyślnym pakiecie Nextclouda.**\n\n### Wsparcie\n\nDoceniamy każde wsparcie dla tego projektu:\n- ⭐ Oznacz nasze repozytorium na GitHubie \n- ❗Zgłoś problem lub propozycję funkcji \n- 💁 Rozwiąż problem i utwórz Pull Request \n- 🧑‍💻 Rozwijaj własną aplikację używając AppAPI.\n\nJesteśmy naprawdę podekscytowani przyszłością projektu AppAPI i jego potencjałem do przekształcenia sposobu, w jaki aplikacje są tworzone i używane w Nextcloudzie. \n\nZapraszamy serdecznie do udziału – deweloperów, myślicieli, twórców i wizjonerów – aby pomóc w kształtowaniu bardziej wszechstronnego, stabilnego i bezpiecznego środowiska aplikacji. \n\n*Twoje pomysły, sugestie i wkład są dla nas bezcenne.*",
    "The AppAPI Project is an exciting initiative that aims to revolutionize the way applications are developed for Nextcloud." : "Projekt AppAPI to ekscytująca inicjatywa, której celem jest zrewolucjonizowanie sposobu tworzenia aplikacji dla Nextcloud.",
    "Deploy Daemons" : "Demony wdrożeniowe",
    "Deploy Daemon (DaemonConfig) is an ExApps orchestration daemon." : "Demon wdrożeniowy (DaemonConfig) to demon orkiestracji ExApps.",
    "Deploy Daemons. Deploy Daemon (DaemonConfig) is an ExApps orchestration daemon." : "Demony wdrożeniowe. Demon wdrożeniowy (DaemonConfig) to demon orkiestracji ExApps.",
    "Default Deploy Daemon is not accessible. Please verify its configuration" : "Domyślny demon wdrożeniowy jest niedostępny. Sprawdź jego konfigurację.",
    "Specify container restart policy, e.g. 'always' to ensure ExApp running after daemon server reboot" : "Określ politykę ponownego uruchamiania kontenera, np. „always”, aby zapewnić działanie ExApp po restarcie serwera demona",
    "This settings changes are reflected only for newly created containers" : "Zmiany tych ustawień zostaną odzwierciedlone tylko w przypadku nowo utworzonych kontenerów",
    "{license}-licensed" : "na licencji {license}",
    "Update to {version}" : "Zaktualizuj do {version}",
    "Delete data on remove" : "Usuń dane przy usuwaniu",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Ta aplikacja nie ma przypisanej minimalnej wersji Nextcloud. W przyszłości będzie to błąd.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Ta aplikacja nie ma przypisanej maksymalnej wersji Nextcloud. W przyszłości będzie to błąd.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Ta aplikacja nie może być zainstalowana, ponieważ nie są spełnione następujące zależności:",
    "View in store" : "Zobacz w sklepie",
    "Visit website" : "Odwiedź stronę",
    "Report a bug" : "Zgłoś błąd",
    "User documentation" : "Dokumentacja użytkownika",
    "Admin documentation" : "Dokumentacja administratora",
    "Developer documentation" : "Dokumentacja dewelopera",
    "This app is not registered in AppStore. No extra information available. Only enable/disable and remove actions are allowed." : "Ta aplikacja nie jest zarejestrowana w AppStore. Brak dodatkowych informacji. Dozwolone są tylko akcje włączania/wyłączania i usuwania.",
    "This app is supported via your current Nextcloud subscription." : "Ta aplikacja jest obsługiwana za pośrednictwem bieżącej subskrypcji Nextcloud.",
    "Supported" : "Wspierany",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Polecane aplikacje są tworzone przez społeczność. Oferują główną funkcjonalność i są gotowe do użycia w produkcji.",
    "Featured" : "Polecane",
    "Update to {update}" : "Zaktualizuj do {update}",
    "All ExApps are up-to-date." : "Wszystkie ExApps są aktualne.",
    "Default Deploy daemon is not accessible" : "Domyślny demon wdrażania jest niedostępny",
    "Icon" : "Ikona",
    "Version" : "Wersja",
    "Daemon" : "Demon",
    "Level" : "Poziom",
    "Actions" : "Akcje",
    "Results from other categories" : "Wyniki z innych kategorii",
    "No apps found" : "Nie znaleziono aplikacji",
    "_%n ExApp has an update available_::_%n apps have an update available_" : ["%n ExApp ma dostępne aktualizacje","%n aplikacje mają dostępne aktualizacje","%n aplikacji ma dostępne aktualizacje","%n aplikacji ma dostępne aktualizacje"],
    "_Update_::_Update all_" : ["Zaktualizuj","Zaktualizuj","Zaktualizuj","Zaktualizuj wszystko"],
    "Deploy Daemon" : "Uruchom demona",
    "Type" : "Rodzaj",
    "Display Name" : "Wyświetlana nazwa",
    "GPUs support" : "Obsługa procesorów graficznych",
    "Are you sure you want delete Deploy Daemon" : "Czy na pewno chcesz usunąć demona wdrożeniowego",
    "All ExApps on this daemon will be removed" : "Wszystkie ExAppy na tym demonie zostaną usunięte",
    "All ExApps installed on this daemon will be removed" : "Wszystkie ExAppy zainstalowane na tym demonie zostaną usunięte",
    "\"manual-install\" Deploy Daemon cannot be set as default" : "Demon wdrożeniowy „manual-install” nie może być ustawiony jako domyślny",
    "Failed to save admin options. Check the logs" : "Nie udało się zapisać opcji administratora. Sprawdź dzienniki",
    "Deploy daemon config details" : "Szczegóły konfiguracji demona wdrożeniowego",
    "Manual install daemon usually used for development. It cannot be set as default daemon." : "Ręczny demon instalacyjny zwykle używany do rozwoju. Nie może być ustawiony jako domyślny demon.",
    "Deploy config" : "Konfiguracja wdrożenia",
    "Verify connection" : "Sprawdź połączenie",
    "No Deploy daemons configured" : "Brak skonfigurowanych demonów wdrożeniowych",
    "Register a custom one or setup from available templates" : "Zarejestruj własnego lub skonfiguruj z dostępnych szablonów",
    "Register Daemon" : "Zarejestruj demona",
    "AppAPI will try to install small skeleton ExApp to verify Daemon configured correctly and deployment steps are passing." : "AppAPI spróbuje zainstalować mały szkielet ExApp, aby sprawdzić, czy demon jest poprawnie skonfigurowany i czy etapy wdrażania zostały wykonane.",
    "The following Deploy test checks must be passed to succeed:" : "Następujące testy wdrożenia muszą zostać zaliczone, aby zakończyć sukcesem:",
    "More info" : "Więcej informacji",
    "Remove test ExApp" : "Usuń testowy ExApp",
    "Start Deploy test" : "Rozpocznij test wdrożenia",
    "Stop Deploy test" : "Zatrzymaj test wdrożenia",
    "ExApp is unregistered and container is removed on \"Stop deploy test\"" : "ExApp zostaje wyrejestrowany, a kontener usunięty przy „Zatrzymaj test wdrożenia”",
    "Hostname to access ExApps" : "Nazwa hosta umożliwiająca dostęp do ExApps",
    "Hostname or path to access Docker daemon (e.g. nextcloud-appapi-dsp:2375, /var/run/docker.sock)" : "Nazwa hosta lub ścieżka dostępu do demona Docker (np. nextcloud-appapi-dsp:2375, /var/run/docker.sock)",
    "Daemon with this name already exists" : "Demon o tej nazwie już istnieje",
    "Password must be at least 12 characters long" : "Hasło musi mieć co najmniej 12 znaków",
    "With https enabled network is set to host" : "Przy włączonym https sieć jest ustawiona na host",
    "Changes would be applied only for newly installed ExApps. For existing ExApps, Docker containers should be recreated." : "Zmiany zostaną zastosowane tylko do nowo zainstalowanych ExApp. Dla istniejących ExApps kontenery Dockera powinny zostać odtworzone.",
    "URL should start with http:// or https://" : "Adres URL powinien zaczynać się od http:// lub https://",
    "For HTTPS daemon, Nextcloud URL should be HTTPS" : "Dla demona HTTPS adres URL Nextcloud powinien być HTTPS",
    "All available GPU devices on daemon host will be requested to be enabled in ExApp containers by Docker." : "Wszystkie dostępne urządzenia GPU na hoście demona zostaną poproszone o włączenie w kontenerach ExApp przez Dockera.",
    "Edit Deploy Daemon" : "Edytuj Deploy Daemon",
    "Register Deploy Daemon" : "Zarejestruj Deploy Daemon",
    "Select daemon configuration template" : "Wybierz szablon konfiguracji Daemon",
    "Unique Deploy Daemon Name" : "Unikalna nazwa Deploy Daemon",
    "Select daemon deploy method" : "Wybierz metodę wdrażania demona",
    "Set daemon as default" : "Ustaw demona jako domyślnego",
    "Set as default daemon" : "Ustaw jako domyślnego demona",
    "Enable https" : "Włącz https",
    "Show deploy config" : "Pokaż konfigurację wdrożenia",
    "Hide deploy config" : "Ukryj konfigurację wdrożenia",
    "Network" : "Sieć",
    "Docker network name" : "Nazwa sieci Dockera",
    "Additional option" : "Opcja dodatkowa",
    "by {author}\n{license}" : "wykonane przez {author}\n{license}",
    "Your apps" : "Twoje aplikacje",
    "Documentation" : "Dokumentacja",
    "Details" : "Szczegóły",
    "Changelog" : "Dziennik zmian",
    "Active apps" : "Aktywne aplikacje",
    "Disabled apps" : "Wyłączone aplikacje",
    "Updates" : "Aktualizacje",
    "Featured apps" : "Polecane aplikacje",
    "Supported apps" : "Obsługiwane aplikacje",
    "manual-install apps cannot be updated" : "aplikacji instalowanych ręcznie nie można aktualizować",
    "{progress}% Deploying" : "{progress}% Wdrażanie",
    "{progress}% Initializing" : "{progress}% Inicjalizacja",
    "Healthchecking" : "Sprawdzanie stanu zdrowia",
    "Deploy and Enable" : "Wdróż i włącz",
    "Enable" : "Włącz",
    "Disable" : "Wyłącz",
    "Allow untested app" : "Zezwalaj na nietestowane aplikacje",
    "Default Deploy daemon is not accessible. Please verify configuration" : "Domyślny demon wdrażania nie jest dostępny. Proszę sprawdzić konfigurację",
    "The app will be downloaded from the App Store and deployed on default Deploy Daemon" : "Aplikacja zostanie pobrana ze Sklepu Aplikacji i wdrożona na domyślnym Demonie Wdrażania",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Ta aplikacja jest niezgodna z wersją Nextcloud. Przy dalszej kontynuacji, możesz pozwolić na zainstalowanie tej aplikacji. Pamiętaj, że aplikacja może nie działać zgodnie z oczekiwaniami.",
    "Your ExApps" : "Twoje ExApps",
    "An error occurred during the request. Unable to proceed." : "Wystąpił błąd podczas żądania. Nie można kontynuować.",
    "The app has been enabled but needs to be updated." : "Aplikacja została włączona, ale wymaga aktualizacji.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Błąd: Ta aplikacja nie zostanie włączona ze względu na możliwość niestabilnej pracy serwera",
    "### Boost your Nextcloud with AppAPI and its specially designed applications.\n\n\nThe AppAPI is a project within the Nextcloud ecosystem designed to streamline and enhance the process of\napplication development, deployment, and management.\n\nIt introduces a new methodology that allows developers to create\napplications using a variety of programming languages, not limited to PHP, which was traditionally used in Nextcloud development.\n\n\n### List of applications that require AppAPI:\n\n- [talk_bot_ai_example](https://github.com/cloud-py-api/talk_bot_ai_example)\n- [upscaler_example](https://github.com/cloud-py-api/upscaler_example)\n- [image_to_text_example](https://github.com/cloud-py-api/file_to_text_example)\n- [ai_image_generator_bot](https://github.com/cloud-py-api/ai_image_generator_bot)\n- [SummarAI](https://github.com/nextcloud/sumupbot)\n\n_If you wish to develop an application, we will gladly help and assist you._\n\n### Support\n\nWe appreciate any support for this project:\n\n- ⭐ Star our work on GitHub\n- ❗ Create an Issue or feature request\n- 💁 Resolve an Issue and create a Pull Request\n- 🧑‍💻 Develop your own application using AppAPI\n\nWe are genuinely excited about the future of the AppAPI project and its potential to transform\nthe way applications are developed and experienced within Nextcloud.\n\nAs we embark on this journey, we warmly invite you - developers, thinkers, creators, and visionaries -\nto join us in shaping a more versatile, stable, and secure app landscape.\n\n*Your insights, suggestions, and contributions are invaluable to us.*" : "### Wzmocnij swojego Nextclouda dzięki AppAPI i jego specjalnie zaprojektowanym aplikacjom. \n\n\nProjekt AppAPI w ekosystemie Nextcloud został zaprojektowany, aby usprawnić i ulepszyć proces \ntworzenia, wdrażania i zarządzania aplikacjami. \n\nWprowadza nową metodologię, która pozwala deweloperom tworzyć aplikacje w różnych językach programowania, nie tylko w PHP, które tradycyjnie było używane w Nextcloudzie.\n\n\n## Lista aplikacji wymagających AppAPI: \n- [talk_bot_ai_example](https://github.com/cloud-py-api/talk_bot_ai_example)\n- [upscaler_example](https://github.com/cloud-py-api/upscaler_example)\n- [image_to_text_example](https://github.com/cloud-py-api/file_to_text_example)\n- [ai_image_generator_bot](https://github.com/cloud-py-api/ai_image_generator_bot)\n- [SummarAI](https://github.com/nextcloud/sumupbot)\n\nJeśli chcesz stworzyć aplikację, chętnie Ci pomożemy i wesprzemy.\n\n### Wsparcie\n\nDoceniamy każde wsparcie dla tego projektu \n– ⭐ Oznacz nasze repozytorium na GitHubie \n– ❗Zgłoś problem lub propozycję funkcji \n– 🧑‍💻 Rozwiąż problem i utwórz Pull Request \n– 📦 Rozwijaj własną aplikację używając AppAPI.\n\nJesteśmy naprawdę podekscytowani przyszłością projektu AppAPI i jego potencjałem do przekształcenia sposobu, w jaki aplikacje są tworzone i używane w Nextcloudzie. \n\nZapraszamy serdecznie do udziału – deweloperów, pomysłodawców, twórców i wizjonerów – aby pomóc w kształtowaniu bardziej wszechstronnego, stabilnego i bezpiecznego środowiska aplikacji. \n\n*Twoje pomysły, sugestie i wkład są dla nas bezcenne.*"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
