.photos-location[data-v-872fbb5c]{display:flex;flex-direction:column}.photos-location .folder[data-v-872fbb5c]{margin-bottom:16px}.app-content{display:flex;flex-grow:1;flex-direction:column;align-content:space-between}.app-navigation__photos :deep(.app-navigation-entry-icon.icon-photos){background-size:20px}.app-navigation__footer{padding:calc(var(--default-grid-baseline) * 2)}
