OC.L10N.register(
    "related_resources",
    {
    "Calendar" : "Ημερολόγιο",
    "Calendar \"%s\"" : "Ημερολόγιο «%s»",
    "Deck" : "Deck",
    "Deck board \"%s\"" : "Πίνακας Deck «%s»",
    "Files" : "Αρχεία",
    "File \"%s\"" : "Αρχείο «%s»",
    "Group Folder" : "Φάκελος Ομάδας",
    "Group Folder \"%s\"" : "Φάκελος Ομάδας «%s»",
    "Talk conversation" : "Συνομιλία στο Talk",
    "Conversation with %s" : "Συνομιλία με το/την %s",
    "Talk" : "Talk",
    "Talk conversation \"%s\"" : "Συνομιλία στο Talk «%s»",
    "Related Resources" : "Σχετικοί Πόροι",
    "Displays resources related to current item in right panel" : "Εμφανίζει πόρους σχετικούς με το τρέχον στοιχείο στο δεξί πάνελ",
    "Displays resources related to current item in right panel." : "Εμφανίζει πόρους σχετικούς με το τρέχον στοιχείο στο δεξί πάνελ."
},
"nplurals=2; plural=(n != 1);");
