<?php
// This file is auto-generated. Do not edit!
return array('digits-ordinal'=>array('-x'=>array('rule'=>'−→→'),'integer'=>array(array('rule'=>'=#,##0=.'))),'spellout-numbering-year'=>array('-x'=>array('rule'=>'−→→'),'x.x'=>array('rule'=>'=0.0='),'integer'=>array(array('rule'=>'=0='))),'spellout-numbering'=>array('-x'=>array('rule'=>'−→→'),'integer'=>array(array('rule'=>'=#,##0.#='))),'spellout-cardinal'=>array('-x'=>array('rule'=>'−→→'),'integer'=>array(array('rule'=>'=#,##0.#='))),'spellout-ordinal'=>array('-x'=>array('rule'=>'−→→'),'integer'=>array(array('rule'=>'=#,##0.#=.'))));
