OC.L10N.register(
    "profile",
    {
    "View profile" : "Veire perfil",
    "Profile picker" : "Selector de perfil",
    "Profile" : "Perfil",
    "Searching …" : "Recèrca…",
    "Not found" : "Non trobat",
    "Search for a user profile" : "Cercar un perfil utilizaire",
    "Search for a user profile. Start typing" : "Cercar un perfil utilizaire. Començatz de picar",
    "Insert selected user profile link" : "Inserir lo ligam del perfil utilizaire seleccionat",
    "Insert" : "Inserir",
    "Profile not found" : "Perfil pas trobat",
    "Back to %s" : "Tornar a %s",
    "Edit Profile" : "Modificar perfil",
    "The profile does not exist." : "Lo perfil existís pas."
},
"nplurals=2; plural=(n > 1);");
