/*!
 * SPDX-FileCopyrightText: 2019 Nextcloud GmbH and Nextcloud contributors
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */.icon-room{background-image:var(--icon-talk-dark)}.icon-circle{background-image:var(--icon-circles-dark)}.icon-guests{background-image:var(--icon-user-dark)}/*# sourceMappingURL=icons.css.map */
