OC.L10N.register(
    "files_downloadlimit",
    {
    "Files download limit" : "Límite de descarga de ficheiros",
    "File link share download limit" : "Límite de descarga para ficheiros con ligazóns para compartir",
    "This app allows limiting the number of downloads for external link shares." : "Esta aplicación permite limitar o número de descargas de ligazóns externas para compartir",
    "The minimum limit is 1" : "O límite mínimo é 1",
    "Failed to set download limit" : "Produciuse un fallo ao definir o límite de descarga",
    "Failed to remove download limit" : "Produciuse un fallo ao retirar o límite de descarga",
    "Limit downloads" : "Limitar as descargas",
    "Set download limit" : "Definir o límite de descarga",
    "Setting a new limit will reset the download count" : "Definir un novo límite restabelecerá o reconto de descargas",
    "_1 remaining download allowed_::_{count} remaining downloads allowed_" : ["1 descarga restante permitida","{count} descargas restantes permitidas"],
    "Download limit" : "Límite de descarga",
    "Configure the default download limit for external shares." : "Configurar o límite de descarga predeterminado para comparticións externas.",
    "Default download limit for external shares" : "Límite de descarga predeterminado para comparticións externas",
    "Set default download limit" : "Definir o límite de descarga predeterminado",
    "You have reached the maximum amount of downloads allowed" : "Acadou a cantidade máxima de descargas permitidas",
    "This share has a limited number of downloads. Are you sure you want to trigger a new download?" : "Esta compartición ten un número limitado de descargas. Está seguro de que quere activar unha nova descarga?",
    "Failed to set default download limit" : "Produciuse un fallo ao definir o límite de descarga predeterminado",
    "Failed to remove default download limit" : "Produciuse un fallo ao retirar o límite de descarga predeterminado"
},
"nplurals=2; plural=(n != 1);");
