OC.L10N.register(
    "app_api",
    {
    "Daemon config not found" : "Usanidi wa Daemon haujapatikana",
    "Error starting install of ExApp" : "Hitilafu katika kuanzisha usakinishaji wa ExApp",
    "ExApp failed to register, check the NC logs" : "ExApp imeshindwa kusajili, angalia kumbukumbu za NC",
    "ExApp not found, failed to get status" : "ExApp haikupatikana, imeshindwa kupata hali",
    "Error adding Docker registry" : "Hitilafu katika kuongeza Usajili wa Docker",
    "Error removing Docker registry" : "Hitilafu katika kuondoa Usajili wa Docker",
    "This app is not installed from the AppStore. No extra information available. Only enable/disable and remove actions are allowed." : "Programu hii haijasakinishwa kutoka kwa AppStore. Hakuna maelezo ya ziada yanayopatikana. Wezesha/lemaza na uondoe vitendo pekee ndivyo vinavyoruhusiwa.",
    "Could not perform installation of ExApp" : "Haikuweza kusakinisha ExApp",
    "Failed to enable ExApp" : "Imeshindwa kuwezesha ExApp",
    "Failed to disable ExApp" : "Imeshindwa kuzima ExApp",
    "Could not update ExApp" : "Haikuweza kusasisha ExApp",
    "Error starting update of ExApp" : "Hitilafu imetokea wakati wa kuanzisha sasisho la ExApp",
    "Could not perform update of ExApp" : "Haikuweza kusasisha ExApp",
    "ExApp not found, failed to get logs" : "ExApp haikupatikana, imeshindwa kupata kumbukumbu",
    "Failed to get container logs. Note: Downloading Docker container works only for containers with the json-file or journald logging driver. Error: %s" : "Imeshindwa kupata kumbukumbu za kontena. Kumbuka: Kupakua kontena ya Docker hufanya kazi tu kwa kontena zilizo na faili ya json au kiendesha magogo cha kumbukumbu. Hitilafu: %s",
    "ExApp not found, failed to get deploy options" : "ExApp haijapatikana, imeshindwa kupata chaguo za kusambaza",
    "AppAPI authentication failed" : "Uthibitishaji wa AppAPI umeshindwa",
    "AppAPI ExApp notifier" : "Arifa ya AppAPI ExApp",
    "AppAPI" : "AppAPI",
    "AI Integration Team" : "Timu ya Ujumuishaji ya AI",
    "ExApps Settings" : "Mipangilio ya ExApps",
    "AppAPI deploy daemon" : "Tumia daemon ya AppAPI ",
    "AppAPI default deploy daemon is not set. Please register a default deploy daemon in the settings to install External Apps (Ex-Apps)." : "Daemon chaguo-msingi ya AppAPI haijawekwa. Tafadhali sajili daemoni chaguo-msingi ya kutumia katika mipangilio ili kusakinisha Programu za Nje (Programu za Zamani).",
    "AppAPI default deploy daemon \"%s\" is not accessible. Please check the daemon configuration." : "Daemon chaguo-msingi ya programu ya kusambaza \"%s\" haipatikani. Tafadhali angalia usanidi wa daemoni.",
    "The AppAPI default deploy daemon is not using HaRP. Please consider switching to HaRP for better performance." : "Daemon chaguo-msingi ya AppAPI haitumii HaRP. Tafadhali zingatia kuhamia HaRP kwa utendakazi bora.",
    "AppAPI HaRP version check" : "Angalia toleo la AppAPI HaRP",
    "Could not retrieve HaRP version from daemon \"%s\"" : " Haikuweza kupata toleo la HaRP kutoka kwa daemon \"%s\"",
    "HaRP version for daemon \"%s\" is \"%s\", which is too old. The minimum required version is \"%s\". Please update the daemon to the latest version." : "Toleo la HaRP la daemon \"%s\" ni \"%s\", ambalo ni nzee sana. Toleo la chini linalohitajika ni \"%s\". Tafadhali sasisha daemon hadi toleo jipya zaidi.",
    "Failed to check HaRP version for daemon \"%s\": %s" : "Imeshindwa kuangalia toleo la HaRP kwa daemon \"%s\": %s",
    "Nextcloud AppAPI" : "AppAPI ya Nextcloud ",
    "### What is AppAPI?\n\nAppAPI is the Nextcloud component that enables **External Apps (ExApps)**.\nExApps are apps whose backend runs **outside** the Nextcloud PHP process (usually as a Docker container), while still integrating with your Nextcloud users, permissions and web UI.\n\n### Do I need it?\n\nNo. If you do not plan to install External Apps, you can disable AppAPI.\n\nIf AppAPI is enabled without a configured Deploy Daemon, Nextcloud will show the info message:\n\n> \"AppAPI default deploy daemon is not set …\"\n\nThat warning means: \"External Apps are not configured yet\".\n\nYou can either disable AppAPI, or configure a Deploy Daemon (see below).\n\n### How do External Apps get deployed?\n\nA **Deploy Daemon** is the service Nextcloud talks to in order to install, start, stop and reach ExApps.\n\nTwo options are available:\n\n- **HaRP** (recommended for Nextcloud 32+) — a high-performance reverse proxy with FRP tunneling\n- **Docker Socket Proxy** (legacy) — scheduled for removal in Nextcloud 35\n\nSee the [admin documentation](https://docs.nextcloud.com/server/latest/admin_manual/exapps_management/DeployConfigurations.html) for setup instructions." : "### AppAPI ni nini?\n\nAppAPI ni kijenzi cha Nextcloud kinachowasha **Programu za Nje (ExApps)**.\nExApps ni programu ambazo mazingira yake ya nyuma huendesha **nje** mchakato wa Nextcloud PHP (kawaida kama chombo cha Docker), huku zikiendelea kuunganishwa na watumiaji wako wa Nextcloud, ruhusa na UI ya wavuti.\n\n### Je, ninaihitaji?\n\nHapana. Ikiwa huna mpango wa kusakinisha Programu za Nje, unaweza kuzima AppAPI.\n\nIkiwa AppAPI imewashwa bila Deploy Daemon iliyosanidiwa, Nextcloud itaonyesha ujumbe wa maelezo:\n\n> \"Daemon chaguomsingi ya kusambaza ya AppAPI haijawekwa ...\"\n\nOnyo hilo linamaanisha: \"Programu za Nje bado hazijasanidiwa\".\n\nUnaweza kuzima AppAPI, au kusanidi Deploy Daemon (tazama hapa chini).\n\n### Programu za Nje hutumwa vipi?\n\n**Tumia Daemon** ni huduma Nextcloud inazungumza nayo ili kusakinisha, kuanzisha, kusimamisha na kufikia ExApps.\n\nChaguzi mbili zinapatikana:\n\n- **HaRP** (imependekezwa kwa Nextcloud 32+) - seva mbadala ya utendakazi wa hali ya juu iliyo na tunnel ya FRP\n- **Proksi ya Soketi ya Docker** (urithi) - imeratibiwa kuondolewa katika Nextcloud 35\n\nTazama [hati za msimamizi](https://docs.nextcloud.com/server/latest/admin_manual/exapps_management/DeployConfigurations.html) kwa maagizo ya usanidi.",
    "External Apps management" : "Usimamizi wa Programu za Nje",
    "Admin options saved" : "Chaguo za msimamizi zimehifadhiwa",
    "Failed to save admin options" : "Imeshindwa kuhifadhi chaguo za msimamizi",
    "The AppAPI Project is an exciting initiative that aims to revolutionize the way applications are developed for Nextcloud through the use of docker containers. Allowing for greater programming language choice and allowing computationally expensive tasks to be offloaded to a different server." : "Mradi wa AppAPI ni mpango wa kufurahisha ambao unalenga kubadilisha jinsi programu zinavyotengenezwa kwa Nextcloud kupitia utumiaji wa kontena za docker. Kuruhusu chaguo kubwa zaidi la lugha ya upangaji na kuruhusu majukumu ya gharama ya hesabu kupakiwa kwa seva tofauti.",
    "Deploy daemons" : "Sambaza damoni",
    "A deploy daemon (DaemonConfig) is an ExApps orchestration daemon." : "Deploy daemon (DaemonConfig) ni daemoni ya orchestration ya ExApps.",
    "Deploy daemons. A deploy daemon (DaemonConfig) is an ExApps orchestration daemon." : "Sambaza damoni. Deploy daemon (DaemonConfig) ni daemoni ya orchestration ya ExApps.",
    "Default deploy daemon is not accessible. Please check its configuration" : "Daemon chaguo-msingi haipatikani. Tafadhali angalia usanidi wake",
    "ExApp init timeout (minutes)" : "Muda wa kuanzisha ExApp (dakika)",
    "ExApp initialization process timeout after which AppAPI will mark it as failed" : "Muda wa mchakato wa uanzishaji wa ExApp umekwisha ambapo AppAPI itatia alama kuwa imeshindwa",
    "ExApp init timeout" : "Muda wa ExApp umekwisha",
    "ExApp container restart policy" : "Sera ya kuanzisha upya kontena la ExApp",
    "Choose the container restart policy, e.g. 'always' to ensure ExApps will be running after a daemon server reboot" : "Chagua sera ya kuanzisha upya kontena, k.m. 'daima' ili kuhakikisha ExApps itakuwa inaendeshwa baada ya kuwasha tena seva ya daemoni",
    "This settings changes are effective only for newly created containers" : "Mabadiliko haya ya mipangilio yanafaa tu kwa vyombo vipya vilivyoundwa",
    "Deploy daemon deletion confirmation" : "Deploy daemon deletion confirmation",
    "Are you sure you want delete the \"{name}\" deploy daemon?" : "Je, una uhakika unataka kufuta daemoni ya kutumia \"{name}\"?",
    "Remove all ExApps installed on this daemon" : "Ondoa ExApps zote zilizosakinishwa kwenye daemoni hii",
    "Cancel" : "Ghairi",
    "Delete" : "Futa",
    "A \"manual-install\" deploy daemon cannot be set as default" : "Daemon ya \"kusakinisha kwa mikono\" haiwezi kuwekwa kama chaguo-msingi",
    "Failed to save admin settings. Check the logs" : "Imeshindwa kuhifadhi mipangilio ya msimamizi. Angalia kumbukumbu",
    "Password confirmation failed" : "Uthibitishaji wa nenosiri umeshindikana",
    "Default" : "Chaguo msingi",
    "Set as default" : "Weka kama chaguomsingi",
    "Test deploy" : "Usambazaji wa majaribio",
    "Docker registries" : "Usajili wa Docker",
    "Edit" : "Hariri",
    "Daemon connection successful" : "Muunganisho wa Daemon umefaulu",
    "Failed to connect to the daemon. Check the logs" : "Imeshindwa kuunganisha kwenye daemon. Angalia kumbukumbu",
    "Failed to check connection to the daemon. Check the logs" : "Imeshindwa kuangalia muunganisho kwenye daemon. Angalia kumbukumbu",
    "Unlimited" : "Isiyo na kikomo",
    "{size} GiB" : "{size} GiB",
    "{size} MiB" : "{size} MiB",
    "_{n} CPU_::_{n} CPUs_" : ["{n} CPU","{n} CPUs"],
    "Deploy daemon configuration" : "Tumia usanidi wa daemoni",
    "Deploy daemon configuration details" : "Tumia maelezo ya usanidi wa daemoni",
    "Deploy daemon" : "Weka daemon",
    "Default daemon. ExApps will be installed on it" : "Daemon chaguo-msingi. ExApps itasakinishwa juu yake",
    "The \"Manual install\" daemon is usually used for development. It cannot be set as the default daemon." : "Daemon ya \"Usakinishaji wa Mwongozo\" kawaida hutumiwa kwa usanidi. Haiwezi kuwekwa kama daemoni chaguo-msingi.",
    "ExApps installed" : "ExApps imesakinishwa",
    "Name" : "Jina",
    "Protocol" : "Itifaki",
    "Host" : "Mwenyeji",
    "ExApp direct communication (FRP disabled)" : "Mawasiliano ya moja kwa moja ya ExApp (FRP imezimwa)",
    "Deploy options" : "Weka chaguzi",
    "Docker network" : "Mtandao wa Docker ",
    "Nextcloud URL" : "URL ya Nextcloud ",
    "HaProxy password" : "Nenosiri la HaProxy",
    "GPU support" : "Usaidizi wa GPU ",
    "Computation device" : "Kifaa cha kuhesabu",
    "Memory limit" : "Kikomo cha kumbukumbu",
    "CPU limit" : "Kikomo cha CPU",
    "Additional options" : "Chaguzi za ziada",
    "Check connection" : "Angalia muunganisho",
    "Registered Deploy daemons list" : "Orodha ya miunganisho iliyosajiliwa ya Deploy",
    "No Deploy daemons are registered" : "Hakuna damoni za kutumia zilizosajiliwa",
    "Register a custom one or configure one from the available templates" : "Sajili maalum au usanidi kutoka kwa violezo vinavyopatikana",
    "Register daemon" : "Sajili daemon",
    "Register ExApp in Nextcloud" : "Sajili ExApp katika Nextcloud",
    "Check if the ExApp is registered in Nextcloud before deployment" : "Angalia ikiwa ExApp imesajiliwa katika Nextcloud kabla ya kupelekwa",
    "Image pull" : "Kuvuta picha",
    "Check if the image is successfully pulled" : "Angalia ikiwa picha imevutwa kwa ufanisi",
    "Container started" : "Chombo kimeanza",
    "Check if the image successfully pulled and container is created and started" : "Angalia ikiwa picha imevutwa kwa ufanisi na kontena imeundwa na kuanza",
    "Heartbeat" : "Mapigo ya moyo",
    "Check for the heartbeat is finished and healthy" : "Angalia mapigo ya moyo yamekamilika na yenye afya",
    "Init step" : "Hatua ya awali",
    "Wait for initialization step to finish" : "Subiri hadi hatua ya uanzishaji imalizike",
    "Enabled" : "Washwa",
    "Check if ExApp successfully handled the enabled event and registered all stuff properly" : "Angalia ikiwa ExApp ilifanikiwa kushughulikia tukio lililowezeshwa na kusajili vitu vyote vizuri",
    "Only if ExApp container is preset" : "Ikiwa tu chombo cha ExApp kimewekwa mapema",
    "Deploy test passed successfully!" : "Jaribio la kutuma limefaulu!",
    "Deploy test failed at step \"{step}\"" : "Jaribio la kusambaza limeshindwa kwa hatua \"{step}\"",
    "AppAPI will try to install small skeleton ExApp to check that the daemon is configured correctly and the deployment steps are successful." : "AppAPI itajaribu kusakinisha kiunzi kidogo cha ExApp ili kuangalia kama daemoni imesanidiwa ipasavyo na hatua za kupeleka zimefaulu.",
    "The following deploy test checks must succeed:" : "Ukaguzi ufuatao wa kupeleka lazima ufaulu:",
    "More information" : "Taarifa zaidi",
    "Download ExApp logs" : "Pakua kumbukumbu za ExApp",
    "Remove the test ExApp" : "Ondoa jaribio la ExApp",
    "Start the deploy test" : "Anza jaribio la kusambaza",
    "Stop the deploy test" : "Acha jaribio la kusambaza",
    "The test ExApp is unregistered and its container is removed on \"Stop the deploy test\"" : "ExApp ya majaribio haijasajiliwa na kontena lake huondolewa kwenye \"Sitisha jaribio la kusambaza\"",
    "Please enter a registry domain" : "Tafadhali ingiza kikoa cha usajili",
    "\"From\" cannot be \"local\"" : "\"Kutoka\" haiwezi kuwa \"ndani\"",
    "This registry mapping already exists" : "Upangaji huu wa usajili tayari upo",
    "\"From\" and \"To\" cannot be the same" : "\"Kutoka\" na \"Kwa\" haziwezi kuwa sawa",
    "Docker registry mapping added" : "Uwekaji ramani wa usajili wa Docker umeongezwa",
    "Error adding Docker registry mapping" : "Hitilafu katika kuongeza ramani ya usajili wa Docker",
    "Docker registry mapping removed" : "Ramani ya Usajili wa Docker imeondolewa",
    "Error removing Docker registry mapping" : "Hitilafu katika kuondoa ramani ya usajili wa Docker",
    "Override Docker registries" : "Badilisha rejista za Docker",
    "Configure Docker registry override mappings for the selected daemon." : "Sanidi Usajili wa Docker kubatilisha upangaji wa daemon iliyochaguliwa.",
    "The matching source registry in ExApp info.xml will be overwritten during deployment (image pull step)." : "Sajili ya chanzo inayolingana katika maelezo ya ExApp.xml itafutwa wakati wa kupeleka (hatua ya kuvuta picha).",
    "This is useful if you want to use a custom Docker registry, for example, to use a private Docker registry, or to use a different Docker registry for testing." : "Hii ni muhimu ikiwa unataka kutumia sajili maalum ya Docker, kwa mfano, kutumia sajili ya kibinafsi ya Docker, au kutumia sajili tofauti ya Docker kwa majaribio.",
    "Image pull will be skipped" : "Uvutaji wa picha utarukwa",
    "Remove" : "Ondoa",
    "No custom Docker registries are registered" : "Hakuna sajili maalum za Docker zilizosajiliwa",
    "Add registry override mapping" : "Ongeza ramani ya ubatilishaji wa usajili",
    "From" : "Tangu/ kutoka",
    "registry URL (e.g. ghcr.io)" : "URL ya usajili (e.g. ghcr.io)",
    "To" : "Mpaka/ hadi",
    "registry URL (e.g. docker.io)" : "URL ya usajili (e.g. docker.io)",
    "Add" : "Ongeza",
    "Hostname used by Nextcloud to access the ExApps" : "Jina la mwenyeji linalotumiwa na Nextcloud kufikia ExApps",
    "The hostname (and port) at which the {name} is available. This does not need to be a public host, just a host accessible by the Nextcloud server, e.g. {host}." : "The hostname (and port) at which the {name} is available. This does not need to be a public host, just a host accessible by the Nextcloud server, e.g. {host}.",
    "The hostname (and port) or path at which the {name} is available. This does not need to be a public host, just a host accessible by the Nextcloud server. It can also be the path to the Docker socket. (e.g. nextcloud-appapi-dsp:2375, /var/run/docker.sock)" : "Jina la mpangishaji (na lango) au njia ambayo {name} inapatikana. Hii haihitaji kuwa mwenyeji wa umma, mwenyeji tu anayeweza kufikiwa na seva ya Nextcloud. Inaweza pia kuwa njia ya tundu la Docker. (k.m. nextcloud-appapi-dsp:2375, /var/run/docker.sock)",
    "A daemon with this name already exists" : "Daemon yenye jina hili tayari ipo",
    "The secret key for the HaRP container communication (HP_SHARED_KEY)." : "Ufunguo wa siri wa mawasiliano ya chombo cha HaRP (HP_SHARED_KEY).",
    "AppAPI Docker Socket Proxy authentication password" : "Nenosiri la uthibitishaji la Soketi ya Wakala wa AppAPI Docker",
    "Changes are only effective for newly installed ExApps. For existing ExApps, the Docker containers should be recreated to apply the new settings values." : "Mabadiliko yanafaa kwa ExApps mpya zilizosakinishwa pekee. Kwa ExApps zilizopo, vyombo vya Docker vinapaswa kuundwa upya ili kutumia maadili mapya ya mipangilio.",
    "The Docker network that the deployed ExApps will use." : "Mtandao wa Docker ambao ExApps iliyotumwa itatumia.",
    "The URL should start with http:// or https://" : "URL inapaswa kuanza na http:// au https://",
    "For a HTTPS daemon, the Nextcloud URL should be HTTPS" : "Kwa daemoni ya HTTPS, URL ya Nextcloud inapaswa kuwa HTTPS",
    "All available GPU devices on the daemon host need to be enabled in ExApp containers by Docker." : "Vifaa vyote vinavyopatikana vya GPU kwenye seva pangishi ya daemon vinahitaji kuwashwa katika vyombo vya ExApp na Docker.",
    "DaemonConfig successfully registered" : "DaemonConfig imesajiliwa",
    "Failed to register DaemonConfig. Check the logs" : "Imeshindwa kusajili DaemonConfig. Angalia kumbukumbu",
    "DaemonConfig successfully updated" : "DaemonConfig imesasishwa",
    "Failed to update DaemonConfig. Check the logs" : "Imeshindwa kusasisha DaemonConfig. Angalia kumbukumbu",
    "Failed to connect to Daemon. Check the logs" : "Imeshindwa kuunganisha kwa Daemon. Angalia kumbukumbu",
    "Failed to check connection to Daemon. Check the logs" : "Imeshindwa kuangalia muunganisho kwenye Daemon. Angalia kumbukumbu",
    "Edit the deploy daemon" : "Hariri daemon ya kusambaza",
    "Register a new deploy daemon" : "Register a new deploy daemon",
    "Daemon configuration template" : "Kiolezo cha usanidi wa Daemon",
    "Select a daemon configuration template" : "Chagua kiolezo cha usanidi wa daemoni",
    "Daemon registration form" : "Fomu ya usajili ya Daemon",
    "Unique deploy daemon name" : "Jina la kipekee la kutumia daemon",
    "Unique deploy Daemon name" : "Jina la kipekee la kutumia daemon",
    "Display name" : "Jina la kuonyesha",
    "Deployment method" : "Mbinu ya kupeleka",
    "Select the daemon deploy method" : "Chagua mbinu ya kutumia daemoni",
    "HaRP host" : "mwenyeji wa HaRP",
    "Daemon host" : "mwenyeji ni Daemon",
    "HaRP shared key" : "Ufunguo wa pamoja wa HaRP",
    "The password must be at least 12 characters long" : "Nenosiri lazima liwe na urefu wa angalau vibambo 12",
    "Set this daemon as the default one" : "Weka daemon hii kama chaguo-msingi",
    "Set as the default daemon" : "Weka kama daemoni chaguo-msingi",
    "Enable HTTPS" : "Washa HTTPS",
    "Show deploy options" : "Onyesha chaguo za kutumia",
    "Hide deploy options" : "Ficha chaguzi za kusambaza",
    "Enable HaRP" : "Washa HaRP",
    "FRP server address" : "Anwani ya seva ya FRP",
    "The address (host:port) of the FRP server that should be reachable by the ExApp in the network defined in the 'Docker network' section." : "Anwani (mwenyeji: ingilio) ya seva ya FRP ambayo inapaswa kufikiwa na ExApp katika mtandao iliyofafanuliwa katika sehemu ya 'Docker network'.",
    "Docker socket proxy port" : "Mlango wa wakala wa tundu la Docker",
    "The port in HaRP which the Docker socket proxy connects to. This should be exposed but for the in-built one, it is not required to be exposed or changed." : "Lango katika HaRP ambayo proksi ya soketi ya Docker inaunganishwa nayo. Hii inapaswa kufichuliwa lakini kwa iliyojengwa ndani, haihitajiki kufichuliwa au kubadilishwa.",
    "Disable FRP" : "Zima FRP",
    "FRP is always disabled for the All-in-One setup." : "FRP imezimwa kila wakati kwa usanidi wa All-in-One.",
    "Flag for advanced setups only. Disables the FRP tunnel between ExApps and HaRP." : "Ripoti kwa usanidi wa hali ya juu pekee. Huzima njia ya FRP kati ya ExApps na HaRP.",
    "Docker network for ex-app deployment must be defined" : "Mtandao wa Docker kwa utumaji wa programu ya zamani lazima ufafanuliwe",
    "Compute device" : "Kuhesabu kifaa",
    "Memory limit (in MiB)" : "Kikomo cha kumbukumbu (katika MiB)",
    "Must be a positive integer" : "Lazima iwe nambari chanya",
    "Maximum amount of memory that the ExApp container can use in mebibytes" : "Kiwango cha juu cha kumbukumbu ambacho chombo cha ExApp kinaweza kutumia katika mebibytes",
    "CPU limit as decimal value" : "Kikomo cha CPU kama thamani ya desimali",
    "Must be a positive number" : "Lazima iwe nambari chanya",
    "Maximum number of CPU cores that the ExApp container can use (e.g. 0.5 for half a core, 2 for two cores)" : "Idadi ya juu zaidi ya cores za CPU ambazo chombo cha ExApp kinaweza kutumia (k.m. 0.5 kwa nusu ya msingi, 2 kwa core mbili)",
    "Add additional option" : "Ongeza chaguo la ziada",
    "Option key (unique)" : "Ufunguo mbadala (unique)",
    "Option key (unique, e.g. my_key)" : "Ufunguo mbadala (unique, e.g. my_key)",
    "Option key is required" : "Ufunguo mbadala unahitajika",
    "Option value" : "Thamani ya chaguo",
    "Option value is required" : "Thamani ya chaguo inahitajika",
    "Confirm" : "Thibitisha",
    "Save" : "Hifadhi",
    "Register" : "Sajiri",
    "External Apps" : "Programu za Nje",
    "### Boost your Nextcloud with AppAPI and its specially designed applications.\n\n\nThe AppAPI is a project within the Nextcloud ecosystem designed to streamline and enhance the process of\napplication development, deployment, and management.\n\nIt introduces a new methodology that allows developers to create\napplications using a variety of programming languages, not limited to PHP, which was traditionally used in Nextcloud development.\n\n### Bundled App\n\n**Starting with Nextcloud 30.0.1, this application is included in the default Nextcloud package.**\n\n### Support\n\nWe appreciate any support for this project:\n\n- ⭐ Star our work on GitHub\n- ❗ Create an Issue or feature request\n- 💁 Resolve an Issue and create a Pull Request\n- 🧑‍💻 Develop your own application using AppAPI\n\nWe are genuinely excited about the future of the AppAPI project and its potential to transform\nthe way applications are developed and experienced within Nextcloud.\n\nAs we embark on this journey, we warmly invite you - developers, thinkers, creators, and visionaries -\nto join us in shaping a more versatile, stable, and secure app landscape.\n\n*Your insights, suggestions, and contributions are invaluable to us.*" : "### Boresha Nextcloud yako ukitumia AppAPI na programu zake zilizoundwa mahususi.\n\n\nAppAPI ni mradi ndani ya mfumo ikolojia wa Nextcloud ulioundwa ili kuhuisha na kuboresha mchakato wa\nmaendeleo ya maombi, upelekaji na usimamizi.\n\nInatanguliza mbinu mpya ambayo inaruhusu wasanidi kuunda\nprogramu kwa kutumia lugha mbalimbali za programu, sio tu kwa PHP, ambayo ilitumiwa jadi katika maendeleo ya Nextcloud.\n\n### Programu Iliyounganishwa\n\n**Kuanzia na Nextcloud 30.0.1, programu tumizi hii imejumuishwa kwenye kifurushi chaguomsingi cha Nextcloud.**\n\n### Msaada\n\nTunashukuru msaada wowote kwa mradi huu:\n\n- ⭐ Weka nyota kazi yetu kwenye GitHub\n- ❗ Unda Tatizo au ombi la kipengele\n- 💁 Suluhisha Tatizo na uunde Ombi la Kuvuta\n- 🧑‍💻 Tengeneza programu yako mwenyewe kwa kutumia AppAPI\n\nTunayo furaha ya kweli kuhusu mustakabali wa mradi wa AppAPI na uwezekano wake wa kubadilisha\njinsi maombi yanavyotengenezwa na uzoefu ndani ya Nextcloud.\n\nTunapoanza safari hii, tunakualika kwa moyo mkunjufu - watengenezaji, wanafikra, watayarishi na wenye maono -\nili ujiunge nasi katika kuunda mlolongo wa programu nyingi zaidi, thabiti na salama.\n\n*Maarifa, mapendekezo na michango yako ni ya thamani sana kwetu.*",
    "The AppAPI Project is an exciting initiative that aims to revolutionize the way applications are developed for Nextcloud." : "Mradi wa AppAPI ni mpango wa kusisimua ambao unalenga kuleta mageuzi katika jinsi programu zinavyoundwa kwa Nextcloud.",
    "Deploy Daemons" : "Tumia Daemons",
    "Deploy Daemon (DaemonConfig) is an ExApps orchestration daemon." : "Tumia Daemon (DaemonConfig) ni daemon ya orchestration ya ExApps.",
    "Deploy Daemons. Deploy Daemon (DaemonConfig) is an ExApps orchestration daemon." : "Tumia Daemons. Tumia Daemon (DaemonConfig) ni daemon ya orchestration ya ExApps.",
    "Default Deploy Daemon is not accessible. Please verify its configuration" : "Daemon ya Kusambaza Chaguomsingi haipatikani. Tafadhali thibitisha usanidi wake",
    "Specify container restart policy, e.g. 'always' to ensure ExApp running after daemon server reboot" : "Bainisha sera ya kuanzisha upya kontena, k.m. 'daima' ili kuhakikisha ExApp inaendesha baada ya kuwasha tena seva ya daemon",
    "This settings changes are reflected only for newly created containers" : "Mabadiliko haya ya mipangilio yanaonyeshwa kwa vyombo vipya pekee",
    "{license}-licensed" : "{license}-iliyopewa leseni",
    "Update to {version}" : "Sasisha kwenda {version}",
    "Delete data on remove" : "Futa data juu ya kuondoa",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Programu hii haina toleo la chini kabisa la Nextcloud lililokabidhiwa. Hili litakuwa kosa katika siku zijazo.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Programu hii haina toleo la juu zaidi la Nextcloud lililokabidhiwa. Hili litakuwa kosa katika siku zijazo.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Programu hii haiwezi kusakinishwa kwa sababu tegemezi zifuatazo hazijatimizwa:",
    "View in store" : "Tazama kwenye stoo",
    "Visit website" : "Tembelea tovuti",
    "Report a bug" : "Ripoti hitilafu",
    "User documentation" : "Nyaraka za mtumiaji",
    "Admin documentation" : "Nyaraka za msimamizi",
    "Developer documentation" : "Nyaraka za msanidi",
    "This app is not registered in AppStore. No extra information available. Only enable/disable and remove actions are allowed." : "Programu hii haijasajiliwa katika AppStore. Hakuna maelezo ya ziada yanayopatikana. Wezesha/lemaza na uondoe vitendo pekee ndivyo vinavyoruhusiwa.",
    "This app is supported via your current Nextcloud subscription." : "Programu hii inaauniwa kupitia usajili wako wa sasa wa Nextcloud.",
    "Supported" : "Imeungwa mkono",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Programu zinazoangaziwa hutengenezwa na ndani ya jumuiya. Wanatoa utendaji wa kati na wako tayari kwa matumizi ya uzalishaji.",
    "Featured" : "Iliyoangaziwa",
    "Update to {update}" : "Sasisha kwenda {update}",
    "All ExApps are up-to-date." : "ExApps zote ni za kisasa.",
    "Default Deploy daemon is not accessible" : "Daemon chaguomsingi ya Kusambaza haipatikani",
    "Icon" : "Aikoni",
    "Version" : "Toleo",
    "Daemon" : "Daemon",
    "Level" : "Kiwango",
    "Actions" : "Utendekaji",
    "Results from other categories" : "Matokeo kutoka kwa kategoria zingine",
    "No apps found" : "Hakuna programu zilizopatikana",
    "_%n ExApp has an update available_::_%n apps have an update available_" : ["%n ExApp has an update available","%n programu zina sasisho linalopatikana "],
    "_Update_::_Update all_" : ["Update","Sasisha zote"],
    "Deploy Daemon" : "Tumia Daemon",
    "Type" : "Aina",
    "Display Name" : "Jina la Kuonyesha",
    "GPUs support" : "Usaidizi wa GPU",
    "Are you sure you want delete Deploy Daemon" : "Je, una uhakika unataka kufuta Deploy Daemon",
    "All ExApps on this daemon will be removed" : "ExApps zote kwenye daemoni hii zitaondolewa",
    "All ExApps installed on this daemon will be removed" : "ExApps zote zilizosakinishwa kwenye daemoni hii zitaondolewa",
    "\"manual-install\" Deploy Daemon cannot be set as default" : "\"sakinisha kwa mikono\" Deploy Daemon haiwezi kuwekwa kama chaguo-msingi",
    "Failed to save admin options. Check the logs" : "Imeshindwa kuhifadhi chaguo za msimamizi. Angalia kumbukumbu",
    "Deploy daemon config details" : "Tumia maelezo ya usanidi wa daemon",
    "Manual install daemon usually used for development. It cannot be set as default daemon." : "Daemon ya usakinishaji kwa mikono kawaida hutumika kwa usanidi. Haiwezi kuwekwa kama daemon chaguo-msingi.",
    "Deploy config" : "Weka usanidi",
    "Verify connection" : "Thibitisha muunganisho",
    "No Deploy daemons configured" : "Hakuna damoni za kutumia zilizosanidiwa",
    "Register a custom one or setup from available templates" : "Sajili moja maalum au usanidi kutoka kwa violezo vinavyopatikana",
    "Register Daemon" : "Sajili Daemon",
    "AppAPI will try to install small skeleton ExApp to verify Daemon configured correctly and deployment steps are passing." : "AppAPI itajaribu kusakinisha kiunzi kidogo cha ExApp ili kuthibitisha Daemon iliyosanidiwa ipasavyo na hatua za kupeleka zinapita.",
    "The following Deploy test checks must be passed to succeed:" : "Ukaguzi ufuatao wa Tumia lazima upitishwe ili kufaulu:",
    "More info" : "Maelezo zaidi",
    "Remove test ExApp" : "Ondoa jaribio la ExApp",
    "Start Deploy test" : "Anza jaribio la Kusambaza",
    "Stop Deploy test" : "Acha Kujaribu Kuweka",
    "ExApp is unregistered and container is removed on \"Stop deploy test\"" : "ExApp haijasajiliwa na kontena linaondolewa kwenye \"Stop deploy test\"",
    "Hostname to access ExApps" : "Jina la mpangishaji ili kufikia ExApps",
    "Hostname or path to access Docker daemon (e.g. nextcloud-appapi-dsp:2375, /var/run/docker.sock)" : "Jina la mpangishaji au njia ya kufikia daemon ya Docker (k.m. nextcloud-appapi-dsp:2375, /var/run/docker.sock)",
    "Daemon with this name already exists" : "Daemon yenye jina hili tayari ipo",
    "Password must be at least 12 characters long" : "Nenosiri lazima liwe na urefu wa angalau vibambo 12",
    "With https enabled network is set to host" : "Kwa kuwasha https, mtandao umewekwa kuwa mwenyeji",
    "Changes would be applied only for newly installed ExApps. For existing ExApps, Docker containers should be recreated." : "Mabadiliko yatatumika kwa ExApps mpya zilizosakinishwa pekee. Kwa ExApps zilizopo, vyombo vya Docker vinapaswa kuundwa upya.",
    "URL should start with http:// or https://" : "URL inapaswa kuanza na http:// au https://",
    "For HTTPS daemon, Nextcloud URL should be HTTPS" : "Kwa daemon ya HTTPS, Nextcloud URL inapaswa kuwa HTTPS",
    "All available GPU devices on daemon host will be requested to be enabled in ExApp containers by Docker." : "Vifaa vyote vinavyopatikana vya GPU kwenye seva pangishi ya daemon vitaombwa kuwashwa katika vyombo vya ExApp na Docker.",
    "Edit Deploy Daemon" : "Hariri utumiaji wa Daemon",
    "Register Deploy Daemon" : "Sajili utumiaji wa Daemon",
    "Select daemon configuration template" : "Chagua kiolezo cha usanidi wa daemoni",
    "Unique Deploy Daemon Name" : "Tumia Jina la Daemon la Kipekee",
    "Select daemon deploy method" : "Chagua mbinu ya kutumia daemoni",
    "Set daemon as default" : "Weka daemon kama chaguo-msingi",
    "Set as default daemon" : "Weka kama daemoni chaguo-msingi",
    "Enable https" : "Wezesha https",
    "Show deploy config" : "Onyesha usanidi wa kupeleka",
    "Hide deploy config" : "Ficha usanidi wa kupeleka",
    "Network" : "Mtandao",
    "Docker network name" : "Jina la mtandao wa Docker",
    "Additional option" : "Chaguo la ziada",
    "by {author}\n{license}" : "na {author}\n{license}",
    "Your apps" : "Programu zako",
    "Documentation" : "Uhifadhi wa nyaraka",
    "Details" : "Maelezo ya kina",
    "Changelog" : "Changelog",
    "Active apps" : "Programu zinazotumika",
    "Disabled apps" : "Programu zilizozimwa",
    "Updates" : "Masasisho",
    "Featured apps" : "Programu zilizoangaziwa",
    "Supported apps" : "Programu zinazotumika",
    "manual-install apps cannot be updated" : "programu za kusakinisha kwa mikono haziwezi kusasishwa",
    "{progress}% Deploying" : "{progress}% Inapeleka",
    "{progress}% Initializing" : "{progress}% inaanzisha",
    "Healthchecking" : "Uangaliaji wa afya",
    "Deploy and Enable" : "Weka na Wezesha",
    "Enable" : "Wezesha",
    "Disable" : "Zima",
    "Allow untested app" : "Ruhusu programu ambayo haijajaribiwa",
    "Default Deploy daemon is not accessible. Please verify configuration" : "Daemon chaguomsingi ya Kusambaza haipatikani. Tafadhali thibitisha usanidi",
    "The app will be downloaded from the App Store and deployed on default Deploy Daemon" : "Programu itapakuliwa kutoka kwa Duka la Programu na kutumwa kwa chaguo-msingi ya Deploy Daemon",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Programu hii haijatiwa alama kuwa inatumika na toleo lako la Nextcloud. Ukiendelea bado utaweza kusakinisha programu. Kumbuka kwamba programu inaweza kufanya kazi kama ilivyotarajiwa.",
    "Your ExApps" : "ExApps yako",
    "An error occurred during the request. Unable to proceed." : "Hitilafu ilitokea wakati wa ombi. Imeshindwa kuendelea.",
    "The app has been enabled but needs to be updated." : "Programu imewashwa lakini inahitaji kusasishwa.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Hitilafu: Programu hii haiwezi kuwashwa kwa sababu inafanya seva kutokuwa thabiti",
    "### Boost your Nextcloud with AppAPI and its specially designed applications.\n\n\nThe AppAPI is a project within the Nextcloud ecosystem designed to streamline and enhance the process of\napplication development, deployment, and management.\n\nIt introduces a new methodology that allows developers to create\napplications using a variety of programming languages, not limited to PHP, which was traditionally used in Nextcloud development.\n\n\n### List of applications that require AppAPI:\n\n- [talk_bot_ai_example](https://github.com/cloud-py-api/talk_bot_ai_example)\n- [upscaler_example](https://github.com/cloud-py-api/upscaler_example)\n- [image_to_text_example](https://github.com/cloud-py-api/file_to_text_example)\n- [ai_image_generator_bot](https://github.com/cloud-py-api/ai_image_generator_bot)\n- [SummarAI](https://github.com/nextcloud/sumupbot)\n\n_If you wish to develop an application, we will gladly help and assist you._\n\n### Support\n\nWe appreciate any support for this project:\n\n- ⭐ Star our work on GitHub\n- ❗ Create an Issue or feature request\n- 💁 Resolve an Issue and create a Pull Request\n- 🧑‍💻 Develop your own application using AppAPI\n\nWe are genuinely excited about the future of the AppAPI project and its potential to transform\nthe way applications are developed and experienced within Nextcloud.\n\nAs we embark on this journey, we warmly invite you - developers, thinkers, creators, and visionaries -\nto join us in shaping a more versatile, stable, and secure app landscape.\n\n*Your insights, suggestions, and contributions are invaluable to us.*" : "### Boresha Nextcloud yako ukitumia AppAPI na programu zake zilizoundwa mahususi.\n\n\nAppAPI ni mradi ndani ya mfumo ikolojia wa Nextcloud ulioundwa ili kuhuisha na kuboresha mchakato wa\nmaendeleo ya maombi, upelekaji na usimamizi.\n\nInatanguliza mbinu mpya ambayo inaruhusu wasanidi kuunda\nprogramu kwa kutumia lugha mbalimbali za programu, sio tu kwa PHP, ambayo ilitumiwa jadi katika maendeleo ya Nextcloud.\n\n\n### Orodha ya programu zinazohitaji AppAPI:\n\n- [talk_bot_ai_example](https://github.com/cloud-py-api/talk_bot_ai_example)\n- [upscaler_example](https://github.com/cloud-py-api/upscaler_example)\n- [image_to_text_example](https://github.com/cloud-py-api/file_to_text_example)\n- [ai_image_generator_bot](https://github.com/cloud-py-api/ai_image_generator_bot)\n- [SummarAI](https://github.com/nextcloud/sumupbot)\n\n_Ikiwa ungependa kuunda programu, tutakusaidia kwa furaha na kukusaidia._\n\n### Msaada\n \nTunashukuru msaada wowote kwa mradi huu:\n\n- ⭐ Weka nyota kazi yetu kwenye GitHub\n- ❗ Unda Tatizo au ombi la kipengele\n- 💁 Suluhisha Tatizo na uunde Ombi la Kuvuta\n- 🧑‍💻 Tengeneza programu yako mwenyewe kwa kutumia AppAPI\n\nTunayo furaha ya kweli kuhusu mustakabali wa mradi wa AppAPI na uwezekano wake wa kubadilisha\njinsi maombi yanavyotengenezwa na uzoefu ndani ya Nextcloud.\n\nTunapoanza safari hii, tunakualika kwa moyo mkunjufu - watengenezaji, wanafikra, watayarishi na wenye maono -\nili ujiunge nasi katika kuunda mlolongo wa programu nyingi zaidi, thabiti na salama.\n\n*Maarifa, mapendekezo na michango yako ni ya thamani sana kwetu.*"
},
"nplurals=2; plural=(n != 1);");
