OC.L10N.register(
    "provisioning_api",
    {
    "Logged in account must be an administrator or have authorization to edit this setting." : "La cuenta qu'anició la sesión ha ser de l'alministración o tener l'autorización pa editar esta opción.",
    "Could not create non-existing user ID" : "Nun se pudo crear la ID d'usuariu inexistente",
    "User already exists" : "L'usuariu yá esiste",
    "Group %1$s does not exist" : "El grupu «%1$s» nun esiste",
    "Insufficient privileges for group %1$s" : "El grupu «%1$s» nun tien los permisos abondos",
    "No group specified (required for sub-admins)" : "Nun s'especificó nengún grupu (ríquese pa los soalministradores)",
    "Sub-admin group does not exist" : "El grupu soalministrador nun esiste",
    "Cannot create sub-admins for admin group" : "Nun se puen crear soalministradores pal grupu d'alministradores",
    "No permissions to promote sub-admins" : "Nun hai nengún permisu p'ascender a soalministradores",
    "Invalid password value" : "El valor de la contraseña ye inválidu",
    "Required email address was not provided" : "Nun se fornió la direición de corréu electrónicu riquida",
    "Invalid email address" : "La direición de corréu electrónicu ye inválida",
    "Invalid language" : "La llingua ye inválida",
    "Invalid quota value: %1$s" : "El valor de la cuota ye inválidu: %1$s",
    "Invalid quota value. %1$s is exceeding the maximum quota" : "El valor de la cuota ye inválidu. %1$s supera la cuota máxima.",
    "Unlimited quota is forbidden on this instance" : "Prohíbese la cuota infinita nesta instancia",
    "Setting the password is not supported by the users backend" : "El backend d'usuarios nun ye compatible cola configuración de la contraseña",
    "Invalid locale" : "La locale ye inválida",
    "Cannot remove yourself from the admin group" : "Nun pues quitate del grupu d'alministradores",
    "Cannot remove yourself from this group as you are a sub-admin" : "Nun pues quitate d'esti grupu darréu que yes un soalministrador",
    "Not viable to remove user from the last group you are sub-admin of" : "Nun ye viable quitar l'usuariu del últimu grupu del que yes soalministrador",
    "User does not exist" : "L'usuariu nun esiste",
    "Group does not exist" : "El grupu nun esiste",
    "User is not a sub-admin of this group" : "L'usuariu nun ye un soalministrador d'esti grupu",
    "Email address not available" : "La direición de corréu electrónicu nun ta disponible",
    "Sending email failed" : "Falló l'unviu del corréu electrónicu",
    "Email confirmation" : "Confirmación del corréu electrónicu",
    "To enable the email address %s please click the button below." : "P'activar la direición de corréu electrónicu «%s», calca nel botón d'abaxo.",
    "Confirm" : "Confirmar",
    "Email was already removed from account and cannot be confirmed anymore." : "Quitóse la direición de corréu electrónicu de la cuenta y yá nun se pue confirmar.",
    "Could not verify mail because the token is expired." : "Nun se pudo verificar la direición de corréu electrónicu porque'l pase caducó.",
    "Could not verify mail because the token is invalid." : "Nun se pudo verificar la direición de corréu electrónicu porque'l pase ye inválidu.",
    "An unexpected error occurred. Please contact your admin." : "Prodúxose un error inesperáu. Ponte en contautu cola alministración.",
    "Email confirmation successful" : "El mensaxe de cofirmación foi correutu",
    "Provisioning API" : "API d'aprovisionamientu",
    "This application enables a set of APIs that external systems can use to manage accounts, groups and apps." : "Esta aplicación activa un conxuntu d'APIs que los sistemes esternos puen usar pa xestionar cuentes grupos y aplicaciones."
},
"nplurals=2; plural=(n != 1);");
