OC.L10N.register(
    "office",
    {
    "Office" : "Σουίτα Γραφείου",
    "Office overview" : "Επισκόπηση σουίτας γραφείου",
    "Office overview app for Nextcloud" : "Εφαρμογή επισκόπησης σουίτας γραφείου για το Nextcloud",
    "Create new" : "Δημιουργία νέου",
    "Scroll left" : "Κύλιση αριστερά",
    "Scroll right" : "Κύλιση δεξιά",
    "Blank" : "Κενό",
    "Search {category}" : "Αναζήτηση {category}",
    "Search" : "Αναζήτηση",
    "Failed to create file" : "Αποτυχία δημιουργίας αρχείου",
    "Failed to load files" : "Αποτυχία φόρτωσης αρχείων",
    "No office suite installed" : "Δεν υπάρχει εγκατεστημένη σουίτα γραφείου",
    "{count} found in {category}" : "Βρέθηκαν {count} στην κατηγορία {category}",
    "Recent {category}" : "Πρόσφατα: {category}",
    "Filter files" : "Φιλτράρισμα αρχείων",
    "All" : "Όλα",
    "Mine" : "Δικά μου",
    "Shared with me" : "Κοινόχρηστα με εμένα",
    "Switch to grid view" : "Εναλλαγή σε προβολή πλέγματος",
    "Switch to list view" : "Εναλλαγή σε προβολή λίστας",
    "No {category} found" : "Δεν βρέθηκε {category}",
    "Switch to \"All\" to see every file you have access to" : "Μεταβείτε στο \"Όλα\" για να δείτε κάθε αρχείο στο οποίο έχετε πρόσβαση",
    "Search all in Files" : "Αναζήτηση όλων στα Αρχεία",
    "Show all in Files" : "Εμφάνιση όλων στα Αρχεία",
    "Create" : "Δημιουργία",
    "Filename" : "Όνομα αρχείου",
    "Documents" : "Έγγραφα",
    "Spreadsheets" : "Υπολογιστικά φύλλα",
    "Presentations" : "Παρουσιάσεις",
    "Diagrams" : "Διαγράμματα",
    "Filename cannot be empty" : "Το όνομα αρχείου δεν μπορεί να είναι κενό",
    "Filename contains invalid characters" : "Το όνομα αρχείου περιέχει μη έγκυρους χαρακτήρες",
    "{count} {category} found" : "Βρέθηκαν {count} {category}"
},
"nplurals=2; plural=(n != 1);");
